
//
// @(#)btyaccpar, based on byacc 1.8 (Berkeley)
// Parser skeleton modified for use in the Firebird project by Nickolay Samofatov
//
#define YYBTYACC 1

#include "firebird.h"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "../dsql/Nodes.h"
#include "../dsql/AggNodes.h"
#include "../dsql/DdlNodes.h"
#include "../dsql/BoolNodes.h"
#include "../dsql/ExprNodes.h"
#include "../dsql/PackageNodes.h"
#include "../dsql/StmtNodes.h"
#include "../dsql/WinNodes.h"
#include "../jrd/RecordSourceNodes.h"
#include "../common/classes/Nullable.h"
#include "gen/parse.h"
#include "../dsql/Parser.h"

#define YYERROR_DETAILED

/*
*	PROGRAM:	Dynamic SQL runtime support
*	MODULE:		parse.y
*	DESCRIPTION:	Dynamic SQL parser
*
* The contents of this file are subject to the Interbase Public
* License Version 1.0 (the "License"); you may not use this file
* except in compliance with the License. You may obtain a copy
* of the License at http://www.Inprise.com/IPL.html
*
* Software distributed under the License is distributed on an
* "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
* or implied. See the License for the specific language governing
* rights and limitations under the License.
*
* The Original Code was created by Inprise Corporation
* and its predecessors. Portions created by Inprise Corporation are
* Copyright (C) Inprise Corporation.
*
* All Rights Reserved.
* Contributor(s): ______________________________________.
*
* 2002-02-24 Sean Leyne - Code Cleanup of old Win 3.1 port (WINDOWS_ONLY)
* 2001.05.20 Neil McCalden: Allow a udf to be used in a 'group by' clause.
* 2001.05.30 Claudio Valderrama: DROP TABLE and DROP VIEW lead now to two
*   different node types so DDL can tell which is which.
* 2001.06.13 Claudio Valderrama: SUBSTRING is being surfaced.
* 2001.06.30 Claudio valderrama: Feed (line,column) for each node. See node.h.
* 2001.07.10 Claudio Valderrama: Better (line,column) report and "--" for comments.
* 2001.07.28 John Bellardo: Changes to support parsing LIMIT and FIRST
* 2001.08.03 John Bellardo: Finalized syntax for LIMIT, change LIMIT to SKIP
* 2001.08.05 Claudio Valderrama: closed Bug #448062 and other spaces that appear
*   in rdb$*_source fields when altering domains plus one unexpected null pointer.
* 2001.08.12 Claudio Valderrama: adjust SUBSTRING's starting pos argument here
*   and not in gen.c; this closes Bug #450301.
* 2001.10.01 Claudio Valderrama: enable explicit GRANT...to ROLE role_name.
* 2001.10.06 Claudio Valderrama: Honor explicit USER keyword in GRANTs and REVOKEs.
* 2002.07.05 Mark O'Donohue: change keyword DEBUG to KW_DEBUG to avoid
*			clashes with normal DEBUG macro.
* 2002.07.30 Arno Brinkman:
* 2002.07.30 	Let IN predicate handle value_expressions
* 2002.07.30 	tokens CASE, NULLIF, COALESCE added
* 2002.07.30 	See block < CASE expression > what is added to value as case_expression
* 2002.07.30 	function is split up into aggregate_function, numeric_value_function, string_value_function, generate_value_function
* 2002.07.30 	new group_by_function and added to grp_column_elem
* 2002.07.30 	cast removed from function and added as cast_specification to value
* 2002.08.04 Claudio Valderrama: allow declaring and defining variables at the same time
* 2002.08.04 Dmitry Yemanov: ALTER VIEW
* 2002.08.06 Arno Brinkman: ordinal added to grp_column_elem for using positions in group by
* 2002.08.07 Dmitry Yemanov: INT64/LARGEINT are replaced with BIGINT and available in dialect 3 only
* 2002.08.31 Dmitry Yemanov: allowed user-defined index names for PK/FK/UK constraints
* 2002.09.01 Dmitry Yemanov: RECREATE VIEW
* 2002.09.28 Dmitry Yemanov: Reworked internal_info stuff, enhanced
*							exception handling in SPs/triggers,
*							implemented ROWS_AFFECTED system variable
* 2002.10.21 Nickolay Samofatov: Added support for explicit pessimistic locks
* 2002.10.29 Nickolay Samofatov: Added support for savepoints
* 2002.12.03 Dmitry Yemanov: Implemented ORDER BY clause in subqueries.
* 2002.12.18 Dmitry Yemanov: Added support for SQL-compliant labels and LEAVE statement
* 2002.12.28 Dmitry Yemanov: Added support for parametrized events.
* 2003.01.14 Dmitry Yemanov: Fixed bug with cursors in triggers.
* 2003.01.15 Dmitry Yemanov: Added support for runtime trigger action checks.
* 2003.02.10 Mike Nordell  : Undefined Microsoft introduced macros to get a clean compile.
* 2003.05.24 Nickolay Samofatov: Make SKIP and FIRST non-reserved keywords
* 2003.06.13 Nickolay Samofatov: Make INSERTING/UPDATING/DELETING non-reserved keywords
* 2003.07.01 Blas Rodriguez Somoza: Change DEBUG and IN to avoid conflicts in win32 build/bison
* 2003.08.11 Arno Brinkman: Changed GROUP BY to support all expressions and added "AS" support
*						   with table alias. Also removed group_by_function and ordinal.
* 2003.08.14 Arno Brinkman: Added support for derived tables.
* 2003.10.05 Dmitry Yemanov: Added support for explicit cursors in PSQL.
* 2004.01.16 Vlad Horsun: added support for default parameters and
*   EXECUTE BLOCK statement
* Adriano dos Santos Fernandes
*/

#include "firebird.h"
#include "dyn_consts.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <stdarg.h>

#include "gen/iberror.h"
#include "../dsql/dsql.h"
#include "../jrd/ibase.h"
#include "../jrd/flags.h"
#include "../jrd/jrd.h"
#include "../jrd/DataTypeUtil.h"
#include "../dsql/errd_proto.h"
#include "../dsql/make_proto.h"
#include "../yvalve/keywords.h"
#include "../yvalve/gds_proto.h"
#include "../jrd/err_proto.h"
#include "../common/intlobj_new.h"
#include "../jrd/Attachment.h"
#include "../common/StatusArg.h"

/* This is needed here to provide backward compatibility when working with SSPI plugin*/
#include "../auth/trusted/AuthSspi.h"

/* since UNIX isn't standard, we have to define*/
/* stuff which is in <limits.h> (which isn't available on all UNIXes...*/

const long SHRT_POS_MAX			= 32767;
const long SHRT_UNSIGNED_MAX	= 65535;
const long SHRT_NEG_MAX			= 32768;
const int POSITIVE	= 0;
const int NEGATIVE	= 1;
const int UNSIGNED	= 2;

/*const int MIN_CACHE_BUFFERS	= 250;*/
/*const int DEF_CACHE_BUFFERS	= 1000;*/

#define YYSTYPE YYSTYPE
#if defined(DEBUG) || defined(DEV_BUILD)
#define YYDEBUG		1
#endif

#define YYREDUCEPOSNFUNC yyReducePosn
#define YYREDUCEPOSNFUNCARG NULL


/* ASF: Inherited attributes (aka rule parameters) are executed even when in trial mode, but action*/
/* rules ({}) are executed only when in full parse mode. NOTRIAL should be used to avoid segfaults*/
/* due to accessing invalid pointers in parameters (not yet returned from action rules).*/
#define NOTRIAL(x) (yytrial ? NULL : (x))


inline unsigned trigger_type_suffix(const unsigned slot1, const unsigned slot2, const unsigned slot3)
{
	return ((slot1 << 1) | (slot2 << 3) | (slot3 << 5));
}


#include "../dsql/chars.h"

using namespace Jrd;
using namespace Firebird;

static int yylhs[] = {                                        -1,
    0,    0,    1,    1,    1,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    3,    3,    3,    3,    3,    3,
    3,    3,    3,    3,    4,    4,    4,    4,  552,  553,
    5,  554,  556,    6,    6,    6,    6,    6,    6,    6,
  557,    6,    6,  558,  559,    6,    7,    7,    7,    7,
    7,    7,    7,    7,    7,    7,    7,    7,    7,  555,
  555,    8,    8,  560,    8,    9,  561,    9,   10,   11,
   12,   12,   12,   12,   12,   13,   13,  562,  562,   14,
   14,   15,   15,   15,   16,   16,   17,   17,   18,   18,
   18,   19,   19,   20,   20,   21,   21,  563,  563,   22,
   22,  564,   23,  565,  566,   24,   24,   24,   24,   24,
   24,   24,  567,   24,   24,  568,   24,   24,   25,   25,
   26,   26,  569,   27,   27,  570,   27,   27,   28,   28,
   28,   28,   28,   28,   29,   29,   29,   30,   30,   31,
   32,   32,   33,   34,   35,   35,  571,  572,  573,   36,
   37,   37,   37,   38,  574,   38,  575,   38,   39,  576,
   39,   40,   41,   41,   41,   41,  577,   42,  578,   42,
   43,   43,   44,   44,   44,   44,   44,   45,   46,   46,
   47,   48,  579,  580,   48,   48,   48,   48,   48,   48,
   48,   48,   48,   48,   48,   48,   48,   48,   48,   48,
   48,  581,   48,  582,   48,   49,   50,   50,   50,   50,
   50,   50,   50,   50,   50,   50,   50,   51,   52,   52,
   52,   52,   52,   52,   52,   52,   52,   52,   52,   53,
   54,   55,   56,   56,   57,   57,   57,  584,  585,   58,
   59,   59,   59,   60,   60,   61,   61,   62,  588,   62,
   63,   63,  590,  591,   64,   65,   65,   66,  592,   66,
   67,   67,  589,  589,   68,   69,   69,  593,   70,   71,
   72,   72,   73,   74,   74,  594,  594,   75,   76,   76,
   77,   78,   78,   79,   79,   80,   81,   81,   81,   82,
  595,  596,  597,  598,   83,   84,   84,   84,   85,   85,
   86,  599,   86,   87,   87,   87,   88,   88,   89,   89,
   90,   90,   91,   91,   92,  600,  601,  602,   93,  586,
  586,   94,   95,   95,   96,  603,   96,   97,   97,   97,
   97,   97,   97,   97,   97,   98,   98,   99,   99,  100,
  100,  100,  100,  604,  605,  101,  102,  102,  103,  606,
  103,  104,  104,  607,  607,  607,  587,  587,  587,  608,
  609,  105,  610,  106,  107,  107,  107,  108,  108,  108,
  611,  109,  612,  109,  613,  110,  110,  614,  615,  111,
  616,  111,  111,  111,  112,  113,  113,  114,  617,  617,
  618,  583,  583,  115,  115,  116,  116,  117,  117,  117,
  117,  118,  118,  118,  118,  118,  118,  119,  619,  119,
  120,  620,  120,  121,  122,  122,  122,  122,  122,  621,
  123,  124,  124,  125,  125,  125,  125,  126,  126,  127,
  127,  127,  127,  127,  128,  129,  130,  130,  130,  130,
  131,  131,  132,  133,  622,  623,  624,  134,  135,  136,
  137,  137,  137,  138,  138,  139,  139,  140,  141,  141,
  142,  143,  144,  144,  144,  145,  145,  146,  147,  625,
  148,  149,  149,  149,  150,  150,  151,  151,  152,  153,
  154,  155,  155,  156,  156,  157,  157,  158,  159,  160,
  160,  161,  161,  162,  162,  163,  163,  163,  163,  164,
  164,  165,  165,  166,  627,  628,  629,  166,  630,  166,
  167,  167,  168,  626,  626,  169,  170,  170,  170,  171,
  171,  172,  173,  173,  173,  174,  174,  175,  175,  176,
  176,  176,  176,  176,  176,  176,  176,  176,  176,  176,
  176,  176,  176,  176,  176,  176,  176,  176,  176,  177,
  177,  178,  178,  178,  178,  178,  179,  180,  180,  180,
  181,  631,  632,  182,  183,  183,  184,  184,  185,  633,
  634,  635,  186,  187,  188,  189,  636,  189,  189,  190,
  190,  191,  192,  192,  193,  194,  194,  637,  195,  195,
  196,  196,  196,  196,  196,  196,  196,  196,  197,  197,
  198,  199,  200,  201,  202,  202,  202,  202,  203,  204,
  204,  205,  205,  206,  207,  207,  208,  208,  209,  210,
  210,  638,  639,  211,  640,  212,  641,  212,  213,  213,
  213,  213,  213,  214,  214,  214,  215,  216,  642,  643,
  217,  217,  218,  218,  218,  218,  218,  218,  219,  219,
  220,  220,  220,  221,  221,  221,  644,  222,  223,  223,
  224,  224,  225,  226,  227,  228,  229,  229,  230,  230,
  230,  230,  230,  230,  231,  232,  232,  232,  233,  233,
  233,  234,  234,  234,  234,  234,  235,  235,  236,  236,
  236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
  236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
  236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
  236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
  236,  236,  236,  237,  237,  238,  238,  238,  238,  238,
  238,  238,  238,  238,  238,  238,  238,  238,  238,  238,
  239,  239,  240,  240,  241,  645,  646,  241,  241,  241,
  241,  241,  647,  241,  241,  241,  241,  241,  241,  241,
  241,  241,  241,  241,  241,  241,  648,  649,  242,  243,
  650,  243,  244,  244,  244,  244,  244,  244,  244,  244,
  244,  245,  651,  245,  246,  246,  246,  246,  246,  246,
  246,  246,  246,  246,  246,  246,  246,  246,  247,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  652,
  652,  249,  249,  250,  250,  250,  251,  251,  252,  253,
  253,  254,  254,  255,  256,  256,  257,  257,  653,  258,
  258,  258,  258,  258,  258,  654,  258,  258,  258,  258,
  259,  259,  260,  260,  260,  261,  261,  262,  263,  263,
  263,  263,  263,  263,  263,  263,  263,  263,  263,  263,
  263,  263,  263,  263,  263,  263,  263,  263,  263,  264,
  264,  264,  265,  265,  266,  266,  267,  267,  268,  268,
  268,  269,  269,  270,  270,  271,  271,  272,  272,  273,
  273,  274,  274,  274,  274,  274,  274,  274,  274,  274,
  274,  655,  655,  656,  657,  275,  275,  275,  275,  276,
  276,  277,  277,  277,  278,  278,  279,  279,  279,  280,
  280,  280,  660,  660,  660,  659,  659,  658,  658,  658,
  281,  281,  282,  282,  282,  661,  661,  283,  283,  283,
  283,  284,  284,  285,  285,  285,  286,  287,  288,  288,
  289,  663,  663,  290,  291,  662,  662,  292,  292,  664,
  664,  665,  666,  293,  294,  294,  295,  295,  296,  667,
  296,  297,  297,  297,  297,  297,  297,  297,  297,  297,
  668,  669,  297,  298,  298,  299,  299,  299,  300,  300,
  300,  301,  301,  301,  302,  302,  302,  303,  303,  304,
  304,  305,  306,  306,  307,  307,  308,  309,  309,  309,
  309,  309,  309,  310,  311,  311,  311,  311,  311,  311,
  311,  311,  311,  311,  311,  311,  311,  312,  313,  313,
  313,  314,  314,  314,  315,  316,  316,  317,  317,  318,
  319,  319,  320,  320,  321,  321,  322,  322,  323,  323,
  323,  324,  324,  325,  326,  327,  328,  328,  328,  329,
  330,  331,  331,  331,  331,  332,  332,  332,  333,  333,
  333,  334,  334,  335,  335,  336,  336,  337,  337,  338,
  338,  672,  672,  339,  340,  340,  341,  341,  342,  342,
  342,  343,  344,  344,  345,  345,  346,  346,  347,  347,
  347,  348,  349,  350,  350,  351,  352,  353,  353,  353,
  353,  354,  354,  355,  355,  356,  357,  357,  357,  357,
  357,  673,  673,  358,  358,  359,  359,  360,  361,  361,
  362,  362,  363,  363,  675,  676,  364,  674,  674,  674,
  674,  674,  674,  365,  365,  366,  366,  367,  367,  368,
  677,  678,  368,  679,  368,  369,  369,  370,  680,  370,
  371,  371,  372,  372,  373,  374,  374,  374,  375,  375,
  376,  376,  377,  377,  378,  378,  681,  681,  379,  379,
  682,  682,  380,  380,  380,  683,  381,  381,  381,  382,
  684,  685,  383,  384,  384,  686,  384,  384,  687,  688,
  385,  689,  690,  386,  387,  387,  387,  387,  691,  388,
  692,  388,  389,  389,  390,  391,  392,  392,  393,  394,
  693,  694,  695,  395,  396,  696,  396,  397,  397,  397,
  398,  398,  399,  400,  400,  401,  402,  402,  403,  403,
  404,  405,  405,  406,  697,  406,  407,  408,  408,  409,
  409,  409,  410,  411,  411,  412,  413,  413,  413,  413,
  413,  413,  413,  414,  414,  414,  414,  414,  414,  414,
  414,  414,  414,  414,  415,  416,  416,  416,  416,  416,
  416,  416,  416,  417,  418,  418,  418,  419,  419,  420,
  420,  421,  421,  422,  422,  423,  423,  423,  424,  424,
  424,  424,  424,  424,  424,  424,  425,  425,  426,  427,
  428,  428,  428,  429,  429,  429,  429,  430,  430,  431,
  698,  699,  700,  432,  702,  433,  703,  434,  704,  435,
  701,  701,  436,  436,  437,  705,  437,  438,  438,  438,
  438,  438,  438,  438,  438,  438,  439,  439,  440,  440,
  441,  441,  706,  707,  708,  442,  709,  710,  443,  711,
  712,  444,  445,  713,  714,  715,  446,  447,  448,  448,
  449,  449,  449,  450,  450,  451,  451,  451,  451,  451,
  452,  452,  453,  453,  454,  454,  455,  455,  456,  456,
  457,  457,  457,  458,  458,  458,  458,  458,  458,  458,
  458,  458,  458,  458,  458,  458,  458,  458,  458,  458,
  458,  458,  458,  458,  458,  458,  458,  458,  458,  458,
  458,  459,  459,  460,  460,  460,  461,  461,  462,  462,
  463,  464,  464,  465,  465,  466,  466,  466,  467,  467,
  467,  467,  468,  468,  468,  468,  468,  469,  469,  470,
  471,  471,  472,  473,  473,  473,  473,  473,  473,  474,
  474,  475,  476,  476,  477,  478,  479,  480,  481,  481,
  482,  483,  483,  483,  484,  484,  484,  485,  485,  485,
  485,  485,  485,  485,  485,  485,  485,  485,  485,  485,
  485,  485,  485,  485,  485,  485,  485,  485,  485,  485,
  485,  485,  485,  485,  485,  485,  486,  486,  486,  486,
  486,  486,  486,  486,  486,  486,  486,  486,  487,  487,
  487,  488,  488,  489,  490,  490,  491,  491,  492,  492,
  493,  494,  494,  494,  495,  496,  496,  497,  498,  498,
  499,  499,  499,  499,  499,  499,  499,  499,  499,  499,
  499,  499,  499,  499,  499,  499,  499,  499,  499,  499,
  499,  499,  499,  499,  499,  499,  499,  499,  499,  499,
  499,  499,  499,  499,  499,  499,  499,  499,  499,  499,
  499,  499,  499,  499,  499,  499,  499,  499,  499,  499,
  499,  500,  500,  500,  500,  500,  500,  500,  500,  501,
  501,  501,  501,  502,  502,  503,  503,  504,  504,  504,
  504,  505,  505,  505,  506,  506,  506,  506,  507,  508,
  508,  509,  509,  509,  509,  509,  510,  510,  716,  717,
  718,  511,  512,  512,  513,  513,  514,  514,  515,  515,
  516,  517,  518,  519,  519,  520,  520,  521,  521,  521,
  521,  521,  521,  521,  521,  521,  521,  671,  671,  670,
  670,  522,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,  544,  545,  546,  547,  548,  549,
  550,  550,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
  551,  551,
};
static int yylen[] = {                                         2,
    1,    2,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    0,    0,
    4,    0,    0,   10,   10,   10,   10,   10,   10,   10,
    0,    8,    8,    0,    0,    7,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    2,    1,    1,    0,
    1,    1,    2,    0,    2,    2,    0,    4,    1,    1,
    1,    1,    1,    2,    2,    2,    2,    0,    1,    2,
    4,    1,    2,    2,    2,    2,    2,    4,    1,    1,
    1,    0,    3,    0,    3,    0,    2,    2,    1,    1,
    2,    0,    4,    0,    0,   10,   10,   10,   10,   10,
   10,   10,    0,    8,    8,    0,    7,    6,    0,    3,
    0,    3,    0,    2,    2,    0,    4,    4,    2,    2,
    2,    2,    2,    2,    1,    2,    2,    2,    4,    1,
    2,    4,    1,    2,    2,    3,    0,    0,    0,   11,
    1,    1,    5,    0,    0,    2,    0,    4,    2,    0,
    4,    2,    0,    2,    2,    1,    0,    2,    0,    4,
    2,    2,    0,    2,    2,    1,    3,    9,    1,    1,
    2,    2,    0,    0,    9,    2,    2,    2,    4,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    3,    0,    3,    0,    4,    2,    2,    2,    2,    4,
    2,    2,    2,    3,    2,    2,    2,    4,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    3,    4,    2,
    2,    2,    0,    1,    1,    1,    4,    0,    0,    8,
    0,    1,    1,    0,    1,    0,    4,    0,    0,    2,
    1,    2,    0,    0,    8,    0,    2,    2,    0,    3,
    1,    1,    0,    1,    2,    0,    1,    2,    4,    3,
    0,    1,    3,    0,    3,    0,    1,    3,    1,    3,
    3,    1,    3,    0,    1,    5,    1,    1,    2,    1,
    0,    0,    0,    0,   10,    0,    2,    5,    0,    2,
    2,    0,    3,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    0,    1,    5,    0,    0,    0,    6,    0,
    1,    1,    0,    2,    2,    0,    3,    3,    2,    2,
    2,    2,    2,    3,    4,    0,    2,    2,    3,    1,
    4,    6,    3,    0,    0,    5,    0,    2,    2,    0,
    3,    3,    4,    0,    1,    2,    0,    1,    1,    0,
    0,    7,    0,    7,    0,    4,    4,    0,    3,    2,
    0,    2,    0,    4,    0,    2,    2,    0,    0,    7,
    0,    7,    3,    2,    6,    0,    3,    4,    1,    1,
    3,    2,    1,    1,    1,    0,    2,    1,    3,    6,
    1,    1,    1,    1,    1,    1,    1,    0,    0,    2,
    2,    0,    3,    3,    1,    1,    5,    2,    3,    0,
    3,    0,    2,    3,    4,    8,    1,    0,    4,    0,
    1,    1,    2,    2,    3,    3,    1,    2,    2,    2,
    1,    1,    4,    3,    0,    0,    0,    6,    1,    1,
    0,    2,    4,    0,    5,    2,    4,    3,    1,    4,
    2,    2,    0,    2,    2,    1,    1,    4,    3,    0,
    8,    0,    2,    1,    5,    3,    0,    2,    1,    1,
    5,    1,    0,    1,    2,    3,    3,    1,    1,    6,
    5,    0,    1,    1,    2,    2,    3,    2,    3,    0,
    1,    1,    2,    4,    0,    0,    0,   11,    0,   13,
    1,    1,    3,    0,    1,    7,    0,    2,    1,    1,
    1,    3,    0,    1,    2,    1,    2,    2,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    2,    1,
    2,    1,    1,    1,    1,    1,    5,    2,    3,    6,
    1,    0,    0,    8,    2,    2,    0,    1,    2,    0,
    0,    0,    7,    3,    5,    1,    0,    7,    7,    2,
    4,    3,    2,    4,    1,    0,    2,    0,    3,    2,
    5,    3,    3,    2,    2,    3,    3,    3,    8,    6,
    3,    0,    3,    2,    1,    1,    3,    3,    7,    0,
    2,    1,    2,    2,    0,    1,    0,    1,    3,    1,
    2,    0,    0,    6,    0,    2,    0,    4,    2,    2,
    2,    2,    1,    1,    1,    1,    2,    2,    0,    0,
    7,    3,    1,    1,    1,    1,    2,    2,    5,    7,
    0,    1,    3,    0,    2,    4,    0,   10,    0,    4,
    2,    4,    4,    5,    1,    1,    0,    3,    7,    6,
    9,    8,    9,    8,    1,    1,    1,    0,    2,    2,
    2,    1,    1,    2,    2,    2,    1,    3,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    3,    2,    2,    2,    3,    3,    2,
    2,    2,    3,    1,    1,    1,    1,    1,    3,    3,
    3,    3,    3,    3,    5,    5,    5,    5,    5,    5,
    0,    2,    2,    1,    2,    0,    0,    5,    2,    2,
    2,    2,    0,    4,    2,    2,    3,    2,    2,    2,
    3,    3,    2,    2,    3,    4,    0,    0,    4,    2,
    0,    3,    2,    3,    2,    2,    2,    3,    3,    2,
    2,    2,    0,    4,    3,    3,    3,    3,    4,    4,
    5,    5,    4,    5,    3,    4,    4,    3,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    2,    1,    1,    0,    1,    1,    2,    2,    3,    0,
    2,    0,    2,    5,    1,    1,    2,    3,    0,    3,
    4,    3,    2,    2,    5,    0,    5,    1,    4,    2,
    0,    2,    7,    6,    4,    2,    0,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    3,    2,    3,    2,
    2,    2,    2,    5,    2,    2,    3,    3,    4,    0,
    2,    2,    1,    1,    1,    3,    1,    1,    3,    6,
    1,    1,    1,    4,    5,    1,    3,    1,    3,    1,
    2,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    0,    0,    6,    4,    6,    5,    0,
    3,    0,    2,    2,    0,    3,    4,    1,    5,    4,
    1,    4,    1,    2,    2,    1,    1,    1,    2,    2,
    2,    2,    0,    3,    5,    1,    1,    2,    3,    1,
    2,    0,    3,    1,    1,    1,    2,    4,    0,    1,
    5,    0,    1,    3,    3,    0,    1,    0,    2,    0,
    1,    0,    0,    5,    3,    3,    0,    2,    2,    0,
    3,    2,    2,    1,    2,    1,    3,    2,    2,    3,
    0,    0,    4,    3,    1,    1,    3,    3,    1,    2,
    3,    0,    1,    2,    0,    1,    1,    1,    1,    1,
    3,    2,    0,    3,    1,    3,    4,    5,    6,    7,
    7,    6,    6,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    2,    1,    1,    1,    1,    2,
    2,    1,    2,    1,    2,    1,    3,    1,    1,    3,
    0,    3,    0,    2,    0,    2,    4,    5,    0,    3,
    2,    1,    3,    6,    1,    1,    1,    4,    4,    1,
    9,    0,    2,    1,    1,    2,    4,    2,    2,    4,
    2,    1,    1,    1,    1,    1,    3,    1,    3,    1,
    3,    0,    1,    2,    1,    3,    1,    1,    1,    1,
    3,    6,    0,    1,    0,    3,    1,    3,    1,    1,
    1,    4,    5,    5,    5,    2,    4,    4,    2,    6,
    4,    0,    3,    1,    3,    1,    0,    1,    2,    2,
    2,    0,    1,    0,    3,    1,    3,    1,    0,    2,
    0,    2,    0,    2,    0,    0,    6,    0,    1,    2,
    1,    1,    1,    1,    3,    2,    1,    1,    2,    1,
    0,    0,    6,    0,    5,    1,    3,    0,    0,    5,
    0,    3,    1,    3,    3,    0,    1,    1,    0,    2,
    1,    1,    2,    4,    0,    1,    1,    1,    0,    3,
    1,    1,    0,    5,    4,    0,    8,    5,    4,    3,
    0,    0,   11,    2,    2,    0,    3,    3,    0,    0,
    5,    0,    0,    6,    4,    6,    2,    4,    0,    8,
    0,   10,    1,    1,    8,    5,    1,    1,    9,    6,
    0,    0,    0,   15,    0,    0,    3,    0,    2,    4,
    1,    3,    4,    1,    3,    3,    1,    1,    0,    1,
    3,    1,    3,    0,    0,    2,    4,    1,    3,    1,
    3,    4,    1,    1,    3,    1,    1,    3,    3,    2,
    3,    3,    4,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    3,    1,    1,    1,    1,    1,
    1,    1,    1,    6,    1,    1,    1,    5,    6,    5,
    6,    1,    3,    3,    4,    1,    1,    2,    3,    5,
    4,    6,    4,    6,    5,    7,    3,    4,    4,    4,
    1,    1,    1,    3,    3,    4,    4,    1,    3,    3,
    0,    0,    0,    6,    0,    7,    0,    6,    0,    7,
    0,    1,    0,    2,    2,    0,    3,    2,    2,    2,
    2,    3,    3,    1,    1,    3,    0,    5,    2,    4,
    3,    2,    0,    0,    0,    5,    0,    0,    5,    0,
    0,    5,    1,    0,    0,    0,    8,    1,    2,    2,
    1,    1,    1,    1,    1,    3,    3,    3,    2,    2,
    0,    2,    3,    2,    1,    1,    1,    1,    1,    3,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    2,    2,    3,    3,    3,    3,
    3,    3,    3,    1,    1,    1,    1,    3,    1,    1,
    1,    1,    1,    1,    2,    2,    0,    3,    0,    3,
    4,    0,    1,    1,    3,    1,    2,    1,    1,    1,
    1,    1,    1,    1,    2,    2,    2,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    2,    1,    1,    2,    1,    1,    1,    1,    1,    2,
    1,    1,    1,    1,    1,    1,    1,    4,    5,    5,
    5,    5,    5,    5,    5,    5,    5,    5,    6,    6,
    4,    4,    4,    4,    6,    6,    6,    6,    6,    6,
    6,    6,    6,    6,    6,    6,    3,    3,    3,    4,
    4,    7,    8,    6,    4,    8,    6,    4,    0,    2,
    2,    1,    1,    6,    0,    3,    0,    2,    1,    1,
    6,    1,    1,    1,    4,    4,    4,    4,    4,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    7,    8,    8,    8,   10,    8,    6,    4,    1,
    1,    4,    4,    7,    8,    0,    2,    7,    6,    6,
    4,    1,    1,    1,    4,    3,    6,    5,    6,    1,
    1,    6,    8,    6,    6,    8,    1,    1,    0,    0,
    0,    8,    4,    5,    0,    2,    3,    5,    4,    5,
    1,    1,    1,    3,    5,    4,    6,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    0,    1,    0,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,
};
static int yydefred[] = {                                      0,
    0,    0,    0,    0,    0,    0,    0,   29,    0,    0,
  102,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    3,    4,    5,   21,   23,   19,   17,   22,   18,
  754,    9,   10,   15,   20,   11, 1024, 1025, 1026,   26,
   27,   25,   28,   24,   16,   12,    0,    0,    7,    0,
    8,    6, 1293, 1294,   13, 1297, 1298,   14,    0,    0,
  763,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  202,    0,  753, 1037,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  234,    0,    0,    0,    0,    0,    0,  202,    0,  181,
    0,    0,    0,  144,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  202,    0,  928,    0,  657,   30,    0,    0,
   30,    0,    0,    0, 1042,    0,    0, 1881, 1882, 1883,
 1884, 1885, 1886, 1887, 1888, 1889, 1890, 1891, 1892, 1893,
 1894, 1895, 1896, 1897, 1899, 1900, 1901, 1902, 1903, 1904,
 1905, 1898, 1906, 1907, 1908, 1909, 1910, 1911,    0, 1912,
 1913, 1914, 1915, 1916, 1917, 1918, 1919, 1920, 1921, 1922,
 1923, 1924, 1925, 1926, 1927, 1928, 1929, 1930, 1931, 1932,
 1933, 1934, 1935, 1936, 1937, 1938, 1939, 1771, 1773, 1774,
 1775, 1776, 1777, 1778, 1796, 1797, 1779, 1781, 1780, 1789,
 1790, 1786, 1782, 1787, 1783, 1785, 1788, 1784, 1792, 1793,
 1791, 1794, 1795, 1799, 1798, 1800, 1801, 1802, 1803, 1804,
 1805, 1806, 1807, 1808, 1809, 1810, 1811, 1812, 1813, 1814,
 1815, 1816, 1817, 1818, 1819, 1820, 1821, 1822, 1823, 1824,
 1825, 1826, 1827, 1828, 1829, 1830, 1831, 1832, 1833, 1834,
 1835, 1836, 1837, 1838, 1839, 1840, 1841, 1842, 1843, 1844,
 1845, 1846, 1847, 1848, 1849, 1850, 1851, 1852, 1853, 1854,
 1855, 1856, 1857, 1858, 1859, 1860, 1861, 1862, 1863, 1864,
 1865, 1866, 1867, 1868, 1874, 1870, 1869, 1871, 1872, 1873,
 1875, 1876, 1877, 1878, 1879, 1880, 1944, 1945, 1946, 1947,
 1948, 1949, 1951, 1952, 1953, 1955, 1956, 1954, 1940, 1957,
 1941, 1942, 1943, 1950, 1958, 1959, 1960, 1961, 1962, 1963,
 1964, 1965, 1966, 1967, 1968, 1969, 1970, 1971, 1972,    0,
 1194,    0, 1764, 1772,    0,    0, 1132,    0, 1763,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  206,
 1027, 1769,    0,    0,    2,    0,    0,    0,    0, 1137,
 1140,    0,    0,    0,    0,  317,  811,  812,  813,  814,
  815,  816,  817,  818,  819,  820,  821,  822,  823,  824,
  825,  826,  827,  828,  829,  830,  831,  839,  833,  834,
  832,  866,  887,  863,  835,  836,  837,  838,  840,  842,
  845,  841,  843,  844,  846,  847,  848,  849,  850,  851,
  852,  853,  854,  855,  856,  857,  858,  868,  881,  878,
  864,  882,  859,  865,  885,  886,  879,  880,  867,  883,
  884,  888,  889,  862,  861,  860,  869,  870,  871,  872,
  873,  874,  875,  876,  877,  765,  777,  810,  755,    0,
 1753,    0,  479,  466,  467,    0,  768,  470, 1745,  773,
    0, 1756,  766,    0, 1757,  449,  441,  442,    0,  761,
  445, 1761,  756, 1196,  760,    0, 1765,  770,    0, 1766,
  666,  759,    0,  769,    0, 1762,  774,  204, 1437,  488,
  762,    0, 1770,    0, 1034, 1540,    0,  194,  316, 1542,
  322,  195,    0, 1749,  182,    0,  186,  192,    0,    0,
  187, 1545,  196, 1547,    0,  188,    0,  190,    0,  199,
 1401,  191,  197,  290,  193,  198,    0, 1748,    0,  204,
 1433,    0,  200, 1247, 1248,    0,    0,  145,    0, 1754,
    0,  936, 1752,  929,    0,  935,  938,  941,  930,  931,
    0,  932,  933,    0,  934, 1768,  940,  942,  943,  204,
    0,    0,  946,    0,    0,    0,  506,    0, 1270,    0,
    0,    0, 1035,    0,    0, 1043, 1045, 1046,    0,    0,
 1163,    0,    0,    0,    0,    0,  215,  208,  216,  207,
  209,  212,  211,  217,    0,    0,  213,    0,    0, 1094,
 1095, 1100,    0, 1099,    0, 1101, 1103, 1109,    0, 1096,
 1098,    0, 1097, 1104, 1108, 1102, 1106, 1107,    0,    0,
    0,    0,    0,    0,    0, 1120,    0,    0,    0,    0,
 1145,    0,    0,    0,    0,    0,    0,  772,    0, 1747,
 1412,  771, 1407,  317,  778,  232,  767,    0,    0,    0,
    0,  148,    0,  285,    0,  897,  898,    0,    0,  446,
  757,  676,  677,    0, 1405,    0,    0, 1320,  906,  905,
    0, 1437,  775,    0,    0, 1041, 1039, 1541,  317,  264,
    0,  230,    0,    0,  272,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  202,    0,  218,  243,  242,    0,
    0,  360,    0,    0, 1402,    0,    0, 1433,  203,    0,
  201,    0,    0,  146,  147,    0,    0,    0,    0,  937,
    0,    0,  939,    0,    0,  948, 1443, 1448,  947,    0,
    0,    0,    0, 1502,    0, 1536,    0, 1742,    0, 1499,
 1646,    0,    0,    0,    0, 1661,    0, 1537,    0, 1531,
 1520,    0, 1519,    0,    0,    0, 1504,    0,    0, 1521,
 1522, 1532, 1533,    0, 1534, 1535,    0,    0,    0, 1539,
 1391, 1392, 1393,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1538, 1528, 1529, 1743, 1503,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1530, 1480,
    0,    0, 1330, 1468, 1337, 1344, 1351, 1345, 1346, 1347,
 1348, 1349, 1352, 1353, 1354, 1350,    0,    0, 1469, 1497,
 1500, 1475,    0, 1523, 1477, 1478, 1479, 1494, 1495, 1496,
 1524, 1476, 1553,    0, 1603,    0, 1554, 1555, 1609, 1610,
 1612, 1613, 1614, 1557,    0, 1620, 1556, 1680, 1681, 1484,
 1481, 1482, 1700, 1701, 1707, 1708, 1483, 1501,    0, 1333,
    0,    0,    0,    0,    0,   31,    0,  123,    0,    0,
    0,    0,  103,  104,  116, 1033,    0,    0, 1087,    0,
    0,    0, 1314, 1334,    0,    0,    0, 1195, 1133,    0,
 1177, 1758,    0,    0,  214, 1030, 1028, 1105, 1113, 1111,
 1110,    0,    0,    0, 1760,    0,    0,    0,    0,    0,
 1122, 1126, 1551,    0, 1148, 1146,    0, 1151, 1149, 1739,
 1152,    0, 1153, 1143,    0,    0, 1741,    0,    0,    0,
 1127,    0,    0, 1269,    0,    0, 1306, 1326,    0, 1402,
    0,    0,  778,    0,    0,    0,    0,    0,  502,    0,
    0,    0,  469,    0,    0,    0,  281,    0,  444,    0,
  757,  735,  734,    0,    0, 1402,    0, 1322,    0,    0,
  776, 1438, 1444,    0,    0,    0,    0,  978, 1016,  982,
    0, 1017,    0,    0,  983,    0,    0,    0, 1008, 1020,
  977, 1003,  979,  980,  975,  981,    0,  953,  954,  962,
    0,  963,  972,    0,  973,  974,  976,    0,    0,    0,
    0,    0,  270,  224,    0,  480,  220,  225,    0,  450,
  219,  675,  221,  227,    0,  665,  223,  226,  204, 1440,
  489,  222,  245,    0,    0,  370,    0,    0,    0,    0,
    0,    0,  291,  189,  363,  205, 1434,    0,    0,  148,
    0,    0,  180, 1543,  179, 1746,    0,    0, 1212,    0,
    0,    0, 1296,  952,  951,    0,  949,    0,    0,    0,
 1525,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1526, 1527,    0, 1505,    0, 1506,    0,    0,    0,
    0, 1709,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1135, 1136,    0,    0,    0,    0,
    0,  604,    0,    0,  649,    0,    0,    0, 1376, 1359,
    0,    0, 1360,    0, 1363,    0, 1361, 1362,    0,    0,
    0, 1356, 1357, 1358,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  157,
  507,    0,   69,   70,    0,    0,    0,    0,    0,   64,
    0,    0,    0,    0, 1168, 1170, 1167, 1179, 1180, 1181,
 1169,    0,    0,    0,    0,    0,    0,  123, 1031,  288,
    0,  286,  287, 1549, 1044, 1043, 1301,    0,    0,    0,
    0,    0,    0, 1176,    0,  210,    0, 1119, 1088, 1118,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1155,
    0,    0, 1156, 1158,    0,    0,    0, 1243,    0, 1139,
 1138,    0,    0,    0, 1472,    0, 1471, 1516, 1518, 1473,
    0, 1128, 1311,    0,    0, 1268,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  918,    0,  907,    0,    0,
  901,    0,  899,    0,    0,  515,    0,    0,  468,  503,
  476,    0,  478,    0,    0,  283,  277,    0,  443,  447,
    0,    0,    0,    0,    0,  926,    0,    0,    0,    0,
 1321,    0,    0, 1435,    0,    0,    0,    0,    0,  484,
  318,  317,    0,  985, 1004, 1005, 1021,    0, 1018,    0,
    0, 1011, 1009, 1010,    0,  267,  253,    0,    0,    0,
  971,    0,    0,    0,    0, 1012,  273,  231,  279,    0,
    0, 1409, 1440,  228,    0,    0,  369,  361,    0,    0,
  682,  683,  680,    0,    0,    0,    0,    0,    0,  687,
  679, 1403, 1402,  292,    0, 1435,    0,    0,    0, 1546,
 1544,    0,    0,    0, 1219, 1221,    0, 1222, 1214, 1215,
    0,  944,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1728, 1729, 1730, 1731, 1732, 1733, 1736, 1737, 1734,
 1735,    0,    0,    0,    0,    0,    0, 1717,    0, 1710,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1692,
 1694, 1693,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1587,    0,    0,    0,    0,
    0, 1588, 1589,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1493, 1341, 1470,  653,    0,    0,  605,    0,  606,    0,
    0,    0,    0,    0,    0,    0, 1387, 1398,    0, 1394,
    0, 1395, 1342,    0,    0,    0,    0,    0,    0,    0,
 1378,    0, 1365, 1367, 1366,    0,    0,    0, 1489,    0,
    0,    0,    0,    0,    0,    0,    0, 1696,    0, 1498,
 1331,    0,    0,  155,    0,    0,    0,    0,    0,    0,
    0,   54,   55,   59,   50,   52,   49,   47,   48,   56,
   53,   58,   51,    0,    0,    0,    0,    0,    0,   45,
  126,  138,  140,    0,    0,    0,    0, 1198,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  120,  122,
    0,    0,    0,    0,    0,    0,  289, 1550,    0,    0,
 1302, 1315,    0, 1300,    0, 1335, 1178,    0, 1093, 1089,
 1115,    0,    0, 1117, 1092, 1147, 1150,    0,    0,    0,
    0,    0,    0,    0,    0, 1517, 1767, 1258, 1257, 1260,
 1261, 1262,    0,    0,    0,    0,    0, 1328,    0, 1403,
  908,    0,    0,  913,    0,  920,  914,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  780,  903,  509,  505,
    0,    0,  511,  512,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  526,  521,    0,    0,  520,    0,  530,  529,
  552,  541,  542,  555,    0,  539,  556,  553,  543,  536,
  554,    0,  545,  546,  544,  634,  636,  635,  537,    0,
  531,  532,  535,  533,  534,  550,  540, 1318, 1317,    0,
    0,    0,  452,  155,    0,    0,  275,    0,  793,  420,
    0,    0,  792,    0,    0,    0,    0,  752,    0,    0,
 1403, 1323,    0,  664,  904,    0, 1445,    0,    0,  481,
  485,    0,    0,    0, 1548,    0,    0,    0,    0, 1019,
    0,  265,  407,  402,  403,  404,  405,  406,  254,    0,
  966,    0,    0,    0,    0,    0,    0,    0,    0,  278,
 1402,  229, 1441,    0,  238,  371,    0,  685,  686,  684,
    0,    0,    0,    0,  708,  702,  696,  720,  693,  690,
  699,  717,  705,  711,  714,  731,  726,    0,  707,  701,
  695,  719,  692,  689,  698,  716,  704,  710,  713,  722,
  730,    0,  709,  703,  697,  721,  694,  691,  700,  718,
  706,  712,  715,  723,  732,    0,    0,    0,    0,    0,
    0,  361,    0,    0,    0,    0,    0,    0,  494,  183,
  157,    0,  155,    0, 1313, 1751, 1220,    0, 1256,    0,
    0,    0,    0,    0, 1558,    0, 1389,    0, 1682,    0,
    0,    0,    0,    0, 1679, 1390,    0,    0,    0, 1508,
 1510,    0,    0,    0,    0,    0,    0, 1711,    0,    0,
    0, 1726, 1615, 1616, 1617, 1683, 1618,    0, 1691,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1590,
    0, 1591,    0, 1595,    0, 1598, 1571, 1572, 1573, 1574,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1332,    0,    0,    0, 1511,    0,    0,    0,
    0,    0,    0, 1396, 1397, 1343,    0,    0, 1388,    0,
    0,    0,    0,    0,    0,    0, 1619, 1695,    0,  650,
    0,    0,    0,    0,   61,    0,    0,    0,    0,    0,
    0,    0,   57,   41,   41,   67,   67,   67,    0,    0,
   73,    0,   72,    0,   71,    0,   66,   80,   87,  123,
    0,    0, 1171, 1203, 1201, 1199,    0, 1271, 1200,    0,
    0,    0,    0,    0,   41,    0,    0,    0,    0,    0,
   41,    0,    0,    0,    0, 1061,    0, 1054,    0,    0,
    0, 1049, 1056, 1065, 1066,    0,    0, 1134, 1090, 1091,
    0,    0,    0,    0, 1157, 1161, 1159, 1244,    0, 1245,
    0,    0,    0,    0, 1312,    0,    0, 1327,  315,    0,
    0,    0,    0,  251,  912,    0,    0,  916,  782,    0,
    0,  785,  787,  786,    0,    0,  783,  790,  791,  970,
    0,  506,  506,    0,    0,  504,    0,  462,    0,  958,
  957,  961,    0,  519,    0,    0,  570,    0,    0,    0,
  613,  616, 1759,  637,  638,    0,  640,  614,    0,  551,
  522,  622,  527,    0,  620,  528,    0,    0,    0,    0,
  611,  475,    0,    0,    0,  448,    0,    0,  891,    0,
    0,    0,  809,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  924,    0,    0,    0, 1439,    0,  486,  487,
  319,  317,    0,    0,    0,    0,    0,    0,    0,  325,
    0,    0,  987,    0,    0, 1023,    0, 1014,    0,    0,
  964,    0,  996,    0,    0,  997, 1000, 1002,  280,    0,
 1435,  321,    0,  239,    0,  375,    0,    0,    0,  670,
  724,  688,  728,  729,  733,    0, 1404,    0, 1424,    0,
 1425,    0,    0,    0,    0,    0,    0, 1415,    0,  293,
  371, 1436,  496,    0,    0,  498,    0,    0,    0,  491,
    0,    0,  495,  184,  155,  149,    0,    0,    0, 1216,
 1295, 1564, 1563,    0,    0,  398,  401, 1560, 1559,    0,
 1568, 1567, 1566, 1565,    0,    0, 1562, 1561,    0,    0,
    0, 1719, 1718,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  656,  608,  607, 1373,
 1370, 1400, 1399, 1368,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1698,    0,  160,  660,    0,  661,  160,
    0,    0,    0,    0,    0,    0,    0,    0,  123,  123,
    0,    0,    0,   83,   84,   75,   74,    0,    0,  139,
    0,    0, 1272, 1182,    0, 1193, 1188,    0,  123,    0,
    0,    0,    0,    0,    0,    0,  113,  113,  123, 1051,
    0,    0, 1055,    0, 1052,    0, 1053, 1062,    0,    0,
 1059, 1058,    0,    0,    0,    0,    0, 1251, 1252, 1250,
    0, 1265, 1267, 1329, 1408,  911,  344,  252,    0,  919,
    0,    0,  784,  788,  789,    0,    0,  397,    0,    0,
  513,    0,    0,  518,    0,    0,    0,  571,    0,    0,
  601,    0,  642,  568,    0,  623,  621,    0,    0,    0,
    0,  562,    0,    0,  160,  453,  456,    0,    0,  794,
    0,  797,  798,  420,    0,  796, 1750,  896,  895,  795,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  808,
  805,  389,    0,  390,    0,    0,    0,    0,    0,    0,
  923, 1406,  668, 1466, 1465,    0,    0,    0,    0,    0,
    0,    0,    0,  327,    0,    0,  333,    0,  330,  329,
  332,  331,  989,    0,  993,  994,    0,    0,    0,    0,
  254,  967,  969,  965,  999, 1403,    0,    0,    0,  373,
  362,  372,    0,    0,    0,  669,    0,    0, 1403, 1417,
    0, 1421,    0,    0, 1418, 1420, 1419,    0,  297,    0,
    0,  497,  499,  490,    0,    0,    0,  160,  152,    0,
    0,  159,  151,    0,    0,    0, 1699, 1727,    0, 1678,
 1611,    0,    0,    0, 1720,    0,    0, 1702, 1704,    0,
 1689, 1690,    0,    0,    0,    0,    0,    0,    0, 1705,
    0, 1570, 1569,    0,    0,    0, 1594,    0, 1597, 1575,
 1576, 1577, 1578, 1579, 1580, 1581, 1582, 1583, 1584, 1585,
 1586, 1369, 1371,    0,    0,    0, 1364,    0, 1604, 1697,
    0,    0,    0,    0,   33,   33,   33,   33,   33,   33,
   33,    0,    0,    0,   68,    0,   82,    0,   81,   90,
   89,   91,   88,    0,  126,    0,    0,  143,  141,  100,
    0, 1174, 1183, 1272,    0,    0, 1184, 1185,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  123,  123,    0,
    0, 1064, 1057,    0, 1073, 1068, 1067,    0, 1071, 1060,
    0, 1299,    0,    0,    0,    0, 1264,  345,  915,    0,
  917,    0,    0,  507,  464,  465,    0,  959,  956,    0,
    0,    0,    0,    0,    0,  643,  644,  646,  645,    0,
    0,    0,  625,    0,  563,    0,    0,    0,    0,  474,
  471,  423,    0,    0,    0,  384,    0,  394,    0,  395,
    0,  799,    0,  800,  392,  807,  806,  803,    0,  893,
    0,    0,  749,  750,  746,  745,  748,  747, 1463,    0,
    0, 1459,    0, 1460, 1446,    0,    0,    0,  338,  340,
    0,  328,  334,  988,    0,  986, 1015,  255,    0,    0,
    0, 1442,  358,  359,  247,  240,    0,  375,  376,  377,
    0,  674,    0,  672, 1402, 1422, 1423, 1426,    0,  294,
  292,    0,  185,  236,    0,    0,  158,  169,    0,    0,
    0,    0,    0,  166,  162,    0,    0,    0, 1227,    0,
 1224,    0, 1228,    0,  399,    0, 1684,    0,    0,    0,
    0,    0,    0,    0, 1688, 1672,    0,    0,    0,    0,
    0,    0,    0, 1592,    0,    0,    0,  662,    0,    0,
  459,    0,  658,  123,  123,  123,  123,  123,  123,  123,
    0,  126,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  124,  125,  135,    0,    0,    0,   99,    0,   46,
    0,  101, 1172,    0,    0, 1186,    0, 1190,  105,  105,
  105,  105,  105,  105,  105,    0,    0,  117, 1074,    0,
 1080,    0, 1085,    0,    0, 1206,    0, 1210, 1141,    0,
  922,  269,    0,    0,    0,    0,    0,    0,  572,    0,
    0,  557,    0,    0,    0,    0,    0,  575,    0,    0,
  457,  458,  473,    0,    0,    0,  427,  421,    0,  378,
  381,  383,  801,  802,  804,  391,    0, 1458, 1457, 1462,
 1456,    0,  339,    0,    0,  335,  991,    0,    0,  258,
  262,  261, 1410,    0,  374,  673,  671,    0,    0,    0,
    0,    0,  292,    0,  364,    0,    0,    0,    0,    0,
  168,  161,    0,  164,  165,  178,    0, 1217, 1231, 1230,
 1234, 1226, 1229,    0, 1685,    0, 1716,    0, 1712, 1703,
 1673, 1674, 1675,    0, 1706,    0, 1677, 1600, 1601, 1593,
 1596,  663,  160,  455,  461,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   42,  130,  137,  129,  132,  136,
  133,  134,  131,   43,   95,  142,   98,   97, 1273,    0,
    0, 1274, 1275,    0,  123,  123,  123,  123,  123,  123,
  123,  114,  115,    0,    0,    0, 1082,    0,    0,  346,
  345,    0,    0,    0,    0,  560,    0,    0,    0,    0,
    0,  627,  633,    0,    0,    0,    0,  626,    0,    0,
    0,    0,    0,    0,    0,    0,  379,  379,  388,    0,
 1453, 1452, 1447,    0, 1451,    0,  343,  260,  268, 1403,
 1428,    0, 1429,    0,  298,  295,  314,  292,  301,    0,
    0,    0,    0,    0,  172,    0,  176,  171,    0, 1225,
    0,    0,    0, 1713,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   93,  127,  128, 1277, 1278,
    0, 1279, 1187,    0,    0,    0,    0,    0,    0,    0,
 1081, 1077, 1076,    0, 1086, 1303, 1207,    0,    0,    0,
    0,  960,  516,    0,  573,  571,    0,  641,  624,    0,
  632,  631, 1755,  629,  630,    0,    0,  566,  565,  618,
  609,    0,    0,    0,  424,    0,    0,    0, 1450, 1454,
 1449, 1455,    0,    0, 1432,    0,  303,    0,    0,    0,
    0,  304,  305,  306,    0,    0,  237,  170,    0,  174,
    0,  153, 1232, 1232,  400, 1714, 1676,  460,   34,   36,
   35,   37,   38,   39,   40, 1282, 1280,  106,  108,  107,
  109,  110,  111,  112, 1078, 1079, 1084,    0,    0,    0,
    0,  349,    0,    0,  577,    0,    0,  599,  628,  564,
    0,    0,  425,    0,    0,    0,  409,    0,    0, 1430,
 1431,  307,  310,  309,  312,  311,  308,  366,  367,  150,
  177,    0,    0, 1283,    0, 1306,    0,  351,    0,    0,
    0,    0,  508,  571,    0,    0,    0,    0,    0,    0,
  590,  619,    0,    0,    0,  380,    0,    0,  382,  342,
    0, 1236,    0, 1235,    0,    0,    0, 1281,    0, 1304,
    0,  356,  352,    0,    0,    0,    0,  589,    0,    0,
    0,    0,    0,    0,    0,    0,  429,    0,  385,    0,
  411,  412,    0, 1233, 1239,    0,    0, 1284,    0, 1287,
    0, 1307,  353,  510,  572,  578,  572,  579,  580,  583,
    0,    0,    0,    0,    0,    0,  596,  598,  597,    0,
    0,    0,    0,    0,  413,    0, 1237,    0,    0, 1289,
    0,    0,    0,    0,    0,    0,    0,    0,  426,    0,
  434,    0,  433,  387,    0,    0,    0,  416,  414,  415,
    0,    0,    0, 1288,    0,    0,  581,  584,    0,    0,
    0,    0,  437,  436,  435,    0,    0,  418, 1240, 1291,
    0,    0,  440,  438,  439,  419,    0,    0,    0,    0,
    0,    0,    0,  417,    0,    0,    0, 1290,    0, 1292,
};
static int yydgoto[] = {                                      20,
   21,   22,   23,   24,   25,  946, 1634, 1265, 1636, 1266,
 1267, 2057, 1268, 1637, 2058, 1269, 1638, 2059, 2873, 2666,
 2890, 2668,   26,  953,  954,  955, 2652, 2882, 2883, 1271,
 1642, 2388, 2669,   27,  104,  724, 2581, 1922, 2287, 2582,
 2825, 2819, 2991, 3128,  548, 1132,   28,  100,   29,  360,
   30,  707,  515, 1094,  459,  101, 2813,  523,  710, 1114,
 1855, 2796, 2123,  512, 2540, 2789, 2970, 1416, 1417, 2971,
  518,  694,  695, 1037, 1098, 1431,  470,  664,  665,   31,
 1292,  533,  536, 2270, 2810, 2982, 3119, 3212, 3213, 3214,
 3116,  648,  508,  509, 1401, 1823, 2220, 2211, 2522, 2779,
 2124, 3070, 3168, 3252,  526, 1124, 2985,  712, 2245, 2552,
 2482, 2951, 3339, 2501, 2747, 2145, 2295, 1832, 3266, 3307,
 3341, 3399, 2483, 2484, 2948, 3195, 3371, 3372, 3373, 3414,
  476,  477,  478,  479,  480, 1101, 1375, 2034, 2183, 2477,
 2860, 2861, 2368, 2451,  463,  464,  465,  466, 2741,  661,
 1033,  467, 1097,  500, 1398, 1399, 1400,  501, 1112,  721,
 1917, 1918, 1919, 1027, 1028, 1029, 1732, 1733, 1734, 2155,
 1753, 1754, 1755, 1756, 1757, 1758, 1759, 1760, 1761, 1762,
 1763, 1764, 3089, 2463, 2464, 1765, 1766, 1767, 2929, 3325,
 3359, 3326, 3360, 3175, 3256, 3301, 1768, 1769, 2461, 1770,
  880, 1568, 1771, 1772, 1773, 1774, 2161, 3189, 3188, 2174,
 2175, 2936, 3088, 1775, 1776, 1777, 1778, 2732, 1779,  881,
 1225,   33, 1261, 2031, 2369,  491, 1107,  492, 1814,  528,
 1103,  674, 1120, 1443, 1449, 1450, 1121, 1386, 1388,   34,
   78,  456, 1359, 1727, 1381, 1803, 2192,  457, 2758, 2490,
  473,  657, 1025, 1363,  494,  681, 1021, 1358, 2711,  485,
 1045,   35,  125,  733, 1077, 2148, 2149, 2150, 2151, 1079,
 1840, 1841, 1080, 2140, 1082, 2538, 2225, 1421, 1083, 2141,
 1085, 1412, 1086, 1409,   36,   37,   38,  977,   39,   40,
   41,  505,   42,   43, 1295, 1669, 2092, 2093, 2094, 2095,
 2696, 3164, 3247, 2910, 2911, 3067, 2912,   44,   45,  629,
  630,  631,  632,  633, 1313,  987, 1309, 1780,  367,  991,
  636,   47,   48,  346,  347, 1216, 1217,  369,  370,  371,
  639,  640,  641, 1002, 1321, 1322, 1323, 1324, 1689, 2101,
 1274, 1275, 1276, 2671,  596,  970, 1277, 1278, 1279, 1280,
 2677, 2678, 1281, 1656,  340,  493, 1654, 2427, 2915, 2916,
 2706,  728, 1142, 2829, 2830, 2831, 2832, 3002, 3311, 3314,
  644, 1327, 1328,  546, 2110, 2430, 1929, 1930, 1012, 1342,
 1781,   50, 1782, 2894, 3052, 3053, 3318, 3348, 1783,   53,
   54, 1784,   56,   57, 1785, 3287, 1014, 1344,  729,  962,
 1786, 1787,  677,  678, 1047,  646, 1018, 1707,  882,  883,
  965, 1139,  884,  885,  886, 1245,  887, 1596,  888,  889,
 1574,  890, 1246,  891,  892,  893,  894,  895,  896, 1577,
 1578,  530,  488,  652, 1104, 1452, 1909, 2268, 2257, 2978,
 3113,  719,  683, 1434,  736, 1052, 1053, 3103, 3104, 3201,
 2521, 2772, 2207, 2516,  897,  898, 1336,  899,  900,  901,
 1165, 1167,  902, 1487,  903, 1834,  904,  905,  906,  907,
  908,  909,  910,  911, 1310, 1133,  524, 1461,  525, 1827,
 1293, 1294,  912,  913,  914,  915, 2854,  916,  917, 2026,
 2329,  918,  919,  920,  921,  922,  923,  924,  925,  926,
  927,  928, 2593,  929, 1524,  930,  931,  932,  933,  934,
  935, 2597, 2843,  936, 1171, 2840, 1172, 1956, 2327,  937,
 1502,  938,  939,  468, 1135,  649,  537,  940, 2486, 1736,
  552,  516,  549, 3182,  519, 3312,  971, 1790,  988,  481,
 1643,  941,  484,  529, 2670, 1222,  565,  361,  942,  943,
  344,  128,  578,  947, 2036, 2864, 2379,  948, 2060, 1270,
 2381, 1617, 2891,  131, 1287, 3055, 2688, 1288, 2653, 2061,
 1130, 1034, 2577, 2288, 1614, 2641, 2820, 2987, 2284, 2575,
  499,  682, 2502, 2244, 2549, 2243, 2795, 2797,  691, 1839,
 2229, 2968, 2972, 1378, 1454, 3120, 2570, 2981, 3118,  689,
  654, 1822, 1350, 2708, 2920, 3249, 3291, 1117, 1856, 1455,
 2246, 2798, 2553, 3097, 3197, 3098, 2503, 2504, 3267, 3340,
 2188,  670, 1040, 1798,  662, 1367, 2143,  945, 1615, 2142,
 2735, 2939, 2458, 2722, 3078, 3294, 3295, 2466, 2733, 2937,
 3180, 2167, 2465,  577,  671, 1041,  376,  655, 1023, 1721,
 2187, 1804, 1713, 2441, 1087, 1404, 1828, 1088, 1089, 1090,
 1091,   80,  957,  687,  586,  960, 2082, 2418, 2698, 1008,
 1003,  592, 2065, 1470, 1928, 2585, 3131, 3282, 3132, 3378,
 1700, 1703,  373, 2393, 2674, 3050, 3237, 3285, 3284, 3315,
 3403, 3428, 1671, 2096, 3248, 1347,  647,  715, 1453, 1908,
  653, 1046, 1020, 1851, 2258,  720, 1456, 1816,  684, 1394,
 1435, 2241, 1395, 2208, 2962, 1510, 1958, 2315,
};
static int yysindex[] = {                                   8428,
37303,  455,39136, 1790,  117,29926,  495,    0,  602,  691,
    0,  455,  650,95391,95784, 2200,99321,  587,  735,    0,
 1141,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1011,  941,    0, 1051,
    0,    0,    0,    0,    0,    0,    0,    0,  959,  951,
    0,89067,99321, 1077,99321,99321,99321,99321,99321,99321,
99321,99321,99321,99321,  849,    0,99321,    0,    0, 1060,
 1707,99321,99321,99321,99321, 1207,99321, 1034,99321,99321,
    0,99321,99321,99321,99321,99321, 1260,    0,99714,    0,
 1472, 1202,99321,    0,99321,99321,99321, 1224,99321,99321,
99321,99321,99321, 1034,99321,99321,99321,99321,99321,99321,
99321,  970,    0,100107,    0,99321,    0,    0,99321,99321,
    0,  -22,99321, 1252,    0,99321, 1136,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1334,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1216,
    0, 1421,    0,    0,99321, 1654,    0, 1680,    0,99321,
99321,99321,99321,99321,99321,99321,99321, 1217,100500,    0,
    0,    0,99321,37924,    0, 1340, 1355,    0, 1148,    0,
    0, 1385,    0,99321, 1422,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1707,
    0,99321,    0,    0,    0,  930,    0,    0,    0,    0,
 1310,    0,    0, 1023,    0,    0,    0,    0, 1299,    0,
    0,    0,    0,    0,    0, 1038,    0,    0, 1422,    0,
    0,    0, 1871,    0,  679,    0,    0,    0,    0,    0,
    0, 1613,    0, 1525,    0,    0, 1509,    0,    0,    0,
    0,    0, 1695,    0,    0, 1707,    0,    0, 1384, 2172,
    0,    0,    0,    0,   60,    0, 1663,    0, 1326,    0,
    0,    0,    0,    0,    0,    0, 1673,    0, 1577,    0,
    0,99321,    0,    0,    0, 1685,99321,    0, 1691,    0,
 1607,    0,    0,    0,99321,    0,    0,    0,    0,    0,
  -19,    0,    0, 1566,    0,    0,    0,    0,    0,    0,
99321,99321,    0,77473, 2008,    0,    0,    0,    0, 1578,
   -3, 1587,    0, 1670,99321,    0,    0,    0, 1791,99321,
    0,99321, 1654,99321,99321, 1857,    0,    0,    0,    0,
    0,    0,    0,    0, 1726,99321,    0, 1793, 1757,    0,
    0,    0, 1867,    0, 1852,    0,    0,    0, 1856,    0,
    0,99321,    0,    0,    0,    0,    0,    0, 1917,99321,
99321,99321,99321, 1870, 1713,    0,  171,  193, 1684,    0,
    0, 1979, 1773, -168, 1739, 1476, 2220,    0, 1886,    0,
    0,    0,    0,    0,    0,    0,    0, 1995, 2011, 1589,
 2043,    0, 1882,    0, 1677,    0,    0, 2011, 2043,    0,
    0,    0,    0, 1619,    0,99321, 2088,    0,    0,    0,
 2091,    0,    0,99321, 2104,    0,    0,    0,    0,    0,
21424,    0, 1939, 1677,    0,99321,99321,99321,99321,99321,
99321,99321,99321, 1785,    0,99321,    0,    0,    0, 2103,
  861,    0,99321,  979,    0,99321,99321,    0,    0,99321,
    0, 2136,99321,    0,    0,86295,70565, 2027, 1739,    0,
 2070, 2072,    0, 1774,99321,    0,    0,    0,    0, 2379,
 2381, 2388, 1997,    0, 2405,    0, 2424,    0, 2425,    0,
    0, 2433, 2435,78101, 2453,    0, 2457,    0, 2470,    0,
    0,    0,    0, 2475, 2081, 2082,    0, 2489, 2502,    0,
    0,    0,    0, 2512,    0,    0,71193, 2517, 2523,    0,
    0,    0,    0, 2552, 2250, 2565, 2580, 2585, 2586, 2609,
 2636,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2640, 2645, 2652,
    0,    0,    0,    0, 2655,    0,    0,    0,    0,    0,
    0,    0, 2657,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2662, 2664, 2668, 2674, 2676,
 2678, 2686, 2687,    0,    0,    0,    0,    0, 2688, 2689,
 2690, 2692, 2695, 2698, 2705, 2706, 2707, 2713, 2718, 2719,
 2720, 2724, 2725, 2726,82497,82497,71821,99321,    0,    0,
 2175, 2515,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,25680, 1740,    0,    0,
    0,    0, 2568,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2041,    0,    0,    0,    0,
    0,    0,    0,    0, 2730,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2731,    0,
 2623, 2729,    0,99321, 2732,    0,   63,    0,85113, 2294,
 2414, 2419,    0,    0,    0,    0,99321,  196,    0,    0,
99321,  168,    0,    0, 2736, 2734,    0,    0,    0, 2137,
    0,    0, 2752,99321,    0,    0,    0,    0,    0,    0,
    0, 2460, 1240, 2465,    0, 2753, 2753,    0, 2469,99321,
    0,    0,    0,78101,    0,    0,78101,    0,    0,    0,
    0,72449,    0,    0,78101,  941,    0,  941,78101, 1644,
    0, 2309,78101,    0, 2769, 1739,    0,    0, 2516,    0,
    0, 1258,    0, 1707, 2455,  926, 2544, 2011,    0,99321,
 1707, 1707,    0, 2776,  196, 2546,    0, 2544,    0, 2776,
    0,    0,    0,  887, 2441,    0, 2176,    0, 2387, 2380,
    0,    0,    0,  104,    0, 2789, 2402,    0,    0,    0,
 2403,    0, 2446, 2796,    0, 2497, 2800,  100,    0,    0,
    0,    0,    0,    0,    0,    0, 2547,    0,    0,    0,
 2754,    0,    0,  229,    0,    0,    0,  244, 2803, 2807,
 2800,  196,    0,    0, 1707,    0,    0,    0, -154,    0,
    0,    0,    0,    0, 1422,    0,    0,    0,    0,    0,
    0,    0,    0, 1707, 1707,    0, 2808, 1038,  870, 2441,
 2097,    0,    0,    0,    0,    0,    0, 2579, 2486,    0,
 2408, 2484,    0,    0,    0,    0, 2492,71821,    0,25680,
  910, 2498,    0,    0,    0,99321,    0, 1807,78101,  693,
    0, 2387,99321,78101, 1833, 1842, 2519,78101, 2387, 1844,
 2553,    0,    0, 1034,    0, 1034,    0,78101,78101,25680,
  617,    0,78101,78101,78101, 2560,78101,78101,78101,78101,
78101,68681,68053, 2553,78101, 1873,78101, 2834,78101,78101,
78101,78101,78101, 2835, 2838,78101,78101,78101,78101,78101,
78101,78101,78101,78101,78101,78101,78101,78101,78101,78101,
78101,81869, 1495, 1495,    0,    0, 2839,    0, 1740, 2180,
 2836,    0,    0,84325,    0,78101,78101,83125,    0,    0,
 2848,  638,    0,78101,    0, 1276,    0,    0,78101, 2452,
 2471,    0,    0,    0,69309,78101,99321,82497,82497,82497,
82497,82497,78101, 2851,78101,73077,93819,99321,77473,    0,
    0, 2508,    0,    0, 2528, 2533, 2534,28713, 2613,    0,
  169,99321,84719, 2578,    0,    0,    0,    0,    0,    0,
    0, 2864, 2861, 2653, 2603, 2604,   63,    0,    0,    0,
 1220,    0,    0,    0,    0,    0,    0,99321, 2027, 1739,
78101,99321,99321,    0, 2387,    0, 1240,    0,    0,    0,
 1240,99321, 2587, 2600,99321, 1240, 2875, 4606, 4721,    0,
 2612, 2888,    0,    0, 4170, 2890, 2895,    0, 4843,    0,
    0,21950, 1975,99321,    0, -137,    0,    0,    0,    0,
 1118,    0,    0,  266,78101,    0,99321, 2434,    0, 1258,
 2454, 2447, -180, 2458,  115,    0, 2514,    0,    0, 1837,
    0, 1707,    0,99321,99321,    0,99321,87474,    0,    0,
    0, 2340,    0, 2915, 2563,    0,    0,  179,    0,    0,
 2916, 1140, 2588, 2590, 2591,    0, 1034, 1365,    0,99321,
    0, 2527, 2370,    0, 2485,99321,99321, 2667,  104,    0,
    0,    0,  211,    0,    0,    0,    0, 1034,    0, 2796,
  179,    0,    0,    0, 3927,    0,    0,  179, 2573,  179,
    0, 2927, 1034, 1034, 1034,    0,    0,    0,    0, 2539,
 1677,    0,    0,    0,99321, 2630,    0,    0,  979,  -31,
    0,    0,    0, 1099,37917, 2371, 3653,30521, 2608,    0,
    0,    0,    0,    0, 2951,    0,  601,99321, 2952,    0,
    0,86295,99321,25680,    0,    0, 2641,    0,    0,    0,
 2500,    0,78101,78101,22610,78101, 2956,78101, 2957, 2958,
 4751,78101,78101,78101,78101,26294, 2960, 2568, 2963,78101,
78101,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2691, 2976, 2981,23224, 2605,78101,    0,78101,    0,
22565,23179, 2980,99321, 6012, 6036, 6626, 6650, 7240,    0,
    0,    0, 2212,73705,    0,    0,    0,    0,36687, 2988,
  245,23793,78101,78101,37300,    0, 7264,24407, 7854, 2994,
 3091,    0,    0, 7878, 8468, 8492, 9082,25021,25635,26249,
26863,27477,28091,28705,29319,29933,30547,31161,31775, 1732,
    0,    0,    0,    0,99321,87867,    0, 2990,    0, 2979,
 1177, 2744,71821, 2774, 1740,71821,    0,    0, 2728,    0,
  486,    0,    0, 2711,83125, 2848,78101, 2627,78101, 3358,
    0,78101,    0,    0,    0, 3008, 2711, 2711,    0, 2772,
 1057, 1057, 1495, 1495,25680, 2437, 3010,    0, 2207,    0,
    0, 3021, 2175,    0, 2671,    0,    0, 2646,   93,   -8,
 2673,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2649, 2661, 3028, 3032, 3039, 2487,    0,
    0,    0,    0, 3043, 2394, 3046, 2715,    0, 2715, 1728,
78101, 2715, 2758, 2760,78101,    0,99321, 2775,    0,    0,
 2733, 2735, 2739,28713, 2809,  491,    0,    0,    0, 3680,
    0,    0, 2498,    0,25680,    0,    0, 3056,    0,    0,
    0, 1240, 1240,    0,    0,    0,    0,85113, 2665,78101,
99321,85900,78101, 2620,78101,    0,    0,    0,    0,    0,
    0,    0, 1205,87867,78101, 2234, 2238,    0,99321,    0,
    0, 2773, 2780,    0, 2783,    0,    0, 2837, 2696,99321,
 1837, 1222, 1107, 1178,99321,21424,    0,    0,    0,    0,
 2852, 3055,    0,    0,90282,  446,    0,99321,  581,    0,
 3088, 2535,78101,    0,    0,99321,99321,99321,104037,99321,
78101,99321,    0,    0, 2827,87081,    0, 3072,    0,    0,
    0,    0,    0,    0, 2801,    0,    0,    0,    0,    0,
    0,  920,    0,    0,    0,    0,    0,    0,    0, 2805,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3081,
    0,99321,    0,    0,90282, 2703,    0, 2671,    0,    0,
 2697,96177,    0,89067,   69,   91,   78,    0, 2011, 2043,
    0,    0, 2870,    0,    0, 2721,    0, 3095, 3098,    0,
    0,    0,    0, 2473,    0,  190, 2247, 2745, 3109,    0,
 2272,    0,    0,    0,    0,    0,    0,    0,    0, 1287,
    0, 3100,99321, 1485, 1034, 3120, 3123, 3124,  196,    0,
    0,    0,    0, 3105,    0,    0, 2441,    0,    0,    0,
 2011,99321, 2043, 2768,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2680,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2567,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2569, 1831, 2530,    0, 2651,
 2863,    0, 2721,99321,99321,  601, 2876,  782,    0,    0,
    0, 2785,    0, 2877,    0,    0,    0, 3143,    0, 1739,
 9106, 9696,90675, 9720,    0,10310,    0,78101,    0,10334,
10924,10948,11538,78729,    0,    0,11562,12152,78101,    0,
    0,78101,74333,78101,25680, 2881, 2767,    0,78101,78101,
78101,    0,    0,    0,    0,    0,    0,78101,    0,78101,
23838, 2770,78101,78101,78101,78101,32389,32389,78101,    0,
78101,    0,78101,    0,78101,    0,    0,    0,    0,    0,
78101,78101,78101,78101,78101,78101,78101,78101,78101,78101,
78101,78101,    0, 2279,87867,99321,    0, 3150,83125, 3153,
 2280,78101, 2894,    0,    0,    0,78101, 2933,    0, 2711,
78101, 2711, 2711, 2387, 2937, 2498,    0,    0,74961,    0,
 2301,99321, 3172, 2955,    0,99321,99321,99321,99321,99321,
99321,99321,    0,    0,    0,    0,    0,    0, 2973,    0,
    0, 2974,    0, 1871,    0, 1871,    0,    0,    0,    0,
99321,    0,    0,    0,    0,    0, 2903,    0,    0,85113,
85113, 2305,99321, 2864,    0, 2646,  155,  818, 2925, 2928,
    0, 3680, 2898,   34, 1065,    0, 2833,    0, 2740, 2737,
 2746,    0,    0,    0,    0,    0, 2500,    0,    0,    0,
 3208, 2394,78101, 2932,    0,    0,    0,    0, 1556,    0,
25680, -137, 2897, 2990,    0, 1739,99321,    0,    0, 2530,
 1707, 1707, 2780,    0,    0, 2856, 2703,    0,    0, 3232,
 2998,    0,    0,    0, 2936, 2945,    0,    0,    0,    0,
 3006,    0,    0,99321,  232,    0, 2926,    0,    0,    0,
    0,    0, 2677,    0, 3009,75589,    0,78101, 2879,25680,
    0,    0,    0,    0,    0, 2965,    0,    0,25680,    0,
    0,    0,    0, 2866,    0,    0,87867,   73, 3255,87867,
    0,    0, 2329,99321, 2852,    0, 1140,96570,    0,99321,
 1197, 1149,    0, 1153,    0, 2930, 2931, 2934, 2935, 2938,
 2939, 2544,    0, 2530, 2941,  505,    0,  141,    0,    0,
    0,    0, 2473, 3105, 3105, 1707, 2946,94212,94212,    0,
 3266,  190,    0,86295, 2904,    0,  179,    0,    0,  179,
    0,  179,    0, 3006, 3267,    0,    0,    0,    0,    0,
    0,    0, 2703,    0, 2361,    0, 1522, 2544, 1549,    0,
    0,    0,    0,    0,    0, 3274,    0, 2651,    0, 2869,
    0, 1707, 2871, 2670, 1707, 1707, 1707,    0,96963,    0,
    0,    0,    0, 3259,  214,    0, 3263, 1033, 3023,    0,
99321,99321,    0,    0,    0,    0, 3280,28089, 1707,    0,
    0,    0,    0, 2961, 3289,    0,    0,    0,    0,12176,
    0,    0,    0,    0,71821,12766,    0,    0,12790,24452,
37311,    0,    0,78101, 2899,13380, 2400,33003,13404,13994,
78101,78101,33617,37914,34231,34845, 2406,78101, 3290, 3291,
25066,14018, 4386, 4438,14608,14632,15222,15246,15836,15860,
16450,16474,17064,17088,17678,17702,    0,    0,    0,    0,
    0,    0,    0,    0,78101, 2711,83125,78101, 2711,78101,
 3293,78101, 3294,    0, 2410,    0,    0, 2852,    0,    0,
 2011, 2917, 2918, 2920, 2922, 2924, 2929, 2942,    0,    0,
 1690, 1655, 1743,    0,    0,    0,    0,  183,97356,    0,
103251,85113,    0,    0, 1826,    0,    0,    0,    0,99321,
99321,99321,99321,99321,99321,99321,    0,    0,    0,    0,
  539, 2823,    0, 2919,    0, 2919,    0,    0, 2940, 1034,
    0,    0, 2944, 1739,85113, 3074, 3026,    0,    0,    0,
 2983,    0,    0,    0,    0,    0,    0,    0,99321,    0,
 3019,78101,    0,    0,    0, 2776, 2776,    0, 3927, 3927,
    0,97749, 3013,    0, 3054, 3327,25680,    0, 3331, 3075,
    0,87867,    0,    0, 1368,    0,    0, 2990, 2883, 2801,
 3077,    0,78101, 2990,    0,    0,    0, 2852,  -73,    0,
99321,    0,    0,    0,91068,    0,    0,    0,    0,    0,
 3014, 1034, 3017,99321, 3104, 3092, 2547,91461, 2855,    0,
    0,    0, 3348,    0, 2964, 3063, 2969, 3101, 3066, 3103,
    0,    0,    0,    0,    0,99321, 2755, 3086,99321, 3086,
 3107,    0,  605,    0, 2703, 1034,    0, 1707,    0,    0,
    0,    0,    0, 3371,    0,    0, 3012, 3006, 3373, 2852,
    0,    0,    0,    0,    0,    0, 2721, 1835,    0,    0,
    0,    0,96570, 2011, 2043,    0, 2011, 2043,    0,    0,
 2984,    0, 2985,99321,    0,    0,    0, 3375,    0,    0,
 2411,    0,    0,    0,85507, 2415, 3396,    0,    0, 3399,
  876,    0,    0, 3069,94605,98142,    0,    0,    0,    0,
    0,78101, 3401,78101,    0,78101,  113,    0,    0,78101,
    0,    0,18292,18316,78101,78101,78101,78101,78101,    0,
25680,    0,    0,78101, 3126,78101,    0,78101,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2711,78101, 2711,    0, 2568,    0,    0,
99321, 3383,99321, 2544,    0,    0,    0,    0,    0,    0,
    0,  239,92640,  239,    0, 2973,    0, 2974,    0,    0,
    0,    0,    0, 3000,    0,  -11,99321,    0,    0,    0,
 1680,    0,    0,    0,78101, 3408,    0,    0,99321, 3405,
 3136, 3137, 3138, 3140, 3145, 3146, 3147,    0,    0,  152,
  600,    0,    0, 3035,    0,    0,    0,99321,    0,    0,
 3427,    0, 2394,78101,78101, 2027,    0,    0,    0,99321,
    0, 3428, 3073,    0,    0,    0,99321,    0,    0, 3430,
78101,79357, 3060,87474, 2990,    0,    0,    0,    0,78101,
78101, 3158,    0,87474,    0, 3433,99321,  232, 2854,    0,
    0,    0, 1226, 3104, 2855,    0,  532,    0, 3202,    0,
 3141,    0, 3148,    0,    0,    0,    0,    0,  -32,    0,
 3220,78101,    0,    0,    0,    0,    0,    0,    0,  -60,
99321,    0, 3086,    0,    0,  605, 3212, 3149,    0,    0,
 1835,    0,    0,    0, 3048,    0,    0,    0,    0,   74,
 2530,    0,    0,    0,    0,    0, 2780,    0,    0,    0,
 2544,    0, 2544,    0,    0,    0,    0,    0, 1707,    0,
    0, 3125,    0,    0, 2875, 3454,    0,    0, 3192, 5371,
28089, 1034,  863,    0,    0, 1707, 2641,    0,    0, 2438,
    0,93033,    0,99321,    0,25680,    0,18906,25680, 3087,
78101,78101, 3196,18930,    0,    0,19520,19544,20134,25680,
 4496, 4522, 1662,    0,20158,20748, 2711,    0, 3450, 2448,
    0, 2852,    0,    0,    0,    0,    0,    0,    0,    0,
 3195,    0,  -11,99321,99321,99321,99321,99321,99321,103644,
103644,    0,    0,    0,  -11, 3151,97356,    0, 3244,    0,
97356,    0,    0, 1739, 3090,    0,99321,    0,    0,    0,
    0,    0,    0,    0,    0,  153,  153,    0,    0, 3475,
    0, 3213,    0,78101, 3482,    0,25680,    0,    0,    0,
    0,    0,90282, 2671, 3483, 2387, 2463,71821,    0,25680,
87474,    0,25680,25680,99321,  550,  965,    0, 2965, 3231,
    0,    0,    0, 3198, 3203, 1871,    0,    0, 3268,    0,
    0,    0,    0,    0,    0,    0,20772,    0,    0,    0,
    0,93426,    0, 3131, 1707,    0,    0,   74, 3201,    0,
    0,    0,    0, 2780,    0,    0,    0, 2467,98535, 3495,
 1707,    0,    0, 3264,    0,78101, 5371, 1707, 1034,   44,
    0,    0, 3506,    0,    0,    0,94605,    0,    0,    0,
    0,    0,    0, 3503,    0,78101,    0, 3135,    0,    0,
    0,    0,    0,78101,    0,78101,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  239,  239,  239,  239,  239,
  239,  239, 3190,92640,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3090,
  -49,    0,    0, 2490,    0,    0,    0,    0,    0,    0,
    0,    0,    0,99321,  864,99321,    0, 2503,78101,    0,
    0, 2852, 3297,99321, 3522,    0,21362,    0, 3265, 2965,
87474,    0,    0,99321,99321,  190, 3122,    0, 3270, 3302,
    0,87474, 1871, 1871, 3089, 3278,    0,    0,    0,94998,
    0,    0,    0,98928,    0,99321,    0,    0,    0,    0,
    0,99321,    0, 3515,    0,    0,    0,    0,    0,  982,
  506,21386, 3536, 3221,    0,   41,    0,    0, 3006,    0,
 3542,99321,99321,    0,78101,25680,21976,99321,  -11,  -11,
  -11,  -11,  -11,  -11,  -11,    0,    0,    0,    0,    0,
 3024,    0,    0,  153,  153,  153,  153,  153,  153,  153,
    0,    0,    0,  568,    0,    0,    0,    0,   21,  -73,
 2011,    0,    0, 3547,    0,    0,87474,    0,    0,  965,
    0,    0,    0,    0,    0,87474, 3301,    0,    0,    0,
    0, 3207, 3089, 1472,    0, 3329,    0,    0,    0,    0,
    0,    0, 3093,98535,    0, 1707,    0, 3027,  537,  925,
 3018,    0,    0,    0, 3099, 3106,    0,    0, 1707,    0,
 3155,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3044,   21, 3105,
 3338,    0, 3343, 2544,    0,    0,  635,    0,    0,    0,
99321,99321,    0, 3281, 2986, 2852,    0, 2852,99321,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,99321, 3283,    0,   64,    0, 1739,    0, 2703, 3233,
 2703, 2011,    0,    0,  635, 3182, 3305,78101, 1710,78101,
    0,    0, 1871,99321, 3577,    0,    0, 3339,    0,    0,
 2505,    0, 3581,    0,   67,78101,  633,    0, 2220,    0,
 1835,    0,    0, 2544, 2507, 2524,78101,    0,78101,79985,
25680, 3206, 3241, 3214,25680, 3260,    0, 1384,    0, 3339,
    0,    0,99321,    0,    0,78101, 3303,    0, 3217,    0,
 3235,    0,    0,    0,    0,    0,    0,    0,    0,    0,
25680, 3033,    0,25680, 3029,25680,    0,    0,    0,  685,
 3089, 3271, 3272, 3600,    0, 1230,    0,99321, 3227,    0,
  689,99321,99321,78101,78101,78101,   -7,   -7,    0, 3350,
    0, 3222,    0,    0, 3317,99321, 3089,    0,    0,    0,
 2529, 3325,    0,    0, 3256, 3612,    0,    0,25680,25680,
 3215,  606,    0,    0,    0, 3089, 1871,    0,    0,    0,
 3234,99321,    0,    0,    0,    0, 3260,    0, 3618, 3612,
 3089, 3238,78101,    0, 3622, 2555,78101,    0, 2566,    0,
};
static int yyrindex[] = {                                   3273,
    0,  285, 1541,    0,    0,    0,    0,    0,    0,    0,
    0,  208,    0,    0,    0,    0,    0,    0,    0,    0,
 3667,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  327,    0,    0,  477,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  322,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 3342,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  322,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,67232,    0,    0,    0, 3277,    0, 3404,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1076,76217,  514,    0,
    0,    0,  485,    0,  403,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  173,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  262,    0,    0,  403,    0,
    0,    0, 3415,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  376,    0,    0,    0,    0,    0,    0,
    0,    0,28130,    0,    0,    0,    0,    0,  177,    0,
    0,    0,    0,    0,   30,    0, 3632,    0, 1037,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 3418,    0,    0,    0,    0,    0,    0,    0,    0,
  509,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  889,    0,    0,  918,    0,    0,    0,    0,    0,    0,
    0, 1054,    0,  220,    0, 4953,    0,91854,    0,    0,
92247,100893,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3284,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3418,    0, 1255,    0,    0,
    0,    0,    0,    0,101286,    0,    0,    0,101679,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  857,    0,    0,    0,    0,76845,69937,
    0,    0, 3285,  609, 1300, 3273,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  324, 3416,    0,
 1489,    0,  172,    0, 1567,    0,    0, 3416, 1489,    0,
    0,    0,    0,  570,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1567,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1851,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  470, 1300,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,39964,    0,    0,    0,
    0,    0,    0,    0,    0,    0,40578,    0,    0,    0,
    0, 6808,    0,    0,    0,    0,    0, 5580, 6194,    0,
    0,    0,    0,37508,    0,    0,    0,41192,41806,    0,
    0,    0,    0,42420,43034,    0,    0,    0,    0,    0,
    0, 7422, 8036, 8650, 9264, 9878,10492,11106,11720,12334,
12948,13562,14176,14790,15404,16018,16632,38122,38736,43648,
17246,17860,18474,19088,44262,19702,20316,20930,21544,22158,
22772,23386,39350,24000,24614,25228,25842,26456,27070,27684,
28298,28912,29526,30140,30754,31368,31982,32596,33210,33824,
34438,35052,35666,36280,36894,44876,45490,46104,46718,47332,
47946,48560,49174,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3273,    0,    0,    0,
 1575,51635,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  967,56547,    0,    0,
    0,    0,  237,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,49788,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,50407,    0,  564,    0, 2639,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1407,
    0,  509,    0,    0,    0,    0, 2477,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3355,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  325,    0,    0,    0, 1300,    0,    0,    0,    0,
  260,    0,    0,    0, 1606,102072,    0, 3422,    0,    0,
    0,    0,    0, 3298,    0,  224,    0,    0,    0, 1008,
    0,    0,    0,    0, 1084,    0,    0,    0, 3273,    0,
    0,    0,    0, 3391, 2335, 3824, 3127,    0,    0,    0,
 3200,    0,    0, 3479,    0,    0, 3527,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  927,    0,    0,    0,
 2085,    0,    0, 2218,    0,    0,    0, 3788, 3279,    0,
 3527,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  403,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1037,    0, 1162,
    0,  546,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3273,    0, 1635,
 3657,  204,    0,    0,    0,    0,    0,80613,    0,80613,
    0, 3273,    0,    0,80613,80613,64336, 3658, 3273,80613,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3275,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,80613,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 3273,52863,53477,    0,    0,    0,35459,36073,    0,
    0,    0,51021,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,81241,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 3658,    0,    0,    0,  220,    0,
    0, 5381,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3273, 3365,    0,    0,    0,    0,    0,    0,
    0,65599,    0,    0,    0,    0, 2639,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  470, 1300,
    0,    0,    0,    0, 3273,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  993,    0,    0,    0,
    0, 3387,    0,    0,67628,    0,  707,    0,  313,    0,
    0,  990,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1627,    0,    0,    0,    0,  546,    0,
 3362,    0,    0,    0,    0,    0,    0,    0,  565,    0,
    0,    0,    0,    0,    0,    0,    0,  637,    0,    0,
    0,    0,    0,102465,    0,    0,    0,    0,    0,    0,
 1633,    0, 1109, 1154, 1416,    0,    0, 1669,  546,    0,
    0, 1708,    0,    0,    0,    0,    0,    0, 3402,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3479,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1567,    0,    0,    0,    0,  246,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1361,    0,
    0,    0,    0,    0,    0,    0, 3403,    0,27475,    0,
    0,    0,    0,    0,    0,    0, 3664,    0,    0,    0,
  207,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2572,    0, 3666,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,88475,88486,88545,88752,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1756,    0,    0,
    0,64757, 3273,    0,57161, 3273,    0,    0,    0,    0,
    0,    0,    0,62073,    0,    0,    0,    0,    0,65178,
    0,    0,    0,    0,    0,    0,57775,58389,    0,52249,
55319,55933,54091,54705, 1521,  391,    0,    0,    0,    0,
    0,    0, 1575,    0, 3447,38500,38538,102858,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3344,29327, 3425,    0,    0,
    0,    0,    0,    0, 3365, 2352, 3381,    0, 3381, 3365,
    0, 3381,    0,    0,    0,66427,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2348,    0,
    0,    0,  204,    0, 1455,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  774,    0,
    0,    0,    0,  810,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  897,    0,    0,    0,    0, 3432,89889, 2292,    0, 2308,
 2106,    0,    0, 2338, 2378, 2474,    0,    0,    0, 2482,
    0,    0,    0,    0,    0, 1358,    0,    0,    0,    0,
    0,    0,    0,    0, 3669,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2456,    0,    0,    0,    0,    0,    0, 1103,    0,    0,
89478,    0,    0,    0,    0,    0,    0,    0, 3416, 1489,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  200, 2615,    0,    0,    0,    0, 3860,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1538,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 3292,    0,    0, 1611,    0,    0,    0,
 3416,    0, 1489,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1809,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1961,    0, 1780, 1157,    0,
  453,    0,    0,    0,    0, 3403,    0, 3423,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1300,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  896,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3684, 3684,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,26908,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,62687,
    0,59003,63301, 3273,    0, 3691,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  255,39114,
    0,  840,    0,  231,    0,  231,    0,    0,    0,    0,
    0,66017,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,65599,    0,102858,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3262,    0,    0,    0,
    0,    0,    0,    0,    0,  203,  207,    0,    0,    0,
 1120, 1387,    0, 1088,    0,    0,    0,    0,    0,    0,
 1053,    0,    0, 1825,    0, 1300,    0,    0,    0, 1780,
    0,    0,  292,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 3386,    0,    0,    0, 3674,    0, 1327,    0,  213,    0,
    0,    0,    0,    0,    0, 3676,    0,    0,    0, 3677,
    0,    0,    0,    0,    0, 3679,    0,    0, 3681,    0,
    0,    0,    0, 3438,    0,    0,    0, 3273,    0,    0,
    0,    0,    0,    0,  158,    0,    0, 1441,    0,    0,
 1808,    0,    0,    0, 1378, 1451, 1597, 1598, 1666, 1696,
 1846,    0,    0, 1780,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 3292, 3292,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 3889,    0,    0,    0, 1059,    0,
    0,    0,    0, 2999,    0,    0,    0,    0,    0,  546,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3349,    0,    0,    0,
    0,    0,    0, 3705,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 3273,    0,    0,    0,    0, 3706,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,59617,    0,    0,63915,    0,
    0,    0,    0,    0,    0,    0,    0, 3687,    0,    0,
 3416,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  202,    0,    0,
 2296,    0,    0,    0, 3365,    0,    0,66837,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  698,    0,  698,    0,    0, 3379,    0,
    0,    0,    0, 1300,    0,    0,  359,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  364,    0,    0,    0,    0, 3298,  741,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3694,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  817,    0,    0,
    0,    0,    0, 3698,    0,    0,    0,  980, 1160,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 3718,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1850,    0, 3446,    0, 3446,
    0,  271,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 4053,    0, 1883,
    0,    0,    0,    0,    0,    0,    0,  429,  497,    0,
    0,    0, 1441, 3416, 1489,    0, 3416, 1489,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1156,
    0,    0,    0,    0,    0,    0,27516,    0,    0,    0,
  357,    0,    0,    0, 3657,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3458,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 3723,    0,    0,    0, 3152,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,60231,    0,60845,    0,  409,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  205,    0,  205,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1910,    0,    0,    0,    0,
 2622,    0,    0,    0,    0,    0,    0,    0,    0, 1922,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1910,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1904,    0,    0,  730,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1058,  924,    0,    0,    0,    0,    0,
    0,    0,    0, 1058,    0,    0,    0, 2593,    0,    0,
    0,    0,    0, 2422, 3354,    0, 4779,    0, 4766,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1820,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3446,
    0,    0, 3446,    0,    0,    0,    0,    0,    0,    0,
 3085,    0,    0,    0,    0,    0,    0,    0, 1163,    0,
 1780,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1928,    0,    0, 1949,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,83536,83930,    0,    0,
    0,    0,    0,    0,    0, 3724,    0,    0, 3359,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2597,
    0,    0,    0,    0,    0,    0,61459,    0,    0,    0,
    0, 2599,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1910,    0,    0,    0,    0,    0,    0,  242,
  382,    0,    0,    0, 1910,    0,    0,    0,    0,    0,
    0,    0,    0,  199,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1910, 1910,    0,    0, 3429,
    0, 3814,    0,    0, 2263,    0, 1934,    0,    0, 1134,
    0,    0,    0, 3447,    0, 3273,    0, 3273,    0, 1127,
 1058,    0, 3459, 3462,    0,    0,    0,    0, 3508,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1953,    0,    0,    0,    0,    0,    0,
 1977, 1438,    0,    0,    0,    0,    0,    0,    0,  256,
    0,    0,    0,    0,    0,    0, 3657,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  205,  205,  205,  205,  205,
  205,  205,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  973,    0,    0,    0,    0,    0,
    0,   70,    0,    0,    0,    0,    0, 1486,86688, 3679,
 1058,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 3480, 1058,    0,    0, 1902,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  263,    0,
    0,    0,    0,    0,    0, 2606,    0,    0, 1910, 1910,
 1910, 1910, 1910, 1910, 1910,    0,    0,    0,    0,    0,
    0,    0,    0, 1910, 1910, 1910, 1910, 1910, 1910, 1910,
    0,    0,    0,    0,    0,    0,    0, 1315,    0, 3520,
 3416,    0,    0,    0,    0,    0, 1058,    0,    0,    0,
    0,    0,    0,    0,    0, 1058,    0,    0,    0,    0,
    0,    0, 1902, 3342,    0,    0, 5967, 5967,    0,    0,
    0,    0,  333,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  452,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  223,    0, 3292,
 3351,    0,    0,    0,    0, 1804,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2188,    0, 2188,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2610,    0,    0,    0, 1300,    0,    0, 3352,
    0, 3416,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  610,    0, 6581,    0, 7195, 1675,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1821,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1881,    0,    0,    0, 1976,  352,    0,    0,    0, 1675,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2616,    0, 4244, 2050,88906, 2221,    0,    0,    0,    0,
 1902, 4234, 4643,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 7809,    0,    0,    0,
    0,    0,  203,    0,    0,  209,    0,    0, 2629, 2222,
    0,    0,    0,    0,    0, 7809, 4067,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 4683,  203,    0,  222,
 7809,    0,    0,    0,    0,    0,    0,    0,    0,    0,
};
static int yycindex[] = {                                      0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 3276,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1789,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3154,    0,    0,
  -45,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3314,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3751,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3752,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3758, 3760,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  823,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 3497,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  547,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1623,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 3762,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3501,
    0,    0, 3504,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3767,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 3549,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 3451,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  886,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 3511,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 3300,    0,    0,    0,    0,    0,    0,  604,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 3457,    0, 3463,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 3776,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 3282,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3242,
 3246,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 3781,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 3576,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3795,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
};
static int yygindex[] = {                                      0,
    0,    0,    0,    0,    0,    0, 2178, 2557,    0, 2558,
 2559, 1467, 2564,    0, 1468, 2570,    0, 1469,-1030,    0,
 2042,  962,    0,    0,    0,    0,-2150,  820,  821, 2571,
 1795, 1449,  974,    0,    0,    0,-2526,    0, 1582, 1048,
    0,    0,  885,    0,    0, 2401,    0,    0,    0,    0,
    0,    0, 3525,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1079,    0,    0,    0,  909,-1574, 1131,-1675,
  192,    0,  543, -540, 3179,    0, 3810, 1693,    0,    0,
 -886,    0,    0,    0,    0,    0,  770,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1679,    0,    0, 1114,
-1975,    0,    0,  644, 3540, 2921,    0,    0, 1625, 1102,
 1344,    0,    0,-1942,    0,-2054,    0, -116,  704,    0,
  567,    0, 1356,-1545,    0,-1540,  481,  538,  541,  522,
   89,-1607,-1510,-1183,    0,    0, -966,-1685,    0, 1180,
    0,  776,-1322, 1182,   94,-1489,-1487,-1167,  745, -444,
 -638,    0,    0,   80,    0, 2466,-1180,    0,    0, 3318,
 2009,    0, 2014, -659,    0, 2901,    0,    0,    0,    0,
-1645,-1012,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,-2636,  987, 1760, 1761,    0,    0,    0,
  551,    0,  556,    0,    0,  640,    0,    0,    0,    0,
 -924,-1426,    0,    0,    0,    0, 2191,    0,  851,    0,
 1769,    0,  764,    0,    0,    0,    0,    0, 3945, 2693,
 2334,    0,    0,    0, 1313,  102,    0,    0,    0, -117,
    0, -342, 2518,    0, 2048,    0, 3286, 2840, -963,    0,
    0,    0,    0, 2237,    0, 1776,    0, 2160,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2617,    0,    0,
    0,    0,    0,    0,-1751,-1662,    0,    0, -657,    0,
 2545, 1736,-2126, -650,    0,    0,    0,-2089,    0, -648,
    0, 2880,    0, 2574,    0,    0,    0,    0,    0,    0,
    0, 3838,    0,    0,    0,    0, 1892,    0, 1569,    0,
 1565,    0,    0,    0,  922,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 3001, 3356, -835,    4,    0,    0,
    0, -512,    0, 3642, 3397,-1418,    0,    0, 1068,    0,
    0,    0, 3353,    0,    0,    0, 2300, -852,    0,    0,
-1156,-1679,    0,    0, 1324,    0, 2723,    0,    0,    0,
    0,    0,    0, 1927, 1588,  121, 2354,    0,    0,  933,
    0, -806,-1222, 2865,    0, 1013,    0,    0,  630,    0,
 -996,    0, 2318,-1297,    0,    0, 3368, 1930,    0,    0,
 4028,    0, 4029,    0,  981,  983,    0,    0, 4032,    0,
    0, 4034,    0,    0, 4035,    0, -721,    0, 3076,-3003,
 -588,    0,-1924,-2350, -985,-2006,  718,    0,-1130, -525,
-1192,-1131, -848,    0,    0,    0,    0,    0,    0,    0,
-1425,    0, 2806,    0,    0,    0,    0,    0,    0, 2461,
    0,    0,    0,    0,    0,-1205,    0, 1781,-1952,    0,
  844, 3326, 3367, 2618, 3315, -561, -283,    0,  954,    0,
    0,-1625,-1733,    0, 2024, -749, 2353,    0,-1056,-1290,
    0,    0,    0, 2802, -849, -847, 2722, -964, -926, -625,
-1279,-1274,-1272,  -70,  -59,-1717, -707,    0,  -97, 1273,
-1226, -601,    0,-1335,    0,    0,    0,    0,    0,    0,
 2084,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,-1328,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1218,    0,-1854,    0,    0,
 -939,-1268,    0, -100, 1839, -692, -114,    5, 1585,-1401,
    0,  -57, 3950,    0,   55,  -51,-1027,  146, -460,  -99,
  -52,   10,    9,  -50,  -53,-2969, 1194, -182,   43,  -14,
    0,    0, 3944,    0, 2000,  338,  -35,    0,    0, 2810,
  316,    0,    0,    0,    0,  383, 1676,    0, -876,-2385,
    0, 2947,    0,-1219,-1188,-2205,    0,    0,    0,    0,
   95, -349, 1506,    0,    0,-2077,-2583,    0,    0,    0,
-1990,    0,  710,    0,    0,-1346,    0,    0,    0,    0,
 -571,    0,-1659,    0,-2028,    0,    0,    0, 2179,    0,
    0,    0,    0,    0,  992,    0,    0,    0,  826,  753,
 1612,    0,    0,    0,    0,    0,    0,  127, 1388,    0,
    0,    0,    0,-2237,-1424,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3064,    0,    0, 3094,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 4097,    0,    0,    0, -732,    0,    0,    0,    0,
 1142,-1202, 1042,    0,    0,    0,    0,  891,    0,    0,
-1500,    0,    0,    0, 1436,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  830,    0,    0, -685,-1622,
 -315,    0,    0,    0,    0,    0,    0,-1303,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,
};
#define YYTABLESIZE 104686
static int yytable[] = {                                     343,
  349,  963,  362,   46, 1317,  460,  569, 1143, 1038,  557,
  510,  995,  998,  560, 1369,  474,  561,  489, 1134,  486,
  495,  511,  342, 1123,  348, 1379,  574, 1220, 1218, 1122,
 1039, 1694, 1788, 1078,  669,  996,  999, 1506,  531, 1789,
 1081,  534, 1084, 1513, 1731, 1338, 2132,  458,  461,  554,
  469,  472,  475,  482,  343,  487,  490,  343,  496,  472,
  559, 1925,  503,  564,  964,  563,  567,  514,  461,  469,
  472, 1272,  482, 1380,  343,  487, 1673,  490,  343,  496,
  472,  538, 1022, 1339,  503, 1335,  513, 2120,  550, 2423,
  343,  553,  461, 1569,  550,  469,  472,  475,  482, 2312,
  343,  487,  490,  566,  496,  472,  538, 1911, 2221,  503,
 2173,  576, 2186,  342,  343,  343, 1645, 1055,  472,  502,
  471,  587, 1691,  562, 1833, 1213, 1214, 1219,  471, 2386,
 2479, 2387, 2185, 1016,  341, 1835, 2525, 2526,  342, 2004,
 1836,  502, 1837, 1710, 2544, 1471, 1838, 2438, 1376, 2137,
 1048, 1797, 1913, 1093, 1708, 1299, 1444, 2010, 1127, 2018,
 1343, 2583, 1337, 2213, 2643,  558,  573, 2435,  575,  984,
  986,  282,  284,  675,  568,  521,  271,  517,  543, 2272,
  608, 2296, 2520, 1811, 1831, 1794,  714,  584, 2204,  483,
  718, 1842,  541, 1842,  532, 2665, 2872, 2966, 1308,  336,
 1610,   94, 2113, 1241,   92, 1427, 1255, 1036, 1285,  527,
  994, 1298, 1641, 1819,   13,  282,  396,  571, 1821,  651,
  735, 1286, 1305, 1796, 2814,  341, 2665, 1296, 1818, 2654,
  282,  284,  997,  879, 1131,  271,  652,  602, 2541, 1923,
 1291, 1777, 1325, 1530, 1531,  246, 1858, 2495, 2680,  579,
  341, 2512, 2888,  955, 1826,  879,  955, 1308,  336,  764,
   94,  678, 1241,   92, 2771, 1255, 1036, 1285,  276, 2737,
  337,  955, 2209,  955, 1319, 1677,  731, 2114,  651, 2887,
 1286, 1305, 2872, 1423, 1036, 1777,  535,  737, 1975, 1218,
 2739,  910, 2450, 2990, 1346,  652,  173, 2040,   90, 1567,
 1777, 2412, 3090,  995,  246, 1583,  995, 2276, 1488, 1705,
 2041,  241, 1246, 2642, 3151, 1715, 3126,  951,  764, 1420,
  678, 1038, 1262,  900, 1263, 3316, 1121,  708, 3346,  337,
  349, 1009,  341,  396, 1349,  461,  469,  472,  482,  343,
  487,  343,  472, 1036,  503, 2164, 2165, 2166,  362, 2130,
  910,  430, 1429, 1246,  348, 3411, 1246, 3362, 1209,  650,
 1389,  658, 1698,  921, 1215, 1263, 1859, 1121, 3250, 1263,
  504, 1246, 2821, 2200, 1413, 1040, 1571, 1957, 3406, 2469,
 1038, 1952,  900, 1263, 1340, 1121, 2198, 3220, 1219,  656,
 2394,  341,  430, 3412, 2032,  430,  582,  163, 2196, 1209,
  163,  502, 1411, 2517, 2277, 1488, 1609, 2201, 2037, 1718,
  430, 1272,  709, 3362, 2841, 2888, 2888, 1209, 3430, 1396,
 1788,  396,  921, 2738, 2273, 1952, 2274, 1789,  357, 1430,
  105, 1605, 3251,  396, 1040, 1569, 1414, 2969,  607, 3413,
 1952,  600,  952, 3178,  598,  692,  725,  469, 2786, 1606,
 1338,  737,  296, 2073,  730, 2443, 1503,  603, 1504, 2595,
 2990, 1411, 1560, 1716, 1048,   94, 2413,  396,   92, 1213,
 2401, 1679,  241,  241,  527, 1680,  955,  659, 1575, 2038,
 1685, 3317, 1010, 1402, 3347, 2788, 3034,  357, 1339,  955,
 1397, 3127,  175, 2197,  317, 1706,  248, 2042, 1600, 1601,
 1602, 1603, 1604, 1419, 2534, 1777, 2535,  955, 1211,   15,
 3152,  296, 1699, 1241, 3221, 2199, 1266,  326, 2499, 2068,
  678,  396,  955,  660, 1325,  678, 2449,  503, 1213,  326,
  678, 2102,  469,  959, 1641,  995, 1392, 2906, 2907,  317,
  469, 2402, 2746,  599,   90, 1413, 2842, 2780,  604,  910,
 2790,  732, 1860, 2740, 1241,  248,  738,  503, 1974,  173,
  326,  910,  326, 1670,  779,  326,  995, 1211,  982,  927,
  475,  678, 1241, 1569, 2184,  967, 1246,  349, 1674,  349,
  972, 2889, 1102, 2351,  722,  246, 2958, 1640, 1263, 1972,
 1121,  503,  910, 3082,  910, 3095,   15, 1704, 1319,  966,
 1036,  968,  727,  348, 1413, 2361,  995,  490, 1259, 1319,
  326, 2431,  993,  651,  739,  985,  985,  985,  985, 2664,
  993,  921, 1209,  779, 1246, 1215, 1036,  341,  927, 1324,
  652,  522, 1276,  921,  993, 1610, 1263,  993, 1095, 1479,
  510, 1567, 1285,  678, 1246, 1952, 1489, 1105,  722, 1259,
 1319, 1116, 1825, 1319, 2016, 1286, 1263,  995, 1121, 1411,
  326,  514, 1290, 2106,  921,  276,  921, 1259, 1319,  738,
 1209, 1129,  341, 1422, 2276, 2871, 2097, 1036, 1777, 1808,
  900,  461,  469,  472,  482,  487,  490,  343,  472, 1668,
 1209,  503,  910, 2583, 2583,  317,  396, 1072,  343, 1215,
 1829,  650,  343, 1241, 1264,  738, 1242, 2039,  475, 1672,
  995, 1136, 2673, 3026, 3027, 3028, 3029, 3030, 3031, 3032,
  738, 1118, 1241, 1411, 2008, 1255, 2011, 1285, 1411, 1213,
 1209, 2278, 2285, 2748, 1477, 1821, 2518, 3353, 1338, 1209,
 1286, 1305, 3192, 3193, 2889, 2889, 2275, 1242,  502, 1246,
 2468,  163, 1099, 2474, 1134,  175, 1072, 1099, 1719, 1433,
 1644, 1263, 1605, 1121,  921, 1242,  326, 1910,  357, 2403,
 1213, 2277,  964, 1211, 1289, 1439, 1339, 1241, 1335, 1567,
 1606, 1209, 1411, 2013,  396, 1111, 2519, 1100, 1213, 1432,
 1096, 2273, 1678, 2274,   94, 1209, 1246,   92, 1411, 1110,
 2780, 3215, 1402, 1106, 2081, 2072, 2952, 3025, 2153, 1249,
   43, 1246, 1246, 2792, 1211,  296, 2955, 3138, 1952,  282,
  284,  964,  781, 1219,  271, 1241, 1415,  659,  341, 2014,
 1824, 1246, 1211,  927,  430, 1575,  249, 1125, 2973,  955,
 3176, 1213,  964, 1263, 1259, 1241, 2099, 2100, 3081, 1282,
 1249, 1681, 2115, 1249, 1684, 1337, 1123, 1209, 1209, 2391,
 2583, 2478, 2776, 1223, 1812,  781, 1402,   91, 1249,  326,
  326, 1402, 1259, 1853, 2349,  574, 1266, 1209, 2414,  927,
 1211,  126, 2104,   91, 1324, 1411, 2589, 1221,  950, 1211,
 1850, 3071,   79, 2247, 2774,  296,  296, 1123, 3296, 2777,
 3424,  910,  910, 1266, 3154, 3155, 3156, 3157, 3158, 3159,
 3160, 1324,  510, 1266, 2395, 1123, 1914,  945, 1507, 1508,
 1259, 1324, 2757, 2791, 2434, 1402,  266, 2691, 3350,  482,
 2514, 2633,  296,  129,  576, 1579, 2805, 2547, 3257,  523,
 1259, 1402,  362, 1810, 2122, 2087,  343,  950,  610, 3425,
 1241,  927, 1000,  510, 2515,  396, 3245,  396,  659,  343,
  510,  510, 2239, 1246, 1361,  781, 1514,  126,  133, 1213,
 1242, 1372, 1373,  921,  921,  514,  945, 1319,  296,  679,
 3387, 1580,  569,  781, 3404,  266, 3007, 1915, 1213, 1253,
 1476, 1283, 1124, 1213, 1411,  127, 1411, 1411, 2438, 1863,
 2539, 1581, 3297, 1842,  451, 2543, 3246, 1514, 1211, 1209,
 1514, 1326, 1241, 1241, 3298, 1371,  781, 3170, 1242,  296,
  396, 2416,  130,  396, 1428, 1514, 2459, 1211, 1402, 2363,
 1253, 1072, 1241, 1124, 2546, 2725, 1129, 1211, 1242, 3222,
  396, 1213, 3169,  510,  510, 1259, 1569, 1411, 1253, 1569,
 1509, 1124, 1254, 1944, 1436, 1437, 3327, 3351,  256, 1514,
 1215, 1213,  134, 1215, 2154,   45,  451, 2947, 2139,  135,
 2157, 3299,  610, 1249,  363, 1125, 3216, 1340, 2932,  680,
 2348, 1297, 2949,  751, 3300, 1211, 1072, 1204, 2938, 1072,
 3273, 2210, 1319, 1254, 1125, 1211, 1211, 2281, 1251,  136,
 2778, 1213,  364, 1252, 1072, 1211,   34, 1259,  738, 3388,
 2317, 1254, 1944, 3405, 3274,  574, 1125,  256, 1134, 1164,
 1123, 1249,   93, 2404,  855,  856, 2015, 1259, 1204,   91,
 1072, 1472, 1599,  347, 1125,  451, 2405, 1402,  472, 1402,
 1402, 1249,  751, 1242, 2959, 1211, 1204, 2961, 2823, 2202,
 2233, 3134, 1213,  736, 1211,  299, 1414, 1612, 1833, 1833,
 1164,  454,  257, 2170, 1241, 2240, 1213,  738, 2282, 1835,
 1835, 2203, 3289, 1282, 1836, 1836, 1837, 1837, 1164, 2365,
 1838, 1838, 1383, 2389, 1072,  576,   81,  569, 1123, 2511,
 1413,  396,  347,  659, 1668, 2679, 1211, 1723, 1723,  365,
 1115, 2248,  266,  266, 1072, 1242, 1242, 1480, 2291,  967,
 1211, 3306,  736, 3309,  299, 1414, 1384, 1072,  472, 2824,
 1253,  257,  569, 2811, 2250, 1242,  964, 3083, 1213, 1213,
  964, 2178,  538, 1570,   37, 2556,  510, 1042, 3073,  660,
  510, 1364,  514,  469, 1465,  510, 1249, 1043, 1213, 1333,
 2212, 3162, 1567, 1253, 1029, 1567, 1124,  496,  576, 1575,
 3072, 1611, 1334, 1729, 1466, 1730, 3163,  879, 2703, 2007,
 3084,  451, 1211, 1211,  396, 1078,  855,  856, 1582,  666,
 3226, 3085, 1081,  967, 1084, 3079,   81,  514,  972, 1440,
  266,  510, 1211, 1123,  672,  678,  668,  985,  137, 1308,
  985, 1253, 1728,  506,  507,  678, 1676,  966, 1249, 1249,
 2712, 1385, 1365, 1029,  348, 1283, 1254,  451, 1467, 1697,
 2862, 1253,  366, 2406, 1124, 1846, 1847, 1848, 1249, 1723,
 2230, 1569,  967, 1247,  254,  256, 2994, 1248, 1514, 1125,
  368, 2736,  660, 2414, 3208,  372, 1119,  751,  667,  469,
  482, 1204, 1737, 1791, 1366, 2179,  966, 1242, 1308,  374,
 1514, 1075, 1861,  673, 1254, 2995,  454, 1778, 3184,  610,
 1778, 1735,  738,  348, 3086,  514,  375,  966, 3336, 2231,
 1213,  469,  482, 1164, 1254, 1778, 1165, 1778, 1788, 2133,
  576,  347,  462,  751, 2433, 1789, 3421, 1800, 1788, 1204,
 1801, 2134,  451,  347,  678, 1789, 1047, 1125,  660, 1441,
 1204, 1075,  454, 1416, 2478,  737, 1442,  736,  738, 1204,
  738, 3432,  254,  472, 1211,  751, 1253, 1165,  347, 1124,
 1165, 1164, 2495, 2415,  347, 3179,  347,  300,  259,  257,
 1802, 1164, 1164,  343,  498, 1165, 3191, 1136, 1926, 2491,
  743, 1164,  504, 2496, 1316, 2011, 1218, 1129,  576, 1204,
 1249, 3209, 1468,  736, 2983, 1047, 1862,  520, 1204,  472,
 2135,  751, 1415,  347,  737,  522,  738, 1416, 3275, 2713,
 2714,  345, 1416, 2919, 1338, 1338, 2416, 3204,  477, 1254,
  738, 1164, 3427,  610,  576,  743,  300, 2130, 1316,  472,
 1164, 2130, 3276, 2417, 2131, 2130,  576, 3210, 1253,  743,
 1204, 1215, 2638, 1316, 1134, 1351, 1134,  547,  292,  642,
 1515,  736, 1339, 1339, 1204, 2440,  259, 1352, 2230,  751,
 2492, 3258, 2389, 3080,  347,  736, 1416, 1567, 2944,  555,
 3260, 2136, 1164, 2896,  586,  345, 1585,  477, 3211, 2493,
  514,  967, 1416, 2497, 1164, 1219, 1164, 2074, 1353, 1229,
 1354, 1515,  668,  576, 1515,  570,  274, 2494, 1962, 2003,
  643, 1254,  348, 2918,  654, 1570,  576, 2234, 1920, 1515,
  585,  968,  672, 1308,  348,  588, 1204, 1204, 1282, 2815,
 1778,  964, 1701, 2969, 2119, 1788,  744,  740,  299,  299,
 1586, 3087, 1789, 1778, 2498,  902, 1204, 1575,  660,  348,
 2945,  510,  510, 1515, 3395,  348,  590,  348, 1164, 1164,
 3396, 1778, 1702, 2885,  681,  274, 1309, 1587, 1809,  347,
  968, 2863,  758,  654, 1336,  292, 1778,  713, 1164, 1416,
 2523, 2548,  482, 2488,  761, 2489,  763,  506,  507, 2946,
 1165,  673, 3263, 3397,  348,  744,  740, 1749, 1355,  663,
  524,  993,  350,  589,  902,  739,  765,  766,  925,  610,
  681,  770,  771,  576,  660, 1336,  972,  514, 1336,  737,
 2156,  292,  506,  507,  591, 1309, 1667, 1240, 1333,  967,
 1778,  758,  551, 1336,  538,  742, 1611,  594, 1165, 1326,
 3398, 1334, 2702, 2499, 1698, 2128,  879,  667, 1165, 1165,
  514, 2644, 2700, 1570,  743,  348,  422,  580, 1165,  595,
  514, 1197,  292,  461,  739,  737,  350,  925,  681, 2138,
 1283, 2163, 1926, 1926, 1926, 2163,  544,  967, 1204, 2152,
 1043, 1791,  681,  347,  347, 1788, 2709, 2235, 1416,  571,
 1416, 1416, 1789,  422,  742,  655, 1788, 1129, 1165,  810,
  743,  966, 3342, 1789,  634,  966,  667, 1165,  545, 1043,
 1164, 1247, 1563, 1251, 1249, 1248, 1250, 2182, 1252, 1427,
  514, 1251, 1249,  737, 1250, 2554, 1252,  514, 2976, 2195,
 2977,  635, 1215,  610, 3342, 1043,  810,  737, 1043, 2152,
  302, 1414, 2555,  605, 2558,  233, 2191,  894, 2194, 1165,
  348,  645, 2557, 1043,  655, 2862,  663,  586,  743,  892,
  357, 1165,  651, 1165, 1310,  422, 1316, 2749,  650, 1749,
 3389,  660,  743,  669, 1081, 1316, 1084,  233, 1427, 1043,
 2759, 1788, 2726,  855,  856,  741,  539,  343, 1789, 1464,
 1788,  894, 2727,  571, 1699,  540, 3418, 1789,  660, 3302,
  744,  740,  587,  892,  422,  571,  894, 1356, 1357,  233,
 2249, 2927, 2728, 1588,  751, 3426,  685, 1042,  892,  357,
  300,  300,  396, 1310, 1749, 1165, 1165, 1043, 1316, 1316,
 3434, 2162, 1515, 1043, 2801, 2162, 3264, 2803, 1336,  469,
  482,  428, 1015, 1166,  741, 1165,  744,  740, 1464,   96,
  676, 3054,   15, 1043, 1515, 2656, 2802,  302,  514, 2804,
  751,  118,  571, 2781,  348,  348, 1043,  365, 1749,  739,
 3383,  686, 3384, 1208,  743,  571, 2373, 2297, 2374,  594,
 2657,  396,  428, 1000, 1166,  428, 1336, 1166,  235, 1336,
  422,  688,  250, 1778, 1316, 2658, 1336, 1336,  690,  742,
  428, 1336, 1166,  302,  744,  740, 1336,  693,   96, 1336,
 1282, 1282,  711, 1316, 1208,  739,  313, 1208,  744,  740,
  118, 1001, 2376, 1336,  716, 2051,  365, 2729, 2730, 2731,
  967,  514, 1208,  717, 1336, 3139, 3140, 3141, 3142, 3143,
 3144, 3145, 1336, 2660,  302,  742, 1336,  235, 1247, 2380,
 1611,  250, 1248,  723, 1570, 1336, 1247,  514,  726, 2053,
 1248,  343,  469,  482,  503,  461,  472,  472, 2661, 2448,
 2428, 1336, 1006,  739,  595,  313, 1735, 1165,  422, 2399,
 2429,  727, 1647, 2662, 2372, 2409,  496,  739,  734, 1048,
  510,  510, 1336,  944, 1648,  576,  576, 1336,  349,  422,
  949, 2436, 2437,  742, 3068,  422, 1000,  588, 1336, 1336,
 1007, 1336,  725, 1330,  956, 1331, 1649,  742,  357, 1218,
 2054, 2375, 2397,  761,  970,  763,  506,  507,  958, 2055,
  357, 1445, 1000, 1446, 1722, 2377, 2378,   49,  422,  102,
  103, 1000,  967, 1000, 1473,  765,  766,   52,  593,  741,
  770,  771, 1283, 1283, 2056,  357, 1447, 1336,  725, 2979,
  973,  357,  961,  357, 1652,  970,  966,   55,  970,  538,
 1482, 1448, 1000, 1336, 1336,  587, 3018, 1723, 1336, 1484,
 1647, 1490,  974,  970,  594,  510, 3019,  510,  510,  506,
  507, 1901, 1648, 1336, 2569,  741, 2527,  978, 2529, 2531,
  357,  976,  967, 1901, 2530,  967, 1901, 1166,  357,  514,
 1533,  588, 3049,  514, 1649, 2487,  725, 1304, 1219,  725,
 1303, 2472,  979,  588, 3349, 1650, 1570,  396, 1735, 1570,
  725,  510, 2485, 2675,  510,  510,  510, 1208,  964,  992,
 1030, 1031, 2562,  490, 2532, 2565, 2566, 2567,  964, 1136,
 2793, 2794,  594,  741, 3379, 1166, 1391,  995,  510, 1390,
 1564,  357, 1652, 1253,  727, 1166, 1166,  741,  396, 2584,
  980,  396,  357, 3022,  981, 1166,  990, 1724, 1197,  595,
  588, 3293,   58,   61,   64, 1208,  396, 2028,  594,  983,
 1253, 1005, 1969,  588,  538, 1725, 1208, 1013,  995, 1017,
  594,  995, 1205,    4,    7, 1208,  469,  482, 2446, 2447,
  727, 1243, 1242, 1244, 2116, 1166,  995, 1253, 2118,  592,
  591, 2117,  855,  856, 1166, 1336, 1019, 2223, 1726, 1474,
 2222, 1478, 1282,  244,  244, 1173, 1483, 1485, 1024, 3332,
 2682, 1491, 2683, 1205, 1026, 1208, 1032,  595, 2676, 3333,
 3334, 3354, 2228,  593, 1208, 2227,  357,  594, 1035, 2347,
 2353, 1205, 2005, 1253, 1036, 1282, 1166, 1534,  727, 1653,
  594,  727, 2715, 2716,  323, 1173, 1173, 1896, 1166, 1173,
 1166, 2367,  727,  595, 2366, 2396, 2685, 1048, 1253, 1896,
  561, 1049, 1896, 1897, 1173,  595, 1208, 1445, 1050, 1446,
  970,  970, 2382, 2383,  970, 1897,  548,  970, 1897, 2476,
 1208, 1048, 2475, 1054,  490, 1092,  349,  576, 1134,  970,
 1109,  593, 1447, 1934, 1113,  343,  469,  482,  503,  461,
  472,  472, 1383,  323, 2752, 1934,  547, 1448, 1934, 1128,
 2672, 2551, 1166, 1166, 2550,  964, 1048, 1141, 2681, 1144,
  576, 1145,  595, 3203,  761, 1215,  763,  593, 1148, 1146,
 1149, 1887, 1166, 1779,  650,  595, 1384, 1150, 2782,  593,
  357,  357, 1208, 1208, 1283, 1779,  612,  514, 1779, 1151,
 2599,  770,  771, 1253, 1152, 2684, 2610,  967,  970, 2609,
 2640, 2812, 1208, 1253, 2550, 2817, 2718,  510, 2578, 2686,
 2687,  393, 1887, 1153, 1154, 1887, 2487, 1283, 2783,  970,
  514, 1570, 1155, 1227, 1156,  970, 1749,  696, 2998,  514,
 1887, 2997, 1228,  514,  592,  591,  593,  697, 3024, 2750,
  698, 3023, 1158,  995,  995, 1229, 1159,  995, 2754,  593,
  995, 2769, 2760, 3076, 2773,  350, 1253, 3111,  970, 1160,
 3110, 3254,  995, 1759, 1161,  351, 1749, 1749,  352, 1784,
 1749, 1385, 1763, 1162, 1163, 1968, 1205, 1945, 1164, 1230,
 3153, 1784,  615, 1390, 1784, 1749, 1231, 1749,  514, 1945,
  615, 1166, 1945, 3166, 1232, 3344, 1253, 3356, 3343, 2808,
 3355, 1168,  592,  591, 1166,  964, 1173, 2485,  699, 1173,
  514, 1233, 1174, 1234, 3358, 3320,  964, 3357, 1224, 3419,
  343,  514, 3343, 1235, 1205, 1236, 1237, 1238, 1243, 1242,
 1244,  995, 1239, 3436, 1208, 1205,  353, 3439,  592,  591,
 2835, 1175,  700, 2833, 1205, 3438, 1176,  701, 1253, 2884,
  592,  591,  995,  702, 1177, 1226, 3440, 1173,  995, 1253,
 1173, 1253, 1514, 2892,  324, 1514,  354, 1173, 1173, 1178,
  355, 1175, 1173, 1240, 1179, 1180,  514, 1173,  514,  323,
 1173,  356, 3324,  463, 1205,  970,  463, 1724,  490,  396,
 1724,  995,  396, 1205, 1173, 1735, 1725, 1735, 1181, 1725,
 1238,  964,  490, 1238, 1254, 1173,  585,  592,  591,  585,
  964, 1284, 1175, 1173,  349, 1175, 1167, 1173, 1257,  582,
  592,  591,  582,  324,  323, 1182, 1173,  703, 1167, 1183,
 1175, 1050,  317,  343, 1184, 1205, 1167, 3321, 2898, 3323,
 2066, 1185, 1173, 2069, 1186, 2921, 1187, 1887, 1887, 1205,
 1167, 1188,  514, 1189, 1887,  357, 2913, 1190, 1647, 1791,
 1050, 1167,  317, 1191,  317, 1192, 1887, 1193, 1173, 1791,
 1648, 2925,  514,  704, 2993, 1194, 1195, 1196, 1197, 1198,
 1173, 1199, 1173,  966, 1200,  317, 1050, 1201,  510, 1050,
 1749, 1735, 1649,  966, 1202, 1203, 1204, 2049, 1167, 2980,
 1140,  358, 1205, 1650, 1050,  510, 2960, 1206, 1207, 1208,
  317, 1205, 1205, 1209, 1210, 1211, 2996,  705,  995, 1255,
 1256, 1260, 2050, 3036, 1258, 1749, 3038, 1157, 1173, 1302,
 1050, 1205, 2051, 1285,  317, 1887,  706, 2052, 1286, 1228,
 1652, 1305, 1307,  963, 1173, 1173, 1301, 1311, 1312, 1173,
 1170, 1316, 1229, 1243, 1242, 1244, 1887, 1341, 1345, 1241,
 1348, 1362, 1887, 1368,  359, 1374, 2053,  343, 1377,  514,
 2214, 3037, 1387,   15, 3040, 1393, 3039, 3042, 1403, 1407,
  323, 1405, 1406,  963, 1050, 1408, 1230, 1410, 3004, 1411,
 3003, 1415, 1424, 1231, 1418, 1887, 1425, 1438, 1457, 1460,
 2215, 1232, 2216, 1458, 1050, 1167,  964, 1462, 1463,  469,
  490,  482,  487,  490,  566,  496,  503, 1050, 1233,  642,
 1234, 1514,  490, 2217, 1536, 1542,  490, 2054, 1543, 1561,
 1235, 1565,  514, 1237, 1238, 1175, 2055, 1576, 1591, 1592,
 1606, 3125, 1647, 1616,  510, 1618,  964, 1653, 2218,   64,
 1619, 1620, 1635, 1655, 1648, 3107, 1657, 2259,  514,  324,
  510, 2056, 1658, 1205, 1659, 1660, 1791,  510, 1390, 1682,
 1926, 3117, 2219, 3043,   64, 1688, 1649, 2152, 3124, 3075,
 1240, 1690, 1683, 1175,   64, 1692, 1175, 1650, 1693,   64,
  966, 1714, 1709, 1175, 1175, 1651, 1173, 3105, 1175, 1712,
 1720, 1792, 1717, 1175,  324, 1793, 1175, 1795, 1805, 1799,
 1806, 1807,  326, 1813, 3114, 1815, 1845, 1817,   64, 1820,
 1175, 2260, 1887, 1843, 1652, 1849, 2261, 1854, 1907, 1878,
 2884, 1175,  343, 2865, 2866, 2867, 2868, 2869, 2870, 1175,
 1912, 1921,  326, 1175,  326, 1927, 1935, 1937,  995, 1009,
 1945, 1938, 1175, 1946, 1949, 2833, 1492, 1493, 1494, 1495,
 1496, 1497, 1498, 1499, 1228,  326, 1950, 1318, 1175,  490,
 1319, 1951, 1954, 1961, 2006, 1325, 3181, 1229, 1329,   64,
 2262, 1973, 1332, 2005, 1984, 2009, 1325, 1983,   64,  995,
  326, 2012,  995, 1232, 1175, 2021, 2263, 2024, 1247,  343,
 2027,  343, 2025, 1243, 1242, 1244, 1175,  995, 1175,  514,
 2029, 1230, 2035,   64,  326, 2033, 1791, 2044, 1231,  461,
 3183, 2046, 2913, 2043, 3165, 2047, 1232, 1791, 3172, 2045,
 3224, 1653, 2048, 2062,  357, 3105, 2063, 2064, 2075, 3202,
  966,  650, 2070, 1233, 2071, 1234, 2098, 3205, 2080, 2103,
 2076,  966, 2077, 2109, 1175, 1235, 2078, 1236, 1237, 1238,
  324, 2126, 2121, 2146, 2127, 1500, 1241,  475,  514, 2122,
 1175, 1175, 2125,  514, 2159, 1175, 1006, 2158, 2144, 2171,
 2176, 1986, 2177, 2264, 1985,  510, 2180, 3225, 2181, 2206,
 1175, 1501, 1735,  357,  993, 2205, 3271, 2189,  510, 2226,
 1243, 1242, 1244, 2209, 3310, 1240, 2210, 2232, 2224, 3280,
 2236, 1464, 1791, 2237, 2238, 2242, 1006, 1006, 2251, 2252,
 1006, 1791, 1475, 2253, 2256, 2254, 2269, 1481, 2280, 2286,
 2289, 1486, 2290, 2313, 2314, 1006,  966, 1006, 2322, 3114,
 2350, 1505, 1140, 2352, 2357,  966, 1511, 1512, 1140, 1007,
 1515, 1516, 1517, 1518, 1519, 1523, 1529, 2355, 1532, 2362,
 1535, 2370, 1537, 1538, 1539, 1540, 1541, 1006, 2371, 1544,
 1545, 1546, 1547, 1548, 1549, 1550, 1551, 1552, 1553, 1554,
 1555, 1556, 1557, 1558, 1559, 2384, 2385, 2392, 2407, 1007,
 1007, 2408, 2265, 1007, 2266, 2267, 1926,  343, 2411, 2419,
 1572, 2425, 3337, 2426,  538, 1227, 2439, 1584, 1007, 2421,
 1007, 1069, 1590, 2420, 1228, 2432, 2422,  475, 1597, 1598,
 3303, 2442, 1175, 2130,  995,  995, 1605, 1229, 1001, 2444,
 1419,  995, 3056, 3057, 3058, 3059, 3060, 3061, 2445,  475,
 1007, 3377, 2452,  995, 2473, 2454, 2462, 2455, 2460, 2172,
 2505, 2506, 2537, 2528, 2507, 2508, 2533, 2545, 2509, 2510,
 2513, 1230, 3363, 2559, 2561, 2564, 2563, 2572, 1231, 1001,
 1069, 2573, 1001, 2578, 1675, 2574, 1232, 2586,  475, 2587,
 2612, 2613, 2596, 2637, 2639, 2645, 2646, 1001, 2647, 1001,
 2648, 1241, 2649, 1233, 2693, 1234, 2704, 2650, 2705, 2695,
 2699, 2707, 1227, 1832, 2710, 1235, 2719, 1236, 1237, 1238,
 2651, 1228,  995,  475, 1239, 2720, 2721,  967, 1697, 1001,
 2701, 2723, 2157, 2724, 1229, 2734, 2755, 2751, 1070,  357,
 2753,  343, 2761,  995, 1006,  995, 2756, 2762, 2763,  995,
 1006,  966, 2764, 2765, 1832, 2767, 2766, 1832, 2768, 1006,
 2770, 1006, 1006, 1006, 3417, 1240, 1006,  967, 1230, 1006,
 2771, 2784, 1832, 2787, 2809, 1231, 2785, 1243, 1242, 1244,
 2775, 1006,  995, 1232,  357, 2826,  995, 1006, 1063,  995,
 1006,  966,  357, 2806, 2807, 2818, 1006, 1070, 2822, 2853,
 1233, 2837, 1234, 2859,  995, 2886,  995, 2897, 2872, 2899,
 2900, 2901, 1235, 2902, 1236, 1237, 1238, 1007, 2903, 2904,
 2905, 1239,  357, 1007,  357, 2909, 2914, 2923, 2922, 2926,
 1006, 2935, 1007, 2940, 1007, 1007, 1007, 2931, 1022, 1007,
 2943, 2495, 1007, 2956, 2953,  357, 2964, 1063, 2965, 1825,
 1006, 2954, 2984, 2986, 1007, 2988, 1931, 1932, 3009, 1934,
 1007, 1936, 1240, 1007, 3006, 1940, 1941, 1942, 1943, 1007,
  357, 1006,  879, 1947, 1948, 3033, 3047, 1006, 3064, 1022,
 3045, 1006, 1022, 3051, 3065, 3069, 1013, 1006, 3074, 3092,
 1955, 3106, 1140, 3093,  357, 3115, 1001, 1022, 3094, 1022,
 3096, 3121, 1001, 1007, 3109, 1006, 3129, 1971, 3133,  995,
 1006, 1001, 3135, 1001, 1001, 1001, 1977, 1978, 1001, 3146,
 3171, 1001, 3173, 1007, 3185, 3187, 3177, 1013, 3186, 1022,
 1013, 3194, 3196, 1001, 1006, 3206, 3218, 3219, 1006, 1001,
  357, 3223, 1001, 3236, 1007, 1013, 3255, 1013, 1001, 3261,
 1007, 1241, 3265, 3272, 1007, 1069, 1464, 3262, 3278, 3277,
 1007, 3269, 3281, 3290, 3286, 3279, 3292, 3329, 3322, 3304,
 2020, 3313, 2022, 3305, 3330, 2023, 3338, 1013, 1007, 1227,
 3345, 2481, 1001, 1007, 1069, 3367, 3368, 3370, 1228, 1832,
 1832, 3386, 3380, 3369, 3381, 3382, 1832, 3385, 3390, 3392,
 3394, 1229, 1001,  995, 3402, 3387, 3388, 1007, 1832,  995,
 1069, 1007, 3416, 1069, 3420, 1298, 3422, 3433,  995, 3423,
 3429, 3437,  995, 1001, 3435,  995,    1, 1175, 1069, 1001,
 1246,  368, 1129, 1001, 1140, 1230, 1131, 1006, 1319, 1001,
  995, 1944, 1231, 1130, 1740,  500,  995, 1116, 1241,  995,
 1232,  501,  451,  483, 1069,  995, 1218, 1001, 1512, 1197,
 1154,  909, 1001, 1223,  482,  492, 1513, 1233, 1722, 1234,
  454,   65, 1070, 1325,   86, 1202, 1329, 1832, 2111, 1235,
  517, 1236, 1237, 1238, 1607,  493, 1001,  538, 1325,  995,
 1001, 1241,  463,  320,  558,  602, 1022,  567, 1832,  549,
  525, 1070, 1022,  156, 1832, 1778, 1686,  396, 1069,  995,
 1007, 1022,  559, 1006, 1022, 1022,  603,  393, 1022, 1461,
 1715, 1022, 1063, 1608, 1687, 1599, 2160, 1070, 1069, 1240,
 1070,  567,  647, 1022, 2169,  648, 1721, 1832,  617, 1022,
  995, 1069, 1022,  472, 1013, 1070,  995,  998, 1022,   19,
 1013, 1063,  354,  355,    0,    9,   21,   25,   28, 1013,
   31,   40, 1013, 1013,  995,   67, 1013,   21,   70, 1013,
   72, 1070,   76, 1083,   79,   85,  100, 1063,   88,   97,
 1063, 1013, 1022,  984,  112,   97, 1007, 1013,  998, 1001,
 1013,  998,  103,  995,  106, 1063, 1013,  995,  109,  115,
   21, 2079, 1022, 1661, 1662, 1663,  998, 2655,  998, 2659,
 1664, 2663, 3048, 3147, 3148, 2390, 1665, 2690, 1666,  992,
 3046, 1063, 1924, 1022,  984, 1070, 2576,  984, 2992, 1022,
 1013, 3123, 1083, 1022,  597, 2974, 3108, 2950,  998, 1022,
 3374, 1108,  984,  497,  984, 1070, 2500, 3207,  990, 2963,
 1013, 2524, 3288,  601, 1306, 2571, 2799, 1022, 1070, 2975,
  992, 3268, 1022,  992, 1832, 1001, 3375, 3431, 2800, 3415,
 3393, 1013, 3391, 3228, 3253, 1063, 2941, 1013,  992, 2942,
  992, 1013, 1916,  975, 2279, 3091, 1022, 1013, 1370,  990,
 1022, 2283,  990, 3407, 3328, 1063,  995, 2470, 2471, 3408,
 2168, 3190, 2467, 3259,   32, 1013, 2030,  990, 1063,  990,
 1013, 1613, 1879, 2858, 2255, 1241, 1857, 2129, 1880, 1044,
 1451, 2300, 2480, 2193, 1844, 2542, 1711, 2306, 1881,  583,
 1426, 1333, 2309, 2410, 1013, 2310, 2311, 1955, 1013, 2692,
 2697, 1882, 2316, 1830, 2318, 3161,  593, 1314,  989, 2105,
  969, 2319, 1004, 2320, 2893, 1646, 2323, 2324, 2325, 2326,
 2398, 3167, 2331, 2067, 2332, 1469, 2333, 3401, 2334, 3130,
 2108, 1011,  995, 2083, 2335, 2336, 2337, 2338, 2339, 2340,
 2341, 2342, 2343, 2344, 2345, 2346, 2424,   49,   51, 1022,
 3149,   52, 3150,   55,   58, 2354, 3352, 1300, 2560, 1883,
 2356, 1589, 2084, 1126, 2359,  998, 2019, 3270, 1051, 1147,
 1852,  998,  995, 3199, 1696, 2112, 1607, 2967,  556, 3008,
  998, 2330, 2536,  998,  998, 2742, 1319,  998, 2085, 1884,
  998, 2086, 3041, 1885,  581, 2400, 1459, 1013, 1886, 1639,
 2816,  984,  998, 2689, 1887, 3400, 2087,  984,  998, 3198,
 2271,  998, 3308,  995, 3376, 2743,  995,  998,  984,  984,
  984, 2924, 1888,  984, 1382, 1022,  984, 1319,  132, 2895,
 1319,  995, 2088,  995, 3283, 3319, 1360,  992,  984,    0,
    0,    0,    0,  992,  984, 1319, 1140,    0,    0,    0,
    0,  998,    0,  984,  992,  992,  992,    0,    0,  992,
    0,    0,  992,    0,    0,    0,  990, 1083,    0,    0,
    0,  998,  990, 1013,  992,    0,    0,    0, 1889,    0,
  992, 1890,    0,  990,  990,  990, 2089,    0,  990,  992,
    0,  990,  998,    0,    0,    0, 1083,    0,  998, 2457,
    0, 1140,  998,  990,    0,    0, 2090,  984,  998,  990,
    0,    0,    0,    0,    0,    0,    0,    0,  990, 2091,
    0,    0, 1083,    0,    0, 1083,  998,    0,  984,    0,
    0,  998,    0,    0,  984,    0,    0,  743,    0,    0,
 1083,    0,  984,  992,  984,    0,    0,    0,    0, 1243,
 1242, 1244,    0,  431,    0,  998,    0,  984,    0,  998,
    0,    0,  984,  746,  992,    0, 1083,  984, 1891,    0,
  992,    0,  990,    0,    0,    0,    0,    0,  992,    0,
  992,    0,    0,    0,    0,    0,    0, 1892,    0,    0,
  748,    0,    0,  990,  431,  984,    0,  431,  992,  990,
    0,    0,    0,  992, 1749, 1749, 1749, 1749, 1749,  990,
 1749,    0,  431,    0,    0,    0,    0,    0,    0,    0,
 1083,    0,    0, 1749, 1749, 1749,    0,  990,    0,    0,
  995,  992,  990,    0,    0,    0,  995,    0,    0,    0,
 1083,    0,    0,    0,    0,    0,    0,    0,  995,  995,
    0,    0,  995, 1083, 1749,  995,  758, 1955,  998,    0,
  990,    0, 1319, 1319, 2603, 2604,    0,  995,    0, 1319,
    0, 2611,  760,  995,    0,    0,    0,    0,    0,    0,
    0,    0,  995,    0,    0,    0,  761,    0,  763,  506,
  507,    0,    0,    0,  984,    0,    0,    0, 2632,    0,
    0, 2634,    0, 2636,    0,    0,    0,    0,  765,  766,
  767,  768,  769,  770,  771,  772,  773,    0,    0,    0,
    0,    0,    0,  775,  776,    0,    0,    0,    0,    0,
  992,    0,  780,    0,  998,    0,  995,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2617,    0,    0, 2616,
 1319, 1227,    0,  591, 1319,    0,    0,  995,    0,  990,
 1228,    0,    0,  995,    0, 1243, 1242, 1244,    0,    0,
  984, 1319,    0,  995,    0,    0,    0, 1319,    0,    0,
    0,    0,    0,    0,    0, 1140,    0,    0,    0,    0,
    0,  995,    0,    0,    0,    0,  995,    0, 2619,    0,
    0, 2618,    0,    0,    0,    0,  992, 1230,    0,    0,
 1319,    0,    0,    0, 1231,    0, 1140, 1243, 1242, 1244,
    0,    0, 1232,    0,  995, 1749,    0,    0,    0,  431,
  431,    0,    0,    0, 1749,  990,  431,    0,    0, 1233,
 1749, 1234,    0,    0, 1749,    0,    0, 1749,    0,    0,
    0, 1235,    0, 1236, 1237, 1238, 3015,    0,    0, 3014,
 1239,    0,    0,    0,    0,    0,    0,    0,    0, 1319,
    0,    0,    0,    0,    0, 1243, 1242, 1244,    0,    0,
    0, 1749, 3017,  854,    0,  855,  856,  857, 1749,    0,
    0,    0,    0,    0,    0,    0, 1749,    0,    0,    0,
    0, 1243, 1242, 1244,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1749,    0, 1749,    0,  431,    0,    0,
    0,    0,    0,  995,    0, 1749,    0, 1749, 1749, 1749,
    0,    0,    0,    0, 1749, 2836,    0, 2838,  431, 2839,
    0,    0,    0, 2844,  431,    0,    0,    0, 2847, 2848,
 2849, 2850, 2851,    0,    0,    0,    0, 2852,    0, 2855,
    0, 2856,  432,    0,    0,    0, 1686, 1227,    0,    0,
    0,    0,    0,    0,    0, 1749, 1228,  431, 2857,    0,
    0,    0,    0,    0,    0, 1243, 1242, 1244,    0, 1229,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  995,
    0,    0,  430,  432,    0,    0,  432,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1140, 1227,
    0,  432,    0, 1230,    0,    0,    0,    0, 1228,    0,
 1231,    0,    0,    0,    0,    0,  431,    0, 1232,    0,
    0, 1229,    0,  430,    0,    0,  430, 2917, 1140,    0,
    0, 2908,    0,    0,    0, 1233,    0, 1234,    0,    0,
    0,  430,    0,    0,    0, 2930,    0, 1235,    0, 1236,
 1237, 1238,    0, 2933, 2934, 1230, 1239, 1227,    0,    0,
    0, 1687, 1231,    0,    0,  953, 1228, 1241,    0,    0,
 1232,    0,    0,    0,    0,    0,    0,    0,  266, 1229,
 1243, 1242, 1244, 1227,    0, 2957,    0, 1233,    0, 1234,
    0, 1939, 1228,    0,    0,    0,    0, 1240,    0, 1235,
    0, 1236, 1237, 1238,    0, 1229,  953,    0, 1239,  953,
 1243, 1242, 1244, 1230,    0,    0,    0,    0,    0,  266,
 1231,    0,  266,    0,  953,    0,    0,    0, 1232,    0,
    0,    0,    0, 3016,    0,    0,    0,  266,    0, 1230,
    0, 1749,    0,    0,    0, 1233, 1231, 1234, 1767, 1240,
    0,    0,    0,    0, 1232,    0,    0, 1235,    0, 1236,
 1237, 1238,    0,    0, 1955, 2839, 1239, 1227,    0,    0,
    0, 1233,    0, 1234,    0,    0, 1228,    0,    0,    0,
    0,    0,    0, 1235,    0, 1236, 1237, 1238,    0, 1229,
    0,    0, 1239,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1243, 1242, 1244,    0,    0, 1240,    0,    0,
    0,    0,    0,    0, 3035,    0,    0,    0,  432,  432,
    0,    0,    0, 1230,    0,  432, 3044,    0,    0,    0,
 1231,    0,    0, 1240,    0,    0,    0,    0, 1232,    0,
    0,    0,    0,    0,    0,    0,    0, 3062, 3063,    0,
    0, 3077, 1761,    0,    0, 1233,    0, 1234,  430,  430,
    0,    0,    0,    0,    0,  430,    0, 1235,    0, 1236,
 1237, 1238,    0,    0,    0,    0, 1239,    0,    0,    0,
    0,    0, 1227, 1241,    0,    0,    0,    0,    0,    0,
    0, 1228, 1761, 1761,    0, 1761, 1761, 1761, 1770,    0,
    0,    0,    0,    0, 1229,    0,  432,    0,    0, 3122,
 1761, 1761, 1227,    0,    0, 1761,    0, 1240,    0,    0,
    0, 1228,    0,    0,    0,    0,    0,  432,    0, 1955,
    0,    0,    0,  432, 1229, 1241,    0, 3136, 1230, 3137,
    0,  953,  953,    0,    0, 1231,  430,    0,  953,    0,
    0,    0,    0, 1232,  266,  266,    0,    0,    0,    0,
  953,  266,    0,    0,    0,    0,  432,  430, 1230,    0,
 1233,    0, 1234,  430,    0, 1231,    0,    0,    0,    0,
    0,    0, 1235, 1232, 1236, 1237, 1238,    0,    0,    0,
    0, 1239, 2917, 1241,    0,    0,    0,    0,    0,    0,
 1233,    0, 1234,    0, 1227,    0,  430,  544,    0,    0,
    0,    0, 1235, 1228, 1236, 1237, 1238,    0,    0, 1241,
    0, 1239,    0,    0,    0,  432, 1229,    0,    0,  953,
    0,    0, 1240,    0,    0,    0,    0,    0,    0,  545,
    0,    0,  266,    0,    0,    0,    0,    0,    0,    0,
  953,    0,    0,    0,    0,    0,  953,    0, 1955,    0,
 1230,    0, 1240,  266,    0,  430,    0, 1231,    0,  266,
    0,    0,    0,    0,    0, 1232,    0,    0,    0,    0,
 3229, 3230, 3231, 3232, 3233, 3234, 3235,    0,    0,  953,
    0,    0, 1233,    0, 1234, 3238, 3239, 3240, 3241, 3242,
 3243, 3244,  266, 1241, 1235,    0, 1236, 1237, 1238, 1761,
    0, 1761,    0, 1239,    0,    0, 1761, 1761,    0, 1761,
 1761, 1761,    0,    0,    0,    0, 1761,    0,    0,    0,
    0, 1761, 1761,    0, 1761,    0, 1761, 1761,    0, 1761,
    0,    0, 1761, 1761, 1761,    0,    0,    0,    0, 1761,
    0, 1761, 1761,    0, 1240,    0, 1761,    0, 1761,    0,
 1761, 1761,    0,    0, 1761,    0,    0, 1761,    0, 1761,
    0, 1761, 1761,    0, 1761, 1761, 1761,    0, 1761, 1761,
 1761,    0,    0,    0, 1761,    0, 1761, 1761, 1761,    0,
    0,    0, 1761,    0,    0,    0, 1761,    0, 1761, 1761,
 1761, 1761,    0, 1761,    0, 1761, 1761,    0, 1761, 1761,
 1761,    0, 1761,    0,    0,    0, 1761,    0, 1241,    0,
 1761, 3331, 1761, 3335, 1761,    0, 1761, 1761, 1761, 1761,
 1761,    0, 1761, 1761, 1761,    0,    0,    0, 1761, 1140,
 1761, 1761,    0,    0, 1761, 1761, 1761,    0, 1241, 1761,
 3361, 1761, 3364, 3366, 1761, 1761, 1761, 1761,    0, 1761,
    0, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1140,
    0,    0, 1761,    0, 1761, 1761,    0,    0, 1761,    0,
    0,    0,    0,    0,    0, 1761,    0, 1761,    0, 1761,
 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761,    0, 1761,
 1761, 1761, 1761,    0, 1761, 1761,    0, 3361, 3409, 3410,
    0,    0, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761,
 1761, 1761, 1761, 1761, 1761,    0, 1761, 1761, 1761, 1761,
 1761,    0, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761,
 1241,    0, 1761, 1761, 1761, 1761, 1761, 1761, 1761,    0,
    0, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761,
    0, 1761,    0, 1761, 1761, 1761,    0, 1761, 1761,    0,
 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761,
 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761,
 1761, 1761,    0, 1761, 1761, 1761, 1761, 1761, 1761,    0,
 1761, 1761, 1761, 1761,    0, 1761,    0, 1761, 1761, 1761,
 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761,
 1761, 1761, 1761, 1761, 1761,    0, 1761, 1761, 1761, 1761,
    0, 1761, 1761, 1761, 1761, 1761,    0, 1761, 1761, 1761,
 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761,
    0, 1761, 1761, 1761, 1761, 1761, 1761,    0, 1761, 1761,
 1761, 1761, 1761, 1761, 1761, 1761,    0, 1761, 1761, 1761,
 1761,    0, 1761, 1761, 1761, 1761, 1761, 1761,    0, 1507,
 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761,
    0, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761,
 1761, 1761,    0, 1761, 1761, 1761, 1761, 1761, 1761, 1761,
 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761, 1761,
 1507, 1507, 1507, 1507, 1507,    0, 1507,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1507, 1507,
 1507, 1507, 2579,    0,    0, 1057,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   78,    0, 2580,    0,    0,
    0, 1058,    0, 1059,    0,    0,    0,    0,    0,    0,
   78,    0, 1507,    0,    0,    0,    0,    0,    0,    0,
   78,    0,    0,    0,    0,    0,   78,    0,    0,    0,
    0,   78,    0,    0,    0,    0,   78,    0,    0,   78,
    0, 1060,    0,    0,    0,    0,    0, 1061, 1062, 1063,
    0, 1064, 1065, 1066,    0, 1067,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1068,
    0, 1069,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   62, 2989,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1070,    0,    0,    0,    0,    0,    0,   78,    0,    0,
    0,    0,    0,    0,    0,    0, 1071,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   78, 1072,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   78,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   78,    0, 1073, 1074,    0,    0, 1507, 1507, 1507,    0,
    0, 1507,    0, 1507, 1507,    0,    0, 1507, 1507, 1075,
 1507,    0,    0,    0,    0, 1507, 1507,    0, 1507, 1507,
 1507, 1507, 1507, 1507,    0,    0, 1507,    0,    0, 1507,
    0,    0,    0,    0,    0,    0, 1507,    0, 1507, 1507,
 1507, 1507, 1507, 1507, 1507, 1507,   78,    0, 1507,   78,
    0, 1507,    0, 1507, 1507,    0,    0, 1507, 1507, 1507,
    0, 1507, 1507, 1507, 1507, 1507, 1507, 1507,    0,    0,
    0, 1507, 1507, 1507, 1507, 1507,    0,    0,    0, 1507,
    0,    0,    0,    0,    0,    0,    0, 1507, 1507, 1507,
 1507, 1507, 1507,    0,    0,    0, 1507, 1507,    0, 1507,
    0, 1507,    0, 1507, 1507, 1507,    0, 1507,    0, 1507,
 1507, 1507,    0, 1507, 1507, 1507, 1507, 1507,    0, 1507,
 1507,    0,    0,    0, 1507, 1507,  408, 1507, 1507,    0,
 1507, 1507, 1507, 1507,    0,    0, 1507,    0, 1507,    0,
 1507, 1507, 1507, 1507, 1507,    0, 1507,    0, 1507,    0,
 1507, 1507, 1507, 1507, 1507,   78,    0, 1507, 1507, 1507,
    0, 1507, 1507, 1507,    0,    0,    0,  408, 1076,    0,
  408,    0, 1507, 1507, 1507,    0, 1507, 1507, 1507,    0,
 1507,    0,    0,    0, 1507,  408, 1507, 1507, 1507, 1507,
    0, 1507,    0, 1507, 1507, 1507, 1507, 1507, 1507, 1507,
 1507,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1507, 1507, 1963, 1507, 1507, 1507,    0,    0,    0,    0,
 1507, 1507, 1507, 1507, 1507,    0, 1507,    0,    0, 1507,
 1507, 1243, 1242, 1244, 1507, 1507, 1964,    0, 1507, 1507,
 1507, 1507, 1507, 1507, 1507, 1507, 1507,    0, 1507,    0,
    0,    0,    0,    0,    0, 1243, 1242, 1244, 1507, 1507,
 1507, 1507, 1507, 1507, 1507, 1507, 1507, 1507, 1507, 1507,
 1507, 1507, 1507, 1507, 1507, 1507, 1507, 1507, 1507,    0,
 1507, 1507, 1507, 1507, 1507, 1507,    0, 1507, 1507, 1507,
 1507,    0, 1507,    0, 1507, 1507, 1507, 1507, 1507, 1507,
 1507, 1507, 1507, 1507, 1507, 1507, 1507, 1507, 1507, 1507,
 1507, 1507,    0, 1507, 1507, 1507, 1507,    0, 1507, 1507,
 1507, 1507, 1507,    0, 1507, 1507, 1507, 1507, 1507, 1507,
 1507, 1507, 1507, 1507, 1507, 1507, 1507, 1507, 1507, 1507,
 1507, 1507, 1507, 1507,    0, 1507, 1507, 1507, 1507, 1507,
 1507, 1507, 1507, 1509, 1507, 1507, 1507, 1507,    0, 1507,
 1507, 1507, 1507, 1507, 1507,    0,    0, 1507, 1507, 1507,
 1507, 1507, 1507, 1507, 1507, 1507,    0,    0,    0,    0,
    0, 1507,    0, 1507, 1507, 1507, 1507, 1507, 1507,    0,
 1507,    0,    0,    0, 1509, 1509, 1509, 1509, 1509,    0,
 1509,    0,  409,  408,    0,    0,    0,    0,    0,  409,
    0,    0, 1509, 1509, 1509, 1509,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1227,    0,    0,    0,    0,    0,    0,
    0,    0, 1228,    0,    0,    0, 1509,    0,    0,    0,
    0,    0,    0,    0,    0, 1229,    0, 1227,    0,    0,
    0,    0,    0,    0,    0,    0, 1228,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1229,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1230,
  409,    0,    0,    0,    0,    0, 1231,    0,    0,    0,
    0,    0,    0,    0, 1232,    0,    0,    0,    0,    0,
    0,  409,    0, 1230,    0,    0,    0,  409,    0,    0,
 1231, 1233,    0, 1234,    0,    0,    0,    0, 1232,    0,
    0,    0,    0, 1235,    0, 1236, 1237, 1238,    0,    0,
    0,    0, 1239,    0,    0, 1233,    0, 1234,    0,    0,
  409,    0,    0,    0,    0,    0,    0, 1235,    0, 1236,
 1237, 1238,    0,    0,    0,    0, 1239,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1240,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1240,    0,    0,
 1509, 1509, 1509,    0,    0, 1509,    0, 1509, 1509,    0,
    0, 1509, 1509,    0, 1509,    0,    0,    0,    0, 1509,
 1509,    0, 1509, 1509, 1509, 1509, 1509, 1509,    0,    0,
 1509,    0,    0, 1509,    0,    0,    0,    0,    0,    0,
 1509,    0, 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1509,
    0,    0, 1509,    0,    0, 1509,    0, 1509, 1509,    0,
    0, 1509, 1509, 1509,    0, 1509, 1509, 1509, 1509, 1509,
 1509, 1509,    0,    0,    0, 1509, 1509, 1509, 1509, 1509,
    0,    0,    0, 1509,    0,    0,    0,    0,    0,    0,
    0, 1509, 1509, 1509, 1509, 1509, 1509,    0,    0,    0,
 1509, 1509,    0, 1509,    0, 1509,    0, 1509, 1509, 1509,
    0, 1509,    0, 1509, 1509, 1509,    0, 1509, 1509, 1509,
 1509, 1509,    0, 1509, 1509,    0,    0,    0, 1509, 1509,
  386, 1509, 1509,    0, 1509, 1509, 1509, 1509,    0,    0,
 1509,    0, 1509,    0, 1509, 1509, 1509, 1509, 1509,    0,
 1509,    0, 1509,    0, 1509, 1509, 1509, 1509, 1509, 1241,
    0, 1509, 1509, 1509,    0, 1509, 1509, 1509,    0,    0,
    0,  386,    0,    0,  386,    0, 1509, 1509, 1509,    0,
 1509, 1509, 1509, 1241, 1509,    0,    0,    0, 1509,  386,
 1509, 1509, 1509, 1509,    0, 1509,    0, 1509, 1509, 1509,
 1509, 1509, 1509, 1509, 1509,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1509, 1509, 1965, 1509, 1509, 1509,
    0,    0,    0,    0, 1509, 1509, 1509, 1509, 1509,    0,
 1509,    0,    0, 1509, 1509, 1243, 1242, 1244, 1509, 1509,
 1966,    0, 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1509,
 1509,    0, 1509,    0,    0,    0,    0,    0,    0, 1243,
 1242, 1244, 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1509,
 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1509,
 1509, 1509, 1509,    0, 1509, 1509, 1509, 1509, 1509, 1509,
    0, 1509, 1509, 1509, 1509,    0, 1509,    0, 1509, 1509,
 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1509,
 1509, 1509, 1509, 1509, 1509, 1509,    0, 1509, 1509, 1509,
 1509,    0, 1509, 1509, 1509, 1509, 1509,    0, 1509, 1509,
 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1509,
 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1509,    0, 1509,
 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1771, 1509, 1509,
 1509, 1509,    0, 1509, 1509, 1509, 1509, 1509, 1509,    0,
    0, 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1509, 1509,
    0,    0,    0,    0,    0, 1509,    0, 1509, 1509, 1509,
 1509, 1509, 1509,    0, 1509,    0,    0, 1744, 1771, 1771,
 1771, 1771, 1771, 1771, 1771,    0,  386,  386,    0,    0,
    0,    0,    0,  386,    0, 1771, 1771, 1771, 1771, 1771,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1227,    0,    0,
    0,    0,    0,    0,    0,    0, 1228,    0, 1771,    0,
 1771,    0,    0,    0,    0,    0,    0,    0,    0, 1229,
    0, 1227,    0,    0,    0,    0,    0,    0,    0,    0,
 1228,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1229,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1230,  386,    0,    0,    0,    0,    0,
 1231,    0,    0,    0,    0,    0,    0,    0, 1232,    0,
    0,    0,    0,    0,    0,  386,    0, 1230,    0,    0,
    0,  386,    0,    0, 1231, 1233,    0, 1234,    0,    0,
    0,    0, 1232,    0,    0,    0,    0, 1235,    0, 1236,
 1237, 1238,    0,    0,    0,    0, 1239,    0,    0, 1233,
    0, 1234,    0,    0,  386,    0,    0,    0,    0,    0,
    0, 1235,    0, 1236, 1237, 1238,    0,    0,    0,    0,
 1239,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1240,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0,    0, 1771,    0, 1771,    0,    0, 1771,
    0, 1771, 1771,    0,    0, 1771, 1771,    0, 1771,    0,
    0,    0,    0,    0, 1771,    0, 1771, 1771, 1771, 1771,
    0, 1771,    0,    0, 1771,    0,    0, 1771,    0,    0,
    0,    0,    0,    0, 1771,    0, 1771, 1771,    0, 1771,
 1771, 1771, 1771, 1771,    0,    0, 1771,    0,    0, 1771,
    0, 1771, 1771,    0,    0, 1771, 1771, 1771,    0, 1771,
 1771, 1771, 1771, 1771, 1771, 1771,    0,    0,    0, 1771,
 1771, 1771, 1771, 1771,    0,    0,    0, 1771,    0,    0,
    0,    0,    0,    0,    0, 1771, 1771, 1771, 1771, 1771,
 1771,    0,    0,    0, 1771, 1771,    0, 1771,    0, 1771,
    0, 1771, 1771, 1771,    0, 1771,    0, 1771, 1771, 1771,
    0, 1771, 1771, 1771, 1771, 1771,    0, 1771, 1771,    0,
    0,    0,    0, 1771,  410, 1771, 1771,    0,    0, 1771,
 1771, 1771,    0,    0, 1771,    0, 1771,    0,    0, 1771,
 1771, 1771, 1771,    0, 1771,    0, 1771,    0, 1771, 1771,
 1771, 1771, 1771, 1241,    0, 1771, 1771, 1771,    0, 1771,
 1771,    0,    0,    0,    0,  410,    0,    0,  410,    0,
 1771, 1771, 1771,    0, 1771, 1771, 1771, 1241, 1771,    0,
    0,    0, 1771,  410, 1771, 1771, 1771, 1771,    0, 1771,
    0, 1771, 1771, 1771, 1771, 1771, 1771, 1771, 1771,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1771, 1771,
 1967, 1771, 1771, 1771,    0,    0,    0,    0, 1771, 1771,
 1771, 1771, 1771,    0, 1771,    0,    0, 1771, 1771, 1243,
 1242, 1244, 1771, 1771, 1980,    0, 1771, 1771, 1771, 1771,
 1771, 1771, 1771, 1771, 1771,    0, 1771,    0,    0,    0,
    0,    0,    0, 1243, 1242, 1244, 1771, 1771, 1771, 1771,
 1771, 1771, 1771, 1771, 1771, 1771, 1771, 1771, 1771, 1771,
 1771, 1771, 1771, 1771, 1771, 1771, 1771,    0, 1771, 1771,
 1771, 1771, 1771, 1771,    0, 1771, 1771, 1771, 1771,    0,
 1771,    0, 1771, 1771, 1771, 1771, 1771, 1771, 1771, 1771,
 1771, 1771, 1771, 1771, 1771, 1771, 1771, 1771, 1771, 1771,
    0, 1771, 1771, 1771, 1771,    0, 1771, 1771, 1771, 1771,
 1771,    0, 1771, 1771, 1771, 1771, 1771, 1771, 1771, 1771,
 1771, 1771, 1771, 1771, 1771, 1771, 1771, 1771, 1771, 1771,
 1771, 1771, 1771, 1771, 1771, 1771, 1771, 1771, 1771, 1771,
 1771, 1808, 1771, 1771, 1771, 1771,    0, 1771, 1771, 1771,
 1771, 1771, 1771,    0,    0, 1771, 1771, 1771, 1771, 1771,
 1771, 1771, 1771, 1771,    0,    0,    0,    0,    0, 1771,
    0, 1771, 1771, 1771, 1771, 1771, 1771,    0, 1771,    0,
    0, 1621, 1808, 1808, 1808, 1808, 1808, 1808, 1808,    0,
  412,  410,    0,    0,    0,    0,    0,  412,    0, 1808,
 1808, 1808, 1808, 1808,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1227,    0,    0,    0,    0,    0,    0,    0,    0,
 1228,    0, 1808,    0, 1808,    0,    0,    0,    0,    0,
    0,    0,    0, 1229,    0, 1227,    0,    0,    0,    0,
    0,    0,    0,    0, 1228,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1229,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1230,  412,    0,
    0,    0,    0,    0, 1231,    0,    0,    0,    0,    0,
    0,    0, 1232,    0,    0,    0,    0,    0,    0,  412,
    0, 1230,    0,    0,    0,  412,    0,    0, 1231, 1233,
    0, 1234,    0,    0,    0,    0, 1232,    0,    0,    0,
    0, 1235,    0, 1236, 1237, 1238,    0,    0,    0,    0,
 1239,    0,    0, 1233,    0, 1234,    0,    0,  412,    0,
    0,    0,    0,    0,    0, 1235,    0, 1236, 1237, 1238,
    0,    0,    0,    0, 1239,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1240,    0,    0, 1808,    0,
 1808,    0,    0, 1808,    0, 1808, 1808,    0,    0, 1808,
 1808,    0, 1808,    0,    0,    0,    0,    0, 1808,    0,
 1808, 1808, 1808, 1808,    0, 1808,    0,    0, 1808,    0,
    0, 1808,    0,    0,    0,    0,    0,    0, 1808,    0,
 1808, 1808,    0, 1808, 1808, 1808, 1808, 1808,    0,    0,
 1808,    0,    0, 1808,    0, 1808, 1808,    0,    0, 1808,
 1808, 1808,    0, 1808, 1808, 1808, 1808, 1808, 1808, 1808,
    0,    0,    0, 1808, 1808, 1808, 1808, 1808,    0,    0,
    0, 1808,    0,    0,    0,    0,    0,    0,    0, 1808,
 1808, 1808, 1808, 1808, 1808,    0,    0,    0, 1808, 1808,
    0, 1808,    0, 1808,    0, 1808, 1808, 1808,    0, 1808,
    0, 1808, 1808, 1808,    0, 1808, 1808, 1808, 1808, 1808,
    0, 1808, 1808,    0,    0,    0,    0, 1808,  428, 1808,
 1808,    0,    0, 1808, 1808, 1808,    0,    0, 1808,    0,
 1808,    0,    0, 1808, 1808, 1808, 1808,    0, 1808,    0,
 1808,    0, 1808, 1808, 1808, 1808, 1808, 1241,    0, 1808,
 1808, 1808,    0, 1808, 1808,    0,    0,    0,    0,  428,
    0,    0,  428,    0, 1808, 1808, 1808,    0, 1808, 1808,
 1808, 1241, 1808,    0,    0,    0, 1808,  428, 1808, 1808,
 1808, 1808,    0, 1808,    0, 1808, 1808, 1808, 1808, 1808,
 1808, 1808, 1808,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1808, 1808, 1982, 1808, 1808, 1808,    0,    0,
    0,    0, 1808, 1808, 1808, 1808, 1808,    0, 1808,    0,
    0, 1808, 1808, 1243, 1242, 1244, 1808, 1808, 1987,    0,
 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808,    0,
 1808,    0,    0,    0,    0,    0,    0, 1243, 1242, 1244,
 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808,
 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808,
 1808,    0, 1808, 1808, 1808, 1808, 1808, 1808,    0, 1808,
 1808, 1808, 1808,    0, 1808,    0, 1808, 1808, 1808, 1808,
 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808,
 1808, 1808, 1808, 1808,    0, 1808, 1808, 1808, 1808,    0,
 1808, 1808, 1808, 1808, 1808,    0, 1808, 1808, 1808, 1808,
 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808,
 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808,
 1808, 1808, 1808, 1808, 1808, 1810, 1808, 1808, 1808, 1808,
    0, 1808, 1808, 1808, 1808, 1808, 1808,    0,    0, 1808,
 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808,    0,    0,
    0,    0,    0, 1808,    0, 1808, 1808, 1808, 1808, 1808,
 1808,    0, 1808,    0,    0, 1622, 1810, 1810, 1810, 1810,
 1810, 1810, 1810,    0,  428,  428,    0,    0,    0,    0,
    0,  428,    0, 1810, 1810, 1810, 1810, 1810,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1227,    0,    0,    0,    0,
    0,    0,    0,    0, 1228,    0, 1810,    0, 1810,    0,
    0,    0,    0,    0,    0,    0,    0, 1229,    0, 1227,
    0,    0,    0,    0,    0,    0,    0,    0, 1228,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1229,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1230,  428,    0,    0,    0,    0,    0, 1231,    0,
    0,    0,    0,    0,    0,    0, 1232,    0,    0,    0,
    0,    0,    0,  428,    0, 1230,    0,    0,    0,  428,
    0,    0, 1231, 1233,    0, 1234,    0,    0,    0,    0,
 1232,    0,    0,    0,    0, 1235,    0, 1236, 1237, 1238,
    0,    0,    0,    0, 1239,    0,    0, 1233,    0, 1234,
    0,    0,  428,    0,    0,    0,    0,    0,    0, 1235,
    0, 1236, 1237, 1238,    0,    0,    0,    0, 1239,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1240,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1240,
    0,    0, 1810,    0, 1810,    0,    0, 1810,    0, 1810,
 1810,    0,    0, 1810, 1810,    0, 1810,    0,    0,    0,
    0,    0, 1810,    0, 1810, 1810, 1810, 1810,    0, 1810,
    0,    0, 1810,    0,    0, 1810,    0,    0,    0,    0,
    0,    0, 1810,    0, 1810, 1810,    0, 1810, 1810, 1810,
 1810, 1810,    0,    0, 1810,    0,    0, 1810,    0, 1810,
 1810,    0,    0, 1810, 1810, 1810,    0, 1810, 1810, 1810,
 1810, 1810, 1810, 1810,    0,    0,    0, 1810, 1810, 1810,
 1810, 1810,    0,    0,    0, 1810,    0,    0,    0,    0,
    0,    0,    0, 1810, 1810, 1810, 1810, 1810, 1810,    0,
    0,    0, 1810, 1810,    0, 1810,    0, 1810,    0, 1810,
 1810, 1810,    0, 1810,    0, 1810, 1810, 1810,    0, 1810,
 1810, 1810, 1810, 1810,    0, 1810, 1810,    0,    0,    0,
    0, 1810,    0, 1810, 1810,    0,    0, 1810, 1810, 1810,
    0,    0, 1810,    0, 1810,    0,    0, 1810, 1810, 1810,
 1810,    0, 1810,    0, 1810,    0, 1810, 1810, 1810, 1810,
 1810, 1241,    0, 1810, 1810, 1810,    0, 1810, 1810,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1810, 1810,
 1810,    0, 1810, 1810, 1810, 1241, 1810,    0,    0,    0,
 1810,    0, 1810, 1810, 1810, 1810,    0, 1810,    0, 1810,
 1810, 1810, 1810, 1810, 1810, 1810, 1810,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1810, 1810, 1988, 1810,
 1810, 1810,    0,    0,    0,    0, 1810, 1810, 1810, 1810,
 1810,    0, 1810,    0,    0, 1810, 1810, 1243, 1242, 1244,
 1810, 1810, 1989,    0, 1810, 1810, 1810, 1810, 1810, 1810,
 1810, 1810, 1810,    0, 1810,    0,    0,    0,    0,    0,
    0, 1243, 1242, 1244, 1810, 1810, 1810, 1810, 1810, 1810,
 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1810,
 1810, 1810, 1810, 1810, 1810,    0, 1810, 1810, 1810, 1810,
 1810, 1810,    0, 1810, 1810, 1810, 1810,    0, 1810,    0,
 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1810,
 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1810,    0, 1810,
 1810, 1810, 1810,    0, 1810, 1810, 1810, 1810, 1810,    0,
 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1810,
 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1810,
 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1810, 1812,
 1810, 1810, 1810, 1810,    0, 1810, 1810, 1810, 1810, 1810,
 1810,    0,    0, 1810, 1810, 1810, 1810, 1810, 1810, 1810,
 1810, 1810,    0,    0,    0,    0,    0, 1810,    0, 1810,
 1810, 1810, 1810, 1810, 1810,    0, 1810,    0,    1, 1624,
 1812, 1812, 1812, 1812, 1812, 1812, 1812,    0,    0,    0,
    0,    0,    0,    0,    0,    2,    0, 1812, 1812, 1812,
 1812, 1812,    0,    3,    0,    0,    0,    0,    0,    0,
    0,    4,    0,    5,    0,    0,    0,    0,    6, 1227,
    0,    0,    0,    0,    7,    0,    0,    0, 1228,    0,
 1812,    0, 1812,    0,    0,    0,    0,    0,    8,    0,
    0, 1229,    0, 1227,    0,    0,    0,    9,    0,    0,
    0,    0, 1228,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1229,    0,    0,    0,    0,
    0,    0,   10,    0,    0, 1230,    0,    0,    0,    0,
    0,    0, 1231,    0,    0,    0,    0,    0,    0,    0,
 1232,    0,    0,    0,    0,    0,    0,    0,    0, 1230,
    0,    0,    0,    0,    0,    0, 1231, 1233,    0, 1234,
    0,    0,    0,   11, 1232,   12,    0,    0,   13, 1235,
    0, 1236, 1237, 1238,    0,    0,    0,    0, 1239,    0,
    0, 1233,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0,   14, 1235,    0, 1236, 1237, 1238,    0,    0,
    0,    0, 1239,    0,   15,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1240,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   16,    0,    0, 1240,    0,    0, 1812,    0, 1812,    0,
    0, 1812,    0, 1812, 1812,   17,   18, 1812, 1812,    0,
 1812,    0,    0,    0,    0,    0, 1812,    0, 1812, 1812,
 1812, 1812,    0, 1812,    0,    0, 1812,   19,    0, 1812,
    0,    0,    0,    0,    0,    0, 1812,    0, 1812, 1812,
    0, 1812, 1812, 1812, 1812, 1812,    0,    0, 1812,    0,
    0, 1812,    0, 1812, 1812,    0,    0, 1812, 1812, 1812,
    0, 1812, 1812, 1812, 1812, 1812, 1812, 1812,    0,    0,
    0, 1812, 1812, 1812, 1812, 1812,    0,    0,    0, 1812,
    0,    0,    0,    0,    0,    0,    0, 1812, 1812, 1812,
 1812, 1812, 1812,    0,    0,    0, 1812, 1812,    0, 1812,
    0, 1812,    0, 1812, 1812, 1812,    0, 1812,    0, 1812,
 1812, 1812,    0, 1812, 1812, 1812, 1812, 1812,    0, 1812,
 1812,    0,    0,    0,    0, 1812,    0, 1812, 1812,    0,
    0, 1812, 1812, 1812,    0,    0, 1812,    0, 1812,    0,
    0, 1812, 1812, 1812, 1812,    0, 1812,    0, 1812,    0,
 1812, 1812, 1812, 1812, 1812, 1241,    0, 1812, 1812, 1812,
    0, 1812, 1812,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1812, 1812, 1812,    0, 1812, 1812, 1812, 1241,
 1812,    0,    0,    0, 1812,    0, 1812, 1812, 1812, 1812,
    0, 1812,    0, 1812, 1812, 1812, 1812, 1812, 1812, 1812,
 1812,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1812, 1812, 1990, 1812, 1812, 1812,    0,    0,    0,    0,
 1812, 1812, 1812, 1812, 1812,    0, 1812,    0,    0, 1812,
 1812, 1243, 1242, 1244, 1812, 1812, 2292,    0, 1812, 1812,
 1812, 1812, 1812, 1812, 1812, 1812, 1812,    0, 1812,    0,
    0,    0,    0,    0,    0, 1243, 1242, 1244, 1812, 1812,
 1812, 1812, 1812, 1812, 1812, 1812, 1812, 1812, 1812, 1812,
 1812, 1812, 1812, 1812, 1812, 1812, 1812, 1812, 1812,    0,
 1812, 1812, 1812, 1812, 1812, 1812,    0, 1812, 1812, 1812,
 1812,    0, 1812,    0, 1812, 1812, 1812, 1812, 1812, 1812,
 1812, 1812, 1812, 1812, 1812, 1812, 1812, 1812, 1812, 1812,
 1812, 1812,    0, 1812, 1812, 1812, 1812,    0, 1812, 1812,
 1812, 1812, 1812,    0, 1812, 1812, 1812, 1812, 1812, 1812,
 1812, 1812, 1812, 1812, 1812, 1812, 1812, 1812, 1812, 1812,
 1812, 1812, 1812, 1812, 1812, 1812, 1812, 1812, 1812, 1812,
 1812, 1812, 1812, 1813, 1812, 1812, 1812, 1812,    0, 1812,
 1812, 1812, 1812, 1812, 1812,    0,    0, 1812, 1812, 1812,
 1812, 1812, 1812, 1812, 1812, 1812,    0,    0,    0,    0,
    0, 1812,    0, 1812, 1812, 1812, 1812, 1812, 1812,    0,
 1812,    0,    0, 1625, 1813, 1813, 1813, 1813, 1813, 1813,
 1813,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1813, 1813, 1813, 1813, 1813,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1227,    0,    0,    0,    0,    0,    0,
    0,    0, 1228,    0, 1813,    0, 1813,    0,    0,    0,
    0,    0,    0,    0,    0, 1229,    0, 1227,    0,    0,
    0,    0,    0,    0,    0,    0, 1228,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1229,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1230,
    0,    0,    0,    0,    0,    0, 1231,    0,    0,    0,
    0,    0,    0,    0, 1232,    0,    0,    0,    0,    0,
    0,    0,    0, 1230,    0,    0,    0,    0,    0,    0,
 1231, 1233,    0, 1234,    0,    0,    0,    0, 1232,    0,
    0,    0,    0, 1235,    0, 1236, 1237, 1238,    0,    0,
    0,    0, 1239,    0,    0, 1233,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1235,    0, 1236,
 1237, 1238,    0,    0,    0,    0, 1239,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1240,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1240,    0,    0,
 1813,    0, 1813,    0,    0, 1813,    0, 1813, 1813,    0,
    0, 1813, 1813,    0, 1813,    0,    0,    0,    0,    0,
 1813,    0, 1813, 1813, 1813, 1813,    0, 1813,    0,    0,
 1813,    0,    0, 1813,    0,    0,    0,    0,    0,    0,
 1813,    0, 1813, 1813,    0, 1813, 1813, 1813, 1813, 1813,
    0,    0, 1813,    0,    0, 1813,    0, 1813, 1813,    0,
    0, 1813, 1813, 1813,    0, 1813, 1813, 1813, 1813, 1813,
 1813, 1813,    0,    0,    0, 1813, 1813, 1813, 1813, 1813,
    0,    0,    0, 1813,    0,    0,    0,    0,    0,    0,
    0, 1813, 1813, 1813, 1813, 1813, 1813,    0,    0,    0,
 1813, 1813,    0, 1813,    0, 1813,    0, 1813, 1813, 1813,
    0, 1813,    0, 1813, 1813, 1813,    0, 1813, 1813, 1813,
 1813, 1813,    0, 1813, 1813,    0,    0,    0,    0, 1813,
    0, 1813, 1813,    0,    0, 1813, 1813, 1813,    0,    0,
 1813,    0, 1813,    0,    0, 1813, 1813, 1813, 1813,    0,
 1813,    0, 1813,    0, 1813, 1813, 1813, 1813, 1813, 1241,
    0, 1813, 1813, 1813,    0, 1813, 1813,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1813, 1813, 1813,    0,
 1813, 1813, 1813, 1241, 1813,    0,    0,    0, 1813,    0,
 1813, 1813, 1813, 1813,    0, 1813,    0, 1813, 1813, 1813,
 1813, 1813, 1813, 1813, 1813,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1813, 1813, 2293, 1813, 1813, 1813,
    0,    0,    0,    0, 1813, 1813, 1813, 1813, 1813,    0,
 1813,    0,    0, 1813, 1813, 1243, 1242, 1244, 1813, 1813,
 2298,    0, 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813,
 1813,    0, 1813,    0,    0,    0,    0,    0,    0, 1243,
 1242, 1244, 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813,
 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813,
 1813, 1813, 1813,    0, 1813, 1813, 1813, 1813, 1813, 1813,
    0, 1813, 1813, 1813, 1813,    0, 1813,    0, 1813, 1813,
 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813,
 1813, 1813, 1813, 1813, 1813, 1813,    0, 1813, 1813, 1813,
 1813,    0, 1813, 1813, 1813, 1813, 1813,    0, 1813, 1813,
 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813,
 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813,
 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1814, 1813, 1813,
 1813, 1813,    0, 1813, 1813, 1813, 1813, 1813, 1813,    0,
    0, 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813, 1813,
    0,    0,    0,    0,    0, 1813,    0, 1813, 1813, 1813,
 1813, 1813, 1813,    0, 1813,    0,    0, 1626, 1814, 1814,
 1814, 1814, 1814, 1814, 1814,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1814, 1814, 1814, 1814, 1814,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1227,    0,    0,
    0,    0,    0,    0,    0,    0, 1228,    0, 1814,    0,
 1814,    0,    0,    0,    0,    0,    0,    0,    0, 1229,
    0, 1227,    0,    0,    0,    0,    0,    0,    0,    0,
 1228,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1229,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1230,    0,    0,    0,    0,    0,    0,
 1231,    0,    0,    0,    0,    0,    0,    0, 1232,    0,
    0,    0,    0,    0,    0,    0,    0, 1230,    0,    0,
    0,    0,    0,    0, 1231, 1233,    0, 1234,    0,    0,
    0,    0, 1232,    0,    0,    0,    0, 1235,    0, 1236,
 1237, 1238,    0,    0,    0,    0, 1239,    0,    0, 1233,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1235,    0, 1236, 1237, 1238,    0,    0,    0,    0,
 1239,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1240,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0,    0, 1814,    0, 1814,    0,    0, 1814,
    0, 1814, 1814,    0,    0, 1814, 1814,    0, 1814,    0,
    0,    0,    0,    0, 1814,    0, 1814, 1814, 1814, 1814,
    0, 1814,    0,    0, 1814,    0,    0, 1814,    0,    0,
    0,    0,    0,    0, 1814,    0, 1814, 1814,    0, 1814,
 1814, 1814, 1814, 1814,    0,    0, 1814,    0,    0, 1814,
    0, 1814, 1814,    0,    0, 1814, 1814, 1814,    0, 1814,
 1814, 1814, 1814, 1814, 1814, 1814,    0,    0,    0, 1814,
 1814, 1814, 1814, 1814,    0,    0,    0, 1814,    0,    0,
    0,    0,    0,    0,    0, 1814, 1814, 1814, 1814, 1814,
 1814,    0,    0,    0, 1814, 1814,    0, 1814,    0, 1814,
    0, 1814, 1814, 1814,    0, 1814,    0, 1814, 1814, 1814,
    0, 1814, 1814, 1814, 1814, 1814,    0, 1814, 1814,    0,
    0,    0,    0, 1814,    0, 1814, 1814,    0,    0, 1814,
 1814, 1814,    0,    0, 1814,    0, 1814,    0,    0, 1814,
 1814, 1814, 1814,    0, 1814,    0, 1814,    0, 1814, 1814,
 1814, 1814, 1814, 1241,    0, 1814, 1814, 1814,    0, 1814,
 1814,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1814, 1814, 1814,    0, 1814, 1814, 1814, 1241, 1814,    0,
    0,    0, 1814,    0, 1814, 1814, 1814, 1814,    0, 1814,
    0, 1814, 1814, 1814, 1814, 1814, 1814, 1814, 1814,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1814, 1814,
 2299, 1814, 1814, 1814,    0,    0,    0,    0, 1814, 1814,
 1814, 1814, 1814,    0, 1814,    0,    0, 1814, 1814, 1243,
 1242, 1244, 1814, 1814, 2301,    0, 1814, 1814, 1814, 1814,
 1814, 1814, 1814, 1814, 1814,    0, 1814,    0,    0,    0,
    0,    0,    0, 1243, 1242, 1244, 1814, 1814, 1814, 1814,
 1814, 1814, 1814, 1814, 1814, 1814, 1814, 1814, 1814, 1814,
 1814, 1814, 1814, 1814, 1814, 1814, 1814,    0, 1814, 1814,
 1814, 1814, 1814, 1814,    0, 1814, 1814, 1814, 1814,    0,
 1814,    0, 1814, 1814, 1814, 1814, 1814, 1814, 1814, 1814,
 1814, 1814, 1814, 1814, 1814, 1814, 1814, 1814, 1814, 1814,
    0, 1814, 1814, 1814, 1814,    0, 1814, 1814, 1814, 1814,
 1814,    0, 1814, 1814, 1814, 1814, 1814, 1814, 1814, 1814,
 1814, 1814, 1814, 1814, 1814, 1814, 1814, 1814, 1814, 1814,
 1814, 1814, 1814, 1814, 1814, 1814, 1814, 1814, 1814, 1814,
 1814, 1815, 1814, 1814, 1814, 1814,    0, 1814, 1814, 1814,
 1814, 1814, 1814,    0,    0, 1814, 1814, 1814, 1814, 1814,
 1814, 1814, 1814, 1814,    0,    0,    0,    0,    0, 1814,
    0, 1814, 1814, 1814, 1814, 1814, 1814,    0, 1814,    0,
    0, 1628, 1815, 1815, 1815, 1815, 1815, 1815, 1815,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1815,
 1815, 1815, 1815, 1815,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1227,    0,    0,    0,    0,    0,    0,    0,    0,
 1228,    0, 1815,    0, 1815,    0,    0,    0,    0,    0,
    0,    0,    0, 1229,    0, 1227,    0,    0,    0,    0,
    0,    0,    0,    0, 1228,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1229,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1230,    0,    0,
    0,    0,    0,    0, 1231,    0,    0,    0,    0,    0,
    0,    0, 1232,    0,    0,    0,    0,    0,    0,    0,
    0, 1230,    0,    0,    0,    0,    0,    0, 1231, 1233,
    0, 1234,    0,    0,    0,    0, 1232,    0,    0,    0,
    0, 1235,    0, 1236, 1237, 1238,    0,    0,    0,    0,
 1239,    0,    0, 1233,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1235,    0, 1236, 1237, 1238,
    0,    0,    0,    0, 1239,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1240,    0,    0, 1815,    0,
 1815,    0,    0, 1815,    0, 1815, 1815,    0,    0, 1815,
 1815,    0, 1815,    0,    0,    0,    0,    0, 1815,    0,
 1815, 1815, 1815, 1815,    0, 1815,    0,    0, 1815,    0,
    0, 1815,    0,    0,    0,    0,    0,    0, 1815,    0,
 1815, 1815,    0, 1815, 1815, 1815, 1815, 1815,    0,    0,
 1815,    0,    0, 1815,    0, 1815, 1815,    0,    0, 1815,
 1815, 1815,    0, 1815, 1815, 1815, 1815, 1815, 1815, 1815,
    0,    0,    0, 1815, 1815, 1815, 1815, 1815,    0,    0,
    0, 1815,    0,    0,    0,    0,    0,    0,    0, 1815,
 1815, 1815, 1815, 1815, 1815,    0,    0,    0, 1815, 1815,
    0, 1815,    0, 1815,    0, 1815, 1815, 1815,    0, 1815,
    0, 1815, 1815, 1815,    0, 1815, 1815, 1815, 1815, 1815,
    0, 1815, 1815,    0,    0,    0,    0, 1815,    0, 1815,
 1815,    0,    0, 1815, 1815, 1815,    0,    0, 1815,    0,
 1815,    0,    0, 1815, 1815, 1815, 1815,    0, 1815,    0,
 1815,    0, 1815, 1815, 1815, 1815, 1815, 1241,    0, 1815,
 1815, 1815,    0, 1815, 1815,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1815, 1815, 1815,    0, 1815, 1815,
 1815, 1241, 1815,    0,    0,    0, 1815,    0, 1815, 1815,
 1815, 1815,    0, 1815,    0, 1815, 1815, 1815, 1815, 1815,
 1815, 1815, 1815,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1815, 1815, 2302, 1815, 1815, 1815,    0,    0,
    0,    0, 1815, 1815, 1815, 1815, 1815,    0, 1815,    0,
    0, 1815, 1815, 1243, 1242, 1244, 1815, 1815, 2303,    0,
 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815,    0,
 1815,    0,    0,    0,    0,    0,    0, 1243, 1242, 1244,
 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815,
 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815,
 1815,    0, 1815, 1815, 1815, 1815, 1815, 1815,    0, 1815,
 1815, 1815, 1815,    0, 1815,    0, 1815, 1815, 1815, 1815,
 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815,
 1815, 1815, 1815, 1815,    0, 1815, 1815, 1815, 1815,    0,
 1815, 1815, 1815, 1815, 1815,    0, 1815, 1815, 1815, 1815,
 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815,
 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815,
 1815, 1815, 1815, 1815, 1815, 1816, 1815, 1815, 1815, 1815,
    0, 1815, 1815, 1815, 1815, 1815, 1815,    0,    0, 1815,
 1815, 1815, 1815, 1815, 1815, 1815, 1815, 1815,    0,    0,
    0,    0,    0, 1815,    0, 1815, 1815, 1815, 1815, 1815,
 1815,    0, 1815,    0,    0, 1629, 1816, 1816, 1816, 1816,
 1816, 1816, 1816,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1816, 1816, 1816, 1816, 1816,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1227,    0,    0,    0,    0,
    0,    0,    0,    0, 1228,    0, 1816,    0, 1816,    0,
    0,    0,    0,    0,    0,    0,    0, 1229,    0, 1227,
    0,    0,    0,    0,    0,    0,    0,    0, 1228,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1229,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1230,    0,    0,    0,    0,    0,    0, 1231,    0,
    0,    0,    0,    0,    0,    0, 1232,    0,    0,    0,
    0,    0,    0,    0,    0, 1230,    0,    0,    0,    0,
    0,    0, 1231, 1233,    0, 1234,    0,    0,    0,    0,
 1232,    0,    0,    0,    0, 1235,    0, 1236, 1237, 1238,
    0,    0,    0,    0, 1239,    0,    0, 1233,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1235,
    0, 1236, 1237, 1238,    0,    0,    0,    0, 1239,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1240,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1240,
    0,    0, 1816,    0, 1816,    0,    0, 1816,    0, 1816,
 1816,    0,    0, 1816, 1816,    0, 1816,    0,    0,    0,
    0,    0, 1816,    0, 1816, 1816, 1816, 1816,    0, 1816,
    0,    0, 1816,    0,    0, 1816,    0,    0,    0,    0,
    0,    0, 1816,    0, 1816, 1816,    0, 1816, 1816, 1816,
 1816, 1816,    0,    0, 1816,    0,    0, 1816,    0, 1816,
 1816,    0,    0, 1816, 1816, 1816,    0, 1816, 1816, 1816,
 1816, 1816, 1816, 1816,    0,    0,    0, 1816, 1816, 1816,
 1816, 1816,    0,    0,    0, 1816,    0,    0,    0,    0,
    0,    0,    0, 1816, 1816, 1816, 1816, 1816, 1816,    0,
    0,    0, 1816, 1816,    0, 1816,    0, 1816,    0, 1816,
 1816, 1816,    0, 1816,    0, 1816, 1816, 1816,    0, 1816,
 1816, 1816, 1816, 1816,    0, 1816, 1816,    0,    0,    0,
    0, 1816,    0, 1816, 1816,    0,    0, 1816, 1816, 1816,
    0,    0, 1816,    0, 1816,    0,    0, 1816, 1816, 1816,
 1816,    0, 1816,    0, 1816,    0, 1816, 1816, 1816, 1816,
 1816, 1241,    0, 1816, 1816, 1816,    0, 1816, 1816,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1816, 1816,
 1816,    0, 1816, 1816, 1816, 1241, 1816,    0,    0,    0,
 1816,    0, 1816, 1816, 1816, 1816,    0, 1816,    0, 1816,
 1816, 1816, 1816, 1816, 1816, 1816, 1816,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1816, 1816, 2304, 1816,
 1816, 1816,    0,    0,    0,    0, 1816, 1816, 1816, 1816,
 1816,    0, 1816,    0,    0, 1816, 1816, 1243, 1242, 1244,
 1816, 1816, 2307,    0, 1816, 1816, 1816, 1816, 1816, 1816,
 1816, 1816, 1816,    0, 1816,    0,    0,    0,    0,    0,
    0, 1243, 1242, 1244, 1816, 1816, 1816, 1816, 1816, 1816,
 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1816,
 1816, 1816, 1816, 1816, 1816,    0, 1816, 1816, 1816, 1816,
 1816, 1816,    0, 1816, 1816, 1816, 1816,    0, 1816,    0,
 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1816,
 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1816,    0, 1816,
 1816, 1816, 1816,    0, 1816, 1816, 1816, 1816, 1816,    0,
 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1816,
 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1816,
 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1816, 1817,
 1816, 1816, 1816, 1816,    0, 1816, 1816, 1816, 1816, 1816,
 1816,    0,    0, 1816, 1816, 1816, 1816, 1816, 1816, 1816,
 1816, 1816,    0,    0,    0,    0,    0, 1816,    0, 1816,
 1816, 1816, 1816, 1816, 1816,    0, 1816,    0,    0, 1631,
 1817, 1817, 1817, 1817, 1817, 1817, 1817,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1817, 1817, 1817,
 1817, 1817,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1227,
    0,    0,    0,    0,    0,    0,    0,    0, 1228,    0,
 1817,    0, 1817,    0,    0,    0,    0,    0,    0,    0,
    0, 1229,    0, 1227,    0,    0,    0,    0,    0,    0,
    0,    0, 1228,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1229,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1230,    0,    0,    0,    0,
    0,    0, 1231,    0,    0,    0,    0,    0,    0,    0,
 1232,    0,    0,    0,    0,    0,    0,    0,    0, 1230,
    0,    0,    0,    0,    0,    0, 1231, 1233,    0, 1234,
    0,    0,    0,    0, 1232,    0,    0,    0,    0, 1235,
    0, 1236, 1237, 1238,    0,    0,    0,    0, 1239,    0,
    0, 1233,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1235,    0, 1236, 1237, 1238,    0,    0,
    0,    0, 1239,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1240,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1240,    0,    0, 1817,    0, 1817,    0,
    0, 1817,    0, 1817, 1817,    0,    0, 1817, 1817,    0,
 1817,    0,    0,    0,    0,    0, 1817,    0, 1817, 1817,
 1817, 1817,    0, 1817,    0,    0, 1817,    0,    0, 1817,
    0,    0,    0,    0,    0,    0, 1817,    0, 1817, 1817,
    0, 1817, 1817, 1817, 1817, 1817,    0,    0, 1817,    0,
    0, 1817,    0, 1817, 1817,    0,    0, 1817, 1817, 1817,
    0, 1817, 1817, 1817, 1817, 1817, 1817, 1817,    0,    0,
    0, 1817, 1817, 1817, 1817, 1817,    0,    0,    0, 1817,
    0,    0,    0,    0,    0,    0,    0, 1817, 1817, 1817,
 1817, 1817, 1817,    0,    0,    0, 1817, 1817,    0, 1817,
    0, 1817,    0, 1817, 1817, 1817,    0, 1817,    0, 1817,
 1817, 1817,    0, 1817, 1817, 1817, 1817, 1817,    0, 1817,
 1817,    0,    0,    0,    0, 1817,    0, 1817, 1817,    0,
    0, 1817, 1817, 1817,    0,    0, 1817,    0, 1817,    0,
    0, 1817, 1817, 1817, 1817,    0, 1817,    0, 1817,    0,
 1817, 1817, 1817, 1817, 1817, 1241,    0, 1817, 1817, 1817,
    0, 1817, 1817,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1817, 1817, 1817,    0, 1817, 1817, 1817, 1241,
 1817,    0,    0,    0, 1817,    0, 1817, 1817, 1817, 1817,
    0, 1817,    0, 1817, 1817, 1817, 1817, 1817, 1817, 1817,
 1817,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1817, 1817, 2308, 1817, 1817, 1817,    0,    0,    0,    0,
 1817, 1817, 1817, 1817, 1817,    0, 1817,    0,    0, 1817,
 1817, 1243, 1242, 1244, 1817, 1817, 2588,    0, 1817, 1817,
 1817, 1817, 1817, 1817, 1817, 1817, 1817,    0, 1817,    0,
    0,    0,    0,    0,    0, 1243, 1242, 1244, 1817, 1817,
 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817,
 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817,    0,
 1817, 1817, 1817, 1817, 1817, 1817,    0, 1817, 1817, 1817,
 1817,    0, 1817,    0, 1817, 1817, 1817, 1817, 1817, 1817,
 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817,
 1817, 1817,    0, 1817, 1817, 1817, 1817,    0, 1817, 1817,
 1817, 1817, 1817,    0, 1817, 1817, 1817, 1817, 1817, 1817,
 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817,
 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817,
 1817, 1817, 1817, 1818, 1817, 1817, 1817, 1817,    0, 1817,
 1817, 1817, 1817, 1817, 1817,    0,    0, 1817, 1817, 1817,
 1817, 1817, 1817, 1817, 1817, 1817,    0,    0,    0,    0,
    0, 1817,    0, 1817, 1817, 1817, 1817, 1817, 1817,    0,
 1817,    0,    0, 1633, 1818, 1818, 1818, 1818, 1818, 1818,
 1818,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1818, 1818, 1818, 1818, 1818,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1227,    0,    0,    0,    0,    0,    0,
    0,    0, 1228,    0, 1818,    0, 1818,    0,    0,    0,
    0,    0,    0,    0,    0, 1229,    0, 1227,    0,    0,
    0,    0,    0,    0,    0,    0, 1228,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1229,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1230,
    0,    0,    0,    0,    0,    0, 1231,    0,    0,    0,
    0,    0,    0,    0, 1232,    0,    0,    0,    0,    0,
    0,    0,    0, 1230,    0,    0,    0,    0,    0,    0,
 1231, 1233,    0, 1234,    0,    0,    0,    0, 1232,    0,
    0,    0,    0, 1235,    0, 1236, 1237, 1238,    0,    0,
    0,    0, 1239,    0,    0, 1233,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1235,    0, 1236,
 1237, 1238,    0,    0,    0,    0, 1239,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1240,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1240,    0,    0,
 1818,    0, 1818,    0,    0, 1818,    0, 1818, 1818,    0,
    0, 1818, 1818,    0, 1818,    0,    0,    0,    0,    0,
 1818,    0, 1818, 1818, 1818, 1818,    0, 1818,    0,    0,
 1818,    0,    0, 1818,    0,    0,    0,    0,    0,    0,
 1818,    0, 1818, 1818,    0, 1818, 1818, 1818, 1818, 1818,
    0,    0, 1818,    0,    0, 1818,    0, 1818, 1818,    0,
    0, 1818, 1818, 1818,    0, 1818, 1818, 1818, 1818, 1818,
 1818, 1818,    0,    0,    0, 1818, 1818, 1818, 1818, 1818,
    0,    0,    0, 1818,    0,    0,    0,    0,    0,    0,
    0, 1818, 1818, 1818, 1818, 1818, 1818,    0,    0,    0,
 1818, 1818,    0, 1818,    0, 1818,    0, 1818, 1818, 1818,
    0, 1818,    0, 1818, 1818, 1818,    0, 1818, 1818, 1818,
 1818, 1818,    0, 1818, 1818,    0,    0,    0,    0, 1818,
    0, 1818, 1818,    0,    0, 1818, 1818, 1818,    0,    0,
 1818,    0, 1818,    0,    0, 1818, 1818, 1818, 1818,    0,
 1818,    0, 1818,    0, 1818, 1818, 1818, 1818, 1818, 1241,
    0, 1818, 1818, 1818,    0, 1818, 1818,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1818, 1818, 1818,    0,
 1818, 1818, 1818, 1241, 1818,    0,    0,    0, 1818,    0,
 1818, 1818, 1818, 1818,    0, 1818,    0, 1818, 1818, 1818,
 1818, 1818, 1818, 1818, 1818,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1818, 1818, 2590, 1818, 1818, 1818,
    0,    0,    0,    0, 1818, 1818, 1818, 1818, 1818,    0,
 1818,    0,    0, 1818, 1818, 1243, 1242, 1244, 1818, 1818,
 2591,    0, 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818,
 1818,    0, 1818,    0,    0,    0,    0,    0,    0, 1243,
 1242, 1244, 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818,
 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818,
 1818, 1818, 1818,    0, 1818, 1818, 1818, 1818, 1818, 1818,
    0, 1818, 1818, 1818, 1818,    0, 1818,    0, 1818, 1818,
 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818,
 1818, 1818, 1818, 1818, 1818, 1818,    0, 1818, 1818, 1818,
 1818,    0, 1818, 1818, 1818, 1818, 1818,    0, 1818, 1818,
 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818,
 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818,
 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1819, 1818, 1818,
 1818, 1818,    0, 1818, 1818, 1818, 1818, 1818, 1818,    0,
    0, 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818, 1818,
    0,    0,    0,    0,    0, 1818,    0, 1818, 1818, 1818,
 1818, 1818, 1818,    0, 1818,    0,    0, 1634, 1819, 1819,
 1819, 1819, 1819, 1819, 1819,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1819, 1819, 1819, 1819, 1819,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1227,    0,    0,
    0,    0,    0,    0,    0,    0, 1228,    0, 1819,    0,
 1819,    0,    0,    0,    0,    0,    0,    0,    0, 1229,
    0, 1227,    0,    0,    0,    0,    0,    0,    0,    0,
 1228,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1229,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1230,    0,    0,    0,    0,    0,    0,
 1231,    0,    0,    0,    0,    0,    0,    0, 1232,    0,
    0,    0,    0,    0,    0,    0,    0, 1230,    0,    0,
    0,    0,    0,    0, 1231, 1233,    0, 1234,    0,    0,
    0,    0, 1232,    0,    0,    0,    0, 1235,    0, 1236,
 1237, 1238,    0,    0,    0,    0, 1239,    0,    0, 1233,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1235,    0, 1236, 1237, 1238,    0,    0,    0,    0,
 1239,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1240,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0,    0, 1819,    0, 1819,    0,    0, 1819,
    0, 1819, 1819,    0,    0, 1819, 1819,    0, 1819,    0,
    0,    0,    0,    0, 1819,    0, 1819, 1819, 1819, 1819,
    0, 1819,    0,    0, 1819,    0,    0, 1819,    0,    0,
    0,    0,    0,    0, 1819,    0, 1819, 1819,    0, 1819,
 1819, 1819, 1819, 1819,    0,    0, 1819,    0,    0, 1819,
    0, 1819, 1819,    0,    0, 1819, 1819, 1819,    0, 1819,
 1819, 1819, 1819, 1819, 1819, 1819,    0,    0,    0, 1819,
 1819, 1819, 1819, 1819,    0,    0,    0, 1819,    0,    0,
    0,    0,    0,    0,    0, 1819, 1819, 1819, 1819, 1819,
 1819,    0,    0,    0, 1819, 1819,    0, 1819,    0, 1819,
    0, 1819, 1819, 1819,    0, 1819,    0, 1819, 1819, 1819,
    0, 1819, 1819, 1819, 1819, 1819,    0, 1819, 1819,    0,
    0,    0,    0, 1819,    0, 1819, 1819,    0,    0, 1819,
 1819, 1819,    0,    0, 1819,    0, 1819,    0,    0, 1819,
 1819, 1819, 1819,    0, 1819,    0, 1819,    0, 1819, 1819,
 1819, 1819, 1819, 1241,    0, 1819, 1819, 1819,    0, 1819,
 1819,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1819, 1819, 1819,    0, 1819, 1819, 1819, 1241, 1819,    0,
    0,    0, 1819,    0, 1819, 1819, 1819, 1819,    0, 1819,
    0, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1819, 1819,
 2598, 1819, 1819, 1819,    0,    0,    0,    0, 1819, 1819,
 1819, 1819, 1819,    0, 1819,    0,    0, 1819, 1819, 1243,
 1242, 1244, 1819, 1819, 2601,    0, 1819, 1819, 1819, 1819,
 1819, 1819, 1819, 1819, 1819,    0, 1819,    0,    0,    0,
    0,    0,    0, 1243, 1242, 1244, 1819, 1819, 1819, 1819,
 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819,
 1819, 1819, 1819, 1819, 1819, 1819, 1819,    0, 1819, 1819,
 1819, 1819, 1819, 1819,    0, 1819, 1819, 1819, 1819,    0,
 1819,    0, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819,
 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819,
    0, 1819, 1819, 1819, 1819,    0, 1819, 1819, 1819, 1819,
 1819,    0, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819,
 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819,
 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819,
 1819, 1820, 1819, 1819, 1819, 1819,    0, 1819, 1819, 1819,
 1819, 1819, 1819,    0,    0, 1819, 1819, 1819, 1819, 1819,
 1819, 1819, 1819, 1819,    0,    0,    0,    0,    0, 1819,
    0, 1819, 1819, 1819, 1819, 1819, 1819,    0, 1819,    0,
    0, 1635, 1820, 1820, 1820, 1820, 1820, 1820, 1820,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1820,
 1820, 1820, 1820, 1820,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1227,    0,    0,    0,    0,    0,    0,    0,    0,
 1228,    0, 1820,    0, 1820,    0,    0,    0,    0,    0,
    0,    0,    0, 1229,    0, 1227,    0,    0,    0,    0,
    0,    0,    0,    0, 1228,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1229,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1230,    0,    0,
    0,    0,    0,    0, 1231,    0,    0,    0,    0,    0,
    0,    0, 1232,    0,    0,    0,    0,    0,    0,    0,
    0, 1230,    0,    0,    0,    0,    0,    0, 1231, 1233,
    0, 1234,    0,    0,    0,    0, 1232,    0,    0,    0,
    0, 1235,    0, 1236, 1237, 1238,    0,    0,    0,    0,
 1239,    0,    0, 1233,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1235,    0, 1236, 1237, 1238,
    0,    0,    0,    0, 1239,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1240,    0,    0, 1820,    0,
 1820,    0,    0, 1820,    0, 1820, 1820,    0,    0, 1820,
 1820,    0, 1820,    0,    0,    0,    0,    0, 1820,    0,
 1820, 1820, 1820, 1820,    0, 1820,    0,    0, 1820,    0,
    0, 1820,    0,    0,    0,    0,    0,    0, 1820,    0,
 1820, 1820,    0, 1820, 1820, 1820, 1820, 1820,    0,    0,
 1820,    0,    0, 1820,    0, 1820, 1820,    0,    0, 1820,
 1820, 1820,    0, 1820, 1820, 1820, 1820, 1820, 1820, 1820,
    0,    0,    0, 1820, 1820, 1820, 1820, 1820,    0,    0,
    0, 1820,    0,    0,    0,    0,    0,    0,    0, 1820,
 1820, 1820, 1820, 1820, 1820,    0,    0,    0, 1820, 1820,
    0, 1820,    0, 1820,    0, 1820, 1820, 1820,    0, 1820,
    0, 1820, 1820, 1820,    0, 1820, 1820, 1820, 1820, 1820,
    0, 1820, 1820,    0,    0,    0,    0, 1820,    0, 1820,
 1820,    0,    0, 1820, 1820, 1820,    0,    0, 1820,    0,
 1820,    0,    0, 1820, 1820, 1820, 1820,    0, 1820,    0,
 1820,    0, 1820, 1820, 1820, 1820, 1820, 1241,    0, 1820,
 1820, 1820,    0, 1820, 1820,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1820, 1820, 1820,    0, 1820, 1820,
 1820, 1241, 1820,    0,    0,    0, 1820,    0, 1820, 1820,
 1820, 1820,    0, 1820,    0, 1820, 1820, 1820, 1820, 1820,
 1820, 1820, 1820,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1820, 1820, 2602, 1820, 1820, 1820,    0,    0,
    0,    0, 1820, 1820, 1820, 1820, 1820,    0, 1820,    0,
    0, 1820, 1820, 1243, 1242, 1244, 1820, 1820, 2615,    0,
 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820,    0,
 1820,    0,    0,    0,    0,    0,    0, 1243, 1242, 1244,
 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820,
 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820,
 1820,    0, 1820, 1820, 1820, 1820, 1820, 1820,    0, 1820,
 1820, 1820, 1820,    0, 1820,    0, 1820, 1820, 1820, 1820,
 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820,
 1820, 1820, 1820, 1820,    0, 1820, 1820, 1820, 1820,    0,
 1820, 1820, 1820, 1820, 1820,    0, 1820, 1820, 1820, 1820,
 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820,
 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820,
 1820, 1820, 1820, 1820, 1820, 1821, 1820, 1820, 1820, 1820,
    0, 1820, 1820, 1820, 1820, 1820, 1820,    0,    0, 1820,
 1820, 1820, 1820, 1820, 1820, 1820, 1820, 1820,    0,    0,
    0,    0,    0, 1820,    0, 1820, 1820, 1820, 1820, 1820,
 1820,    0, 1820,    0,    0, 1636, 1821, 1821, 1821, 1821,
 1821, 1821, 1821,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1821, 1821, 1821, 1821, 1821,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1227,    0,    0,    0,    0,
    0,    0,    0,    0, 1228,    0, 1821,    0, 1821,    0,
    0,    0,    0,    0,    0,    0,    0, 1229,    0, 1227,
    0,    0,    0,    0,    0,    0,    0,    0, 1228,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1229,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1230,    0,    0,    0,    0,    0,    0, 1231,    0,
    0,    0,    0,    0,    0,    0, 1232,    0,    0,    0,
    0,    0,    0,    0,    0, 1230,    0,    0,    0,    0,
    0,    0, 1231, 1233,    0, 1234,    0,    0,    0,    0,
 1232,    0,    0,    0,    0, 1235,    0, 1236, 1237, 1238,
    0,    0,    0,    0, 1239,    0,    0, 1233,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1235,
    0, 1236, 1237, 1238,    0,    0,    0,    0, 1239,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1240,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1240,
    0,    0, 1821,    0, 1821,    0,    0, 1821,    0, 1821,
 1821,    0,    0, 1821, 1821,    0, 1821,    0,    0,    0,
    0,    0, 1821,    0, 1821, 1821, 1821, 1821,    0, 1821,
    0,    0, 1821,    0,    0, 1821,    0,    0,    0,    0,
    0,    0, 1821,    0, 1821, 1821,    0, 1821, 1821, 1821,
 1821, 1821,    0,    0, 1821,    0,    0, 1821,    0, 1821,
 1821,    0,    0, 1821, 1821, 1821,    0, 1821, 1821, 1821,
 1821, 1821, 1821, 1821,    0,    0,    0, 1821, 1821, 1821,
 1821, 1821,    0,    0,    0, 1821,    0,    0,    0,    0,
    0,    0,    0, 1821, 1821, 1821, 1821, 1821, 1821,    0,
    0,    0, 1821, 1821,    0, 1821,    0, 1821,    0, 1821,
 1821, 1821,    0, 1821,    0, 1821, 1821, 1821,    0, 1821,
 1821, 1821, 1821, 1821,    0, 1821, 1821,    0,    0,    0,
    0, 1821,    0, 1821, 1821,    0,    0, 1821, 1821, 1821,
    0,    0, 1821,    0, 1821,    0,    0, 1821, 1821, 1821,
 1821,    0, 1821,    0, 1821,    0, 1821, 1821, 1821, 1821,
 1821, 1241,    0, 1821, 1821, 1821,    0, 1821, 1821,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1821, 1821,
 1821,    0, 1821, 1821, 1821, 1241, 1821,    0,    0,    0,
 1821,    0, 1821, 1821, 1821, 1821,    0, 1821,    0, 1821,
 1821, 1821, 1821, 1821, 1821, 1821, 1821,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1821, 1821, 2620, 1821,
 1821, 1821,    0,    0,    0,    0, 1821, 1821, 1821, 1821,
 1821,    0, 1821,    0,    0, 1821, 1821, 1243, 1242, 1244,
 1821, 1821, 2621,    0, 1821, 1821, 1821, 1821, 1821, 1821,
 1821, 1821, 1821,    0, 1821,    0,    0,    0,    0,    0,
    0, 1243, 1242, 1244, 1821, 1821, 1821, 1821, 1821, 1821,
 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821,
 1821, 1821, 1821, 1821, 1821,    0, 1821, 1821, 1821, 1821,
 1821, 1821,    0, 1821, 1821, 1821, 1821,    0, 1821,    0,
 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821,
 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821,    0, 1821,
 1821, 1821, 1821,    0, 1821, 1821, 1821, 1821, 1821,    0,
 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821,
 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821,
 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1822,
 1821, 1821, 1821, 1821,    0, 1821, 1821, 1821, 1821, 1821,
 1821,    0,    0, 1821, 1821, 1821, 1821, 1821, 1821, 1821,
 1821, 1821,    0,    0,    0,    0,    0, 1821,    0, 1821,
 1821, 1821, 1821, 1821, 1821,    0, 1821,    0,    0, 1637,
 1822, 1822, 1822, 1822, 1822, 1822, 1822,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1822, 1822, 1822,
 1822, 1822,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1227,
    0,    0,    0,    0,    0,    0,    0,    0, 1228,    0,
 1822,    0, 1822,    0,    0,    0,    0,    0,    0,    0,
    0, 1229,    0, 1227,    0,    0,    0,    0,    0,    0,
    0,    0, 1228,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1229,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1230,    0,    0,    0,    0,
    0,    0, 1231,    0,    0,    0,    0,    0,    0,    0,
 1232,    0,    0,    0,    0,    0,    0,    0,    0, 1230,
    0,    0,    0,    0,    0,    0, 1231, 1233,    0, 1234,
    0,    0,    0,    0, 1232,    0,    0,    0,    0, 1235,
    0, 1236, 1237, 1238,    0,    0,    0,    0, 1239,    0,
    0, 1233,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1235,    0, 1236, 1237, 1238,    0,    0,
    0,    0, 1239,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1240,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1240,    0,    0, 1822,    0, 1822,    0,
    0, 1822,    0, 1822, 1822,    0,    0, 1822, 1822,    0,
 1822,    0,    0,    0,    0,    0, 1822,    0, 1822, 1822,
 1822, 1822,    0, 1822,    0,    0, 1822,    0,    0, 1822,
    0,    0,    0,    0,    0,    0, 1822,    0, 1822, 1822,
    0, 1822, 1822, 1822, 1822, 1822,    0,    0, 1822,    0,
    0, 1822,    0, 1822, 1822,    0,    0, 1822, 1822, 1822,
    0, 1822, 1822, 1822, 1822, 1822, 1822, 1822,    0,    0,
    0, 1822, 1822, 1822, 1822, 1822,    0,    0,    0, 1822,
    0,    0,    0,    0,    0,    0,    0, 1822, 1822, 1822,
 1822, 1822, 1822,    0,    0,    0, 1822, 1822,    0, 1822,
    0, 1822,    0, 1822, 1822, 1822,    0, 1822,    0, 1822,
 1822, 1822,    0, 1822, 1822, 1822, 1822, 1822,    0, 1822,
 1822,    0,    0,    0,    0, 1822,    0, 1822, 1822,    0,
    0, 1822, 1822, 1822,    0,    0, 1822,    0, 1822,    0,
    0, 1822, 1822, 1822, 1822,    0, 1822,    0, 1822,    0,
 1822, 1822, 1822, 1822, 1822, 1241,    0, 1822, 1822, 1822,
    0, 1822, 1822,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1822, 1822, 1822,    0, 1822, 1822, 1822, 1241,
 1822,    0,    0,    0, 1822,    0, 1822, 1822, 1822, 1822,
    0, 1822,    0, 1822, 1822, 1822, 1822, 1822, 1822, 1822,
 1822,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1822, 1822, 2622, 1822, 1822, 1822,    0,    0,    0,    0,
 1822, 1822, 1822, 1822, 1822,    0, 1822,    0,    0, 1822,
 1822, 1243, 1242, 1244, 1822, 1822, 2623,    0, 1822, 1822,
 1822, 1822, 1822, 1822, 1822, 1822, 1822,    0, 1822,    0,
    0,    0,    0,    0,    0, 1243, 1242, 1244, 1822, 1822,
 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822,
 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822,    0,
 1822, 1822, 1822, 1822, 1822, 1822,    0, 1822, 1822, 1822,
 1822,    0, 1822,    0, 1822, 1822, 1822, 1822, 1822, 1822,
 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822,
 1822, 1822,    0, 1822, 1822, 1822, 1822,    0, 1822, 1822,
 1822, 1822, 1822,    0, 1822, 1822, 1822, 1822, 1822, 1822,
 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822,
 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822,
 1822, 1822, 1822, 1823, 1822, 1822, 1822, 1822,    0, 1822,
 1822, 1822, 1822, 1822, 1822,    0,    0, 1822, 1822, 1822,
 1822, 1822, 1822, 1822, 1822, 1822,    0,    0,    0,    0,
    0, 1822,    0, 1822, 1822, 1822, 1822, 1822, 1822,    0,
 1822,    0,    0, 1639, 1823, 1823, 1823, 1823, 1823, 1823,
 1823,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1823, 1823, 1823, 1823, 1823,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1227,    0,    0,    0,    0,    0,    0,
    0,    0, 1228,    0, 1823,    0, 1823,    0,    0,    0,
    0,    0,    0,    0,    0, 1229,    0, 1227,    0,    0,
    0,    0,    0,    0,    0,    0, 1228,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1229,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1230,
    0,    0,    0,    0,    0,    0, 1231,    0,    0,    0,
    0,    0,    0,    0, 1232,    0,    0,    0,    0,    0,
    0,    0,    0, 1230,    0,    0,    0,    0,    0,    0,
 1231, 1233,    0, 1234,    0,    0,    0,    0, 1232,    0,
    0,    0,    0, 1235,    0, 1236, 1237, 1238,    0,    0,
    0,    0, 1239,    0,    0, 1233,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1235,    0, 1236,
 1237, 1238,    0,    0,    0,    0, 1239,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1240,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1240,    0,    0,
 1823,    0, 1823,    0,    0, 1823,    0, 1823, 1823,    0,
    0, 1823, 1823,    0, 1823,    0,    0,    0,    0,    0,
 1823,    0, 1823, 1823, 1823, 1823,    0, 1823,    0,    0,
 1823,    0,    0, 1823,    0,    0,    0,    0,    0,    0,
 1823,    0, 1823, 1823,    0, 1823, 1823, 1823, 1823, 1823,
    0,    0, 1823,    0,    0, 1823,    0, 1823, 1823,    0,
    0, 1823, 1823, 1823,    0, 1823, 1823, 1823, 1823, 1823,
 1823, 1823,    0,    0,    0, 1823, 1823, 1823, 1823, 1823,
    0,    0,    0, 1823,    0,    0,    0,    0,    0,    0,
    0, 1823, 1823, 1823, 1823, 1823, 1823,    0,    0,    0,
 1823, 1823,    0, 1823,    0, 1823,    0, 1823, 1823, 1823,
    0, 1823,    0, 1823, 1823, 1823,    0, 1823, 1823, 1823,
 1823, 1823,    0, 1823, 1823,    0,    0,    0,    0, 1823,
    0, 1823, 1823,    0,    0, 1823, 1823, 1823,    0,    0,
 1823,    0, 1823,    0,    0, 1823, 1823, 1823, 1823,    0,
 1823,    0, 1823,    0, 1823, 1823, 1823, 1823, 1823, 1241,
    0, 1823, 1823, 1823,    0, 1823, 1823,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1823, 1823, 1823,    0,
 1823, 1823, 1823, 1241, 1823,    0,    0,    0, 1823,    0,
 1823, 1823, 1823, 1823,    0, 1823,    0, 1823, 1823, 1823,
 1823, 1823, 1823, 1823, 1823,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1823, 1823, 2624, 1823, 1823, 1823,
    0,    0,    0,    0, 1823, 1823, 1823, 1823, 1823,    0,
 1823,    0,    0, 1823, 1823, 1243, 1242, 1244, 1823, 1823,
 2625,    0, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823,
 1823,    0, 1823,    0,    0,    0,    0,    0,    0, 1243,
 1242, 1244, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823,
 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823,
 1823, 1823, 1823,    0, 1823, 1823, 1823, 1823, 1823, 1823,
    0, 1823, 1823, 1823, 1823,    0, 1823,    0, 1823, 1823,
 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823,
 1823, 1823, 1823, 1823, 1823, 1823,    0, 1823, 1823, 1823,
 1823,    0, 1823, 1823, 1823, 1823, 1823,    0, 1823, 1823,
 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823,
 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823,
 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1824, 1823, 1823,
 1823, 1823,    0, 1823, 1823, 1823, 1823, 1823, 1823,    0,
    0, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823,
    0,    0,    0,    0,    0, 1823,    0, 1823, 1823, 1823,
 1823, 1823, 1823,    0, 1823,    0,    0, 1640, 1824, 1824,
 1824, 1824, 1824, 1824, 1824,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1824, 1824, 1824, 1824, 1824,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1227,    0,    0,
    0,    0,    0,    0,    0,    0, 1228,    0, 1824,    0,
 1824,    0,    0,    0,    0,    0,    0,    0,    0, 1229,
    0, 1227,    0,    0,    0,    0,    0,    0,    0,    0,
 1228,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1229,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1230,    0,    0,    0,    0,    0,    0,
 1231,    0,    0,    0,    0,    0,    0,    0, 1232,    0,
    0,    0,    0,    0,    0,    0,    0, 1230,    0,    0,
    0,    0,    0,    0, 1231, 1233,    0, 1234,    0,    0,
    0,    0, 1232,    0,    0,    0,    0, 1235,    0, 1236,
 1237, 1238,    0,    0,    0,    0, 1239,    0,    0, 1233,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1235,    0, 1236, 1237, 1238,    0,    0,    0,    0,
 1239,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1240,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0,    0, 1824,    0, 1824,    0,    0, 1824,
    0, 1824, 1824,    0,    0, 1824, 1824,    0, 1824,    0,
    0,    0,    0,    0, 1824,    0, 1824, 1824, 1824, 1824,
    0, 1824,    0,    0, 1824,    0,    0, 1824,    0,    0,
    0,    0,    0,    0, 1824,    0, 1824, 1824,    0, 1824,
 1824, 1824, 1824, 1824,    0,    0, 1824,    0,    0, 1824,
    0, 1824, 1824,    0,    0, 1824, 1824, 1824,    0, 1824,
 1824, 1824, 1824, 1824, 1824, 1824,    0,    0,    0, 1824,
 1824, 1824, 1824, 1824,    0,    0,    0, 1824,    0,    0,
    0,    0,    0,    0,    0, 1824, 1824, 1824, 1824, 1824,
 1824,    0,    0,    0, 1824, 1824,    0, 1824,    0, 1824,
    0, 1824, 1824, 1824,    0, 1824,    0, 1824, 1824, 1824,
    0, 1824, 1824, 1824, 1824, 1824,    0, 1824, 1824,    0,
    0,    0,    0, 1824,    0, 1824, 1824,    0,    0, 1824,
 1824, 1824,    0,    0, 1824,    0, 1824,    0,    0, 1824,
 1824, 1824, 1824,    0, 1824,    0, 1824,    0, 1824, 1824,
 1824, 1824, 1824, 1241,    0, 1824, 1824, 1824,    0, 1824,
 1824,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1824, 1824, 1824,    0, 1824, 1824, 1824, 1241, 1824,    0,
    0,    0, 1824,    0, 1824, 1824, 1824, 1824,    0, 1824,
    0, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1824, 1824,
 2626, 1824, 1824, 1824,    0,    0,    0,    0, 1824, 1824,
 1824, 1824, 1824,    0, 1824,    0,    0, 1824, 1824, 1243,
 1242, 1244, 1824, 1824, 2627,    0, 1824, 1824, 1824, 1824,
 1824, 1824, 1824, 1824, 1824,    0, 1824,    0,    0,    0,
    0,    0,    0, 1243, 1242, 1244, 1824, 1824, 1824, 1824,
 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824,
 1824, 1824, 1824, 1824, 1824, 1824, 1824,    0, 1824, 1824,
 1824, 1824, 1824, 1824,    0, 1824, 1824, 1824, 1824,    0,
 1824,    0, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824,
 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824,
    0, 1824, 1824, 1824, 1824,    0, 1824, 1824, 1824, 1824,
 1824,    0, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824,
 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824,
 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824,
 1824, 1825, 1824, 1824, 1824, 1824,    0, 1824, 1824, 1824,
 1824, 1824, 1824,    0,    0, 1824, 1824, 1824, 1824, 1824,
 1824, 1824, 1824, 1824,    0,    0,    0,    0,    0, 1824,
    0, 1824, 1824, 1824, 1824, 1824, 1824,    0, 1824,    0,
    0, 1641, 1825, 1825, 1825, 1825, 1825, 1825, 1825,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1825,
 1825, 1825, 1825, 1825,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1227,    0,    0,    0,    0,    0,    0,    0,    0,
 1228,    0, 1825,    0, 1825,    0,    0,    0,    0,    0,
    0,    0,    0, 1229,    0, 1227,    0,    0,    0,    0,
    0,    0,    0,    0, 1228,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1229,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1230,    0,    0,
    0,    0,    0,    0, 1231,    0,    0,    0,    0,    0,
    0,    0, 1232,    0,    0,    0,    0,    0,    0,    0,
    0, 1230,    0,    0,    0,    0,    0,    0, 1231, 1233,
    0, 1234,    0,    0,    0,    0, 1232,    0,    0,    0,
    0, 1235,    0, 1236, 1237, 1238,    0,    0,    0,    0,
 1239,    0,    0, 1233,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1235,    0, 1236, 1237, 1238,
    0,    0,    0,    0, 1239,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1240,    0,    0, 1825,    0,
 1825,    0,    0, 1825,    0, 1825, 1825,    0,    0, 1825,
 1825,    0, 1825,    0,    0,    0,    0,    0, 1825,    0,
 1825, 1825, 1825, 1825,    0, 1825,    0,    0, 1825,    0,
    0, 1825,    0,    0,    0,    0,    0,    0, 1825,    0,
 1825, 1825,    0, 1825, 1825, 1825, 1825, 1825,    0,    0,
 1825,    0,    0, 1825,    0, 1825, 1825,    0,    0, 1825,
 1825, 1825,    0, 1825, 1825, 1825, 1825, 1825, 1825, 1825,
    0,    0,    0, 1825, 1825, 1825, 1825, 1825,    0,    0,
    0, 1825,    0,    0,    0,    0,    0,    0,    0, 1825,
 1825, 1825, 1825, 1825, 1825,    0,    0,    0, 1825, 1825,
    0, 1825,    0, 1825,    0, 1825, 1825, 1825,    0, 1825,
    0, 1825, 1825, 1825,    0, 1825, 1825, 1825, 1825, 1825,
    0, 1825, 1825,    0,    0,    0,    0, 1825,    0, 1825,
 1825,    0,    0, 1825, 1825, 1825,    0,    0, 1825,    0,
 1825,    0,    0, 1825, 1825, 1825, 1825,    0, 1825,    0,
 1825,    0, 1825, 1825, 1825, 1825, 1825, 1241,    0, 1825,
 1825, 1825,    0, 1825, 1825,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1825, 1825, 1825,    0, 1825, 1825,
 1825, 1241, 1825,    0,    0,    0, 1825,    0, 1825, 1825,
 1825, 1825,    0, 1825,    0, 1825, 1825, 1825, 1825, 1825,
 1825, 1825, 1825,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1825, 1825, 2628, 1825, 1825, 1825,    0,    0,
    0,    0, 1825, 1825, 1825, 1825, 1825,    0, 1825,    0,
    0, 1825, 1825, 1243, 1242, 1244, 1825, 1825, 2629,    0,
 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825,    0,
 1825,    0,    0,    0,    0,    0,    0, 1243, 1242, 1244,
 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825,
 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825,
 1825,    0, 1825, 1825, 1825, 1825, 1825, 1825,    0, 1825,
 1825, 1825, 1825,    0, 1825,    0, 1825, 1825, 1825, 1825,
 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825,
 1825, 1825, 1825, 1825,    0, 1825, 1825, 1825, 1825,    0,
 1825, 1825, 1825, 1825, 1825,    0, 1825, 1825, 1825, 1825,
 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825,
 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825,
 1825, 1825, 1825, 1825, 1825, 1829, 1825, 1825, 1825, 1825,
    0, 1825, 1825, 1825, 1825, 1825, 1825,    0,    0, 1825,
 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825,    0,    0,
    0,    0,    0, 1825,    0, 1825, 1825, 1825, 1825, 1825,
 1825,    0, 1825,    0,    0, 1642, 1829, 1829, 1829, 1829,
 1829, 1829, 1829,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1829, 1829, 1829, 1829, 1829,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1227,    0,    0,    0,    0,
    0,    0,    0,    0, 1228,    0, 1829,    0, 1829,    0,
    0,    0,    0,    0,    0,    0,    0, 1229,    0, 1227,
    0,    0,    0,    0,    0,    0,    0,    0, 1228,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1229,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1230,    0,    0,    0,    0,    0,    0, 1231,    0,
    0,    0,    0,    0,    0,    0, 1232,    0,    0,    0,
    0,    0,    0,    0,    0, 1230,    0,    0,    0,    0,
    0,    0, 1231, 1233,    0, 1234,    0,    0,    0,    0,
 1232,    0,    0,    0,    0, 1235,    0, 1236, 1237, 1238,
    0,    0,    0,    0, 1239,    0,    0, 1233,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1235,
    0, 1236, 1237, 1238,    0,    0,    0,    0, 1239,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1240,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1240,
    0,    0, 1829,    0, 1829,    0,    0, 1829,    0, 1829,
 1829,    0,    0, 1829, 1829,    0, 1829,    0,    0,    0,
    0,    0, 1829,    0, 1829, 1829, 1829, 1829,    0, 1829,
    0,    0, 1829,    0,    0, 1829,    0,    0,    0,    0,
    0,    0, 1829,    0, 1829, 1829,    0, 1829, 1829, 1829,
 1829, 1829,    0,    0, 1829,    0,    0, 1829,    0, 1829,
 1829,    0,    0, 1829, 1829, 1829,    0, 1829, 1829, 1829,
 1829, 1829, 1829, 1829,    0,    0,    0, 1829, 1829, 1829,
 1829, 1829,    0,    0,    0, 1829,    0,    0,    0,    0,
    0,    0,    0, 1829, 1829, 1829, 1829, 1829, 1829,    0,
    0,    0, 1829, 1829,    0, 1829,    0, 1829,    0, 1829,
 1829, 1829,    0, 1829,    0, 1829, 1829, 1829,    0, 1829,
 1829, 1829, 1829, 1829,    0, 1829, 1829,    0,    0,    0,
    0, 1829,    0, 1829, 1829,    0,    0, 1829, 1829, 1829,
    0,    0, 1829,    0, 1829,    0,    0, 1829, 1829, 1829,
 1829,    0, 1829,    0, 1829,    0, 1829, 1829, 1829, 1829,
 1829, 1241,    0, 1829, 1829, 1829,    0, 1829, 1829,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1829, 1829,
 1829,    0, 1829, 1829, 1829, 1241, 1829,    0,    0,    0,
 1829,    0, 1829, 1829, 1829, 1829,    0, 1829,    0, 1829,
 1829, 1829, 1829, 1829, 1829, 1829, 1829,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1829, 1829, 2630, 1829,
 1829, 1829,    0,    0,    0,    0, 1829, 1829, 1829, 1829,
 1829,    0, 1829,    0,    0, 1829, 1829, 1243, 1242, 1244,
 1829, 1829, 2631,    0, 1829, 1829, 1829, 1829, 1829, 1829,
 1829, 1829, 1829,    0, 1829,    0,    0,    0,    0,    0,
    0, 1243, 1242, 1244, 1829, 1829, 1829, 1829, 1829, 1829,
 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829,
 1829, 1829, 1829, 1829, 1829,    0, 1829, 1829, 1829, 1829,
 1829, 1829,    0, 1829, 1829, 1829, 1829,    0, 1829,    0,
 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829,
 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829,    0, 1829,
 1829, 1829, 1829,    0, 1829, 1829, 1829, 1829, 1829,    0,
 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829,
 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829,
 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1830,
 1829, 1829, 1829, 1829,    0, 1829, 1829, 1829, 1829, 1829,
 1829,    0,    0, 1829, 1829, 1829, 1829, 1829, 1829, 1829,
 1829, 1829,    0,    0,    0,    0,    0, 1829,    0, 1829,
 1829, 1829, 1829, 1829, 1829,    0, 1829,    0,    0, 1643,
 1830, 1830, 1830, 1830, 1830, 1830, 1830,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1830, 1830, 1830,
 1830, 1830,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1227,
    0,    0,    0,    0,    0,    0,    0,    0, 1228,    0,
 1830,    0, 1830,    0,    0,    0,    0,    0,    0,    0,
    0, 1229,    0, 1227,    0,    0,    0,    0,    0,    0,
    0,    0, 1228,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1229,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1230,    0,    0,    0,    0,
    0,    0, 1231,    0,    0,    0,    0,    0,    0,    0,
 1232,    0,    0,    0,    0,    0,    0,    0,    0, 1230,
    0,    0,    0,    0,    0,    0, 1231, 1233,    0, 1234,
    0,    0,    0,    0, 1232,    0,    0,    0,    0, 1235,
    0, 1236, 1237, 1238,    0,    0,    0,    0, 1239,    0,
    0, 1233,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1235,    0, 1236, 1237, 1238,    0,    0,
    0,    0, 1239,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1240,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1240,    0,    0, 1830,    0, 1830,    0,
    0, 1830,    0, 1830, 1830,    0,    0, 1830, 1830,    0,
 1830,    0,    0,    0,    0,    0, 1830,    0, 1830, 1830,
 1830, 1830,    0, 1830,    0,    0, 1830,    0,    0, 1830,
    0,    0,    0,    0,    0,    0, 1830,    0, 1830, 1830,
    0, 1830, 1830, 1830, 1830, 1830,    0,    0, 1830,    0,
    0, 1830,    0, 1830, 1830,    0,    0, 1830, 1830, 1830,
    0, 1830, 1830, 1830, 1830, 1830, 1830, 1830,    0,    0,
    0, 1830, 1830, 1830, 1830, 1830,    0,    0,    0, 1830,
    0,    0,    0,    0,    0,    0,    0, 1830, 1830, 1830,
 1830, 1830, 1830,    0,    0,    0, 1830, 1830,    0, 1830,
    0, 1830,    0, 1830, 1830, 1830,    0, 1830,    0, 1830,
 1830, 1830,    0, 1830, 1830, 1830, 1830, 1830,    0, 1830,
 1830,    0,    0,    0,    0, 1830,    0, 1830, 1830,    0,
    0, 1830, 1830, 1830,    0,    0, 1830,    0, 1830,    0,
    0, 1830, 1830, 1830, 1830,    0, 1830,    0, 1830,    0,
 1830, 1830, 1830, 1830, 1830, 1241,    0, 1830, 1830, 1830,
    0, 1830, 1830,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1830, 1830, 1830,    0, 1830, 1830, 1830, 1241,
 1830,    0,    0,    0, 1830,    0, 1830, 1830, 1830, 1830,
    0, 1830,    0, 1830, 1830, 1830, 1830, 1830, 1830, 1830,
 1830,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1830, 1830, 2845, 1830, 1830, 1830,    0,    0,    0,    0,
 1830, 1830, 1830, 1830, 1830,    0, 1830,    0,    0, 1830,
 1830, 1243, 1242, 1244, 1830, 1830, 2846,    0, 1830, 1830,
 1830, 1830, 1830, 1830, 1830, 1830, 1830,    0, 1830,    0,
    0,    0,    0,    0,    0, 1243, 1242, 1244, 1830, 1830,
 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830,
 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830,    0,
 1830, 1830, 1830, 1830, 1830, 1830,    0, 1830, 1830, 1830,
 1830,    0, 1830,    0, 1830, 1830, 1830, 1830, 1830, 1830,
 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830,
 1830, 1830,    0, 1830, 1830, 1830, 1830,    0, 1830, 1830,
 1830, 1830, 1830,    0, 1830, 1830, 1830, 1830, 1830, 1830,
 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830,
 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830,
 1830, 1830, 1830, 1831, 1830, 1830, 1830, 1830,    0, 1830,
 1830, 1830, 1830, 1830, 1830,    0,    0, 1830, 1830, 1830,
 1830, 1830, 1830, 1830, 1830, 1830,    0,    0,    0,    0,
    0, 1830,    0, 1830, 1830, 1830, 1830, 1830, 1830,    0,
 1830,    0,    0, 1644, 1831, 1831, 1831, 1831, 1831, 1831,
 1831,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1831, 1831, 1831, 1831, 1831,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1227,    0,    0,    0,    0,    0,    0,
    0,    0, 1228,    0, 1831,    0, 1831,    0,    0,    0,
    0,    0,    0,    0,    0, 1229,    0, 1227,    0,    0,
    0,    0,    0,    0,    0,    0, 1228,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1229,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1230,
    0,    0,    0,    0,    0,    0, 1231,    0,    0,    0,
    0,    0,    0,    0, 1232,    0,    0,    0,    0,    0,
    0,    0,    0, 1230,    0,    0,    0,    0,    0,    0,
 1231, 1233,    0, 1234,    0,    0,    0,    0, 1232,    0,
    0,    0,    0, 1235,    0, 1236, 1237, 1238,    0,    0,
    0,    0, 1239,    0,    0, 1233,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1235,    0, 1236,
 1237, 1238,    0,    0,    0,    0, 1239,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1240,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1240,    0,    0,
 1831,    0, 1831,    0,    0, 1831,    0, 1831, 1831,    0,
    0, 1831, 1831,    0, 1831,    0,    0,    0,    0,    0,
 1831,    0, 1831, 1831, 1831, 1831,    0, 1831,    0,    0,
 1831,    0,    0, 1831,    0,    0,    0,    0,    0,    0,
 1831,    0, 1831, 1831,    0, 1831, 1831, 1831, 1831, 1831,
    0,    0, 1831,    0,    0, 1831,    0, 1831, 1831,    0,
    0, 1831, 1831, 1831,    0, 1831, 1831, 1831, 1831, 1831,
 1831, 1831,    0,    0,    0, 1831, 1831, 1831, 1831, 1831,
    0,    0,    0, 1831,    0,    0,    0,    0,    0,    0,
    0, 1831, 1831, 1831, 1831, 1831, 1831,    0,    0,    0,
 1831, 1831,    0, 1831,    0, 1831,    0, 1831, 1831, 1831,
    0, 1831,    0, 1831, 1831, 1831,    0, 1831, 1831, 1831,
 1831, 1831,    0, 1831, 1831,    0,    0,    0,    0, 1831,
    0, 1831, 1831,    0,    0, 1831, 1831, 1831,    0,    0,
 1831,    0, 1831,    0,    0, 1831, 1831, 1831, 1831,    0,
 1831,    0, 1831,    0, 1831, 1831, 1831, 1831, 1831, 1241,
    0, 1831, 1831, 1831,    0, 1831, 1831,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1831, 1831, 1831,    0,
 1831, 1831, 1831, 1241, 1831,    0,    0,    0, 1831,    0,
 1831, 1831, 1831, 1831,    0, 1831,    0, 1831, 1831, 1831,
 1831, 1831, 1831, 1831, 1831,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1831, 1831, 3005, 1831, 1831, 1831,
    0,    0,    0,    0, 1831, 1831, 1831, 1831, 1831,    0,
 1831,    0,    0, 1831, 1831, 1243, 1242, 1244, 1831, 1831,
 3010,    0, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831,
 1831,    0, 1831,    0,    0,    0,    0,    0,    0, 1243,
 1242, 1244, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831,
 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831,
 1831, 1831, 1831,    0, 1831, 1831, 1831, 1831, 1831, 1831,
    0, 1831, 1831, 1831, 1831,    0, 1831,    0, 1831, 1831,
 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831,
 1831, 1831, 1831, 1831, 1831, 1831,    0, 1831, 1831, 1831,
 1831,    0, 1831, 1831, 1831, 1831, 1831,    0, 1831, 1831,
 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831,
 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831,
 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1833, 1831, 1831,
 1831, 1831,    0, 1831, 1831, 1831, 1831, 1831, 1831,    0,
    0, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831,
    0,    0,    0,    0,    0, 1831,    0, 1831, 1831, 1831,
 1831, 1831, 1831,    0, 1831,    0,    0, 1645, 1833, 1833,
 1833, 1833, 1833, 1833, 1833,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1833, 1833, 1833, 1833, 1833,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1227,    0,    0,
    0,    0,    0,    0,    0,    0, 1228,    0, 1833,    0,
 1833,    0,    0,    0,    0,    0,    0,    0,    0, 1229,
    0, 1227,    0,    0,    0,    0,    0,    0,    0,    0,
 1228,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1229,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1230,    0,    0,    0,    0,    0,    0,
 1231,    0,    0,    0,    0,    0,    0,    0, 1232,    0,
    0,    0,    0,    0,    0,    0,    0, 1230,    0,    0,
    0,    0,    0,    0, 1231, 1233,    0, 1234,    0,    0,
    0,    0, 1232,    0,    0,    0,    0, 1235,    0, 1236,
 1237, 1238,    0,    0,    0,    0, 1239,    0,    0, 1233,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1235,    0, 1236, 1237, 1238,    0,    0,    0,    0,
 1239,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1240,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0,    0, 1833,    0, 1833,    0,    0, 1833,
    0, 1833, 1833,    0,    0, 1833, 1833,    0, 1833,    0,
    0,    0,    0,    0, 1833,    0, 1833, 1833, 1833, 1833,
    0, 1833,    0,    0, 1833,    0,    0, 1833,    0,    0,
    0,    0,    0,    0, 1833,    0, 1833, 1833,    0, 1833,
 1833, 1833, 1833, 1833,    0,    0, 1833,    0,    0, 1833,
    0, 1833, 1833,    0,    0, 1833, 1833, 1833,    0, 1833,
 1833, 1833, 1833, 1833, 1833, 1833,    0,    0,    0, 1833,
 1833, 1833, 1833, 1833,    0,    0,    0, 1833,    0,    0,
    0,    0,    0,    0,    0, 1833, 1833, 1833, 1833, 1833,
 1833,    0,    0,    0, 1833, 1833,    0, 1833,    0, 1833,
    0, 1833, 1833, 1833,    0, 1833,    0, 1833, 1833, 1833,
    0, 1833, 1833, 1833, 1833, 1833,    0, 1833, 1833,    0,
    0,    0,    0, 1833,    0, 1833, 1833,    0,    0, 1833,
 1833, 1833,    0,    0, 1833,    0, 1833,    0,    0, 1833,
 1833, 1833, 1833,    0, 1833,    0, 1833,    0, 1833, 1833,
 1833, 1833, 1833, 1241,    0, 1833, 1833, 1833,    0, 1833,
 1833,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1833, 1833, 1833,    0, 1833, 1833, 1833, 1241, 1833,    0,
    0,    0, 1833,    0, 1833, 1833, 1833, 1833,    0, 1833,
    0, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1833, 1833,
 3011, 1833, 1833, 1833,    0,    0,    0,    0, 1833, 1833,
 1833, 1833, 1833,    0, 1833,    0,    0, 1833, 1833, 1243,
 1242, 1244, 1833, 1833, 3012,    0, 1833, 1833, 1833, 1833,
 1833, 1833, 1833, 1833, 1833,    0, 1833,    0,    0,    0,
    0,    0,    0, 1243, 1242, 1244, 1833, 1833, 1833, 1833,
 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1833, 1833, 1833, 1833, 1833, 1833,    0, 1833, 1833,
 1833, 1833, 1833, 1833,    0, 1833, 1833, 1833, 1833,    0,
 1833,    0, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833,
    0, 1833, 1833, 1833, 1833,    0, 1833, 1833, 1833, 1833,
 1833,    0, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1835, 1833, 1833, 1833, 1833,    0, 1833, 1833, 1833,
 1833, 1833, 1833,    0,    0, 1833, 1833, 1833, 1833, 1833,
 1833, 1833, 1833, 1833,    0,    0,    0,    0,    0, 1833,
    0, 1833, 1833, 1833, 1833, 1833, 1833,    0, 1833,    0,
    0, 1647, 1835, 1835, 1835, 1835, 1835, 1835, 1835,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1835,
 1835, 1835, 1835, 1835,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1227,    0,    0,    0,    0,    0,    0,    0,    0,
 1228,    0, 1835,    0, 1835,    0,    0,    0,    0,    0,
    0,    0,    0, 1229,    0, 1227,    0,    0,    0,    0,
    0,    0,    0,    0, 1228,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1229,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1230,    0,    0,
    0,    0,    0,    0, 1231,    0,    0,    0,    0,    0,
    0,    0, 1232,    0,    0,    0,    0,    0,    0,    0,
    0, 1230,    0,    0,    0,    0,    0,    0, 1231, 1233,
    0, 1234,    0,    0,    0,    0, 1232,    0,    0,    0,
    0, 1235,    0, 1236, 1237, 1238,    0,    0,    0,    0,
 1239,    0,    0, 1233,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1235,    0, 1236, 1237, 1238,
    0,    0,    0,    0, 1239,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1240,    0,    0, 1835,    0,
 1835,    0,    0, 1835,    0, 1835, 1835,    0,    0, 1835,
 1835,    0, 1835,    0,    0,    0,    0,    0, 1835,    0,
 1835, 1835, 1835, 1835,    0, 1835,    0,    0, 1835,    0,
    0, 1835,    0,    0,    0,    0,    0,    0, 1835,    0,
 1835, 1835,    0, 1835, 1835, 1835, 1835, 1835,    0,    0,
 1835,    0,    0, 1835,    0, 1835, 1835,    0,    0, 1835,
 1835, 1835,    0, 1835, 1835, 1835, 1835, 1835, 1835, 1835,
    0,    0,    0, 1835, 1835, 1835, 1835, 1835,    0,    0,
    0, 1835,    0,    0,    0,    0,    0,    0,    0, 1835,
 1835, 1835, 1835, 1835, 1835,    0,    0,    0, 1835, 1835,
    0, 1835,    0, 1835,    0, 1835, 1835, 1835,    0, 1835,
    0, 1835, 1835, 1835,    0, 1835, 1835, 1835, 1835, 1835,
    0, 1835, 1835,    0,    0,    0,    0, 1835,    0, 1835,
 1835,    0,    0, 1835, 1835, 1835,    0,    0, 1835,    0,
 1835,    0,    0, 1835, 1835, 1835, 1835,    0, 1835,    0,
 1835,    0, 1835, 1835, 1835, 1835, 1835, 1241,    0, 1835,
 1835, 1835,    0, 1835, 1835,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1835, 1835, 1835,    0, 1835, 1835,
 1835, 1241, 1835,    0,    0,    0, 1835,    0, 1835, 1835,
 1835, 1835,    0, 1835,    0, 1835, 1835, 1835, 1835, 1835,
 1835, 1835, 1835,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1835, 1835, 3013, 1835, 1835, 1835,    0,    0,
    0,    0, 1835, 1835, 1835, 1835, 1835,    0, 1835,    0,
    0, 1835, 1835, 1243, 1242, 1244, 1835, 1835, 3020,    0,
 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835,    0,
 1835,    0,    0,    0,    0,    0,    0, 1243, 1242, 1244,
 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835,
 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835,
 1835,    0, 1835, 1835, 1835, 1835, 1835, 1835,    0, 1835,
 1835, 1835, 1835,    0, 1835,    0, 1835, 1835, 1835, 1835,
 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835,
 1835, 1835, 1835, 1835,    0, 1835, 1835, 1835, 1835,    0,
 1835, 1835, 1835, 1835, 1835,    0, 1835, 1835, 1835, 1835,
 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835,
 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835,
 1835, 1835, 1835, 1835, 1835, 1836, 1835, 1835, 1835, 1835,
    0, 1835, 1835, 1835, 1835, 1835, 1835,    0,    0, 1835,
 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835,    0,    0,
    0,    0,    0, 1835,    0, 1835, 1835, 1835, 1835, 1835,
 1835,    0, 1835,    0,    0, 1648, 1836, 1836, 1836, 1836,
 1836, 1836, 1836,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1836, 1836, 1836, 1836, 1836,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1227,    0,    0,    0,    0,
    0,    0,    0,    0, 1228,    0, 1836,    0, 1836,    0,
    0,    0,    0,    0,    0,    0,    0, 1229,    0, 1227,
    0,    0,    0,    0,    0,    0,    0,    0, 1228,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1229,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1230,    0,    0,    0,    0,    0,    0, 1231,    0,
    0,    0,    0,    0,    0,    0, 1232,    0,    0,    0,
    0,    0,    0,    0,    0, 1230,    0,    0,    0,    0,
    0,    0, 1231, 1233,    0, 1234,    0,    0,    0,    0,
 1232,    0,    0,    0,    0, 1235,    0, 1236, 1237, 1238,
    0,    0,    0,    0, 1239,    0,    0, 1233,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1235,
    0, 1236, 1237, 1238,    0,    0,    0,    0, 1239,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1240,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1240,
    0,    0, 1836,    0, 1836,    0,    0, 1836,    0, 1836,
 1836,    0,    0, 1836, 1836,    0, 1836,    0,    0,    0,
    0,    0, 1836,    0, 1836, 1836, 1836, 1836,    0, 1836,
    0,    0, 1836,    0,    0, 1836,    0,    0,    0,    0,
    0,    0, 1836,    0, 1836, 1836,    0, 1836, 1836, 1836,
 1836, 1836,    0,    0, 1836,    0,    0, 1836,    0, 1836,
 1836,    0,    0, 1836, 1836, 1836,    0, 1836, 1836, 1836,
 1836, 1836, 1836, 1836,    0,    0,    0, 1836, 1836, 1836,
 1836, 1836,    0,    0,    0, 1836,    0,    0,    0,    0,
    0,    0,    0, 1836, 1836, 1836, 1836, 1836, 1836,    0,
    0,    0, 1836, 1836,    0, 1836,    0, 1836,    0, 1836,
 1836, 1836,    0, 1836,    0, 1836, 1836, 1836,    0, 1836,
 1836, 1836, 1836, 1836,    0, 1836, 1836,    0,    0,    0,
    0, 1836,    0, 1836, 1836,    0,    0, 1836, 1836, 1836,
    0,    0, 1836,    0, 1836,    0,    0, 1836, 1836, 1836,
 1836,    0, 1836,    0, 1836,    0, 1836, 1836, 1836, 1836,
 1836, 1241,    0, 1836, 1836, 1836,    0, 1836, 1836,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1836, 1836,
 1836,    0, 1836, 1836, 1836, 1241, 1836,    0,    0,    0,
 1836,    0, 1836, 1836, 1836, 1836,    0, 1836,    0, 1836,
 1836, 1836, 1836, 1836, 1836, 1836, 1836,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1836, 1836, 3021, 1836,
 1836, 1836,    0,    0,    0,    0, 1836, 1836, 1836, 1836,
 1836,    0, 1836,    0,    0, 1836, 1836, 1243, 1242, 1244,
 1836, 1836, 3099,    0, 1836, 1836, 1836, 1836, 1836, 1836,
 1836, 1836, 1836,    0, 1836,    0,    0,    0,    0,    0,
    0, 1243, 1242, 1244, 1836, 1836, 1836, 1836, 1836, 1836,
 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836,
 1836, 1836, 1836, 1836, 1836,    0, 1836, 1836, 1836, 1836,
 1836, 1836,    0, 1836, 1836, 1836, 1836,    0, 1836,    0,
 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836,
 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836,    0, 1836,
 1836, 1836, 1836,    0, 1836, 1836, 1836, 1836, 1836,    0,
 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836,
 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836,
 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1837,
 1836, 1836, 1836, 1836,    0, 1836, 1836, 1836, 1836, 1836,
 1836,    0,    0, 1836, 1836, 1836, 1836, 1836, 1836, 1836,
 1836, 1836,    0,    0,    0,    0,    0, 1836,    0, 1836,
 1836, 1836, 1836, 1836, 1836,    0, 1836,    0,    0, 1649,
 1837, 1837, 1837, 1837, 1837, 1837, 1837,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1837, 1837, 1837,
 1837, 1837,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1227,
    0,    0,    0,    0,    0,    0,    0,    0, 1228,    0,
 1837,    0, 1837,    0,    0,    0,    0,    0,    0,    0,
    0, 1229,    0, 1227,    0,    0,    0,    0,    0,    0,
    0,    0, 1228,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1229,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1230,    0,    0,    0,    0,
    0,    0, 1231,    0,    0,    0,    0,    0,    0,    0,
 1232,    0,    0,    0,    0,    0,    0,    0,    0, 1230,
    0,    0,    0,    0,    0,    0, 1231, 1233,    0, 1234,
    0,    0,    0,    0, 1232,    0,    0,    0,    0, 1235,
    0, 1236, 1237, 1238,    0,    0,    0,    0, 1239,    0,
    0, 1233,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1235,    0, 1236, 1237, 1238,    0,    0,
    0,    0, 1239,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1240,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1240,    0,    0, 1837,    0, 1837,    0,
    0, 1837,    0, 1837, 1837,    0,    0, 1837, 1837,    0,
 1837,    0,    0,    0,    0,    0, 1837,    0, 1837, 1837,
 1837, 1837,    0, 1837,    0,    0, 1837,    0,    0, 1837,
    0,    0,    0,    0,    0,    0, 1837,    0, 1837, 1837,
    0, 1837, 1837, 1837, 1837, 1837,    0,    0, 1837,    0,
    0, 1837,    0, 1837, 1837,    0,    0, 1837, 1837, 1837,
    0, 1837, 1837, 1837, 1837, 1837, 1837, 1837,    0,    0,
    0, 1837, 1837, 1837, 1837, 1837,    0,    0,    0, 1837,
    0,    0,    0,    0,    0,    0,    0, 1837, 1837, 1837,
 1837, 1837, 1837,    0,    0,    0, 1837, 1837,    0, 1837,
    0, 1837,    0, 1837, 1837, 1837,    0, 1837,    0, 1837,
 1837, 1837,    0, 1837, 1837, 1837, 1837, 1837,    0, 1837,
 1837,    0,    0,    0,    0, 1837,    0, 1837, 1837,    0,
    0, 1837, 1837, 1837,    0,    0, 1837,    0, 1837,    0,
    0, 1837, 1837, 1837, 1837,    0, 1837,    0, 1837,    0,
 1837, 1837, 1837, 1837, 1837, 1241,    0, 1837, 1837, 1837,
    0, 1837, 1837,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1837, 1837, 1837,    0, 1837, 1837, 1837, 1241,
 1837,    0,    0,    0, 1837,    0, 1837, 1837, 1837, 1837,
    0, 1837,    0, 1837, 1837, 1837, 1837, 1837, 1837, 1837,
 1837,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1837, 1837, 3174, 1837, 1837, 1837,    0,    0,    0,    0,
 1837, 1837, 1837, 1837, 1837,    0, 1837,    0,    0, 1837,
 1837, 1243, 1242, 1244, 1837, 1837, 3217,    0, 1837, 1837,
 1837, 1837, 1837, 1837, 1837, 1837, 1837,    0, 1837,    0,
    0,    0,    0,    0,    0, 1243, 1242, 1244, 1837, 1837,
 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837,
 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837,    0,
 1837, 1837, 1837, 1837, 1837, 1837,    0, 1837, 1837, 1837,
 1837,    0, 1837,    0, 1837, 1837, 1837, 1837, 1837, 1837,
 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837,
 1837, 1837,    0, 1837, 1837, 1837, 1837,    0, 1837, 1837,
 1837, 1837, 1837,    0, 1837, 1837, 1837, 1837, 1837, 1837,
 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837,
 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837,
 1837, 1837, 1837, 1838, 1837, 1837, 1837, 1837,    0, 1837,
 1837, 1837, 1837, 1837, 1837,    0,    0, 1837, 1837, 1837,
 1837, 1837, 1837, 1837, 1837, 1837,    0,    0,    0,    0,
    0, 1837,    0, 1837, 1837, 1837, 1837, 1837, 1837,    0,
 1837,    0,    0, 1650, 1838, 1838, 1838, 1838, 1838, 1838,
 1838,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1838, 1838, 1838, 1838, 1838,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1227,    0,    0,    0,    0,    0,    0,
    0,    0, 1228,    0, 1838,    0, 1838,    0,    0,    0,
    0,    0,    0,    0,    0, 1229,    0, 1227,    0,    0,
    0,    0,    0,    0,    0,    0, 1228,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1229,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1230,
    0,    0,    0,    0,    0,    0, 1231,    0,    0,    0,
    0,    0,    0,    0, 1232, 1056,    0,    0, 1057,    0,
    0,    0,    0, 1230,    0,    0,    0,    0,    0,    0,
 1231, 1233,    0, 1234, 1058,    0, 1059,    0, 1232,    0,
    0,    0,    0, 1235,    0, 1236, 1237, 1238,    0,    0,
    0,    0, 1239,    0,    0, 1233,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1235,    0, 1236,
 1237, 1238,    0,    0, 1060,    0, 1239,    0,    0,    0,
 1061, 1062, 1063,    0, 1064, 1065, 1066,    0, 1067,    0,
    0,    0,    0, 1240,    0,    0,    0,    0,    0,    0,
    0,    0, 1068,    0, 1069,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1240,    0,    0,
 1838,    0, 1838,    0,    0, 1838,    0, 1838, 1838,    0,
    0, 1838, 1838, 1070, 1838,    0,    0,    0,    0,    0,
 1838,    0, 1838, 1838, 1838, 1838,    0, 1838,    0, 1071,
 1838,    0,    0, 1838,    0,    0,    0,    0,    0,    0,
 1838,    0, 1838, 1838,    0, 1838, 1838, 1838, 1838, 1838,
    0, 1072, 1838,    0,    0, 1838,    0, 1838, 1838,    0,
    0, 1838, 1838, 1838,    0, 1838, 1838, 1838, 1838, 1838,
 1838, 1838,    0,    0,    0, 1838, 1838, 1838, 1838, 1838,
    0,    0,    0, 1838,    0, 1073, 1074,    0,    0,    0,
    0, 1838, 1838, 1838, 1838, 1838, 1838,    0,    0,    0,
 1838, 1838, 1075, 1838,    0, 1838,    0, 1838, 1838, 1838,
    0, 1838,    0, 1838, 1838, 1838,    0, 1838, 1838, 1838,
 1838, 1838,    0, 1838, 1838,    0,    0,    0,    0, 1838,
    0, 1838, 1838,    0,    0, 1838, 1838, 1838,    0,    0,
 1838,    0, 1838,    0,    0, 1838, 1838, 1838, 1838,    0,
 1838,    0, 1838,    0, 1838, 1838, 1838, 1838, 1838, 1241,
    0, 1838, 1838, 1838,    0, 1838, 1838,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1838, 1838, 1838,    0,
 1838, 1838, 1838, 1241, 1838,    0,    0,    0, 1838,    0,
 1838, 1838, 1838, 1838,    0, 1838,    0, 1838, 1838, 1838,
 1838, 1838, 1838, 1838, 1838,    0,    0,    0,    0, 1243,
 1242, 1244,    0,    0, 1838, 1838, 3227, 1838, 1838, 1838,
    0,    0,    0,    0, 1838, 1838, 1838, 1838, 1838,    0,
 1838,    0,    0, 1838, 1838, 1243, 1242, 1244, 1838, 1838,
    0,    0, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838,
 1838,    0, 1838,    0,    0,    0,    0,    0,    0,    0,
    0, 1076, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838,
 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838,
 1838, 1838, 1838,    0, 1838, 1838, 1838, 1838, 1838, 1838,
    0, 1838, 1838, 1838, 1838,    0, 1838,    0, 1838, 1838,
 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838,
 1838, 1838, 1838, 1838, 1838, 1838,    0, 1838, 1838, 1838,
 1838,    0, 1838, 1838, 1838, 1838, 1838,    0, 1838, 1838,
 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838,
 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838,
 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1841, 1838, 1838,
 1838, 1838,    0, 1838, 1838, 1838, 1838, 1838, 1838,    0,
    0, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838,
    0,    0,    0,    0,    0, 1838,    0, 1838, 1838, 1838,
 1838, 1838, 1838,    0, 1838,    0,    0, 1651, 1841, 1841,
 1841, 1841, 1841, 1841, 1841,    0,    0,    0,    0,    0,
    0, 1227,    0,    0,    0, 1841, 1841, 1841, 1841, 1841,
 1228,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1229,    0,    0,    0, 1227,    0,    0,
    0,    0,    0,    0,    0,    0, 1228,    0, 1841,    0,
 1841,    0,    0,    0,    0,    0,    0,    0,    0, 1229,
    0,    0,    0,    0,    0,    0,    0, 1230,    0,    0,
    0,    0,    0,    0, 1231,    0,    0,    0,    0,    0,
    0,    0, 1232,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1230,    0,    0,    0,    0,    0, 1233,
 1231, 1234,    0,    0,    0,    0,    0,    0, 1232,    0,
    0, 1235,    0, 1236, 1237, 1238,    0,    0,    0,    0,
 1239,    0,    0,    0,    0, 1233,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1235,    0, 1236,
 1237, 1238,    0,    0,    0,    0, 1239,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0,    0,    0,    0,    0,    0, 1695,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1240,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1841,    0, 1841,    0,    0, 1841,
    0, 1841, 1841,    0,    0, 1841, 1841,    0, 1841,    0,
    0,    0,    0,    0, 1841,    0, 1841, 1841, 1841, 1841,
    0, 1841,    0,    0, 1841,    0,    0, 1841,    0,    0,
    0,    0,    0,    0, 1841,    0, 1841, 1841,    0, 1841,
 1841, 1841, 1841, 1841,    0,    0, 1841,    0,    0, 1841,
    0, 1841, 1841,    0,    0, 1841, 1841, 1841,    0, 1841,
 1841, 1841, 1841, 1841, 1841, 1841,    0,    0,    0, 1841,
 1841, 1841, 1841, 1841,    0,    0,    0, 1841,    0,    0,
    0,    0,    0,    0,    0, 1841, 1841, 1841, 1841, 1841,
 1841,    0,    0,    0, 1841, 1841,    0, 1841,    0, 1841,
    0, 1841, 1841, 1841,    0, 1841,    0, 1841, 1841, 1841,
    0, 1841, 1841, 1841, 1841, 1841,    0, 1841, 1841,    0,
    0,    0,    0, 1841,    0, 1841, 1841, 1241,    0, 1841,
 1841, 1841,    0,    0, 1841,    0, 1841,    0,    0, 1841,
 1841, 1841, 1841,    0, 1841,    0, 1841,    0, 1841, 1841,
 1841, 1841, 1841, 1241,    0, 1841, 1841, 1841,    0, 1841,
 1841,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1841, 1841, 1841,    0, 1841, 1841, 1841,    0, 1841,    0,
    0,    0, 1841,    0, 1841, 1841, 1841, 1841, 1959, 1841,
    0, 1841, 1841, 1841, 1841, 1841, 1841, 1841, 1841,    0,
    0,    0,    0,    0, 1243, 1242, 1244,    0, 1841, 1841,
    0, 1841, 1841, 1841,    0,    0,    0,    0, 1841, 1841,
 1841, 1841, 1841,    0, 1841,    0,    0, 1841, 1841,    0,
    0,    0, 1841, 1841,    0,    0, 1841, 1841, 1841, 1841,
 1841, 1841, 1841, 1841, 1841,    0, 1841,    0,    0, 1243,
 1242, 1244,    0,    0,    0,    0, 1841, 1841, 1841, 1841,
 1841, 1841, 1841, 1841, 1841, 1841, 1841, 1841, 1841, 1841,
 1841, 1841, 1841, 1841, 1841, 1841, 1841,    0, 1841, 1841,
 1841, 1841, 1841, 1841,    0, 1841, 1841, 1841, 1841,    0,
 1841,    0, 1841, 1841, 1841, 1841, 1841, 1841, 1841, 1841,
 1841, 1841, 1841, 1841, 1841, 1841, 1841, 1841, 1841, 1841,
    0, 1841, 1841, 1841, 1841,    0, 1841, 1841, 1841, 1841,
 1841,    0, 1841, 1841, 1841, 1841, 1841, 1841, 1841, 1841,
 1841, 1841, 1841, 1841, 1841, 1841, 1841, 1841, 1841, 1841,
 1841, 1841, 1841, 1841, 1841, 1841, 1841, 1841, 1841, 1841,
 1841, 1843, 1841, 1841, 1841, 1841,    0, 1841, 1841, 1841,
 1841, 1841, 1841,    0,    0, 1841, 1841, 1841, 1841, 1841,
 1841, 1841, 1841, 1841,    0,    0,    0,    0,    0, 1841,
    0, 1841, 1841, 1841, 1841, 1841, 1841,    0, 1841,    0,
    0, 1652, 1843, 1843, 1843, 1843, 1843, 1843, 1843,    0,
    0,    0,    0,    0,    0,    0, 1227,    0,    0, 1843,
 1843, 1843, 1843, 1843,    0, 1228,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1229,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1843,    0, 1843,    0,    0,    0,    0,    0,
    0, 1227,    0, 1933,    0,    0,    0,    0,    0,    0,
 1228,    0, 1230,    0,    0,    0,    0,    0,    0, 1231,
    0,    0,    0, 1229,    0,    0,    0, 1232,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1233,    0, 1234,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1235, 1230, 1236, 1237,
 1238,    0,    0,    0, 1231, 1239,    0,    0,    0,    0,
    0,    0, 1232,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1233,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1235,    0, 1236, 1237, 1238, 1240,    0,    0,    0,
 1239,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0,    0,    0,    0,    0,    0, 1843,    0,
 1843,    0,    0, 1843,    0, 1843, 1843,    0,    0, 1843,
 1843,    0, 1843,    0,    0,    0,    0,    0, 1843,    0,
 1843, 1843, 1843, 1843,    0, 1843,    0,    0, 1843,    0,
    0, 1843,    0,    0,    0,    0,    0,    0, 1843,    0,
 1843, 1843,    0, 1843, 1843, 1843, 1843, 1843,    0,    0,
 1843,    0,    0, 1843,    0, 1843, 1843,    0,    0, 1843,
 1843, 1843,    0, 1843, 1843, 1843, 1843, 1843, 1843, 1843,
    0,    0,    0, 1843, 1843, 1843, 1843, 1843,    0,    0,
    0, 1843,    0,    0,    0,    0,    0,    0,    0, 1843,
 1843, 1843, 1843, 1843, 1843,    0,    0,    0, 1843, 1843,
    0, 1843,    0, 1843,    0, 1843, 1843, 1843,    0, 1843,
    0, 1843, 1843, 1843,    0, 1843, 1843, 1843, 1843, 1843,
    0, 1843, 1843,    0,    0,    0,    0, 1843,    0, 1843,
 1843,    0, 1241, 1843, 1843, 1843,    0,    0, 1843,    0,
 1843,    0,    0, 1843, 1843, 1843, 1843,    0, 1843,    0,
 1843,    0, 1843, 1843, 1843, 1843, 1843,    0,    0, 1843,
 1843, 1843,    0, 1843, 1843,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1843, 1843, 1843, 1241, 1843, 1843,
 1843,    0, 1843,    0,    0,    0, 1843,    0, 1843, 1843,
 1843, 1843, 1960, 1843,    0, 1843, 1843, 1843, 1843, 1843,
 1843, 1843, 1843,    0,    0,    0,    0,    0, 1243, 1242,
 1244,    0, 1843, 1843,    0, 1843, 1843, 1843,    0,    0,
    0,    0, 1843, 1843, 1843, 1843, 1843,    0, 1843,    0,
    0, 1843, 1843,    0,    0,    0, 1843, 1843,    0,    0,
 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843,    0,
 1843,    0,    0, 1243, 1242, 1244,    0,    0,    0,    0,
 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843,
 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843,
 1843,    0, 1843, 1843, 1843, 1843, 1843, 1843,    0, 1843,
 1843, 1843, 1843,    0, 1843,    0, 1843, 1843, 1843, 1843,
 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843,
 1843, 1843, 1843, 1843,    0, 1843, 1843, 1843, 1843,    0,
 1843, 1843, 1843, 1843, 1843,    0, 1843, 1843, 1843, 1843,
 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843,
 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843,
 1843, 1843, 1843, 1843, 1843, 1844, 1843, 1843, 1843, 1843,
    0, 1843, 1843, 1843, 1843, 1843, 1843,    0,    0, 1843,
 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843,    0,    0,
    0,    0,    0, 1843,    0, 1843, 1843, 1843, 1843, 1843,
 1843,    0, 1843,    0,    0, 1653, 1844, 1844, 1844, 1844,
 1844, 1844, 1844,    0,    0,    0,    0,    0,    0,    0,
 1227,    0,    0, 1844, 1844, 1844, 1844, 1844,    0, 1228,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1229,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1844,    0, 1844,    0,
    0,    0,    0,    0,    0, 1227,    0,    0,    0,    0,
    0,    0,    0,    0, 1228,    0, 1230,    0,    0,    0,
    0,    0,    0, 1231,    0,    0,    0, 1229,    0,    0,
    0, 1232,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1233,    0,
 1234,    0,    0,    0,    0,    0,    0, 1952,    0,    0,
 1235, 1230, 1236, 1237, 1238,    0,    0,    0, 1231, 1239,
    0,    0,    0,    0,    0,    0, 1232,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1233,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1235,    0, 1236, 1237, 1238,
 1240,    0,    0,    0, 1239,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1240,    0,    0,    0,    0,
    0,    0, 1844,    0, 1844,    0,    0, 1844,    0, 1844,
 1844,    0,    0, 1844, 1844,    0, 1844,    0,    0,    0,
    0,    0, 1844,    0, 1844, 1844, 1844, 1844,    0, 1844,
    0,    0, 1844,    0,    0, 1844,    0,    0,    0,    0,
    0,    0, 1844,    0, 1844, 1844,    0, 1844, 1844, 1844,
 1844, 1844,    0,    0, 1844,    0,    0, 1844,    0, 1844,
 1844,    0,    0, 1844, 1844, 1844,    0, 1844, 1844, 1844,
 1844, 1844, 1844, 1844,    0,    0,    0, 1844, 1844, 1844,
 1844, 1844,    0,    0,    0, 1844,    0,    0,    0,    0,
    0,    0,    0, 1844, 1844, 1844, 1844, 1844, 1844,    0,
    0,    0, 1844, 1844,    0, 1844,    0, 1844,    0, 1844,
 1844, 1844,    0, 1844,    0, 1844, 1844, 1844,    0, 1844,
 1844, 1844, 1844, 1844,    0, 1844, 1844,    0,    0,    0,
    0, 1844,    0, 1844, 1844,    0, 1241, 1844, 1844, 1844,
    0,    0, 1844,    0, 1844,    0,    0, 1844, 1844, 1844,
 1844,    0, 1844,    0, 1844,    0, 1844, 1844, 1844, 1844,
 1844,    0,    0, 1844, 1844, 1844,    0, 1844, 1844,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1844, 1844,
 1844, 1953, 1844, 1844, 1844,    0, 1844,    0,    0,    0,
 1844,    0, 1844, 1844, 1844, 1844, 1976, 1844,    0, 1844,
 1844, 1844, 1844, 1844, 1844, 1844, 1844,    0,    0,    0,
    0,    0, 1243, 1242, 1244,    0, 1844, 1844,    0, 1844,
 1844, 1844,    0,    0,    0,    0, 1844, 1844, 1844, 1844,
 1844,    0, 1844,    0,    0, 1844, 1844,    0,    0,    0,
 1844, 1844,    0,    0, 1844, 1844, 1844, 1844, 1844, 1844,
 1844, 1844, 1844,    0, 1844,    0,    0, 1243, 1242, 1244,
    0,    0,    0,    0, 1844, 1844, 1844, 1844, 1844, 1844,
 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844,
 1844, 1844, 1844, 1844, 1844,    0, 1844, 1844, 1844, 1844,
 1844, 1844,    0, 1844, 1844, 1844, 1844,    0, 1844,    0,
 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844,
 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844,    0, 1844,
 1844, 1844, 1844,    0, 1844, 1844, 1844, 1844, 1844,    0,
 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844,
 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844,
 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1847,
 1844, 1844, 1844, 1844,    0, 1844, 1844, 1844, 1844, 1844,
 1844,    0,    0, 1844, 1844, 1844, 1844, 1844, 1844, 1844,
 1844, 1844,    0,    0,    0,    0,    0, 1844,    0, 1844,
 1844, 1844, 1844, 1844, 1844,    0, 1844,    0,    0, 1654,
 1847, 1847, 1847, 1847, 1847, 1847, 1847,    0,    0,    0,
    0,    0,    0,    0, 1227,    0,    0, 1847, 1847, 1847,
 1847, 1847,    0, 1228,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1229,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1847,    0, 1847,    0,    0,    0,    0,    0,    0, 1227,
    0,    0,    0,    0,    0,    0,    0,    0, 1228,    0,
 1230,    0,    0,    0,    0,    0,    0, 1231,    0,    0,
    0, 1229,    0,    0,    0, 1232,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1233,    0, 1234,    0,    0,    0,    0,    0,
    0, 2321,    0,    0, 1235, 1230, 1236, 1237, 1238,    0,
    0,    0, 1231, 1239,    0,    0,    0,    0,    0,    0,
 1232,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1233,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1235,
    0, 1236, 1237, 1238, 1240,    0,    0,    0, 1239,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1240,
    0,    0,    0,    0,    0,    0, 1847,    0, 1847,    0,
    0, 1847,    0, 1847, 1847,    0,    0, 1847, 1847,    0,
 1847,    0,    0,    0,    0,    0, 1847,    0, 1847, 1847,
 1847, 1847,    0, 1847,    0,    0, 1847,    0,    0, 1847,
    0,    0,    0,    0,    0,    0, 1847,    0, 1847, 1847,
    0, 1847, 1847, 1847, 1847, 1847,    0,    0, 1847,    0,
    0, 1847,    0, 1847, 1847,    0,    0, 1847, 1847, 1847,
    0, 1847, 1847, 1847, 1847, 1847, 1847, 1847,    0,    0,
    0, 1847, 1847, 1847, 1847, 1847,    0,    0,    0, 1847,
    0,    0,    0,    0,    0,    0,    0, 1847, 1847, 1847,
 1847, 1847, 1847,    0,    0,    0, 1847, 1847,    0, 1847,
    0, 1847,    0, 1847, 1847, 1847,    0, 1847,    0, 1847,
 1847, 1847,    0, 1847, 1847, 1847, 1847, 1847,    0, 1847,
 1847,    0,    0,    0,    0, 1847,    0, 1847, 1847,    0,
 1241, 1847, 1847, 1847,    0,    0, 1847,    0, 1847,    0,
    0, 1847, 1847, 1847, 1847,    0, 1847,    0, 1847,    0,
 1847, 1847, 1847, 1847, 1847,    0,    0, 1847, 1847, 1847,
    0, 1847, 1847,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1847, 1847, 1847, 1241, 1847, 1847, 1847,    0,
 1847,    0,    0,    0, 1847,    0, 1847, 1847, 1847, 1847,
 1981, 1847,    0, 1847, 1847, 1847, 1847, 1847, 1847, 1847,
 1847,    0,    0,    0,    0,    0, 1243, 1242, 1244,    0,
 1847, 1847,    0, 1847, 1847, 1847,    0,    0,    0,    0,
 1847, 1847, 1847, 1847, 1847,    0, 1847,    0,    0, 1847,
 1847,    0,    0,    0, 1847, 1847,    0,    0, 1847, 1847,
 1847, 1847, 1847, 1847, 1847, 1847, 1847,    0, 1847,    0,
    0, 1243, 1242, 1244,    0,    0,    0,    0, 1847, 1847,
 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847,
 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847,    0,
 1847, 1847, 1847, 1847, 1847, 1847,    0, 1847, 1847, 1847,
 1847,    0, 1847,    0, 1847, 1847, 1847, 1847, 1847, 1847,
 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847,
 1847, 1847,    0, 1847, 1847, 1847, 1847,    0, 1847, 1847,
 1847, 1847, 1847,    0, 1847, 1847, 1847, 1847, 1847, 1847,
 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847,
 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847,
 1847, 1847, 1847, 1849, 1847, 1847, 1847, 1847,    0, 1847,
 1847, 1847, 1847, 1847, 1847,    0,    0, 1847, 1847, 1847,
 1847, 1847, 1847, 1847, 1847, 1847,    0,    0,    0,    0,
    0, 1847,    0, 1847, 1847, 1847, 1847, 1847, 1847,    0,
 1847,    0,    0, 1655, 1849, 1849, 1849, 1849, 1849, 1849,
 1849,    0,    0,    0,    0,    0,    0,    0, 1227,    0,
    0, 1849, 1849, 1849, 1849, 1849,    0, 1228,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1229,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1849,    0, 1849,    0,    0,    0,
    0,    0,    0, 1227,    0,    0,    0,    0,    0,    0,
    0,    0, 1228,    0, 1230,    0,    0,    0,    0,    0,
    0, 1231,    0,    0,    0, 1229,    0,    0,    0, 1232,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1233,    0, 1234,    0,
    0,    0,    0, 2592,    0,    0,    0,    0, 1235, 1230,
 1236, 1237, 1238,    0,    0,    0, 1231, 1239,    0,    0,
    0,    0,    0,    0, 1232,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1233,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1235,    0, 1236, 1237, 1238, 1240,    0,
    0,    0, 1239,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1240,    0,    0,    0,    0,    0,    0,
 1849,    0, 1849,    0,    0, 1849,    0, 1849, 1849,    0,
    0, 1849, 1849,    0, 1849,    0,    0,    0,    0,    0,
 1849,    0, 1849, 1849, 1849, 1849,    0, 1849,    0,    0,
 1849,    0,    0, 1849,    0,    0,    0,    0,    0,    0,
 1849,    0, 1849, 1849,    0, 1849, 1849, 1849, 1849, 1849,
    0,    0, 1849,    0,    0, 1849,    0, 1849, 1849,    0,
    0, 1849, 1849, 1849,    0, 1849, 1849, 1849, 1849, 1849,
 1849, 1849,    0,    0,    0, 1849, 1849, 1849, 1849, 1849,
    0,    0,    0, 1849,    0,    0,    0,    0,    0,    0,
    0, 1849, 1849, 1849, 1849, 1849, 1849,    0,    0,    0,
 1849, 1849,    0, 1849,    0, 1849,    0, 1849, 1849, 1849,
    0, 1849,    0, 1849, 1849, 1849,    0, 1849, 1849, 1849,
 1849, 1849,    0, 1849, 1849,    0,    0,    0,    0, 1849,
    0, 1849, 1849,    0, 1241, 1849, 1849, 1849,    0,    0,
 1849,    0, 1849,    0,    0, 1849, 1849, 1849, 1849,    0,
 1849,    0, 1849,    0, 1849, 1849, 1849, 1849, 1849,    0,
    0, 1849, 1849, 1849,    0, 1849, 1849,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1849, 1849, 1849, 1241,
 1849, 1849, 1849,    0, 1849,    0,    0,    0, 1849,    0,
 1849, 1849, 1849, 1849, 1991, 1849,    0, 1849, 1849, 1849,
 1849, 1849, 1849, 1849, 1849,    0,    0,    0,    0,    0,
 1243, 1242, 1244,    0, 1849, 1849,    0, 1849, 1849, 1849,
    0,    0,    0,    0, 1849, 1849, 1849, 1849, 1849,    0,
 1849,    0,    0, 1849, 1849,    0,    0,    0, 1849, 1849,
    0,    0, 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849,
 1849,    0, 1849,    0,    0, 1243, 1242, 1244,    0,    0,
    0,    0, 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849,
 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849,
 1849, 1849, 1849,    0, 1849, 1849, 1849, 1849, 1849, 1849,
    0, 1849, 1849, 1849, 1849,    0, 1849,    0, 1849, 1849,
 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849,
 1849, 1849, 1849, 1849, 1849, 1849,    0, 1849, 1849, 1849,
 1849,    0, 1849, 1849, 1849, 1849, 1849,    0, 1849, 1849,
 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849,
 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849,
 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1851, 1849, 1849,
 1849, 1849,    0, 1849, 1849, 1849, 1849, 1849, 1849,    0,
    0, 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849, 1849,
    0,    0,    0,    0,    0, 1849,    0, 1849, 1849, 1849,
 1849, 1849, 1849,    0, 1849,    0,    0, 1656, 1851, 1851,
 1851, 1851, 1851, 1851, 1851,    0,    0,    0,    0,    0,
    0,    0, 1227,    0,    0, 1851, 1851, 1851, 1851, 1851,
    0, 1228,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1229,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1851,    0,
 1851,    0,    0,    0,    0,    0,    0, 1227,    0,    0,
    0,    0,    0,    0,    0,    0, 1228,    0, 1230,    0,
    0,    0,    0,    0,    0, 1231,    0,    0,    0, 1229,
    0,    0,    0, 1232,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1233,    0, 1234,    0,    0,    0,    0,    0,    0, 2614,
    0,    0, 1235, 1230, 1236, 1237, 1238,    0,    0,    0,
 1231, 1239,    0,    0,    0,    0,    0,    0, 1232,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1233,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1235,    0, 1236,
 1237, 1238, 1240,    0,    0,    0, 1239,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1240,    0,    0,
    0,    0,    0,    0, 1851,    0, 1851,    0,    0, 1851,
    0, 1851, 1851,    0,    0, 1851, 1851,    0, 1851,    0,
    0,    0,    0,    0, 1851,    0, 1851, 1851, 1851, 1851,
    0, 1851,    0,    0, 1851,    0,    0, 1851,    0,    0,
    0,    0,    0,    0, 1851,    0, 1851, 1851,    0, 1851,
 1851, 1851, 1851, 1851,    0,    0, 1851,    0,    0, 1851,
    0, 1851, 1851,    0,    0, 1851, 1851, 1851,    0, 1851,
 1851, 1851, 1851, 1851, 1851, 1851,    0,    0,    0, 1851,
 1851, 1851, 1851, 1851,    0,    0,    0, 1851,    0,    0,
    0,    0,    0,    0,    0, 1851, 1851, 1851, 1851, 1851,
 1851,    0,    0,    0, 1851, 1851,    0, 1851,    0, 1851,
    0, 1851, 1851, 1851,    0, 1851,    0, 1851, 1851, 1851,
    0, 1851, 1851, 1851, 1851, 1851,    0, 1851, 1851,    0,
    0,    0,    0, 1851,    0, 1851, 1851,    0, 1241, 1851,
 1851, 1851,    0,    0, 1851,    0, 1851,    0,    0, 1851,
 1851, 1851, 1851,    0, 1851,    0, 1851,    0, 1851, 1851,
 1851, 1851, 1851,    0,    0, 1851, 1851, 1851,    0, 1851,
 1851,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1851, 1851, 1851, 1241, 1851, 1851, 1851,    0, 1851,    0,
    0,    0, 1851,    0, 1851, 1851, 1851, 1851, 1992, 1851,
    0, 1851, 1851, 1851, 1851, 1851, 1851, 1851, 1851,    0,
    0,    0,    0,    0, 1243, 1242, 1244,    0, 1851, 1851,
    0, 1851, 1851, 1851,    0,    0,    0,    0, 1851, 1851,
 1851, 1851, 1851,    0, 1851,    0,    0, 1851, 1851,    0,
    0,    0, 1851, 1851,    0,    0, 1851, 1851, 1851, 1851,
 1851, 1851, 1851, 1851, 1851,    0, 1851,    0,    0, 1243,
 1242, 1244,    0,    0,    0,    0, 1851, 1851, 1851, 1851,
 1851, 1851, 1851, 1851, 1851, 1851, 1851, 1851, 1851, 1851,
 1851, 1851, 1851, 1851, 1851, 1851, 1851,    0, 1851, 1851,
 1851, 1851, 1851, 1851,    0, 1851, 1851, 1851, 1851,    0,
 1851,    0, 1851, 1851, 1851, 1851, 1851, 1851, 1851, 1851,
 1851, 1851, 1851, 1851, 1851, 1851, 1851, 1851, 1851, 1851,
    0, 1851, 1851, 1851, 1851,    0, 1851, 1851, 1851, 1851,
 1851,    0, 1851, 1851, 1851, 1851, 1851, 1851, 1851, 1851,
 1851, 1851, 1851, 1851, 1851, 1851, 1851, 1851, 1851, 1851,
 1851, 1851, 1851, 1851, 1851, 1851, 1851, 1851, 1851, 1851,
 1851, 1852, 1851, 1851, 1851, 1851,    0, 1851, 1851, 1851,
 1851, 1851, 1851,    0,    0, 1851, 1851, 1851, 1851, 1851,
 1851, 1851, 1851, 1851,    0,    0,    0,    0,    0, 1851,
    0, 1851, 1851, 1851, 1851, 1851, 1851,    0, 1851,    0,
    0, 1659, 1852, 1852, 1852, 1852, 1852, 1852, 1852,    0,
    0,    0,    0,    0,    0,    0, 1227,    0,    0, 1852,
 1852, 1852, 1852, 1852,    0, 1228,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1229,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1852,    0, 1852,    0,    0,    0,    0,    0,
    0, 1227,    0,    0,    0,    0,    0,    0,    0,    0,
 1228,    0, 1230,    0,    0,    0,    0,    0,    0, 1231,
    0,    0,    0, 1229,    0,    0,    0, 1232,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1233,    0, 1234,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1235, 1230, 1236, 1237,
 1238,    0,    0,    0, 1231, 1239,    0,    0,    0,    0,
    0,    0, 1232,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1233,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1235,    0, 1236, 1237, 1238, 1240,    0,    0,    0,
 1239,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0,    0,    0,    0,    0,    0, 1852,    0,
 1852,    0,    0, 1852,    0, 1852, 1852,    0,    0, 1852,
 1852,    0, 1852,    0,    0,    0,    0,    0, 1852,    0,
 1852, 1852, 1852, 1852,    0, 1852,    0,    0, 1852,    0,
    0, 1852,    0,    0,    0,    0,    0,    0, 1852,    0,
 1852, 1852,    0, 1852, 1852, 1852, 1852, 1852,    0,    0,
 1852,    0,    0, 1852,    0, 1852, 1852,    0,    0, 1852,
 1852, 1852,    0, 1852, 1852, 1852, 1852, 1852, 1852, 1852,
    0,    0,    0, 1852, 1852, 1852, 1852, 1852,    0,    0,
    0, 1852,    0,    0,    0,    0,    0,    0,    0, 1852,
 1852, 1852, 1852, 1852, 1852,    0,    0,    0, 1852, 1852,
    0, 1852,    0, 1852,    0, 1852, 1852, 1852,    0, 1852,
    0, 1852, 1852, 1852,    0, 1852, 1852, 1852, 1852, 1852,
    0, 1852, 1852,    0,    0,    0,    0, 1852,    0, 1852,
 1852,    0, 1241, 1852, 1852, 1852,    0,    0, 1852,    0,
 1852,    0,    0, 1852, 1852, 1852, 1852,    0, 1852,    0,
 1852,    0, 1852, 1852, 1852, 1852, 1852,    0,    0, 1852,
 1852, 1852,    0, 1852, 1852,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1852, 1852, 1852, 1241, 1852, 1852,
 1852,    0, 1852,    0,    0,    0, 1852,    0, 1852, 1852,
 1852, 1852, 1993, 1852,    0, 1852, 1852, 1852, 1852, 1852,
 1852, 1852, 1852,    0,    0,    0,    0,    0, 1243, 1242,
 1244,    0, 1852, 1852,    0, 1852, 1852, 1852,    0,    0,
    0,    0, 1852, 1852, 1852, 1852, 1852,    0, 1852,    0,
    0, 1852, 1852,    0,    0,    0, 1852, 1852,    0,    0,
 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852,    0,
 1852,    0,    0, 1243, 1242, 1244,    0,    0,    0,    0,
 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852,
 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852,
 1852,    0, 1852, 1852, 1852, 1852, 1852, 1852,    0, 1852,
 1852, 1852, 1852,    0, 1852,    0, 1852, 1852, 1852, 1852,
 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852,
 1852, 1852, 1852, 1852,    0, 1852, 1852, 1852, 1852,    0,
 1852, 1852, 1852, 1852, 1852,    0, 1852, 1852, 1852, 1852,
 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852,
 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852,
 1852, 1852, 1852, 1852, 1852, 1853, 1852, 1852, 1852, 1852,
    0, 1852, 1852, 1852, 1852, 1852, 1852,    0,    0, 1852,
 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852,    0,    0,
    0,    0,    0, 1852,    0, 1852, 1852, 1852, 1852, 1852,
 1852,    0, 1852,    0,    0, 1660, 1853, 1853, 1853, 1853,
 1853, 1853, 1853,    0,    0,    0,    0,    0,    0,    0,
 1227,    0,    0, 1853, 1853, 1853, 1853, 1853,    0, 1228,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1229,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1853,    0, 1853,    0,
    0,    0,    0,    0,    0, 1227,    0,    0,    0,    0,
    0,    0,    0,    0, 1228,    0, 1230,    0,    0,    0,
    0,    0,    0, 1231,    0,    0,    0, 1229,    0,    0,
    0, 1232,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1233,    0,
 1234,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1235, 1230, 1236, 1237, 1238,    0,    0,    0, 1944, 1239,
    0,    0,    0,    0,    0,    0, 1232,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1233,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1235,    0, 1236, 1237, 1238,
 1240,    0,    0,    0, 1239,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1240,    0,    0,    0,    0,
    0,    0, 1853,    0, 1853,    0,    0, 1853,    0, 1853,
 1853,    0,    0, 1853, 1853,    0, 1853,    0,    0,    0,
    0,    0, 1853,    0, 1853, 1853, 1853, 1853,    0, 1853,
    0,    0, 1853,    0,    0, 1853,    0,    0,    0,    0,
    0,    0, 1853,    0, 1853, 1853,    0, 1853, 1853, 1853,
 1853, 1853,    0,    0, 1853,    0,    0, 1853,    0, 1853,
 1853,    0,    0, 1853, 1853, 1853,    0, 1853, 1853, 1853,
 1853, 1853, 1853, 1853,    0,    0,    0, 1853, 1853, 1853,
 1853, 1853,    0,    0,    0, 1853,    0,    0,    0,    0,
    0,    0,    0, 1853, 1853, 1853, 1853, 1853, 1853,    0,
    0,    0, 1853, 1853,    0, 1853,    0, 1853,    0, 1853,
 1853, 1853,    0, 1853,    0, 1853, 1853, 1853,    0, 1853,
 1853, 1853, 1853, 1853,    0, 1853, 1853,    0,    0,    0,
    0, 1853,    0, 1853, 1853,    0, 1241, 1853, 1853, 1853,
    0,    0, 1853,    0, 1853,    0,    0, 1853, 1853, 1853,
 1853,    0, 1853,    0, 1853,    0, 1853, 1853, 1853, 1853,
 1853,    0,    0, 1853, 1853, 1853,    0, 1853, 1853,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1853, 1853,
 1853, 1241, 1853, 1853, 1853,    0, 1853,    0,    0,    0,
 1853,    0, 1853, 1853, 1853, 1853, 1994, 1853,    0, 1853,
 1853, 1853, 1853, 1853, 1853, 1853, 1853,    0,    0,    0,
    0,    0, 1243, 1242, 1244,    0, 1853, 1853,    0, 1853,
 1853, 1853,    0,    0,    0,    0, 1853, 1853, 1853, 1853,
 1853,    0, 1853,    0,    0, 1853, 1853,    0,    0,    0,
 1853, 1853,    0,    0, 1853, 1853, 1853, 1853, 1853, 1853,
 1853, 1853, 1853,    0, 1853,    0,    0, 1468, 1468, 1468,
    0,    0,    0,    0, 1853, 1853, 1853, 1853, 1853, 1853,
 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853,
 1853, 1853, 1853, 1853, 1853,    0, 1853, 1853, 1853, 1853,
 1853, 1853,    0, 1853, 1853, 1853, 1853,    0, 1853,    0,
 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853,
 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853,    0, 1853,
 1853, 1853, 1853,    0, 1853, 1853, 1853, 1853, 1853,    0,
 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853,
 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853,
 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1854,
 1853, 1853, 1853, 1853,    0, 1853, 1853, 1853, 1853, 1853,
 1853,    0,    0, 1853, 1853, 1853, 1853, 1853, 1853, 1853,
 1853, 1853,    0,    0,    0,    0,    0, 1853,    0, 1853,
 1853, 1853, 1853, 1853, 1853,    0, 1853,    0,    0, 1662,
 1854, 1854, 1854, 1854, 1854, 1854, 1854,    0,    0,    0,
    0,    0,    0,    0, 1227,    0,    0, 1854, 1854, 1854,
 1854, 1854,    0, 1228,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1229,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1854,    0, 1854,    0,    0,    0,    0,    0,    0, 1468,
    0,    0,    0,    0,    0,    0,    0,    0, 1468,    0,
 1230,    0,    0,    0,    0,    0,    0, 1231,    0,    0,
    0, 1468,    0,    0,    0, 1232,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1233,    0, 1234,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1235, 1468, 1236, 1237, 1238,    0,
    0,    0, 1468, 1239,    0,    0,    0,    0,    0,    0,
 1468,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1468,    0, 1468,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1468,
    0, 1468, 1468, 1468, 1240,    0,    0,    0, 1468,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1468,
    0,    0,    0,    0,    0,    0, 1854,    0, 1854,    0,
    0, 1854,    0, 1854, 1854,    0,    0, 1854, 1854,    0,
 1854,    0,    0,    0,    0,    0, 1854,    0, 1854, 1854,
 1854, 1854,    0, 1854,    0,    0, 1854,    0,    0, 1854,
    0,    0,    0,    0,    0,    0, 1854,    0, 1854, 1854,
    0, 1854, 1854, 1854, 1854, 1854,    0,    0, 1854,    0,
    0, 1854,    0, 1854, 1854,    0,    0, 1854, 1854, 1854,
    0, 1854, 1854, 1854, 1854, 1854, 1854, 1854,    0,    0,
    0, 1854, 1854, 1854, 1854, 1854,    0,    0,    0, 1854,
    0,    0,    0,    0,    0,    0,    0, 1854, 1854, 1854,
 1854, 1854, 1854,    0,    0,    0, 1854, 1854,    0, 1854,
    0, 1854,    0, 1854, 1854, 1854,    0, 1854,    0, 1854,
 1854, 1854,    0, 1854, 1854, 1854, 1854, 1854,    0, 1854,
 1854,    0,    0,    0,    0, 1854,    0, 1854, 1854,    0,
 1241, 1854, 1854, 1854,    0,    0, 1854,    0, 1854,    0,
    0, 1854, 1854, 1854, 1854,    0, 1854,    0, 1854,    0,
 1854, 1854, 1854, 1854, 1854,    0,    0, 1854, 1854, 1854,
    0, 1854, 1854,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1854, 1854, 1854, 1468, 1854, 1854, 1854,    0,
 1854,    0,    0,    0, 1854,    0, 1854, 1854, 1854, 1854,
 1995, 1854,    0, 1854, 1854, 1854, 1854, 1854, 1854, 1854,
 1854,    0,    0,    0,    0,    0, 1243, 1242, 1244,    0,
 1854, 1854,    0, 1854, 1854, 1854,    0,    0,    0,    0,
 1854, 1854, 1854, 1854, 1854,    0, 1854,    0,    0, 1854,
 1854,    0,    0,    0, 1854, 1854,    0,    0, 1854, 1854,
 1854, 1854, 1854, 1854, 1854, 1854, 1854,    0, 1854,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1854, 1854,
 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854,
 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854,    0,
 1854, 1854, 1854, 1854, 1854, 1854,    0, 1854, 1854, 1854,
 1854,    0, 1854,    0, 1854, 1854, 1854, 1854, 1854, 1854,
 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854,
 1854, 1854,    0, 1854, 1854, 1854, 1854,    0, 1854, 1854,
 1854, 1854, 1854,    0, 1854, 1854, 1854, 1854, 1854, 1854,
 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854,
 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854,
 1854, 1854, 1854, 1855, 1854, 1854, 1854, 1854,    0, 1854,
 1854, 1854, 1854, 1854, 1854,    0,    0, 1854, 1854, 1854,
 1854, 1854, 1854, 1854, 1854, 1854,    0,    0,    0,    0,
    0, 1854,    0, 1854, 1854, 1854, 1854, 1854, 1854,    0,
 1854,    0,    0, 1663, 1855, 1855, 1855, 1855, 1855, 1855,
 1855,    0,    0,    0,    0,    0,    0,    0, 1227,    0,
    0, 1855, 1855, 1855, 1855, 1855,  155, 1228,    0,  155,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1229,  155,    0,    0,    0,  155,    0,  155,    0,    0,
    0,    0,    0,    0, 1855,    0, 1855,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  167,    0,    0,
  167,    0,    0,    0, 1230,    0,    0,    0,    0,    0,
    0, 1231,  167,    0,    0,  155,  167,    0,  167, 1232,
    0,  155,  155,  155,    0,  155,  155,  155,    0,  155,
    0,    0,    0,    0,    0,    0, 1233,    0, 1234,    0,
    0,    0,    0,  155,    0,  155,    0,    0, 1235,    0,
 1236, 1237, 1238,    0,    0,    0,  167, 1239,    0,    0,
    0,    0,  167,  167,  167,    0,  167,  167,  167,    0,
  167,    0,    0,    0,  155,    0,    0,    0,    0,  154,
    0,    0,    0,    0,  167,    0,  167,    0,    0,    0,
  155,    0,    0,    0,    0,    0,    0,    0, 1240,    0,
    0,    0,    0,    0,  167,    0,    0,    0,    0,    0,
    0,    0,  155,    0,    0,  167,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  167,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  155,  155,    0,    0,
 1855,    0, 1855,  167,    0, 1855,    0, 1855, 1855,    0,
    0, 1855, 1855,  155, 1855,    0,    0,    0,    0,    0,
 1855,    0, 1855, 1855, 1855, 1855,    0, 1855,    0,    0,
 1855,    0,    0, 1855,    0,    0,    0,  167,  167,    0,
 1855,    0, 1855, 1855,    0, 1855, 1855, 1855, 1855, 1855,
    0,    0, 1855,    0,  167, 1855,    0, 1855, 1855,    0,
    0, 1855, 1855, 1855,    0, 1855, 1855, 1855, 1855, 1855,
 1855, 1855,    0,    0,    0, 1855, 1855, 1855, 1855, 1855,
    0,    0,    0, 1855,    0,    0,    0,    0,    0,    0,
    0, 1855, 1855, 1855, 1855, 1855, 1855,    0,    0,    0,
 1855, 1855,    0, 1855,    0, 1855,    0, 1855, 1855, 1855,
    0, 1855,    0, 1855, 1855, 1855,    0, 1855, 1855, 1855,
 1855, 1855,    0, 1855, 1855,    0,    0,    0,    0, 1855,
    0, 1855, 1855,    0, 1241, 1855, 1855, 1855,    0,    0,
 1855,    0, 1855,    0,    0, 1855, 1855, 1855, 1855,    0,
 1855,    0, 1855,    0, 1855, 1855, 1855, 1855, 1855,    0,
    0, 1855, 1855, 1855,    0, 1855, 1855,    0,    0,    0,
    0,    0,  155,    0,    0,    0, 1855, 1855, 1855,    0,
 1855, 1855, 1855,    0, 1855,    0,    0,    0, 1855,    0,
 1855, 1855, 1855, 1855, 1996, 1855,    0, 1855, 1855, 1855,
 1855, 1855, 1855, 1855, 1855,    0,    0,    0,    0,    0,
 1243, 1242, 1244,  167, 1855, 1855,    0, 1855, 1855, 1855,
    0,    0,    0,    0, 1855, 1855, 1855, 1855, 1855,    0,
 1855,    0,    0, 1855, 1855,    0,    0,    0, 1855, 1855,
    0,    0, 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855,
 1855,    0, 1855,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855,
 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855,
 1855, 1855, 1855,    0, 1855, 1855, 1855, 1855, 1855, 1855,
    0, 1855, 1855, 1855, 1855,    0, 1855,    0, 1855, 1855,
 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855,
 1855, 1855, 1855, 1855, 1855, 1855,    0, 1855, 1855, 1855,
 1855,    0, 1855, 1855, 1855, 1855, 1855,    0, 1855, 1855,
 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855,
 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855,
 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1856, 1855, 1855,
 1855, 1855,    0, 1855, 1855, 1855, 1855, 1855, 1855,    0,
    0, 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855, 1855,
    0,    0,    0,    0,    0, 1855,    0, 1855, 1855, 1855,
 1855, 1855, 1855,    0, 1855,    0,    0, 1664, 1856, 1856,
 1856, 1856, 1856, 1856, 1856,    0,    0,    0,    0,    0,
    0,    0, 1227,    0,    0, 1856, 1856, 1856, 1856, 1856,
 2579, 1228,    0, 1057,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1229, 2580,    0,    0,    0, 1058,
    0, 1059,    0,    0,    0,    0,    0,    0, 1856,    0,
 1856,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  263,    0,    0,  263,    0,    0,    0, 1230,    0,
    0,    0,    0,    0,    0, 1231,    0,    0,    0, 1060,
  263,    0,  263, 1232,    0, 1061, 1062, 1063,    0, 1064,
 1065, 1066,    0, 1067,    0,    0,    0,    0,    0,    0,
 1233,    0, 1234,    0,    0,    0,    0, 1068,    0, 1069,
    0,    0, 1235,    0, 1236, 1237, 1238,    0,    0,    0,
  263, 1239,    0,    0,    0,    0,  263,  263,  263,    0,
  263,  263,  263,    0,  263,    0,    0,    0, 1070,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  263,    0,
  263,    0,    0,    0, 1071,    0,    0,    0,    0,    0,
    0,    0, 1240,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1072,    0,    0,  263,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  263,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1073, 1074,    0,    0, 1856,    0, 1856,  263,    0, 1856,
    0, 1856, 1856,    0,    0, 1856, 1856, 1075, 1856,    0,
    0,    0,    0,    0, 1856,    0, 1856, 1856, 1856, 1856,
    0, 1856,    0,    0, 1856,    0,    0, 1856,    0,    0,
    0,  263,  263,    0, 1856,    0, 1856, 1856,    0, 1856,
 1856, 1856, 1856, 1856,    0,    0, 1856,    0,  263, 1856,
    0, 1856, 1856,    0,    0, 1856, 1856, 1856,    0, 1856,
 1856, 1856, 1856, 1856, 1856, 1856,    0,    0,    0, 1856,
 1856, 1856, 1856, 1856,    0,    0,    0, 1856,    0,    0,
    0,    0,    0,    0,    0, 1856, 1856, 1856, 1856, 1856,
 1856,    0,    0,    0, 1856, 1856,    0, 1856,    0, 1856,
    0, 1856, 1856, 1856,    0, 1856,    0, 1856, 1856, 1856,
    0, 1856, 1856, 1856, 1856, 1856,    0, 1856, 1856,    0,
    0,    0,    0, 1856,    0, 1856, 1856,    0, 1241, 1856,
 1856, 1856,    0,    0, 1856,    0, 1856,    0,    0, 1856,
 1856, 1856, 1856,    0, 1856,    0, 1856,    0, 1856, 1856,
 1856, 1856, 1856,    0,    0, 1856, 1856, 1856,    0, 1856,
 1856,    0,    0,    0,    0,    0, 1076,    0,    0,    0,
 1856, 1856, 1856,    0, 1856, 1856, 1856,    0, 1856,    0,
    0,    0, 1856,    0, 1856, 1856, 1856, 1856, 1997, 1856,
    0, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856,    0,
    0,    0,    0,    0, 1243, 1242, 1244,  263, 1856, 1856,
    0, 1856, 1856, 1856,    0,    0,    0,    0, 1856, 1856,
 1856, 1856, 1856,    0, 1856,    0,    0, 1856, 1856,    0,
    0,    0, 1856, 1856,    0,    0, 1856, 1856, 1856, 1856,
 1856, 1856, 1856, 1856, 1856,    0, 1856,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1856, 1856, 1856, 1856,
 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856,
 1856, 1856, 1856, 1856, 1856, 1856, 1856,    0, 1856, 1856,
 1856, 1856, 1856, 1856,    0, 1856, 1856, 1856, 1856,    0,
 1856,    0, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856,
 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856,
    0, 1856, 1856, 1856, 1856,    0, 1856, 1856, 1856, 1856,
 1856,    0, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856,
 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856,
 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856,
 1856, 1857, 1856, 1856, 1856, 1856,    0, 1856, 1856, 1856,
 1856, 1856, 1856,    0,    0, 1856, 1856, 1856, 1856, 1856,
 1856, 1856, 1856, 1856,    0,    0,    0,    0,    0, 1856,
    0, 1856, 1856, 1856, 1856, 1856, 1856,    0, 1856,    0,
    0, 1665, 1857, 1857, 1857, 1857, 1857, 1857, 1857,    0,
    0,    0,    0,    0,    0,    0, 1227,    0,    0, 1857,
 1857, 1857, 1857, 1857,    0, 1228,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1621, 1229,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1857,    0, 1857,    0,    0,    0,    0,    0,
    0,    0, 1622,    0,    0,    0,    0,    0, 1623,    0,
    0,    0, 1230, 1624,    0,    0,    0,    0, 1625, 1231,
    0, 1626,    0,    0,    0,    0,    0, 1232,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1233,    0, 1234,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1235,    0, 1236, 1237,
 1238,    0,    0,    0,    0, 1239,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1627,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1240,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1628,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1629,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1630,    0,    0,    0,    0,    0, 1857,    0,
 1857,    0,    0, 1857,    0, 1857, 1857,    0,    0, 1857,
 1857,    0, 1857,    0,    0,    0,    0,    0, 1857,    0,
 1857, 1857, 1857, 1857,    0, 1857,    0,    0, 1857,    0,
    0, 1857,    0,    0,    0,    0,    0,    0, 1857,    0,
 1857, 1857,    0, 1857, 1857, 1857, 1857, 1857, 1631,    0,
 1857, 1632,    0, 1857,    0, 1857, 1857,    0,    0, 1857,
 1857, 1857,    0, 1857, 1857, 1857, 1857, 1857, 1857, 1857,
    0,    0,    0, 1857, 1857, 1857, 1857, 1857,    0,    0,
    0, 1857,    0,    0,    0,    0,    0,    0,    0, 1857,
 1857, 1857, 1857, 1857, 1857,    0,    0,    0, 1857, 1857,
    0, 1857,    0, 1857,    0, 1857, 1857, 1857,    0, 1857,
    0, 1857, 1857, 1857,    0, 1857, 1857, 1857, 1857, 1857,
    0, 1857, 1857,    0,    0,    0,    0, 1857,    0, 1857,
 1857,    0, 1241, 1857, 1857, 1857,    0,    0, 1857,    0,
 1857,    0,    0, 1857, 1857, 1857, 1857,    0, 1857,    0,
 1857,    0, 1857, 1857, 1857, 1857, 1857, 1633,    0, 1857,
 1857, 1857,    0, 1857, 1857,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1857, 1857, 1857,    0, 1857, 1857,
 1857,    0, 1857,    0,    0,    0, 1857,    0, 1857, 1857,
 1857, 1857, 1998, 1857,    0, 1857, 1857, 1857, 1857, 1857,
 1857, 1857, 1857,    0,    0,    0,    0,    0, 1243, 1242,
 1244,    0, 1857, 1857,    0, 1857, 1857, 1857,    0,    0,
    0,    0, 1857, 1857, 1857, 1857, 1857,    0, 1857,    0,
    0, 1857, 1857,    0,    0,    0, 1857, 1857,    0,    0,
 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857,    0,
 1857,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857,
 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857,
 1857,    0, 1857, 1857, 1857, 1857, 1857, 1857,    0, 1857,
 1857, 1857, 1857,    0, 1857,    0, 1857, 1857, 1857, 1857,
 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857,
 1857, 1857, 1857, 1857,    0, 1857, 1857, 1857, 1857,    0,
 1857, 1857, 1857, 1857, 1857,    0, 1857, 1857, 1857, 1857,
 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857,
 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857,
 1857, 1857, 1857, 1857, 1857, 1858, 1857, 1857, 1857, 1857,
    0, 1857, 1857, 1857, 1857, 1857, 1857,    0,    0, 1857,
 1857, 1857, 1857, 1857, 1857, 1857, 1857, 1857,    0,    0,
    0,    0,    0, 1857,    0, 1857, 1857, 1857, 1857, 1857,
 1857,    0, 1857,    0,    0, 1666, 1858, 1858, 1858, 1858,
 1858, 1858, 1858,    0,    0,    0,    0,    0,    0,    0,
 1227,    0,    0, 1858, 1858, 1858, 1858, 1858,    0, 1228,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   77, 1229,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1858,    0, 1858,    0,
    0,    0,    0,    0,    0,    0,   77,    0,    0,    0,
    0,    0,   77,    0,    0,    0, 1230,   77,    0,    0,
    0,    0,   77, 1231,    0,   77,    0,    0,    0,    0,
    0, 1232,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1233,    0,
 1234,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1235,    0, 1236, 1237, 1238,    0,    0,    0,    0, 1239,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   77,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1240,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   77,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   77,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   77,    0,    0,    0,
    0,    0, 1858,    0, 1858,    0,    0, 1858,    0, 1858,
 1858,    0,    0, 1858, 1858,    0, 1858,    0,    0,    0,
    0,    0, 1858,    0, 1858, 1858, 1858, 1858,    0, 1858,
    0,    0, 1858,    0,    0, 1858,    0,    0,    0,    0,
    0,    0, 1858,    0, 1858, 1858,    0, 1858, 1858, 1858,
 1858, 1858,   77,    0, 1858,   77,    0, 1858,    0, 1858,
 1858,    0,    0, 1858, 1858, 1858,    0, 1858, 1858, 1858,
 1858, 1858, 1858, 1858,    0,    0,    0, 1858, 1858, 1858,
 1858, 1858,    0,    0,    0, 1858,    0,    0,    0,    0,
    0,    0,    0, 1858, 1858, 1858, 1858, 1858, 1858,    0,
    0,    0, 1858, 1858,    0, 1858,    0, 1858,    0, 1858,
 1858, 1858,    0, 1858,    0, 1858, 1858, 1858,    0, 1858,
 1858, 1858, 1858, 1858,    0, 1858, 1858,    0,    0,    0,
    0, 1858,    0, 1858, 1858,    0, 1241, 1858, 1858, 1858,
    0,    0, 1858,    0, 1858,    0,    0, 1858, 1858, 1858,
 1858,    0, 1858,    0, 1858,    0, 1858, 1858, 1858, 1858,
 1858,   77,    0, 1858, 1858, 1858,    0, 1858, 1858,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1858, 1858,
 1858,    0, 1858, 1858, 1858,    0, 1858,    0,    0,    0,
 1858,    0, 1858, 1858, 1858, 1858, 1999, 1858,    0, 1858,
 1858, 1858, 1858, 1858, 1858, 1858, 1858,    0,    0,    0,
    0,    0, 1243, 1242, 1244,    0, 1858, 1858,    0, 1858,
 1858, 1858,    0,    0,    0,    0, 1858, 1858, 1858, 1858,
 1858,    0, 1858,    0,    0, 1858, 1858,    0,    0,    0,
 1858, 1858,    0,    0, 1858, 1858, 1858, 1858, 1858, 1858,
 1858, 1858, 1858,    0, 1858,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1858, 1858, 1858, 1858, 1858, 1858,
 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858,
 1858, 1858, 1858, 1858, 1858,    0, 1858, 1858, 1858, 1858,
 1858, 1858,    0, 1858, 1858, 1858, 1858,    0, 1858,    0,
 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858,
 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858,    0, 1858,
 1858, 1858, 1858,    0, 1858, 1858, 1858, 1858, 1858,    0,
 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858,
 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858,
 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1860,
 1858, 1858, 1858, 1858,    0, 1858, 1858, 1858, 1858, 1858,
 1858,    0,    0, 1858, 1858, 1858, 1858, 1858, 1858, 1858,
 1858, 1858,    0,    0,    0,    0,    0, 1858,    0, 1858,
 1858, 1858, 1858, 1858, 1858,    0, 1858,    0,    0, 1667,
 1860, 1860, 1860, 1860, 1860, 1860, 1860,    0,    0,    0,
    0,    0,    0,    0, 1227,    0,    0, 1860, 1860, 1860,
 1860, 1860,    0, 1228,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1229,    0,    0,    0,
    0,    0,    0,    0,    0,  106,    0,    0,    0,    0,
 1860,  107, 1860,    0,    0,  108,  109,    0,    0,    0,
    0,  110,    0,    0,  111,    0,    0,    0,    0,    0,
 1230,    0,    0,    0,  112,    0,    0, 1231,    0,    0,
    0,    0,    0,    0,    0, 1232,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1233,    0, 1234,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1235,    0, 1236, 1237, 1238,    0,
    0,    0,    0, 1239,    0,    0,    0,    0,    0,    0,
    0,    0,  113,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  114,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  115,    0, 1240,    0,  116,    0,    0,    0,
    0,  117,    0,    0,    0,    0,    0,  118,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  119,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1860,    0, 1860,    0,
    0, 1860,    0, 1860, 1860,    0,    0, 1860, 1860,    0,
 1860,    0,    0,    0,    0,    0, 1860,    0, 1860, 1860,
 1860, 1860,    0, 1860,    0,    0, 1860,    0,    0, 1860,
    0,  120,    0,    0,  121,    0, 1860,    0, 1860, 1860,
    0, 1860, 1860, 1860, 1860, 1860,    0,    0, 1860,    0,
    0, 1860,    0, 1860, 1860,    0,    0, 1860, 1860, 1860,
    0, 1860, 1860, 1860, 1860, 1860, 1860, 1860,    0,    0,
    0, 1860, 1860, 1860, 1860, 1860,    0,  122,    0, 1860,
    0,    0,    0,    0,    0,    0,    0, 1860, 1860, 1860,
 1860, 1860, 1860,    0,    0,    0, 1860, 1860,    0, 1860,
    0, 1860,    0, 1860, 1860, 1860,    0, 1860,    0, 1860,
 1860, 1860,    0, 1860, 1860, 1860, 1860, 1860,    0, 1860,
 1860,  123,    0,    0,    0, 1860,    0, 1860, 1860,    0,
 1241, 1860, 1860, 1860,    0,    0, 1860,    0, 1860,    0,
  124, 1860, 1860, 1860, 1860,    0, 1860,    0, 1860,    0,
 1860, 1860, 1860, 1860, 1860,    0,    0, 1860, 1860, 1860,
    0, 1860, 1860,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1860, 1860, 1860,    0, 1860, 1860, 1860,    0,
 1860,    0,    0,    0, 1860,    0, 1860, 1860, 1860, 1860,
 2000, 1860,    0, 1860, 1860, 1860, 1860, 1860, 1860, 1860,
 1860,    0,    0,    0,    0,    0, 1243, 1242, 1244,    0,
 1860, 1860,    0, 1860, 1860, 1860,    0,    0,    0,    0,
 1860, 1860, 1860, 1860, 1860,    0, 1860,    0,    0, 1860,
 1860,    0,    0,    0, 1860, 1860,    0,    0, 1860, 1860,
 1860, 1860, 1860, 1860, 1860, 1860, 1860,    0, 1860,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1860, 1860,
 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860,
 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860,    0,
 1860, 1860, 1860, 1860, 1860, 1860,    0, 1860, 1860, 1860,
 1860,    0, 1860,    0, 1860, 1860, 1860, 1860, 1860, 1860,
 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860,
 1860, 1860,    0, 1860, 1860, 1860, 1860,    0, 1860, 1860,
 1860, 1860, 1860,    0, 1860, 1860, 1860, 1860, 1860, 1860,
 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860,
 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860,
 1860, 1860, 1860, 1861, 1860, 1860, 1860, 1860,    0, 1860,
 1860, 1860, 1860, 1860, 1860,    0,    0, 1860, 1860, 1860,
 1860, 1860, 1860, 1860, 1860, 1860,    0,    0,    0,    0,
    0, 1860,    0, 1860, 1860, 1860, 1860, 1860, 1860,    0,
 1860,    0,    0, 1668, 1861, 1861, 1861, 1861, 1861, 1861,
 1861,    0,    0,    0,    0,    0,    0,    0, 1227,    0,
    0, 1861, 1861, 1861, 1861, 1861,    0, 1228,    0,    0,
 1893,    0,    0,    0,    0,    0, 1894,    0,    0,    0,
 1229,    0,    0,    0,    0,    0, 1895,    0,    0,    0,
    0,    0,    0,    0, 1861,    0, 1861,    0,    0, 1896,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1230,    0,    0,    0,    0,    0,
    0, 1231,    0,    0,    0,    0,    0,    0,    0, 1232,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1233,    0, 1234,    0,
    0,    0,    0,    0,    0,    0,    0, 1897, 1235,    0,
 1236, 1237, 1238,    0,    0,    0,    0, 1239,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1898,    0,    0,
    0, 1899,    0,    0,    0,    0, 1900,    0,    0,    0,
    0,    0, 1901,    0,    0,    0,    0,    0, 1240,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1902,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1861,    0, 1861,    0,    0, 1861,    0, 1861, 1861,    0,
    0, 1861, 1861,    0, 1861,    0, 1903,    0,    0, 1904,
 1861,    0, 1861, 1861, 1861, 1861,    0, 1861,    0,    0,
 1861,    0,    0, 1861,    0,    0,    0,    0,    0,    0,
 1861,    0, 1861, 1861,    0, 1861, 1861, 1861, 1861, 1861,
    0,    0, 1861,    0,    0, 1861,    0, 1861, 1861,    0,
    0, 1861, 1861, 1861,    0, 1861, 1861, 1861, 1861, 1861,
 1861, 1861,    0,    0,    0, 1861, 1861, 1861, 1861, 1861,
    0,    0,    0, 1861,    0,    0,    0,    0,    0,    0,
    0, 1861, 1861, 1861, 1861, 1861, 1861,    0,    0,    0,
 1861, 1861,    0, 1861,    0, 1861, 1905, 1861, 1861, 1861,
    0, 1861,    0, 1861, 1861, 1861,    0, 1861, 1861, 1861,
 1861, 1861,    0, 1861, 1861, 1906,    0,    0,    0, 1861,
    0, 1861, 1861,    0, 1241, 1861, 1861, 1861,    0,    0,
 1861,    0, 1861,    0,    0, 1861, 1861, 1861, 1861,    0,
 1861,    0, 1861,    0, 1861, 1861, 1861, 1861, 1861,    0,
    0, 1861, 1861, 1861,    0, 1861, 1861,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1861, 1861, 1861,    0,
 1861, 1861, 1861,    0, 1861,    0,    0,    0, 1861,    0,
 1861, 1861, 1861, 1861, 2001, 1861,    0, 1861, 1861, 1861,
 1861, 1861, 1861, 1861, 1861,    0,    0,    0,    0,    0,
 1243, 1242, 1244,    0, 1861, 1861,    0, 1861, 1861, 1861,
    0,    0,    0,    0, 1861, 1861, 1861, 1861, 1861,    0,
 1861,    0,    0, 1861, 1861,    0,    0,    0, 1861, 1861,
    0,    0, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861,
 1861,    0, 1861,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861,
 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861,
 1861, 1861, 1861,    0, 1861, 1861, 1861, 1861, 1861, 1861,
    0, 1861, 1861, 1861, 1861,    0, 1861,    0, 1861, 1861,
 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861,
 1861, 1861, 1861, 1861, 1861, 1861,    0, 1861, 1861, 1861,
 1861,    0, 1861, 1861, 1861, 1861, 1861,    0, 1861, 1861,
 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861,
 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861,
 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1862, 1861, 1861,
 1861, 1861,    0, 1861, 1861, 1861, 1861, 1861, 1861,    0,
    0, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861,
    0,    0,    0,    0,    0, 1861,    0, 1861, 1861, 1861,
 1861, 1861, 1861,    0, 1861,    0,    0, 1669, 1862, 1862,
 1862, 1862, 1862, 1862, 1862,    0,    0,    0,    0,    0,
    0,    0, 1227,    0,    0, 1862, 1862, 1862, 1862, 1862,
    0, 1228,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1229,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1862,    0,
 1862,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1230,    0,
    0,    0,    0,    0,    0, 1231,    0,    0,    0,    0,
    0,    0,    0, 1232,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1233,    0, 1234,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1235,    0, 1236, 1237, 1238,    0,    0,    0,
    0, 1239,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1240,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1862,    0, 1862,    0,    0, 1862,
    0, 1862, 1862,    0,    0, 1862, 1862,    0, 1862,    0,
    0,    0,    0,    0, 1862,    0, 1862, 1862, 1862, 1862,
    0, 1862,    0,    0, 1862,    0,    0, 1862,    0,    0,
    0,    0,    0,    0, 1862,    0, 1862, 1862,    0, 1862,
 1862, 1862, 1862, 1862,    0,    0, 1862,    0,    0, 1862,
    0, 1862, 1862,    0,    0, 1862, 1862, 1862,    0, 1862,
 1862, 1862, 1862, 1862, 1862, 1862,    0,    0,    0, 1862,
 1862, 1862, 1862, 1862,    0,    0,    0, 1862,    0,    0,
    0,    0,    0,    0,    0, 1862, 1862, 1862, 1862, 1862,
 1862,    0,    0,    0, 1862, 1862,    0, 1862,    0, 1862,
    0, 1862, 1862, 1862,    0, 1862,    0, 1862, 1862, 1862,
    0, 1862, 1862, 1862, 1862, 1862,    0, 1862, 1862,    0,
    0,    0,    0, 1862,    0, 1862, 1862,    0, 1241, 1862,
 1862, 1862,    0,    0, 1862,    0, 1862,    0,    0, 1862,
 1862, 1862, 1862,    0, 1862,    0, 1862,    0, 1862, 1862,
 1862, 1862, 1862,    0,    0, 1862, 1862, 1862,    0, 1862,
 1862,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1862, 1862, 1862,    0, 1862, 1862, 1862,    0, 1862,    0,
    0,    0, 1862,    0, 1862, 1862, 1862, 1862, 2002, 1862,
    0, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862,    0,
    0,    0,    0,    0, 1243, 1242, 1244,    0, 1862, 1862,
    0, 1862, 1862, 1862,    0,    0,    0,    0, 1862, 1862,
 1862, 1862, 1862,    0, 1862,    0,    0, 1862, 1862,    0,
    0,    0, 1862, 1862,    0,    0, 1862, 1862, 1862, 1862,
 1862, 1862, 1862, 1862, 1862,    0, 1862,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1862, 1862, 1862, 1862,
 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862,
 1862, 1862, 1862, 1862, 1862, 1862, 1862,    0, 1862, 1862,
 1862, 1862, 1862, 1862,    0, 1862, 1862, 1862, 1862,    0,
 1862,    0, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862,
 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862,
    0, 1862, 1862, 1862, 1862,    0, 1862, 1862, 1862, 1862,
 1862,    0, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862,
 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862,
 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862,
 1862, 1864, 1862, 1862, 1862, 1862,    0, 1862, 1862, 1862,
 1862, 1862, 1862,    0,    0, 1862, 1862, 1862, 1862, 1862,
 1862, 1862, 1862, 1862,    0,    0,    0,    0,    0, 1862,
    0, 1862, 1862, 1862, 1862, 1862, 1862,    0, 1862,    0,
    0, 1670, 1864, 1864, 1864, 1864, 1864, 1864, 1864,    0,
    0,    0,    0,    0,    0,    0, 1227,    0,    0, 1864,
 1864, 1864, 1864, 1864,    0, 1228,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1229,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1864,    0, 1864,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1230,    0,    0,    0,    0,    0,    0, 1231,
    0,    0,    0,    0,    0,    0,    0, 1232,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1233,    0, 1234,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1235,    0, 1236, 1237,
 1238,    0,    0,    0,    0, 1239,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1240,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1864,    0,
 1864,    0,    0, 1864,    0, 1864, 1864,    0,    0, 1864,
 1864,    0, 1864,    0,    0,    0,    0,    0, 1864,    0,
 1864, 1864, 1864, 1864,    0, 1864,    0,    0, 1864,    0,
    0, 1864,    0,    0,    0,    0,    0,    0, 1864,    0,
 1864, 1864,    0, 1864, 1864, 1864, 1864, 1864,    0,    0,
 1864,    0,    0, 1864,    0, 1864, 1864,    0,    0, 1864,
 1864, 1864,    0, 1864, 1864, 1864, 1864, 1864, 1864, 1864,
    0,    0,    0, 1864, 1864, 1864, 1864, 1864,    0,    0,
    0, 1864,    0,    0,    0,    0,    0,    0,    0, 1864,
 1864, 1864, 1864, 1864, 1864,    0,    0,    0, 1864, 1864,
    0, 1864,    0, 1864,    0, 1864, 1864, 1864,    0, 1864,
    0, 1864, 1864, 1864,    0, 1864, 1864, 1864, 1864, 1864,
    0, 1864, 1864,    0,    0,    0,    0, 1864,    0, 1864,
 1864,    0, 1241, 1864, 1864, 1864,    0,    0, 1864,    0,
 1864,    0,    0, 1864, 1864, 1864, 1864,    0, 1864,    0,
 1864,    0, 1864, 1864, 1864, 1864, 1864,    0,    0, 1864,
 1864, 1864,    0, 1864, 1864,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1864, 1864, 1864,    0, 1864, 1864,
 1864,    0, 1864,    0,    0,    0, 1864,    0, 1864, 1864,
 1864, 1864, 2328, 1864,    0, 1864, 1864, 1864, 1864, 1864,
 1864, 1864, 1864,    0,    0,    0,    0,    0, 1243, 1242,
 1244,    0, 1864, 1864,    0, 1864, 1864, 1864,    0,    0,
    0,    0, 1864, 1864, 1864, 1864, 1864,    0, 1864,    0,
    0, 1864, 1864,    0,    0,    0, 1864, 1864,    0,    0,
 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864,    0,
 1864,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864,
 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864,
 1864,    0, 1864, 1864, 1864, 1864, 1864, 1864,    0, 1864,
 1864, 1864, 1864,    0, 1864,    0, 1864, 1864, 1864, 1864,
 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864,
 1864, 1864, 1864, 1864,    0, 1864, 1864, 1864, 1864,    0,
 1864, 1864, 1864, 1864, 1864,    0, 1864, 1864, 1864, 1864,
 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864,
 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864,
 1864, 1864, 1864, 1864, 1864, 1867, 1864, 1864, 1864, 1864,
    0, 1864, 1864, 1864, 1864, 1864, 1864,    0,    0, 1864,
 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864,    0,    0,
    0,    0,    0, 1864,    0, 1864, 1864, 1864, 1864, 1864,
 1864,    0, 1864,    0,    0, 1638, 1867, 1867, 1867, 1867,
 1867, 1867, 1867,    0,    0,    0,    0,    0,    0,    0,
 1227,    0,    0, 1867, 1867, 1867, 1867, 1867,    0, 1228,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1229,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1867,    0, 1867,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1230,    0,    0,    0,
    0,    0,    0, 1231,    0,    0,    0,    0,    0,    0,
    0, 1232,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1233,    0,
 1234,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1235,    0, 1236, 1237, 1238,    0,    0,    0,    0, 1239,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1240,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1867,    0, 1867,    0,    0, 1867,    0, 1867,
 1867,    0,    0, 1867, 1867,    0, 1867,    0,    0,    0,
    0,    0, 1867,    0, 1867, 1867, 1867, 1867,    0, 1867,
    0,    0, 1867,    0,    0, 1867,    0,    0,    0,    0,
    0,    0, 1867,    0, 1867, 1867,    0, 1867, 1867, 1867,
 1867, 1867,    0,    0, 1867,    0,    0, 1867,    0, 1867,
 1867,    0,    0, 1867, 1867, 1867,    0, 1867, 1867, 1867,
 1867, 1867, 1867, 1867,    0,    0,    0, 1867, 1867, 1867,
 1867, 1867,    0,    0,    0, 1867,    0,    0,    0,    0,
    0,    0,    0, 1867, 1867, 1867, 1867, 1867, 1867,    0,
    0,    0, 1867, 1867,    0, 1867,    0, 1867,    0, 1867,
 1867, 1867,    0, 1867,    0, 1867, 1867, 1867,    0, 1867,
 1867, 1867, 1867, 1867,    0, 1867, 1867,    0,    0,    0,
    0, 1867,    0, 1867, 1867,    0, 1241, 1867, 1867, 1867,
    0,    0, 1867,    0, 1867,    0,    0, 1867, 1867, 1867,
 1867,    0, 1867,    0, 1867,    0, 1867, 1867, 1867, 1867,
 1867,    0,    0, 1867, 1867, 1867,    0, 1867, 1867,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1867, 1867,
 1867,    0, 1867, 1867, 1867,    0, 1867,    0,    0,    0,
 1867,    0, 1867, 1867, 1867, 1867, 2600, 1867,    0, 1867,
 1867, 1867, 1867, 1867, 1867, 1867, 1867,    0,    0,    0,
    0,    0, 1243, 1242, 1244,    0, 1867, 1867,    0, 1867,
 1867, 1867,    0,    0,    0,    0, 1867, 1867, 1867, 1867,
 1867,    0, 1867,    0,    0, 1867, 1867,    0,    0,    0,
 1867, 1867,    0,    0, 1867, 1867, 1867, 1867, 1867, 1867,
 1867, 1867, 1867,    0, 1867,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1867, 1867, 1867, 1867, 1867, 1867,
 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867,
 1867, 1867, 1867, 1867, 1867,    0, 1867, 1867, 1867, 1867,
 1867, 1867,    0, 1867, 1867, 1867, 1867,    0, 1867,    0,
 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867,
 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867,    0, 1867,
 1867, 1867, 1867,    0, 1867, 1867, 1867, 1867, 1867,    0,
 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867,
 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867,
 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1873,
 1867, 1867, 1867, 1867,    0, 1867, 1867, 1867, 1867, 1867,
 1867,    0,    0, 1867, 1867, 1867, 1867, 1867, 1867, 1867,
 1867, 1867,    0,    0,    0,    0,    0, 1867,    0, 1867,
 1867, 1867, 1867, 1867, 1867,    0, 1867,    0,    0, 1671,
 1873, 1873, 1873, 1873, 1873, 1873, 1873,    0,    0,    0,
    0,    0,    0,    0, 1227,    0,    0, 1873, 1873, 1873,
 1873, 1873,    0, 1228,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1229,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1873,    0, 1873,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1230,    0,    0,    0,    0,    0,    0, 1231,    0,    0,
    0,    0,    0,    0,    0, 1232,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1233,    0, 1234,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1235,    0, 1236, 1237, 1238,    0,
    0,    0,    0, 1239,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1240,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1873,    0, 1873,    0,
    0, 1873,    0, 1873, 1873,    0,    0, 1873, 1873,    0,
 1873,    0,    0,    0,    0,    0, 1873,    0, 1873, 1873,
 1873, 1873,    0, 1873,    0,    0, 1873,    0,    0, 1873,
    0,    0,    0,    0,    0,    0, 1873,    0, 1873, 1873,
    0, 1873, 1873, 1873, 1873, 1873,    0,    0, 1873,    0,
    0, 1873,    0, 1873, 1873,    0,    0, 1873, 1873, 1873,
    0, 1873, 1873, 1873, 1873, 1873, 1873, 1873,    0,    0,
    0, 1873, 1873, 1873, 1873, 1873,    0,    0,    0, 1873,
    0,    0,    0,    0,    0,    0,    0, 1873, 1873, 1873,
 1873, 1873, 1873,    0,    0,    0, 1873, 1873,    0, 1873,
    0, 1873,    0, 1873, 1873, 1873,    0, 1873,    0, 1873,
 1873, 1873,    0, 1873, 1873, 1873, 1873, 1873,    0, 1873,
 1873,    0,    0,    0,    0, 1873,    0, 1873, 1873,    0,
 1241, 1873, 1873, 1873,    0,    0, 1873,    0, 1873,    0,
    0, 1873, 1873, 1873, 1873,    0, 1873,    0, 1873,    0,
 1873, 1873, 1873, 1873, 1873,    0,    0, 1873, 1873, 1873,
    0, 1873, 1873,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1873, 1873, 1873,    0, 1873, 1873, 1873,    0,
 1873,    0,    0,    0, 1873,    0, 1873, 1873, 1873, 1873,
 2605, 1873,    0, 1873, 1873, 1873, 1873, 1873, 1873, 1873,
 1873,    0,    0,    0,    0,    0, 1243, 1242, 1244,    0,
 1873, 1873,    0, 1873, 1873, 1873,    0,    0,    0,    0,
 1873, 1873, 1873, 1873, 1873,    0, 1873,    0,    0, 1873,
 1873,    0,    0,    0, 1873, 1873,    0,    0, 1873, 1873,
 1873, 1873, 1873, 1873, 1873, 1873, 1873,    0, 1873,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1873, 1873,
 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873,
 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873,    0,
 1873, 1873, 1873, 1873, 1873, 1873,    0, 1873, 1873, 1873,
 1873,    0, 1873,    0, 1873, 1873, 1873, 1873, 1873, 1873,
 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873,
 1873, 1873,    0, 1873, 1873, 1873, 1873,    0, 1873, 1873,
 1873, 1873, 1873,    0, 1873, 1873, 1873, 1873, 1873, 1873,
 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873,
 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873,
 1873, 1873, 1873, 1880, 1873, 1873, 1873, 1873,    0, 1873,
 1873, 1873, 1873, 1873, 1873,    0,    0, 1873, 1873, 1873,
 1873, 1873, 1873, 1873, 1873, 1873,    0,    0,    0,    0,
    0, 1873,    0, 1873, 1873, 1873, 1873, 1873, 1873,    0,
 1873,    0,    0, 1632, 1880, 1880, 1880, 1880, 1880, 1880,
 1880,    0,    0,    0,    0,    0,    0,    0, 1227,    0,
    0, 1880, 1880, 1880, 1880, 1880,    0, 1228,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1229,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1880,    0, 1880,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1230,    0,    0,    0,    0,    0,
    0, 1231,    0,    0,    0,    0,    0,    0,    0, 1232,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1233,    0, 1234,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1235,    0,
 1236, 1237, 1238,    0,    0,    0,    0, 1239,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1240,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1880,    0, 1880,    0,    0, 1880,    0, 1880, 1880,    0,
    0, 1880, 1880,    0, 1880,    0,    0,    0,    0,    0,
 1880,    0, 1880, 1880, 1880, 1880,    0, 1880,    0,    0,
 1880,    0,    0, 1880,    0,    0,    0,    0,    0,    0,
 1880,    0, 1880, 1880,    0, 1880, 1880, 1880, 1880, 1880,
    0,    0, 1880,    0,    0, 1880,    0, 1880, 1880,    0,
    0, 1880, 1880, 1880,    0, 1880, 1880, 1880, 1880, 1880,
 1880, 1880,    0,    0,    0, 1880, 1880, 1880, 1880, 1880,
    0,    0,    0, 1880,    0,    0,    0,    0,    0,    0,
    0, 1880, 1880, 1880, 1880, 1880, 1880,    0,    0,    0,
 1880, 1880,    0, 1880,    0, 1880,    0, 1880, 1880, 1880,
    0, 1880,    0, 1880, 1880, 1880,    0, 1880, 1880, 1880,
 1880, 1880,    0, 1880, 1880,    0,    0,    0,    0, 1880,
    0, 1880, 1880,    0, 1241, 1880, 1880, 1880,    0,    0,
 1880,    0, 1880,    0,    0, 1880, 1880, 1880, 1880,    0,
 1880,    0, 1880,    0, 1880, 1880, 1880, 1880, 1880,    0,
    0, 1880, 1880, 1880,    0, 1880, 1880,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1880, 1880, 1880,    0,
 1880, 1880, 1880,    0, 1880,    0,    0,    0, 1880,    0,
 1880, 1880, 1880, 1880, 2607, 1880,    0, 1880, 1880, 1880,
 1880, 1880, 1880, 1880, 1880,    0,    0,    0,    0,    0,
 1243, 1242, 1244,    0, 1880, 1880,    0, 1880, 1880, 1880,
    0,    0,    0,    0, 1880, 1880, 1880, 1880, 1880,    0,
 1880,    0,    0, 1880, 1880,    0,    0,    0, 1880, 1880,
    0,    0, 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880,
 1880,    0, 1880,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880,
 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880,
 1880, 1880, 1880,    0, 1880, 1880, 1880, 1880, 1880, 1880,
    0, 1880, 1880, 1880, 1880,    0, 1880,    0, 1880, 1880,
 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880,
 1880, 1880, 1880, 1880, 1880, 1880,    0, 1880, 1880, 1880,
 1880,    0, 1880, 1880, 1880, 1880, 1880,    0, 1880, 1880,
 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880,
 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880,
 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1955, 1880, 1880,
 1880, 1880,    0, 1880, 1880, 1880, 1880, 1880, 1880,    0,
    0, 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880, 1880,
    0,    0,    0,    0,    0, 1880,    0, 1880, 1880, 1880,
 1880, 1880, 1880,    0, 1880,    0,    0, 1657, 1955, 1955,
 1955, 1955, 1955, 1955, 1955,    0,    0,    0,    0,    0,
    0,    0, 1227,    0,    0, 1955, 1955, 1955, 1955, 1955,
    0, 1228,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1229,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1955,    0,
 1955,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1230,    0,
    0,    0,    0,    0,    0, 1231,    0,    0,    0,    0,
    0,    0,    0, 1232,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1233,    0, 1234,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1235,    0, 1236, 1237, 1238,    0,    0,    0,
    0, 1239,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1240,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1955,    0, 1955,    0,    0, 1955,
    0, 1955, 1955,    0,    0, 1955, 1955,    0, 1955,    0,
    0,    0,    0,    0, 1955,    0, 1955, 1955, 1955, 1955,
    0, 1955,    0,    0, 1955,    0,    0, 1955,    0,    0,
    0,    0,    0,    0, 1955,    0, 1955, 1955,    0, 1955,
 1955, 1955, 1955, 1955,    0,    0, 1955,    0,    0, 1955,
    0, 1955, 1955,    0,    0, 1955, 1955, 1955,    0, 1955,
 1955, 1955, 1955, 1955, 1955, 1955,    0,    0,    0, 1955,
 1955, 1955, 1955, 1955,    0,    0,    0, 1955,    0,    0,
    0,    0,    0,    0,    0, 1955, 1955, 1955, 1955, 1955,
 1955,    0,    0,    0, 1955, 1955,    0, 1955,    0, 1955,
    0, 1955, 1955, 1955,    0, 1955,    0, 1955, 1955, 1955,
    0, 1955, 1955, 1955, 1955, 1955,    0, 1955, 1955,    0,
    0,    0,    0, 1955,    0, 1955, 1955,    0, 1241, 1955,
 1955, 1955,    0,    0, 1955,    0, 1955,    0,    0, 1955,
 1955, 1955, 1955,    0, 1955,    0, 1955,    0, 1955, 1955,
 1955, 1955, 1955,    0,    0, 1955, 1955, 1955,    0, 1955,
 1955,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1955, 1955, 1955,    0, 1955, 1955, 1955,    0, 1955,    0,
    0,    0, 1955,    0, 1955, 1955, 1955, 1955, 2608, 1955,
    0, 1955, 1955, 1955, 1955, 1955, 1955, 1955, 1955,    0,
    0,    0,    0,    0, 1243, 1242, 1244,    0, 1955, 1955,
    0, 1955, 1955, 1955,    0,    0,    0,    0, 1955, 1955,
 1955, 1955, 1955,    0, 1955,    0,    0, 1955, 1955,    0,
    0,    0, 1955, 1955,    0,    0, 1955, 1955, 1955, 1955,
 1955, 1955, 1955, 1955, 1955,    0, 1955,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1955, 1955, 1955, 1955,
 1955, 1955, 1955, 1955, 1955, 1955, 1955, 1955, 1955, 1955,
 1955, 1955, 1955, 1955, 1955, 1955, 1955,    0, 1955, 1955,
 1955, 1955, 1955, 1955,    0, 1955, 1955, 1955, 1955,    0,
 1955,    0, 1955, 1955, 1955, 1955, 1955, 1955, 1955, 1955,
 1955, 1955, 1955, 1955, 1955, 1955, 1955, 1955, 1955, 1955,
    0, 1955, 1955, 1955, 1955,    0, 1955, 1955, 1955, 1955,
 1955,    0, 1955, 1955, 1955, 1955, 1955, 1955, 1955, 1955,
 1955, 1955, 1955, 1955, 1955, 1955, 1955, 1955, 1955, 1955,
 1955, 1955, 1955, 1955, 1955, 1955, 1955, 1955, 1955, 1955,
 1955, 1956, 1955, 1955, 1955, 1955,    0, 1955, 1955, 1955,
 1955, 1955, 1955,    0,    0, 1955, 1955, 1955, 1955, 1955,
 1955, 1955, 1955, 1955,    0,    0,    0,    0,    0, 1955,
    0, 1955, 1955, 1955, 1955, 1955, 1955,    0, 1955,    0,
    0, 1658, 1956, 1956, 1956, 1956, 1956, 1956, 1956,    0,
    0,    0,    0,    0,    0,    0, 1227,    0,    0, 1956,
 1956, 1956, 1956, 1956,    0, 1228,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1229,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1956,    0, 1956,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1230,    0,    0,    0,    0,    0,    0, 1231,
    0,    0,    0,    0,    0,    0,    0, 1232,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1233,    0, 1234,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1235,    0, 1236, 1237,
 1238,    0,    0,    0,    0, 1239,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1240,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1956,    0,
 1956,    0,    0, 1956,    0, 1956, 1956,    0,    0, 1956,
 1956,    0, 1956,    0,    0,    0,    0,    0, 1956,    0,
 1956, 1956, 1956, 1956,    0, 1956,    0,    0, 1956,    0,
    0, 1956,    0,    0,    0,    0,    0,    0, 1956,    0,
 1956, 1956,    0, 1956, 1956, 1956, 1956, 1956,    0,    0,
 1956,    0,    0, 1956,    0, 1956, 1956,    0,    0, 1956,
 1956, 1956,    0, 1956, 1956, 1956, 1956, 1956, 1956, 1956,
    0,    0,    0, 1956, 1956, 1956, 1956, 1956,    0,    0,
    0, 1956,    0,    0,    0,    0,    0,    0,    0, 1956,
 1956, 1956, 1956, 1956, 1956,    0,    0,    0, 1956, 1956,
    0, 1956,    0, 1956,    0, 1956, 1956, 1956,    0, 1956,
    0, 1956, 1956, 1956,    0, 1956, 1956, 1956, 1956, 1956,
    0, 1956, 1956,    0,    0,    0,    0, 1956,    0, 1956,
 1956,    0, 1241, 1956, 1956, 1956,    0,    0, 1956,    0,
 1956,    0,    0, 1956, 1956, 1956, 1956,    0, 1956,    0,
 1956,    0, 1956, 1956, 1956, 1956, 1956,    0,    0, 1956,
 1956, 1956,    0, 1956, 1956,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1956, 1956, 1956,    0, 1956, 1956,
 1956,    0, 1956,    0,    0,    0, 1956,    0, 1956, 1956,
 1956, 1956, 1468, 1956,    0, 1956, 1956, 1956, 1956, 1956,
 1956, 1956, 1956,    0,    0,    0,    0,    0, 1468, 1468,
 1468,    0, 1956, 1956,    0, 1956, 1956, 1956,    0,    0,
    0,    0, 1956, 1956, 1956, 1956, 1956,    0, 1956,    0,
    0, 1956, 1956,    0,    0,    0, 1956, 1956,    0,    0,
 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956,    0,
 1956,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956,
 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956,
 1956,    0, 1956, 1956, 1956, 1956, 1956, 1956,    0, 1956,
 1956, 1956, 1956,    0, 1956,    0, 1956, 1956, 1956, 1956,
 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956,
 1956, 1956, 1956, 1956,    0, 1956, 1956, 1956, 1956,    0,
 1956, 1956, 1956, 1956, 1956,    0, 1956, 1956, 1956, 1956,
 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956,
 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956,
 1956, 1956, 1956, 1956, 1956, 1941, 1956, 1956, 1956, 1956,
    0, 1956, 1956, 1956, 1956, 1956, 1956,    0,    0, 1956,
 1956, 1956, 1956, 1956, 1956, 1956, 1956, 1956,    0,    0,
    0,    0,    0, 1956,    0, 1956, 1956, 1956, 1956, 1956,
 1956,    0, 1956,    0,    0, 1623, 1941, 1941, 1941, 1941,
 1941, 1941, 1941,    0,    0,    0,    0,    0,    0,    0,
 1468,    0,    0, 1941, 1941, 1941, 1941, 1941,    0, 1468,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1468,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1941,    0, 1941,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1468,    0,    0,    0,
    0,    0,    0, 1468,    0,    0,    0,    0,    0,    0,
    0, 1468,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1468,    0,
 1468,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1468,    0, 1468, 1468, 1468,    0,    0,    0,    0, 1468,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1468,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1941,    0, 1941,    0,    0, 1941,    0, 1941,
 1941,    0,    0, 1941, 1941,    0, 1941,    0,    0,    0,
    0,    0, 1941,    0, 1941, 1941, 1941, 1941,    0, 1941,
    0,    0, 1941,    0,    0, 1941,    0,    0,    0,    0,
    0,    0, 1941,    0, 1941, 1941,    0, 1941, 1941, 1941,
 1941, 1941,    0,    0, 1941,    0,    0, 1941,    0, 1941,
 1941,    0,    0, 1941, 1941, 1941,    0, 1941, 1941, 1941,
 1941, 1941, 1941, 1941,    0,    0,    0, 1941, 1941, 1941,
 1941, 1941,    0,    0,    0, 1941,    0,    0,    0,    0,
    0,    0,    0, 1941, 1941, 1941, 1941, 1941, 1941,    0,
    0,    0, 1941, 1941,    0, 1941,    0, 1941,    0, 1941,
 1941, 1941,    0, 1941,    0, 1941, 1941, 1941,    0, 1941,
 1941, 1941, 1941, 1941,    0, 1941, 1941,    0,    0,    0,
    0, 1941,    0, 1941, 1941,    0, 1468, 1941, 1941, 1941,
    0,    0, 1941,    0, 1941,    0,    0, 1941, 1941, 1941,
 1941,    0, 1941,    0, 1941,    0, 1941, 1941, 1941, 1941,
 1941,    0,    0, 1941, 1941, 1941,    0, 1941, 1941,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1941, 1941,
 1941,    0, 1941, 1941, 1941,    0, 1941,    0,    0,    0,
 1941,    0, 1941, 1941, 1941, 1941, 1467, 1941,    0, 1941,
 1941, 1941, 1941, 1941, 1941, 1941, 1941,    0,    0,    0,
    0,    0, 1467, 1467, 1467,    0, 1941, 1941,    0, 1941,
 1941, 1941,    0,    0,    0,    0, 1941, 1941, 1941, 1941,
 1941,    0, 1941,    0,    0, 1941, 1941,    0,    0,    0,
 1941, 1941,    0,    0, 1941, 1941, 1941, 1941, 1941, 1941,
 1941, 1941, 1941,    0, 1941,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1941, 1941, 1941, 1941, 1941, 1941,
 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1941,
 1941, 1941, 1941, 1941, 1941,    0, 1941, 1941, 1941, 1941,
 1941, 1941,    0, 1941, 1941, 1941, 1941,    0, 1941,    0,
 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1941,
 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1941,    0, 1941,
 1941, 1941, 1941,    0, 1941, 1941, 1941, 1941, 1941,    0,
 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1941,
 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1941,
 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1941, 1942,
 1941, 1941, 1941, 1941,    0, 1941, 1941, 1941, 1941, 1941,
 1941,    0,    0, 1941, 1941, 1941, 1941, 1941, 1941, 1941,
 1941, 1941,    0,    0,    0,    0,    0, 1941,    0, 1941,
 1941, 1941, 1941, 1941, 1941,    0, 1941,    0,    0, 1627,
 1942, 1942, 1942, 1942, 1942, 1942, 1942,    0,    0,    0,
    0,    0,    0,    0, 1467,    0,    0, 1942, 1942, 1942,
 1942, 1942,    0, 1467,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1467,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1942,    0, 1942,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1467,    0,    0,    0,    0,    0,    0, 1467,    0,    0,
    0,    0,    0,    0,    0, 1467,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1467,    0, 1467,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1467,    0, 1467, 1467, 1467,    0,
    0,    0,    0, 1467,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1467,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1942,    0, 1942,    0,
    0, 1942,    0, 1942, 1942,    0,    0, 1942, 1942,    0,
 1942,    0,    0,    0,    0,    0, 1942,    0, 1942, 1942,
 1942, 1942,    0, 1942,    0,    0, 1942,    0,    0, 1942,
    0,    0,    0,    0,    0,    0, 1942,    0, 1942, 1942,
    0, 1942, 1942, 1942, 1942, 1942,    0,    0, 1942,    0,
    0, 1942,    0, 1942, 1942,    0,    0, 1942, 1942, 1942,
    0, 1942, 1942, 1942, 1942, 1942, 1942, 1942,    0,    0,
    0, 1942, 1942, 1942, 1942, 1942,    0,    0,    0, 1942,
    0,    0,    0,    0,    0,    0,    0, 1942, 1942, 1942,
 1942, 1942, 1942,    0,    0,    0, 1942, 1942,    0, 1942,
    0, 1942,    0, 1942, 1942, 1942,    0, 1942,    0, 1942,
 1942, 1942,    0, 1942, 1942, 1942, 1942, 1942,    0, 1942,
 1942,    0,    0,    0,    0, 1942,    0, 1942, 1942,    0,
 1467, 1942, 1942, 1942,    0,    0, 1942,    0, 1942,    0,
    0, 1942, 1942, 1942, 1942,    0, 1942,    0, 1942,    0,
 1942, 1942, 1942, 1942, 1942,    0,    0, 1942, 1942, 1942,
    0, 1942, 1942,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1942, 1942, 1942,    0, 1942, 1942, 1942,    0,
 1942,    0,    0,    0, 1942,    0, 1942, 1942, 1942, 1942,
    0, 1942,    0, 1942, 1942, 1942, 1942, 1942, 1942, 1942,
 1942,    0,    0,    0,    0,    0, 1243, 1242, 1244,    0,
 1942, 1942,    0, 1942, 1942, 1942,    0,    0,    0,    0,
 1942, 1942, 1942, 1942, 1942,    0, 1942,    0,    0, 1942,
 1942,    0,    0,    0, 1942, 1942,    0,    0, 1942, 1942,
 1942, 1942, 1942, 1942, 1942, 1942, 1942,    0, 1942,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1942, 1942,
 1942, 1942, 1942, 1942, 1942, 1942, 1942, 1942, 1942, 1942,
 1942, 1942, 1942, 1942, 1942, 1942, 1942, 1942, 1942,    0,
 1942, 1942, 1942, 1942, 1942, 1942,    0, 1942, 1942, 1942,
 1942,    0, 1942,    0, 1942, 1942, 1942, 1942, 1942, 1942,
 1942, 1942, 1942, 1942, 1942, 1942, 1942, 1942, 1942, 1942,
 1942, 1942,    0, 1942, 1942, 1942, 1942,    0, 1942, 1942,
 1942, 1942, 1942,    0, 1942, 1942, 1942, 1942, 1942, 1942,
 1942, 1942, 1942, 1942, 1942, 1942, 1942, 1942, 1942, 1942,
 1942, 1942, 1942, 1942, 1942, 1942, 1942, 1942, 1942, 1942,
 1942, 1942, 1942, 1943, 1942, 1942, 1942, 1942,    0, 1942,
 1942, 1942, 1942, 1942, 1942,    0,    0, 1942, 1942, 1942,
 1942, 1942, 1942, 1942, 1942, 1942,    0,    0,    0,    0,
    0, 1942,    0, 1942, 1942, 1942, 1942, 1942, 1942,    0,
 1942,    0,    0, 1630, 1943, 1943, 1943, 1943, 1943, 1943,
 1943,    0,    0,    0,    0,    0,    0,    0, 1227,    0,
    0, 1943, 1943, 1943, 1943, 1943,    0, 1228,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1229,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1943,    0, 1943,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1230,    0,    0,    0,    0,    0,
    0, 1231,    0,    0,    0,    0,    0,    0,    0, 1232,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1233,    0, 1234,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1235,    0,
 1236, 1237, 1238,    0,    0,    0,    0, 1239,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1240,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1492, 1493, 1494, 1495, 1496, 1497, 1498, 1499,    0,    0,
 1943,    0, 1943,    0,    0, 1943,    0, 1943, 1943,    0,
    0, 1943, 1943,    0, 1943,    0,    0,    0,    0,    0,
 1943,    0, 1943, 1943, 1943, 1943,    0, 1943,    0,    0,
 1943,    0,    0, 1943,    0,    0,    0,    0,    0,    0,
 1943,    0, 1943, 1943,    0, 1943, 1943, 1943, 1943, 1943,
    0,    0, 1943,    0,    0, 1943,    0, 1943, 1943,    0,
    0, 1943, 1943, 1943,    0, 1943, 1943, 1943, 1943, 1943,
 1943, 1943,    0,    0,    0, 1943, 1943, 1943, 1943, 1943,
    0,    0,    0, 1943,    0,    0,    0,    0,    0,    0,
    0, 1943, 1943, 1943, 1943, 1943, 1943,    0,    0, 1500,
 1943, 1943,    0, 1943,    0, 1943,    0, 1943, 1943, 1943,
    0, 1943,    0, 1943, 1943, 1943,    0, 1943, 1943, 1943,
 1943, 1943,    0, 1943, 1943, 1501,    0,    0,    0, 1943,
    0, 1943, 1943,    0, 1241, 1943, 1943, 1943,    0,    0,
 1943,    0, 1943,    0,    0, 1943, 1943, 1943, 1943,    0,
 1943,    0, 1943,    0, 1943, 1943, 1943, 1943, 1943,    0,
    0, 1943, 1943, 1943,    0, 1943, 1943,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1943, 1943, 1943,    0,
 1943, 1943, 1943,    0, 1943,    0,    0,    0, 1943,    0,
 1943, 1943, 1943, 1943,    0, 1943,    0, 1943, 1943, 1943,
 1943, 1943, 1943, 1943, 1943,    0,    0,    0,    0, 1243,
 1242, 1244,    0,    0, 1943, 1943,    0, 1943, 1943, 1943,
 1243, 1242, 1244,    0, 1943, 1943, 1943, 1943, 1943,    0,
 1943,    0,    0, 1943, 1943,    0,    0,    0, 1943, 1943,
    0,    0, 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943,
 1943,    0, 1943,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943,
 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943,
 1943, 1943, 1943,    0, 1943, 1943, 1943, 1943, 1943, 1943,
    0, 1943, 1943, 1943, 1943,    0, 1943,    0, 1943, 1943,
 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943,
 1943, 1943, 1943, 1943, 1943, 1943,    0, 1943, 1943, 1943,
 1943,    0, 1943, 1943, 1943, 1943, 1943,    0, 1943, 1943,
 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943,
 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943,
 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1781, 1943, 1943,
 1943, 1943,    0, 1943, 1943, 1943, 1943, 1943, 1943,    0,
    0, 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943, 1943,
    0,    0,    0,    0,    0, 1943,    0, 1943, 1943, 1943,
 1943, 1943, 1943,    0, 1943,    0,    0,    0, 1781, 1781,
 1781, 1781, 1781, 1781, 1781,    0,    0,    0,    0,    0,
    0, 1227,    0,    0,    0, 1781, 1781, 1781, 1781, 1781,
 1228,    0, 1227,    0,    0,    0,    0,   59,    0,    0,
    0, 1228,    0, 1229,    0,    0,    0,    0,    0,    0,
   60,    0,   61,    0, 1229,    0,    0,    0, 1781,    0,
 1781,    0,   62,    0,    0,    0,    0,    0,   63,    0,
    0,    0,   64,    0,    0, 2594,    0, 1230,   65,    0,
    0,   66,    0,    0, 1231,    0,    0,    0, 1230,    0,
    0,   67, 1232,    0,    0, 1231,    0,    0,    0,    0,
    0,    0,    0, 1232,    0,    0,    0,    0,    0, 1233,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
 1233, 1235, 1234, 1236, 1237, 1238,    0,    0,    0,    0,
 1239,    0, 1235,    0, 1236, 1237, 1238,    0,    0,    0,
    0, 1239,    0,    0,    0,    0,    0,    0,    0,   68,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0,    0,    0,    0,    0,    0,    0,   69,
    0,    0, 1240,   70,    0,    0,    0,    0,   71,    0,
    0,    0,    0,    0,   72,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   73,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1781,    0, 1781,    0,    0, 1781,
    0, 1781, 1781,    0,    0, 1781, 1781,    0, 1781,    0,
    0,    0,    0,    0, 1781,    0, 1781, 1781, 1781, 1781,
    0, 1781,    0,    0, 1781,    0,    0, 1781,    0,    0,
    0,    0,    0,    0, 1781,    0, 1781, 1781,   74, 1781,
 1781, 1781, 1781, 1781,    0,    0, 1781,    0,    0, 1781,
    0, 1781, 1781,    0,    0, 1781, 1781, 1781,    0, 1781,
 1781, 1781, 1781, 1781, 1781, 1781,    0,    0,    0, 1781,
 1781, 1781, 1781, 1781,    0,    0,    0, 1781,    0,    0,
    0,    0,    0,    0,   75, 1781, 1781, 1781, 1781, 1781,
 1781,    0,    0,    0, 1781, 1781,    0, 1781, 1979, 1781,
    0, 1781, 1781, 1781,    0, 1781,    0, 1781, 1781, 1781,
    0, 1781, 1781, 1781, 1781, 1781,    0, 1781, 1781,    0,
    0,    0,    0, 1781,    0, 1781, 1781, 1241,   76, 1781,
 1781, 1781,    0,    0, 1781,    0, 1781,    0, 1241, 1781,
 1781, 1781, 1781,    0, 1781,    0, 1781,   77, 1781, 1781,
 1781, 1781, 1781,    0,    0, 1781, 1781, 1781,    0, 1781,
 1781,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1781, 1781, 1781,    0, 1781, 1781, 1781,    0, 1781,    0,
    0,    0, 1781,    0, 1781, 1781, 1781, 1781,    0, 1781,
    0, 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781,    0,
    0,    0,    0, 1243, 1242, 1244,    0,    0, 1781, 1781,
    0, 1781, 1781, 1781,    0,    0,    0,    0, 1781, 1781,
 1781, 1781, 1781,    0, 1781,    0,    0, 1781, 1781,    0,
    0,    0, 1781, 1781,    0,    0, 1781, 1781, 1781, 1781,
 1781, 1781, 1781, 1781, 1781,    0, 1781,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1781, 1781, 1781, 1781,
 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781,
 1781, 1781, 1781, 1781, 1781, 1781, 1781,    0, 1781, 1781,
 1781, 1781, 1781, 1781,    0, 1781, 1781, 1781, 1781,    0,
 1781,    0, 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781,
 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781,
    0, 1781, 1781, 1781, 1781,    0, 1781, 1781, 1781, 1781,
 1781,    0, 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781,
 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781,
 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781,
 1781, 1826, 1781, 1781, 1781, 1781,    0, 1781, 1781, 1781,
 1781, 1781, 1781,    0,    0, 1781, 1781, 1781, 1781, 1781,
 1781, 1781, 1781, 1781,    0,    0,    0,    0,    0, 1781,
    0, 1781, 1781, 1781, 1781, 1781, 1781,    0, 1781,    0,
    0,    0, 1826, 1826, 1826, 1826, 1826, 1826, 1826,    0,
    0,    0,    0,    0,    0, 1227,    0,    0,    0, 1826,
 1826, 1826, 1826, 1826, 1228,    0,    0,    0,    0,    0,
    0, 1864,    0,    0,    0,    0,    0, 1229,  609,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1826,  610, 1826,    0, 1865,    0,    0,    0,
    0,    0, 1866,  611,    0,    0,    0,    0,    0,  612,
    0, 1230, 1867,  613,  614,    0,    0,    0, 1231,  615,
    0,    0,  616,    0,    0, 1868, 1232,    0,    0,    0,
    0,    0,  617,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1233,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1235,    0, 1236, 1237, 1238,
    0,    0,    0,    0, 1239,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  618, 1869,    0,    0,    0,    0,    0,    0,
  619,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1240,    0,    0,    0,    0,
    0,    0, 2606, 1870,    0,    0,    0, 1871,    0,    0,
  620,    0, 1872,    0,  621,    0,    0,    0, 1873,  622,
    0,    0,    0,    0,    0,  623,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1874,    0,    0,    0,
    0,    0,    0,  624,  625,    0,    0,    0, 1826,    0,
 1826,    0,    0, 1826,    0, 1826, 1826,    0,    0, 1826,
 1826,    0, 1826,    0,    0,    0,    0,    0, 1826,    0,
 1826, 1826, 1826, 1826,    0, 1826,    0,    0, 1826,    0,
    0, 1826,    0,    0,    0,    0,    0,    0, 1826,    0,
 1826, 1826, 1875, 1826, 1826, 1826, 1826, 1826,    0,  626,
 1826,    0,  627, 1826,    0, 1826, 1826,    0,    0, 1826,
 1826, 1826,    0, 1826, 1826, 1826, 1826, 1826, 1826, 1826,
    0,    0,    0, 1826, 1826, 1826, 1826, 1826,    0,    0,
    0, 1826,    0,    0,    0,    0,    0,    0,    0, 1826,
 1826, 1826, 1826, 1826, 1826,    0,    0,    0, 1826, 1826,
    0, 1826,    0, 1826,    0, 1826, 1826, 1826,    0, 1826,
    0, 1826, 1826, 1826,    0, 1826, 1826, 1826, 1826, 1826,
    0, 1826, 1826,    0,    0,    0,    0, 1826,    0, 1826,
 1826, 1241, 1876, 1826, 1826, 1826,    0,    0, 1826,    0,
 1826,    0,    0, 1826, 1826, 1826, 1826,    0, 1826,    0,
 1826, 1877, 1826, 1826, 1826, 1826, 1826,    0,  628, 1826,
 1826, 1826,    0, 1826, 1826,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1826, 1826, 1826,    0, 1826, 1826,
 1826,    0, 1826,    0,    0,    0, 1826,    0, 1826, 1826,
 1826, 1826,    0, 1826,    0, 1826, 1826, 1826, 1826, 1826,
 1826, 1826, 1826,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1826, 1826,    0, 1826, 1826, 1826,    0,    0,
    0,    0, 1826, 1826, 1826, 1826, 1826,    0, 1826,    0,
    0, 1826, 1826,    0,    0,    0, 1826, 1826,    0,    0,
 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826,    0,
 1826,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826,
 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826,
 1826,    0, 1826, 1826, 1826, 1826, 1826, 1826,    0, 1826,
 1826, 1826, 1826,    0, 1826,    0, 1826, 1826, 1826, 1826,
 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826,
 1826, 1826, 1826, 1826,    0, 1826, 1826, 1826, 1826,    0,
 1826, 1826, 1826, 1826, 1826,    0, 1826, 1826, 1826, 1826,
 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826,
 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826,
 1826, 1826, 1826, 1826, 1826, 1827, 1826, 1826, 1826, 1826,
    0, 1826, 1826, 1826, 1826, 1826, 1826,    0,    0, 1826,
 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826,    0,    0,
    0,    0,    0, 1826,    0, 1826, 1826, 1826, 1826, 1826,
 1826,    0, 1826,    0,   79,    0, 1827, 1827, 1827, 1827,
 1827, 1827, 1827,    0,    0,    0,    0,    0,    0,   79,
    0,    0,    0, 1827, 1827, 1827, 1827, 1827,    0,   79,
    0,    0,    0,    0,    0,   79,    0,    0,    0,    0,
   79,    0,   76,    0,    0,   79,    0,    0,   79,    0,
    0,    0,    0,    0,    0,    0, 1827,   85, 1827,    0,
    0,    0,    0,    0,    0,    0,    0,   76,    0,    0,
    0,    0,    0,   76,    0,    0,    0,    0,   76,    0,
    0,    0,    0,   76,    0,    0,   76,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   63,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   79,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   79,    0,    0,    0,
    0,    0,    0,    0,   76,    0,    0,    0,    0,    0,
    0,   79,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   79,
    0,    0,    0,    0,   76,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   76,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   76,    0,    0,
    0,    0, 1827,    0, 1827,    0,    0, 1827,    0, 1827,
 1827,    0,    0, 1827, 1827,   79, 1827,    0,   79,    0,
    0,    0, 1827,    0, 1827, 1827, 1827, 1827,    0, 1827,
    0,    0, 1827,    0,    0, 1827,    0,    0,    0,    0,
    0,    0, 1827,    0, 1827, 1827,    0, 1827, 1827, 1827,
 1827, 1827,    0,   76, 1827,    0,   76, 1827,    0, 1827,
 1827,    0,    0, 1827, 1827, 1827,    0, 1827, 1827, 1827,
 1827, 1827, 1827, 1827,    0,    0,    0, 1827, 1827, 1827,
 1827, 1827,    0,    0,    0, 1827,    0,    0,    0,    0,
    0,    0,    0, 1827, 1827, 1827, 1827, 1827, 1827,    0,
    0,    0, 1827, 1827,    0, 1827,    0, 1827,    0, 1827,
 1827, 1827,    0, 1827,    0, 1827, 1827, 1827,    0, 1827,
 1827, 1827, 1827, 1827,   79, 1827, 1827,    0,    0,    0,
    0, 1827,    0, 1827, 1827,    0,    0, 1827, 1827, 1827,
    0,    0, 1827,    0, 1827,    0,    0, 1827, 1827, 1827,
 1827,    0, 1827,    0, 1827,    0, 1827, 1827, 1827, 1827,
 1827,    0,   76, 1827, 1827, 1827,    0, 1827, 1827,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1827, 1827,
 1827,    0, 1827, 1827, 1827,    0, 1827,    0,    0,    0,
 1827,    0, 1827, 1827, 1827, 1827,    0, 1827,    0, 1827,
 1827, 1827, 1827, 1827, 1827, 1827, 1827,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1827, 1827,    0, 1827,
 1827, 1827,    0,    0,    0,    0, 1827, 1827, 1827, 1827,
 1827,    0, 1827,    0,    0, 1827, 1827,    0,    0,    0,
 1827, 1827,    0,    0, 1827, 1827, 1827, 1827, 1827, 1827,
 1827, 1827, 1827,    0, 1827,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1827, 1827, 1827, 1827, 1827, 1827,
 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827,
 1827, 1827, 1827, 1827, 1827,    0, 1827, 1827, 1827, 1827,
 1827, 1827,    0, 1827, 1827, 1827, 1827,    0, 1827,    0,
 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827,
 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827,    0, 1827,
 1827, 1827, 1827,    0, 1827, 1827, 1827, 1827, 1827,    0,
 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827,
 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827,
 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1845,
 1827, 1827, 1827, 1827,    0, 1827, 1827, 1827, 1827, 1827,
 1827,    0,    0, 1827, 1827, 1827, 1827, 1827, 1827, 1827,
 1827, 1827,    0,    0,    0,    0,    0, 1827,    0, 1827,
 1827, 1827, 1827, 1827, 1827,    0, 1827,    0,   82,    0,
 1845, 1845, 1845, 1845, 1845, 1845, 1845,    0,    0,    0,
    0,    0,    0,   89,    0,    0,    0, 1845, 1845, 1845,
 1845, 1845,    0,   82,    0,    0,    0,    0,    0,   82,
    0,    0,    0,    0,   82,   81,    0,    0,    0,   82,
    0,    0,   82,    0,    0,   82,    0,    0,    0,    0,
 1845,   83, 1845,    0,    0,    0,    0,    0,    0,    0,
    0,   84,    0,    0,   85,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   82,    0,    0,    0,    0,    0,   86,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   87,    0,    0,    0,    0,    0,    0,    0,
   82,    0,    0,    0,    0,    0,    0,   88,    0,    0,
    0,    0,    0,    0,    0,   82,    0,    0,    0,    0,
    0,    0,   89,    0,    0,    0,   90,    0,    0,   91,
    0,   92,    0,   82,    0,    0,    0,   93,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   94,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1845,    0, 1845,    0,
    0, 1845,    0, 1845, 1845,    0,    0, 1845, 1845,   82,
 1845,    0,   82,    0,    0,    0, 1845,    0, 1845, 1845,
 1845, 1845,    0, 1845,    0,    0, 1845,    0,    0, 1845,
    0,   95,    0,    0,   96,    0, 1845,    0, 1845, 1845,
    0, 1845, 1845, 1845, 1845, 1845,    0,    0, 1845,    0,
    0, 1845,    0, 1845, 1845,    0,    0, 1845, 1845, 1845,
    0, 1845, 1845, 1845, 1845, 1845, 1845, 1845,    0,    0,
    0, 1845, 1845, 1845, 1845, 1845,    0,   97,    0, 1845,
    0,    0,    0,    0,    0,    0,    0, 1845, 1845, 1845,
 1845, 1845, 1845,    0,    0,    0, 1845, 1845,    0, 1845,
    0, 1845,    0, 1845, 1845, 1845,    0, 1845,    0, 1845,
 1845, 1845,    0, 1845, 1845, 1845, 1845, 1845,   82, 1845,
 1845,   98,    0,    0,    0, 1845,    0, 1845, 1845,    0,
    0, 1845, 1845, 1845,    0,    0, 1845,    0, 1845,    0,
   99, 1845, 1845, 1845, 1845,    0, 1845,    0, 1845,    0,
 1845, 1845, 1845, 1845, 1845,    0,    0, 1845, 1845, 1845,
    0, 1845, 1845,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1845, 1845, 1845,    0, 1845, 1845, 1845,    0,
 1845,    0,    0,    0, 1845,    0, 1845, 1845, 1845, 1845,
    0, 1845,    0, 1845, 1845, 1845, 1845, 1845, 1845, 1845,
 1845,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1845, 1845,    0, 1845, 1845, 1845,    0,    0,    0,    0,
 1845, 1845, 1845, 1845, 1845,    0, 1845,    0,    0, 1845,
 1845,    0,    0,    0, 1845, 1845,    0,    0, 1845, 1845,
 1845, 1845, 1845, 1845, 1845, 1845, 1845,    0, 1845,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1845, 1845,
 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845,
 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845,    0,
 1845, 1845, 1845, 1845, 1845, 1845,    0, 1845, 1845, 1845,
 1845,    0, 1845,    0, 1845, 1845, 1845, 1845, 1845, 1845,
 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845,
 1845, 1845,    0, 1845, 1845, 1845, 1845,    0, 1845, 1845,
 1845, 1845, 1845,    0, 1845, 1845, 1845, 1845, 1845, 1845,
 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845,
 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845,
 1845, 1845, 1845, 1900, 1845, 1845, 1845, 1845,    0, 1845,
 1845, 1845, 1845, 1845, 1845,    0,    0, 1845, 1845, 1845,
 1845, 1845, 1845, 1845, 1845, 1845,    0,    0,    0,    0,
    0, 1845,    0, 1845, 1845, 1845, 1845, 1845, 1845,    0,
 1845,    0,    0,    0, 1900, 1900, 1900, 1900, 1900, 1900,
 1900,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1900, 1900, 1900, 1900,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1900,    0, 1900,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1900,    0, 1900,    0,    0, 1900,    0, 1900, 1900,    0,
    0, 1900, 1900,    0, 1900,    0,    0,    0,    0,    0,
 1900,    0, 1900, 1900, 1900, 1900,    0, 1900,    0,    0,
 1900,    0,    0, 1900,    0,    0,    0,    0,    0,    0,
 1900,    0, 1900, 1900,    0, 1900, 1900, 1900, 1900, 1900,
    0,    0, 1900,    0,    0, 1900,    0, 1900, 1900,    0,
    0, 1900, 1900, 1900,    0, 1900, 1900, 1900, 1900, 1900,
 1900, 1900,    0,    0,    0, 1900, 1900, 1900, 1900, 1900,
    0,    0,    0, 1900,    0,    0,    0,    0,    0,    0,
    0, 1900, 1900, 1900, 1900, 1900, 1900,    0,    0,    0,
 1900, 1900,    0, 1900,    0, 1900,    0, 1900, 1900, 1900,
    0, 1900,    0, 1900, 1900, 1900,    0, 1900, 1900, 1900,
 1900, 1900,    0, 1900, 1900,    0,    0,    0,    0, 1900,
    0, 1900, 1900,    0,    0, 1900, 1900, 1900,    0,    0,
 1900,    0, 1900,    0,    0, 1900, 1900, 1900, 1900,    0,
 1900,    0, 1900,    0, 1900, 1900, 1900, 1900, 1900,    0,
    0, 1900, 1900, 1900,    0, 1900, 1900,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1900, 1900, 1900,    0,
 1900, 1900, 1900,    0, 1900,    0,    0,    0, 1900,    0,
 1900, 1900, 1900, 1900,    0, 1900,    0, 1900, 1900, 1900,
 1900, 1900, 1900, 1900, 1900,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1900, 1900,    0, 1900, 1900, 1900,
    0,    0,    0,    0, 1900, 1900, 1900, 1900, 1900,    0,
 1900,    0,    0, 1900, 1900,    0,    0,    0, 1900, 1900,
    0,    0, 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900,
 1900,    0, 1900,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900,
 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900,
 1900, 1900, 1900,    0, 1900, 1900, 1900, 1900, 1900, 1900,
    0, 1900, 1900, 1900, 1900,    0, 1900,    0, 1900, 1900,
 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900,
 1900, 1900, 1900, 1900, 1900, 1900,    0, 1900, 1900, 1900,
 1900,    0, 1900, 1900, 1900, 1900, 1900,    0, 1900, 1900,
 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900,
 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900,
 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1926, 1900, 1900,
 1900, 1900,    0, 1900, 1900, 1900, 1900, 1900, 1900,    0,
    0, 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900, 1900,
    0,    0,    0,    0,    0, 1900,    0, 1900, 1900, 1900,
 1900, 1900, 1900,    0, 1900,    0,    0,    0, 1926, 1926,
 1926, 1926, 1926, 1926, 1926,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1926, 1926, 1926, 1926,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1926,    0,
 1926,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1926,    0, 1926,    0,    0, 1926,
    0, 1926, 1926,    0,    0, 1926, 1926,    0, 1926,    0,
    0,    0,    0,    0, 1926,    0, 1926, 1926, 1926, 1926,
    0, 1926,    0,    0, 1926,    0,    0, 1926,    0,    0,
    0,    0,    0,    0, 1926,    0, 1926, 1926,    0, 1926,
 1926, 1926, 1926, 1926,    0,    0, 1926,    0,    0, 1926,
    0, 1926, 1926,    0,    0, 1926, 1926, 1926,    0, 1926,
 1926, 1926, 1926, 1926, 1926, 1926,    0,    0,    0, 1926,
 1926, 1926, 1926, 1926,    0,    0,    0, 1926,    0,    0,
    0,    0,    0,    0,    0, 1926, 1926, 1926, 1926, 1926,
 1926,    0,    0,    0, 1926, 1926,    0, 1926,    0, 1926,
    0, 1926, 1926, 1926,    0, 1926,    0, 1926, 1926, 1926,
    0, 1926, 1926, 1926, 1926, 1926,    0, 1926, 1926,    0,
    0,    0,    0, 1926,    0, 1926, 1926,    0,    0, 1926,
 1926, 1926,    0,    0, 1926,    0, 1926,    0,    0, 1926,
 1926, 1926, 1926,    0, 1926,    0, 1926,    0, 1926, 1926,
 1926, 1926, 1926,    0,    0, 1926, 1926, 1926,    0, 1926,
 1926,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1926, 1926, 1926,    0, 1926, 1926, 1926,    0, 1926,    0,
    0,    0, 1926,    0, 1926, 1926, 1926, 1926,    0, 1926,
    0, 1926, 1926, 1926, 1926, 1926, 1926, 1926, 1926,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1926, 1926,
    0, 1926, 1926, 1926,    0,    0,    0,    0, 1926, 1926,
 1926, 1926, 1926,    0, 1926,    0,    0, 1926, 1926,    0,
    0,    0, 1926, 1926,    0,    0, 1926, 1926, 1926, 1926,
 1926, 1926, 1926, 1926, 1926,    0, 1926,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1926, 1926, 1926, 1926,
 1926, 1926, 1926, 1926, 1926, 1926, 1926, 1926, 1926, 1926,
 1926, 1926, 1926, 1926, 1926, 1926, 1926,    0, 1926, 1926,
 1926, 1926, 1926, 1926,    0, 1926, 1926, 1926, 1926,    0,
 1926,    0, 1926, 1926, 1926, 1926, 1926, 1926, 1926, 1926,
 1926, 1926, 1926, 1926, 1926, 1926, 1926, 1926, 1926, 1926,
    0, 1926, 1926, 1926, 1926,    0, 1926, 1926, 1926, 1926,
 1926,    0, 1926, 1926, 1926, 1926, 1926, 1926, 1926, 1926,
 1926, 1926, 1926, 1926, 1926, 1926, 1926, 1926, 1926, 1926,
 1926, 1926, 1926, 1926, 1926, 1926, 1926, 1926, 1926, 1926,
 1926, 1786, 1926, 1926, 1926, 1926,    0, 1926, 1926, 1926,
 1926, 1926, 1926,    0,    0, 1926, 1926, 1926, 1926, 1926,
 1926, 1926, 1926, 1926,    0,    0,    0,    0,    0, 1926,
    0, 1926, 1926, 1926, 1926, 1926, 1926,    0, 1926,    0,
    0,    0, 1786, 1786, 1786, 1786, 1786, 1786, 1786,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1786, 1786, 1786, 1786,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1786,    0, 1786,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1786,    0,
 1786,    0,    0, 1786,    0, 1786, 1786,    0,    0, 1786,
 1786,    0, 1786,    0,    0,    0,    0,    0, 1786,    0,
 1786, 1786, 1786, 1786,    0, 1786,    0,    0, 1786,    0,
    0, 1786,    0,    0,    0,    0,    0,    0, 1786,    0,
 1786, 1786,    0, 1786, 1786, 1786, 1786, 1786,    0,    0,
 1786,    0,    0, 1786,    0, 1786, 1786,    0,    0, 1786,
 1786, 1786,    0, 1786, 1786, 1786, 1786, 1786, 1786, 1786,
    0,    0,    0, 1786, 1786, 1786, 1786, 1786,    0,    0,
    0, 1786,    0,    0,    0,    0,    0,    0,    0, 1786,
 1786, 1786, 1786, 1786, 1786,    0,    0,    0, 1786, 1786,
    0, 1786,    0, 1786,    0, 1786, 1786, 1786,    0, 1786,
    0, 1786, 1786, 1786,    0, 1786, 1786, 1786, 1786, 1786,
    0, 1786, 1786,    0,    0,    0,    0, 1786,    0, 1786,
 1786,    0,    0, 1786, 1786, 1786,    0,    0, 1786,    0,
 1786,    0,    0, 1786, 1786, 1786, 1786,    0, 1786,    0,
 1786,    0, 1786, 1786, 1786, 1786, 1786,    0,    0, 1786,
 1786, 1786,    0, 1786, 1786,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1786, 1786, 1786,    0, 1786, 1786,
 1786,    0, 1786,    0,    0,    0, 1786,    0, 1786, 1786,
 1786, 1786,    0, 1786,    0, 1786, 1786, 1786, 1786, 1786,
 1786, 1786, 1786,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1786, 1786,    0, 1786, 1786, 1786,    0,    0,
    0,    0, 1786, 1786, 1786, 1786, 1786,    0, 1786,    0,
    0, 1786, 1786,    0,    0,    0, 1786, 1786,    0,    0,
 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786,    0,
 1786,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786,
 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786,
 1786,    0, 1786, 1786, 1786, 1786, 1786, 1786,    0, 1786,
 1786, 1786, 1786,    0, 1786,    0, 1786, 1786, 1786, 1786,
 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786,
 1786, 1786, 1786, 1786,    0, 1786, 1786, 1786, 1786,    0,
 1786, 1786, 1786, 1786, 1786,    0, 1786, 1786, 1786, 1786,
 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786,
 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786,
 1786, 1786, 1786, 1786, 1786, 1782, 1786, 1786, 1786, 1786,
    0, 1786, 1786, 1786, 1786, 1786, 1786,    0,    0, 1786,
 1786, 1786, 1786, 1786, 1786, 1786, 1786, 1786,    0,    0,
    0,    0,    0, 1786,    0, 1786, 1786, 1786, 1786, 1786,
 1786,    0, 1786,    0,    0,    0, 1782, 1782, 1782, 1782,
 1782, 1782, 1782,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1782, 1782, 1782, 1782,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1782,    0, 1782,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1782,    0, 1782,    0,    0, 1782,    0, 1782,
 1782,    0,    0, 1782, 1782,    0, 1782,    0,    0,    0,
    0,    0, 1782,    0, 1782, 1782, 1782, 1782,    0, 1782,
    0,    0, 1782,    0,    0, 1782,    0,    0,    0,    0,
    0,    0, 1782,    0, 1782, 1782,    0, 1782, 1782, 1782,
 1782, 1782,    0,    0, 1782,    0,    0, 1782,    0, 1782,
 1782,    0,    0, 1782, 1782, 1782,    0, 1782, 1782, 1782,
 1782, 1782, 1782, 1782,    0,    0,    0, 1782, 1782, 1782,
 1782, 1782,    0,    0,    0, 1782,    0,    0,    0,    0,
    0,    0,    0, 1782, 1782, 1782, 1782, 1782, 1782,    0,
    0,    0, 1782, 1782,    0, 1782,    0, 1782,    0, 1782,
 1782, 1782,    0, 1782,    0, 1782, 1782, 1782,    0, 1782,
 1782, 1782, 1782, 1782,    0, 1782, 1782,    0,    0,    0,
    0, 1782,    0, 1782, 1782,    0,    0, 1782, 1782, 1782,
    0,    0, 1782,    0, 1782,    0,    0, 1782, 1782, 1782,
 1782,    0, 1782,    0, 1782,    0, 1782, 1782, 1782, 1782,
 1782,    0,    0, 1782, 1782, 1782,    0, 1782, 1782,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1782, 1782,
 1782,    0, 1782, 1782, 1782,    0, 1782,    0,    0,    0,
 1782,    0, 1782, 1782, 1782, 1782,    0, 1782,    0, 1782,
 1782, 1782, 1782, 1782, 1782, 1782, 1782,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1782, 1782,    0, 1782,
 1782, 1782,    0,    0,    0,    0, 1782, 1782, 1782, 1782,
 1782,    0, 1782,    0,    0, 1782, 1782,    0,    0,    0,
 1782, 1782,    0,    0, 1782, 1782, 1782, 1782, 1782, 1782,
 1782, 1782, 1782,    0, 1782,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1782, 1782, 1782, 1782, 1782, 1782,
 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1782,
 1782, 1782, 1782, 1782, 1782,    0, 1782, 1782, 1782, 1782,
 1782, 1782,    0, 1782, 1782, 1782, 1782,    0, 1782,    0,
 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1782,
 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1782,    0, 1782,
 1782, 1782, 1782,    0, 1782, 1782, 1782, 1782, 1782,    0,
 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1782,
 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1782,
 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1782, 1794,
 1782, 1782, 1782, 1782,    0, 1782, 1782, 1782, 1782, 1782,
 1782,    0,    0, 1782, 1782, 1782, 1782, 1782, 1782, 1782,
 1782, 1782,    0,    0,    0,    0,    0, 1782,    0, 1782,
 1782, 1782, 1782, 1782, 1782,    0, 1782,    0,    0,    0,
 1794, 1794, 1794, 1794, 1794, 1794, 1794,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1794, 1794,
 1794, 1794,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1794,    0, 1794,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1794,    0, 1794,    0,
    0, 1794,    0, 1794, 1794,    0,    0, 1794, 1794,    0,
 1794,    0,    0,    0,    0,    0, 1794,    0, 1794, 1794,
 1794, 1794,    0, 1794,    0,    0, 1794,    0,    0, 1794,
    0,    0,    0,    0,    0,    0, 1794,    0, 1794, 1794,
    0, 1794, 1794, 1794, 1794, 1794,    0,    0, 1794,    0,
    0, 1794,    0, 1794, 1794,    0,    0, 1794, 1794, 1794,
    0, 1794, 1794, 1794, 1794, 1794, 1794, 1794,    0,    0,
    0, 1794, 1794, 1794, 1794, 1794,    0,    0,    0, 1794,
    0,    0,    0,    0,    0,    0,    0, 1794, 1794, 1794,
 1794, 1794, 1794,    0,    0,    0, 1794, 1794,    0, 1794,
    0, 1794,    0, 1794, 1794, 1794,    0, 1794,    0, 1794,
 1794, 1794,    0, 1794, 1794, 1794, 1794, 1794,    0, 1794,
 1794,    0,    0,    0,    0, 1794,    0, 1794, 1794,    0,
    0, 1794, 1794, 1794,    0,    0, 1794,    0, 1794,    0,
    0, 1794, 1794, 1794, 1794,    0, 1794,    0, 1794,    0,
 1794, 1794, 1794, 1794, 1794,    0,    0, 1794, 1794, 1794,
    0, 1794, 1794,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1794, 1794, 1794,    0, 1794, 1794, 1794,    0,
 1794,    0,    0,    0, 1794,    0, 1794, 1794, 1794, 1794,
    0, 1794,    0, 1794, 1794, 1794, 1794, 1794, 1794, 1794,
 1794,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1794, 1794,    0, 1794, 1794, 1794,    0,    0,    0,    0,
 1794, 1794, 1794, 1794, 1794,    0, 1794,    0,    0, 1794,
 1794,    0,    0,    0, 1794, 1794,    0,    0, 1794, 1794,
 1794, 1794, 1794, 1794, 1794, 1794, 1794,    0, 1794,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1794, 1794,
 1794, 1794, 1794, 1794, 1794, 1794, 1794, 1794, 1794, 1794,
 1794, 1794, 1794, 1794, 1794, 1794, 1794, 1794, 1794,    0,
 1794, 1794, 1794, 1794, 1794, 1794,    0, 1794, 1794, 1794,
 1794,    0, 1794,    0, 1794, 1794, 1794, 1794, 1794, 1794,
 1794, 1794, 1794, 1794, 1794, 1794, 1794, 1794, 1794, 1794,
 1794, 1794,    0, 1794, 1794, 1794, 1794,    0, 1794, 1794,
 1794, 1794, 1794,    0, 1794, 1794, 1794, 1794, 1794, 1794,
 1794, 1794, 1794, 1794, 1794, 1794, 1794, 1794, 1794, 1794,
 1794, 1794, 1794, 1794, 1794, 1794, 1794, 1794, 1794, 1794,
 1794, 1794, 1794, 1799, 1794, 1794, 1794, 1794,    0, 1794,
 1794, 1794, 1794, 1794, 1794,    0,    0, 1794, 1794, 1794,
 1794, 1794, 1794, 1794, 1794, 1794,    0,    0,    0,    0,
    0, 1794,    0, 1794, 1794, 1794, 1794, 1794, 1794,    0,
 1794,    0,    0,    0, 1799, 1799, 1799, 1799, 1799, 1799,
 1799,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1799, 1799, 1799, 1799,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1799,    0, 1799,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1799,    0, 1799,    0,    0, 1799,    0, 1799, 1799,    0,
    0, 1799, 1799,    0, 1799,    0,    0,    0,    0,    0,
 1799,    0, 1799, 1799, 1799, 1799,    0, 1799,    0,    0,
 1799,    0,    0, 1799,    0,    0,    0,    0,    0,    0,
 1799,    0, 1799, 1799,    0, 1799, 1799, 1799, 1799, 1799,
    0,    0, 1799,    0,    0, 1799,    0, 1799, 1799,    0,
    0, 1799, 1799, 1799,    0, 1799, 1799, 1799, 1799, 1799,
 1799, 1799,    0,    0,    0, 1799, 1799, 1799, 1799, 1799,
    0,    0,    0, 1799,    0,    0,    0,    0,    0,    0,
    0, 1799, 1799, 1799, 1799, 1799, 1799,    0,    0,    0,
 1799, 1799,    0, 1799,    0, 1799,    0, 1799, 1799, 1799,
    0, 1799,    0, 1799, 1799, 1799,    0, 1799, 1799, 1799,
 1799, 1799,    0, 1799, 1799,    0,    0,    0,    0, 1799,
    0, 1799, 1799,    0,    0, 1799, 1799, 1799,    0,    0,
 1799,    0, 1799,    0,    0, 1799, 1799, 1799, 1799,    0,
 1799,    0, 1799,    0, 1799, 1799, 1799, 1799, 1799,    0,
    0, 1799, 1799, 1799,    0, 1799, 1799,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1799, 1799, 1799,    0,
 1799, 1799, 1799,    0, 1799,    0,    0,    0, 1799,    0,
 1799, 1799, 1799, 1799,    0, 1799,    0, 1799, 1799, 1799,
 1799, 1799, 1799, 1799, 1799,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1799, 1799,    0, 1799, 1799, 1799,
    0,    0,    0,    0, 1799, 1799, 1799, 1799, 1799,    0,
 1799,    0,    0, 1799, 1799,    0,    0,    0, 1799, 1799,
    0,    0, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,
 1799,    0, 1799,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,
 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,
 1799, 1799, 1799,    0, 1799, 1799, 1799, 1799, 1799, 1799,
    0, 1799, 1799, 1799, 1799,    0, 1799,    0, 1799, 1799,
 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,
 1799, 1799, 1799, 1799, 1799, 1799,    0, 1799, 1799, 1799,
 1799,    0, 1799, 1799, 1799, 1799, 1799,    0, 1799, 1799,
 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,
 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,
 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1828, 1799, 1799,
 1799, 1799,    0, 1799, 1799, 1799, 1799, 1799, 1799,    0,
    0, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,
    0,    0,    0,    0,    0, 1799,    0, 1799, 1799, 1799,
 1799, 1799, 1799,    0, 1799,    0,    0,    0, 1828, 1828,
 1828, 1828, 1828, 1828, 1828,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1828, 1828, 1828, 1828,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1828,    0,
 1828,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1828,    0, 1828,    0,    0, 1828,
    0, 1828, 1828,    0,    0, 1828, 1828,    0, 1828,    0,
    0,    0,    0,    0, 1828,    0, 1828, 1828, 1828, 1828,
    0, 1828,    0,    0, 1828,    0,    0, 1828,    0,    0,
    0,    0,    0,    0, 1828,    0, 1828, 1828,    0, 1828,
 1828, 1828, 1828, 1828,    0,    0, 1828,    0,    0, 1828,
    0, 1828, 1828,    0,    0, 1828, 1828, 1828,    0, 1828,
 1828, 1828, 1828, 1828, 1828, 1828,    0,    0,    0, 1828,
 1828, 1828, 1828, 1828,    0,    0,    0, 1828,    0,    0,
    0,    0,    0,    0,    0, 1828, 1828, 1828, 1828, 1828,
 1828,    0,    0,    0, 1828, 1828,    0, 1828,    0, 1828,
    0, 1828, 1828, 1828,    0, 1828,    0, 1828, 1828, 1828,
    0, 1828, 1828, 1828, 1828, 1828,    0, 1828, 1828,    0,
    0,    0,    0, 1828,    0, 1828, 1828,    0,    0, 1828,
 1828, 1828,    0,    0, 1828,    0, 1828,    0,    0, 1828,
 1828, 1828, 1828,    0, 1828,    0, 1828,    0, 1828, 1828,
 1828, 1828, 1828,    0,    0, 1828, 1828, 1828,    0, 1828,
 1828,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1828, 1828, 1828,    0, 1828, 1828, 1828,    0, 1828,    0,
    0,    0, 1828,    0, 1828, 1828, 1828, 1828,    0, 1828,
    0, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1828, 1828,
    0, 1828, 1828, 1828,    0,    0,    0,    0, 1828, 1828,
 1828, 1828, 1828,    0, 1828,    0,    0, 1828, 1828,    0,
    0,    0, 1828, 1828,    0,    0, 1828, 1828, 1828, 1828,
 1828, 1828, 1828, 1828, 1828,    0, 1828,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1828, 1828, 1828, 1828,
 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828,
 1828, 1828, 1828, 1828, 1828, 1828, 1828,    0, 1828, 1828,
 1828, 1828, 1828, 1828,    0, 1828, 1828, 1828, 1828,    0,
 1828,    0, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828,
 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828,
    0, 1828, 1828, 1828, 1828,    0, 1828, 1828, 1828, 1828,
 1828,    0, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828,
 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828,
 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828,
 1828, 1834, 1828, 1828, 1828, 1828,    0, 1828, 1828, 1828,
 1828, 1828, 1828,    0,    0, 1828, 1828, 1828, 1828, 1828,
 1828, 1828, 1828, 1828,    0,    0,    0,    0,    0, 1828,
    0, 1828, 1828, 1828, 1828, 1828, 1828,    0, 1828,    0,
    0,    0, 1834, 1834, 1834, 1834, 1834, 1834, 1834,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1834, 1834, 1834, 1834,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1834,    0, 1834,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1834,    0,
 1834,    0,    0, 1834,    0, 1834, 1834,    0,    0, 1834,
 1834,    0, 1834,    0,    0,    0,    0,    0, 1834,    0,
 1834, 1834, 1834, 1834,    0, 1834,    0,    0, 1834,    0,
    0, 1834,    0,    0,    0,    0,    0,    0, 1834,    0,
 1834, 1834,    0, 1834, 1834, 1834, 1834, 1834,    0,    0,
 1834,    0,    0, 1834,    0, 1834, 1834,    0,    0, 1834,
 1834, 1834,    0, 1834, 1834, 1834, 1834, 1834, 1834, 1834,
    0,    0,    0, 1834, 1834, 1834, 1834, 1834,    0,    0,
    0, 1834,    0,    0,    0,    0,    0,    0,    0, 1834,
 1834, 1834, 1834, 1834, 1834,    0,    0,    0, 1834, 1834,
    0, 1834,    0, 1834,    0, 1834, 1834, 1834,    0, 1834,
    0, 1834, 1834, 1834,    0, 1834, 1834, 1834, 1834, 1834,
    0, 1834, 1834,    0,    0,    0,    0, 1834,    0, 1834,
 1834,    0,    0, 1834, 1834, 1834,    0,    0, 1834,    0,
 1834,    0,    0, 1834, 1834, 1834, 1834,    0, 1834,    0,
 1834,    0, 1834, 1834, 1834, 1834, 1834,    0,    0, 1834,
 1834, 1834,    0, 1834, 1834,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1834, 1834, 1834,    0, 1834, 1834,
 1834,    0, 1834,    0,    0,    0, 1834,    0, 1834, 1834,
 1834, 1834,    0, 1834,    0, 1834, 1834, 1834, 1834, 1834,
 1834, 1834, 1834,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1834, 1834,    0, 1834, 1834, 1834,    0,    0,
    0,    0, 1834, 1834, 1834, 1834, 1834,    0, 1834,    0,
    0, 1834, 1834,    0,    0,    0, 1834, 1834,    0,    0,
 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834,    0,
 1834,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834,
 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834,
 1834,    0, 1834, 1834, 1834, 1834, 1834, 1834,    0, 1834,
 1834, 1834, 1834,    0, 1834,    0, 1834, 1834, 1834, 1834,
 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834,
 1834, 1834, 1834, 1834,    0, 1834, 1834, 1834, 1834,    0,
 1834, 1834, 1834, 1834, 1834,    0, 1834, 1834, 1834, 1834,
 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834,
 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834,
 1834, 1834, 1834, 1834, 1834, 1958, 1834, 1834, 1834, 1834,
    0, 1834, 1834, 1834, 1834, 1834, 1834,    0,    0, 1834,
 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834,    0,    0,
    0,    0,    0, 1834,    0, 1834, 1834, 1834, 1834, 1834,
 1834,    0, 1834,    0,    0,    0, 1958, 1958, 1958, 1958,
 1958, 1958, 1958,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1958, 1958, 1958, 1958,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1958,    0, 1958,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1958,    0, 1958,    0,    0, 1958,    0, 1958,
 1958,    0,    0, 1958, 1958,    0, 1958,    0,    0,    0,
    0,    0, 1958,    0, 1958, 1958, 1958, 1958,    0, 1958,
    0,    0, 1958,    0,    0, 1958,    0,    0,    0,    0,
    0,    0, 1958,    0, 1958, 1958,    0, 1958, 1958, 1958,
 1958, 1958,    0,    0, 1958,    0,    0, 1958,    0, 1958,
 1958,    0,    0, 1958, 1958, 1958,    0, 1958, 1958, 1958,
 1958, 1958, 1958, 1958,    0,    0,    0, 1958, 1958, 1958,
 1958, 1958,    0,    0,    0, 1958,    0,    0,    0,    0,
    0,    0,    0, 1958, 1958, 1958, 1958, 1958, 1958,    0,
    0,    0, 1958, 1958,    0, 1958,    0, 1958,    0, 1958,
 1958, 1958,    0, 1958,    0, 1958, 1958, 1958,    0, 1958,
 1958, 1958, 1958, 1958,    0, 1958, 1958,    0,    0,    0,
    0, 1958,    0, 1958, 1958,    0,    0, 1958, 1958, 1958,
    0,    0, 1958,    0, 1958,    0,    0, 1958, 1958, 1958,
 1958,    0, 1958,    0, 1958,    0, 1958, 1958, 1958, 1958,
 1958,    0,    0, 1958, 1958, 1958,    0, 1958, 1958,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1958, 1958,
 1958,    0, 1958, 1958, 1958,    0, 1958,    0,    0,    0,
 1958,    0, 1958, 1958, 1958, 1958,    0, 1958,    0, 1958,
 1958, 1958, 1958, 1958, 1958, 1958, 1958,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1958, 1958,    0, 1958,
 1958, 1958,    0,    0,    0,    0, 1958, 1958, 1958, 1958,
 1958,    0, 1958,    0,    0, 1958, 1958,    0,    0,    0,
 1958, 1958,    0,    0, 1958, 1958, 1958, 1958, 1958, 1958,
 1958, 1958, 1958,    0, 1958,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1958, 1958, 1958, 1958, 1958, 1958,
 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1958,
 1958, 1958, 1958, 1958, 1958,    0, 1958, 1958, 1958, 1958,
 1958, 1958,    0, 1958, 1958, 1958, 1958,    0, 1958,    0,
 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1958,
 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1958,    0, 1958,
 1958, 1958, 1958,    0, 1958, 1958, 1958, 1958, 1958,    0,
 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1958,
 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1958,
 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1958, 1959,
 1958, 1958, 1958, 1958,    0, 1958, 1958, 1958, 1958, 1958,
 1958,    0,    0, 1958, 1958, 1958, 1958, 1958, 1958, 1958,
 1958, 1958,    0,    0,    0,    0,    0, 1958,    0, 1958,
 1958, 1958, 1958, 1958, 1958,    0, 1958,    0,    0,    0,
 1959, 1959, 1959, 1959, 1959, 1959, 1959,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1959, 1959,
 1959, 1959,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1959,    0, 1959,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1959,    0, 1959,    0,
    0, 1959,    0, 1959, 1959,    0,    0, 1959, 1959,    0,
 1959,    0,    0,    0,    0,    0, 1959,    0, 1959, 1959,
 1959, 1959,    0, 1959,    0,    0, 1959,    0,    0, 1959,
    0,    0,    0,    0,    0,    0, 1959,    0, 1959, 1959,
    0, 1959, 1959, 1959, 1959, 1959,    0,    0, 1959,    0,
    0, 1959,    0, 1959, 1959,    0,    0, 1959, 1959, 1959,
    0, 1959, 1959, 1959, 1959, 1959, 1959, 1959,    0,    0,
    0, 1959, 1959, 1959, 1959, 1959,    0,    0,    0, 1959,
    0,    0,    0,    0,    0,    0,    0, 1959, 1959, 1959,
 1959, 1959, 1959,    0,    0,    0, 1959, 1959,    0, 1959,
    0, 1959,    0, 1959, 1959, 1959,    0, 1959,    0, 1959,
 1959, 1959,    0, 1959, 1959, 1959, 1959, 1959,    0, 1959,
 1959,    0,    0,    0,    0, 1959,    0, 1959, 1959,    0,
    0, 1959, 1959, 1959,    0,    0, 1959,    0, 1959,    0,
    0, 1959, 1959, 1959, 1959,    0, 1959,    0, 1959,    0,
 1959, 1959, 1959, 1959, 1959,    0,    0, 1959, 1959, 1959,
    0, 1959, 1959,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1959, 1959, 1959,    0, 1959, 1959, 1959,    0,
 1959,    0,    0,    0, 1959,    0, 1959, 1959, 1959, 1959,
    0, 1959,    0, 1959, 1959, 1959, 1959, 1959, 1959, 1959,
 1959,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1959, 1959,    0, 1959, 1959, 1959,    0,    0,    0,    0,
 1959, 1959, 1959, 1959, 1959,    0, 1959,    0,    0, 1959,
 1959,    0,    0,    0, 1959, 1959,    0,    0, 1959, 1959,
 1959, 1959, 1959, 1959, 1959, 1959, 1959,    0, 1959,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1959, 1959,
 1959, 1959, 1959, 1959, 1959, 1959, 1959, 1959, 1959, 1959,
 1959, 1959, 1959, 1959, 1959, 1959, 1959, 1959, 1959,    0,
 1959, 1959, 1959, 1959, 1959, 1959,    0, 1959, 1959, 1959,
 1959,    0, 1959,    0, 1959, 1959, 1959, 1959, 1959, 1959,
 1959, 1959, 1959, 1959, 1959, 1959, 1959, 1959, 1959, 1959,
 1959, 1959,    0, 1959, 1959, 1959, 1959,    0, 1959, 1959,
 1959, 1959, 1959,    0, 1959, 1959, 1959, 1959, 1959, 1959,
 1959, 1959, 1959, 1959, 1959, 1959, 1959, 1959, 1959, 1959,
 1959, 1959, 1959, 1959, 1959, 1959, 1959, 1959, 1959, 1959,
 1959, 1959, 1959, 1960, 1959, 1959, 1959, 1959,    0, 1959,
 1959, 1959, 1959, 1959, 1959,    0,    0, 1959, 1959, 1959,
 1959, 1959, 1959, 1959, 1959, 1959,    0,    0,    0,    0,
    0, 1959,    0, 1959, 1959, 1959, 1959, 1959, 1959,    0,
 1959,    0,    0,    0, 1960, 1960, 1960, 1960, 1960, 1960,
 1960,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1960, 1960, 1960, 1960,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1960,    0, 1960,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1960,    0, 1960,    0,    0, 1960,    0, 1960, 1960,    0,
    0, 1960, 1960,    0, 1960,    0,    0,    0,    0,    0,
 1960,    0, 1960, 1960, 1960, 1960,    0, 1960,    0,    0,
 1960,    0,    0, 1960,    0,    0,    0,    0,    0,    0,
 1960,    0, 1960, 1960,    0, 1960, 1960, 1960, 1960, 1960,
    0,    0, 1960,    0,    0, 1960,    0, 1960, 1960,    0,
    0, 1960, 1960, 1960,    0, 1960, 1960, 1960, 1960, 1960,
 1960, 1960,    0,    0,    0, 1960, 1960, 1960, 1960, 1960,
    0,    0,    0, 1960,    0,    0,    0,    0,    0,    0,
    0, 1960, 1960, 1960, 1960, 1960, 1960,    0,    0,    0,
 1960, 1960,    0, 1960,    0, 1960,    0, 1960, 1960, 1960,
    0, 1960,    0, 1960, 1960, 1960,    0, 1960, 1960, 1960,
 1960, 1960,    0, 1960, 1960,    0,    0,    0,    0, 1960,
    0, 1960, 1960,    0,    0, 1960, 1960, 1960,    0,    0,
 1960,    0, 1960,    0,    0, 1960, 1960, 1960, 1960,    0,
 1960,    0, 1960,    0, 1960, 1960, 1960, 1960, 1960,    0,
    0, 1960, 1960, 1960,    0, 1960, 1960,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1960, 1960, 1960,    0,
 1960, 1960, 1960,    0, 1960,    0,    0,    0, 1960,    0,
 1960, 1960, 1960, 1960,    0, 1960,    0, 1960, 1960, 1960,
 1960, 1960, 1960, 1960, 1960,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1960, 1960,    0, 1960, 1960, 1960,
    0,    0,    0,    0, 1960, 1960, 1960, 1960, 1960,    0,
 1960,    0,    0, 1960, 1960,    0,    0,    0, 1960, 1960,
    0,    0, 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960,
 1960,    0, 1960,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960,
 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960,
 1960, 1960, 1960,    0, 1960, 1960, 1960, 1960, 1960, 1960,
    0, 1960, 1960, 1960, 1960,    0, 1960,    0, 1960, 1960,
 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960,
 1960, 1960, 1960, 1960, 1960, 1960,    0, 1960, 1960, 1960,
 1960,    0, 1960, 1960, 1960, 1960, 1960,    0, 1960, 1960,
 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960,
 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960,
 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1961, 1960, 1960,
 1960, 1960,    0, 1960, 1960, 1960, 1960, 1960, 1960,    0,
    0, 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960, 1960,
    0,    0,    0,    0,    0, 1960,    0, 1960, 1960, 1960,
 1960, 1960, 1960,    0, 1960,    0,    0,    0, 1961, 1961,
 1961, 1961, 1961, 1961, 1961,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1961, 1961, 1961, 1961,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1961,    0,
 1961,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1961,    0, 1961,    0,    0, 1961,
    0, 1961, 1961,    0,    0, 1961, 1961,    0, 1961,    0,
    0,    0,    0,    0, 1961,    0, 1961, 1961, 1961, 1961,
    0, 1961,    0,    0, 1961,    0,    0, 1961,    0,    0,
    0,    0,    0,    0, 1961,    0, 1961, 1961,    0, 1961,
 1961, 1961, 1961, 1961,    0,    0, 1961,    0,    0, 1961,
    0, 1961, 1961,    0,    0, 1961, 1961, 1961,    0, 1961,
 1961, 1961, 1961, 1961, 1961, 1961,    0,    0,    0, 1961,
 1961, 1961, 1961, 1961,    0,    0,    0, 1961,    0,    0,
    0,    0,    0,    0,    0, 1961, 1961, 1961, 1961, 1961,
 1961,    0,    0,    0, 1961, 1961,    0, 1961,    0, 1961,
    0, 1961, 1961, 1961,    0, 1961,    0, 1961, 1961, 1961,
    0, 1961, 1961, 1961, 1961, 1961,    0, 1961, 1961,    0,
    0,    0,    0, 1961,    0, 1961, 1961,    0,    0, 1961,
 1961, 1961,    0,    0, 1961,    0, 1961,    0,    0, 1961,
 1961, 1961, 1961,    0, 1961,    0, 1961,    0, 1961, 1961,
 1961, 1961, 1961,    0,    0, 1961, 1961, 1961,    0, 1961,
 1961,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1961, 1961, 1961,    0, 1961, 1961, 1961,    0, 1961,    0,
    0,    0, 1961,    0, 1961, 1961, 1961, 1961,    0, 1961,
    0, 1961, 1961, 1961, 1961, 1961, 1961, 1961, 1961,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1961, 1961,
    0, 1961, 1961, 1961,    0,    0,    0,    0, 1961, 1961,
 1961, 1961, 1961,    0, 1961,    0,    0, 1961, 1961,    0,
    0,    0, 1961, 1961,    0,    0, 1961, 1961, 1961, 1961,
 1961, 1961, 1961, 1961, 1961,    0, 1961,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1961, 1961, 1961, 1961,
 1961, 1961, 1961, 1961, 1961, 1961, 1961, 1961, 1961, 1961,
 1961, 1961, 1961, 1961, 1961, 1961, 1961,    0, 1961, 1961,
 1961, 1961, 1961, 1961,    0, 1961, 1961, 1961, 1961,    0,
 1961,    0, 1961, 1961, 1961, 1961, 1961, 1961, 1961, 1961,
 1961, 1961, 1961, 1961, 1961, 1961, 1961, 1961, 1961, 1961,
    0, 1961, 1961, 1961, 1961,    0, 1961, 1961, 1961, 1961,
 1961,    0, 1961, 1961, 1961, 1961, 1961, 1961, 1961, 1961,
 1961, 1961, 1961, 1961, 1961, 1961, 1961, 1961, 1961, 1961,
 1961, 1961, 1961, 1961, 1961, 1961, 1961, 1961, 1961, 1961,
 1961, 1962, 1961, 1961, 1961, 1961,    0, 1961, 1961, 1961,
 1961, 1961, 1961,    0,    0, 1961, 1961, 1961, 1961, 1961,
 1961, 1961, 1961, 1961,    0,    0,    0,    0,    0, 1961,
    0, 1961, 1961, 1961, 1961, 1961, 1961,    0, 1961,    0,
    0,    0, 1962, 1962, 1962, 1962, 1962, 1962, 1962,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1962, 1962, 1962, 1962,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1962,    0, 1962,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1962,    0,
 1962,    0,    0, 1962,    0, 1962, 1962,    0,    0, 1962,
 1962,    0, 1962,    0,    0,    0,    0,    0, 1962,    0,
 1962, 1962, 1962, 1962,    0, 1962,    0,    0, 1962,    0,
    0, 1962,    0,    0,    0,    0,    0,    0, 1962,    0,
 1962, 1962,    0, 1962, 1962, 1962, 1962, 1962,    0,    0,
 1962,    0,    0, 1962,    0, 1962, 1962,    0,    0, 1962,
 1962, 1962,    0, 1962, 1962, 1962, 1962, 1962, 1962, 1962,
    0,    0,    0, 1962, 1962, 1962, 1962, 1962,    0,    0,
    0, 1962,    0,    0,    0,    0,    0,    0,    0, 1962,
 1962, 1962, 1962, 1962, 1962,    0,    0,    0, 1962, 1962,
    0, 1962,    0, 1962,    0, 1962, 1962, 1962,    0, 1962,
    0, 1962, 1962, 1962,    0, 1962, 1962, 1962, 1962, 1962,
    0, 1962, 1962,    0,    0,    0,    0, 1962,    0, 1962,
 1962,    0,    0, 1962, 1962, 1962,    0,    0, 1962,    0,
 1962,    0,    0, 1962, 1962, 1962, 1962,    0, 1962,    0,
 1962,    0, 1962, 1962, 1962, 1962, 1962,    0,    0, 1962,
 1962, 1962,    0, 1962, 1962,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1962, 1962, 1962,    0, 1962, 1962,
 1962,    0, 1962,    0,    0,    0, 1962,    0, 1962, 1962,
 1962, 1962,    0, 1962,    0, 1962, 1962, 1962, 1962, 1962,
 1962, 1962, 1962,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1962, 1962,    0, 1962, 1962, 1962,    0,    0,
    0,    0, 1962, 1962, 1962, 1962, 1962,    0, 1962,    0,
    0, 1962, 1962,    0,    0,    0, 1962, 1962,    0,    0,
 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962,    0,
 1962,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962,
 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962,
 1962,    0, 1962, 1962, 1962, 1962, 1962, 1962,    0, 1962,
 1962, 1962, 1962,    0, 1962,    0, 1962, 1962, 1962, 1962,
 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962,
 1962, 1962, 1962, 1962,    0, 1962, 1962, 1962, 1962,    0,
 1962, 1962, 1962, 1962, 1962,    0, 1962, 1962, 1962, 1962,
 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962,
 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962,
 1962, 1962, 1962, 1962, 1962, 1963, 1962, 1962, 1962, 1962,
    0, 1962, 1962, 1962, 1962, 1962, 1962,    0,    0, 1962,
 1962, 1962, 1962, 1962, 1962, 1962, 1962, 1962,    0,    0,
    0,    0,    0, 1962,    0, 1962, 1962, 1962, 1962, 1962,
 1962,    0, 1962,    0,    0,    0, 1963, 1963, 1963, 1963,
 1963, 1963, 1963,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1963, 1963, 1963, 1963,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1963,    0, 1963,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1963,    0, 1963,    0,    0, 1963,    0, 1963,
 1963,    0,    0, 1963, 1963,    0, 1963,    0,    0,    0,
    0,    0, 1963,    0, 1963, 1963, 1963, 1963,    0, 1963,
    0,    0, 1963,    0,    0, 1963,    0,    0,    0,    0,
    0,    0, 1963,    0, 1963, 1963,    0, 1963, 1963, 1963,
 1963, 1963,    0,    0, 1963,    0,    0, 1963,    0, 1963,
 1963,    0,    0, 1963, 1963, 1963,    0, 1963, 1963, 1963,
 1963, 1963, 1963, 1963,    0,    0,    0, 1963, 1963, 1963,
 1963, 1963,    0,    0,    0, 1963,    0,    0,    0,    0,
    0,    0,    0, 1963, 1963, 1963, 1963, 1963, 1963,    0,
    0,    0, 1963, 1963,    0, 1963,    0, 1963,    0, 1963,
 1963, 1963,    0, 1963,    0, 1963, 1963, 1963,    0, 1963,
 1963, 1963, 1963, 1963,    0, 1963, 1963,    0,    0,    0,
    0, 1963,    0, 1963, 1963,    0,    0, 1963, 1963, 1963,
    0,    0, 1963,    0, 1963,    0,    0, 1963, 1963, 1963,
 1963,    0, 1963,    0, 1963,    0, 1963, 1963, 1963, 1963,
 1963,    0,    0, 1963, 1963, 1963,    0, 1963, 1963,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1963, 1963,
 1963,    0, 1963, 1963, 1963,    0, 1963,    0,    0,    0,
 1963,    0, 1963, 1963, 1963, 1963,    0, 1963,    0, 1963,
 1963, 1963, 1963, 1963, 1963, 1963, 1963,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1963, 1963,    0, 1963,
 1963, 1963,    0,    0,    0,    0, 1963, 1963, 1963, 1963,
 1963,    0, 1963,    0,    0, 1963, 1963,    0,    0,    0,
 1963, 1963,    0,    0, 1963, 1963, 1963, 1963, 1963, 1963,
 1963, 1963, 1963,    0, 1963,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1963, 1963, 1963, 1963, 1963, 1963,
 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1963,
 1963, 1963, 1963, 1963, 1963,    0, 1963, 1963, 1963, 1963,
 1963, 1963,    0, 1963, 1963, 1963, 1963,    0, 1963,    0,
 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1963,
 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1963,    0, 1963,
 1963, 1963, 1963,    0, 1963, 1963, 1963, 1963, 1963,    0,
 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1963,
 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1963,
 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1963, 1964,
 1963, 1963, 1963, 1963,    0, 1963, 1963, 1963, 1963, 1963,
 1963,    0,    0, 1963, 1963, 1963, 1963, 1963, 1963, 1963,
 1963, 1963,    0,    0,    0,    0,    0, 1963,    0, 1963,
 1963, 1963, 1963, 1963, 1963,    0, 1963,    0,    0,    0,
 1964, 1964, 1964, 1964, 1964, 1964, 1964,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1964, 1964,
 1964, 1964,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1964,    0, 1964,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1964,    0, 1964,    0,
    0, 1964,    0, 1964, 1964,    0,    0, 1964, 1964,    0,
 1964,    0,    0,    0,    0,    0, 1964,    0, 1964, 1964,
 1964, 1964,    0, 1964,    0,    0, 1964,    0,    0, 1964,
    0,    0,    0,    0,    0,    0, 1964,    0, 1964, 1964,
    0, 1964, 1964, 1964, 1964, 1964,    0,    0, 1964,    0,
    0, 1964,    0, 1964, 1964,    0,    0, 1964, 1964, 1964,
    0, 1964, 1964, 1964, 1964, 1964, 1964, 1964,    0,    0,
    0, 1964, 1964, 1964, 1964, 1964,    0,    0,    0, 1964,
    0,    0,    0,    0,    0,    0,    0, 1964, 1964, 1964,
 1964, 1964, 1964,    0,    0,    0, 1964, 1964,    0, 1964,
    0, 1964,    0, 1964, 1964, 1964,    0, 1964,    0, 1964,
 1964, 1964,    0, 1964, 1964, 1964, 1964, 1964,    0, 1964,
 1964,    0,    0,    0,    0, 1964,    0, 1964, 1964,    0,
    0, 1964, 1964, 1964,    0,    0, 1964,    0, 1964,    0,
    0, 1964, 1964, 1964, 1964,    0, 1964,    0, 1964,    0,
 1964, 1964, 1964, 1964, 1964,    0,    0, 1964, 1964, 1964,
    0, 1964, 1964,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1964, 1964, 1964,    0, 1964, 1964, 1964,    0,
 1964,    0,    0,    0, 1964,    0, 1964, 1964, 1964, 1964,
    0, 1964,    0, 1964, 1964, 1964, 1964, 1964, 1964, 1964,
 1964,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1964, 1964,    0, 1964, 1964, 1964,    0,    0,    0,    0,
 1964, 1964, 1964, 1964, 1964,    0, 1964,    0,    0, 1964,
 1964,    0,    0,    0, 1964, 1964,    0,    0, 1964, 1964,
 1964, 1964, 1964, 1964, 1964, 1964, 1964,    0, 1964,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1964, 1964,
 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964,
 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964,    0,
 1964, 1964, 1964, 1964, 1964, 1964,    0, 1964, 1964, 1964,
 1964,    0, 1964,    0, 1964, 1964, 1964, 1964, 1964, 1964,
 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964,
 1964, 1964,    0, 1964, 1964, 1964, 1964,    0, 1964, 1964,
 1964, 1964, 1964,    0, 1964, 1964, 1964, 1964, 1964, 1964,
 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964,
 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964,
 1964, 1964, 1964, 1965, 1964, 1964, 1964, 1964,    0, 1964,
 1964, 1964, 1964, 1964, 1964,    0,    0, 1964, 1964, 1964,
 1964, 1964, 1964, 1964, 1964, 1964,    0,    0,    0,    0,
    0, 1964,    0, 1964, 1964, 1964, 1964, 1964, 1964,    0,
 1964,    0,    0,    0, 1965, 1965, 1965, 1965, 1965, 1965,
 1965,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1965, 1965, 1965, 1965,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1965,    0, 1965,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1965,    0, 1965,    0,    0, 1965,    0, 1965, 1965,    0,
    0, 1965, 1965,    0, 1965,    0,    0,    0,    0,    0,
 1965,    0, 1965, 1965, 1965, 1965,    0, 1965,    0,    0,
 1965,    0,    0, 1965,    0,    0,    0,    0,    0,    0,
 1965,    0, 1965, 1965,    0, 1965, 1965, 1965, 1965, 1965,
    0,    0, 1965,    0,    0, 1965,    0, 1965, 1965,    0,
    0, 1965, 1965, 1965,    0, 1965, 1965, 1965, 1965, 1965,
 1965, 1965,    0,    0,    0, 1965, 1965, 1965, 1965, 1965,
    0,    0,    0, 1965,    0,    0,    0,    0,    0,    0,
    0, 1965, 1965, 1965, 1965, 1965, 1965,    0,    0,    0,
 1965, 1965,    0, 1965,    0, 1965,    0, 1965, 1965, 1965,
    0, 1965,    0, 1965, 1965, 1965,    0, 1965, 1965, 1965,
 1965, 1965,    0, 1965, 1965,    0,    0,    0,    0, 1965,
    0, 1965, 1965,    0,    0, 1965, 1965, 1965,    0,    0,
 1965,    0, 1965,    0,    0, 1965, 1965, 1965, 1965,    0,
 1965,    0, 1965,    0, 1965, 1965, 1965, 1965, 1965,    0,
    0, 1965, 1965, 1965,    0, 1965, 1965,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1965, 1965, 1965,    0,
 1965, 1965, 1965,    0, 1965,    0,    0,    0, 1965,    0,
 1965, 1965, 1965, 1965,    0, 1965,    0, 1965, 1965, 1965,
 1965, 1965, 1965, 1965, 1965,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1965, 1965,    0, 1965, 1965, 1965,
    0,    0,    0,    0, 1965, 1965, 1965, 1965, 1965,    0,
 1965,    0,    0, 1965, 1965,    0,    0,    0, 1965, 1965,
    0,    0, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965,
 1965,    0, 1965,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965,
 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965,
 1965, 1965, 1965,    0, 1965, 1965, 1965, 1965, 1965, 1965,
    0, 1965, 1965, 1965, 1965,    0, 1965,    0, 1965, 1965,
 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965,
 1965, 1965, 1965, 1965, 1965, 1965,    0, 1965, 1965, 1965,
 1965,    0, 1965, 1965, 1965, 1965, 1965,    0, 1965, 1965,
 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965,
 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965,
 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1552, 1965, 1965,
 1965, 1965,    0, 1965, 1965, 1965, 1965, 1965, 1965,    0,
    0, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965,
    0,    0,    0,    0,    0, 1965,    0, 1965, 1965, 1965,
 1965, 1965, 1965,    0, 1965,    0,    0,    0, 1552, 1552,
 1552, 1552, 1552,    0, 1552,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1552, 1552, 1552, 1552,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1552,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1552,    0, 1552,    0,    0, 1552,
    0, 1552, 1552,    0,    0, 1552, 1552,    0, 1552,    0,
    0,    0,    0,    0, 1552,    0, 1552, 1552, 1552, 1552,
    0, 1552,    0,    0, 1552,    0,    0, 1552,    0,    0,
    0,    0,    0,    0, 1552,    0, 1552, 1552,    0, 1552,
 1552, 1552, 1552, 1552,    0,    0, 1552,    0,    0, 1552,
    0, 1552, 1552,    0,    0, 1552, 1552, 1552,    0, 1552,
 1552, 1552, 1552, 1552, 1552, 1552,    0,    0,    0, 1552,
 1552, 1552, 1552, 1552,    0,    0,    0, 1552,    0,    0,
    0,    0,    0,    0,    0, 1552, 1552, 1552, 1552, 1552,
 1552,    0,    0,    0, 1552, 1552,    0, 1552,    0, 1552,
    0, 1552, 1552, 1552,    0, 1552,    0, 1552, 1552, 1552,
    0, 1552, 1552, 1552, 1552, 1552,    0, 1552, 1552,    0,
    0,    0,    0, 1552,    0, 1552, 1552,    0,    0, 1552,
 1552, 1552,    0,    0, 1552,    0, 1552,    0,    0, 1552,
 1552, 1552, 1552,    0, 1552,    0, 1552,    0, 1552, 1552,
 1552, 1552, 1552,    0,    0, 1552, 1552, 1552,    0, 1552,
 1552,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1552, 1552, 1552,    0, 1552, 1552, 1552,    0, 1552,    0,
    0,    0, 1552,    0, 1552, 1552, 1552, 1552,    0, 1552,
    0, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1552, 1552,
    0, 1552, 1552, 1552,    0,    0,    0,    0, 1552, 1552,
 1552, 1552, 1552,    0, 1552,    0,    0, 1552, 1552,    0,
    0,    0, 1552, 1552,    0,    0, 1552, 1552, 1552, 1552,
 1552, 1552, 1552, 1552, 1552,    0, 1552,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1552, 1552, 1552, 1552,
 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 1552, 1552, 1552, 1552, 1552, 1552, 1552,    0, 1552, 1552,
 1552, 1552, 1552, 1552,    0, 1552, 1552, 1552, 1552,    0,
 1552,    0, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
    0, 1552, 1552, 1552, 1552,    0, 1552, 1552, 1552, 1552,
 1552,    0, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 1552, 1552,    0, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 1552, 1602, 1552, 1552, 1552, 1552, 1749, 1552, 1552, 1552,
 1552, 1552, 1552,    0,    0, 1552, 1552, 1552, 1552, 1552,
 1552, 1552, 1552, 1552,    0,    0,    0,    0,    0, 1552,
    0, 1552, 1552, 1552, 1552, 1552, 1552,    0, 1552,    0,
    0,    0,    0,    0,    0,    0,    0, 1749, 1749, 1749,
 1749, 1749,    0, 1749,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1749, 1749, 1749, 1749,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1749,    0, 1749,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1749,    0, 1749,    0,    0, 1749,    0,
 1749, 1749,    0,    0, 1749, 1749,    0, 1749,    0,    0,
    0,    0,    0, 1749,    0, 1749, 1749, 1749, 1749,    0,
 1749,    0,    0, 1749,    0,    0, 1749,    0,    0,    0,
    0,    0,    0, 1749,    0, 1749, 1749,    0, 1749, 1749,
 1749, 1749, 1749,    0,    0, 1749,    0,    0, 1749,    0,
 1749, 1749,    0,    0, 1749, 1749, 1749,    0, 1749, 1749,
 1749, 1749, 1749, 1749, 1749,    0,    0,    0, 1749, 1749,
 1749, 1749, 1749,    0,    0,    0, 1749,    0,    0,    0,
    0,    0,    0,    0, 1749, 1749, 1749, 1749, 1749, 1749,
    0,    0,    0, 1749, 1749,    0, 1749,    0, 1749,    0,
 1749, 1749, 1749,    0, 1749,    0, 1749, 1749, 1749,    0,
 1749, 1749, 1749, 1749, 1749,    0, 1749, 1749,    0,    0,
    0,    0, 1749,    0, 1749, 1749,    0,    0, 1749, 1749,
 1749,    0,    0, 1749,    0, 1749,    0,    0, 1749, 1749,
 1749, 1749,    0, 1749,    0, 1749,    0, 1749, 1749, 1749,
 1749, 1749,    0,    0, 1749, 1749, 1749,    0, 1749, 1749,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1749,
 1749, 1749,    0, 1749, 1749, 1749,    0, 1749,    0,    0,
    0, 1749,    0, 1749, 1749, 1749, 1749,    0, 1749,    0,
 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1749, 1749,    0,
 1749, 1749, 1749,    0,    0,    0,    0, 1749, 1749, 1749,
 1749, 1749,    0, 1749,    0,    0, 1749, 1749,    0,    0,
    0, 1749, 1749,    0,    0, 1749, 1749, 1749, 1749, 1749,
 1749, 1749, 1749, 1749,    0, 1749,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1749, 1749, 1749, 1749, 1749,
 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749,
 1749, 1749, 1749, 1749, 1749, 1749,    0, 1749, 1749, 1749,
 1749, 1749, 1749,    0, 1749, 1749, 1749, 1749,    0, 1749,
    0, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749,
 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749,    0,
 1749, 1749, 1749, 1749,    0, 1749, 1749, 1749, 1749, 1749,
    0, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749,
 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749,
 1749,    0, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749,
 1767, 1749, 1749, 1749, 1749,    0, 1749, 1749, 1749, 1749,
 1749, 1749,    0,    0, 1749, 1749, 1749, 1749, 1749, 1749,
 1749, 1749, 1749,    0,    0,    0,    0,    0, 1749,    0,
 1749, 1749, 1749, 1749, 1749, 1749,    0, 1749,    0,    0,
    0, 1767, 1767, 1767, 1767, 1767, 1763, 1767,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1767,
 1767, 1767, 1767,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1767,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1767,    0, 1767,
    0,    0, 1767,    0, 1767, 1767,    0,    0, 1767, 1767,
    0, 1767,    0,    0,    0,    0,    0, 1767,    0, 1767,
 1767, 1767, 1767,    0, 1767,    0,    0, 1767,    0,    0,
 1767,    0,    0,    0,    0,    0,    0, 1767,    0, 1767,
 1767,    0, 1767, 1767, 1767, 1767, 1767,    0,    0, 1767,
    0,    0, 1767,    0, 1767, 1767,    0,    0, 1767, 1767,
 1767,    0, 1767, 1767, 1767, 1767, 1767, 1767, 1767,    0,
    0,    0, 1767, 1767, 1767, 1767, 1767,    0,    0,    0,
 1767,    0,    0,    0,    0,    0,    0,    0, 1767, 1767,
 1767, 1767, 1767, 1767,    0,    0,    0, 1767, 1767,    0,
 1767,    0, 1767,    0, 1767, 1767, 1767,    0, 1767,    0,
 1767, 1767, 1767,    0, 1767, 1767, 1767, 1767, 1767,    0,
 1767, 1767,    0,    0,    0,    0, 1767,    0, 1767, 1767,
    0,    0, 1767, 1767, 1767,    0,    0, 1767,    0, 1767,
    0,    0, 1767, 1767, 1767, 1767,    0, 1767,    0, 1767,
    0, 1767, 1767, 1767, 1767, 1767,    0,    0, 1767, 1767,
 1767,    0, 1767, 1767,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1767, 1767, 1767,    0, 1767, 1767, 1767,
    0, 1767,    0,    0,    0, 1767,    0, 1767, 1767, 1767,
 1767,    0, 1767,    0, 1767, 1767, 1767, 1767, 1767, 1767,
 1767, 1767,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1767, 1767,    0, 1767, 1767, 1767,    0,    0,    0,
    0, 1767, 1767, 1767, 1767, 1767,    0, 1767,    0,    0,
 1767, 1767,    0,    0,    0, 1767, 1767,    0,    0, 1767,
 1767, 1767, 1767, 1767, 1767, 1767, 1767, 1767,    0, 1767,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1767,
 1767, 1767, 1767, 1767, 1767, 1767, 1767, 1767, 1767, 1767,
 1767, 1767, 1767, 1767, 1767, 1767, 1767, 1767, 1767, 1767,
    0, 1767, 1767, 1767, 1767, 1767, 1767,    0, 1767, 1767,
 1767, 1767,    0, 1767,    0, 1767, 1767, 1767, 1767, 1767,
 1767, 1767, 1767, 1767, 1767, 1767, 1767, 1767, 1767, 1767,
 1767, 1767, 1767,    0, 1767, 1767, 1767, 1767,    0, 1767,
 1767, 1767, 1767, 1767,    0, 1767, 1767, 1767, 1767, 1767,
 1767, 1767, 1767, 1767, 1767, 1767, 1767, 1767, 1767, 1767,
 1767, 1767, 1767, 1767, 1767,    0, 1767, 1767, 1767, 1767,
 1767, 1767, 1767, 1767, 1474, 1767, 1767, 1767, 1767,    0,
 1767, 1767, 1767, 1767, 1767, 1767,    0,    0, 1767, 1767,
 1767, 1767, 1767, 1767, 1767, 1767, 1767,    0,    0,    0,
    0,    0, 1767,    0, 1767, 1767, 1767, 1767, 1767, 1767,
    0, 1767,    0,    0,    0, 1474, 1474, 1474, 1474, 1474,
    0, 1474,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1474, 1474, 1474, 1474,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1474,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1474,    0, 1474,    0,    0, 1474,    0, 1474, 1474,
    0,    0, 1474, 1474,    0, 1474,    0,    0,    0,    0,
    0, 1474,    0, 1474, 1474, 1474, 1474,    0, 1474,    0,
    0, 1474,    0,    0, 1474,    0,    0,    0,    0,    0,
    0, 1474,    0, 1474, 1474,    0, 1474, 1474, 1474, 1474,
 1474,    0,    0, 1474,    0,    0, 1474,    0, 1474, 1474,
    0,    0, 1474, 1474, 1474,    0, 1474, 1474, 1474, 1474,
 1474, 1474, 1474,    0,    0,    0, 1474, 1474, 1474, 1474,
 1474,    0,    0,    0, 1474,    0,    0,    0,    0,    0,
    0,    0, 1474, 1474, 1474, 1474, 1474, 1474,    0,    0,
    0, 1474, 1474,    0, 1474,    0, 1474,    0, 1474, 1474,
 1474,    0, 1474,    0, 1474, 1474, 1474,    0, 1474, 1474,
 1474, 1474, 1474,    0, 1474, 1474,    0,    0,    0,    0,
 1474,    0, 1474, 1474,    0,    0, 1474, 1474, 1474,    0,
    0, 1474,    0, 1474,    0,    0, 1474, 1474, 1474, 1474,
    0, 1474,    0, 1474,    0, 1474, 1474, 1474, 1474, 1474,
    0,    0, 1474, 1474, 1474,    0, 1474, 1474,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1474, 1474, 1474,
    0, 1474, 1474, 1474,    0, 1474,    0,    0,    0, 1474,
    0, 1474, 1474, 1474, 1474,    0, 1474,    0, 1474, 1474,
 1474, 1474, 1474, 1474, 1474, 1474,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1474, 1474,    0, 1474, 1474,
 1474,    0,    0,    0,    0, 1474, 1474, 1474, 1474, 1474,
    0, 1474,    0,    0, 1474, 1474,    0,    0,    0, 1474,
 1474,    0,    0, 1474, 1474, 1474, 1474, 1474, 1474, 1474,
 1474, 1474,    0, 1474,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1474, 1474, 1474, 1474, 1474, 1474, 1474,
 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474,
 1474, 1474, 1474, 1474,    0, 1474, 1474, 1474, 1474, 1474,
 1474,    0, 1474, 1474, 1474, 1474,    0, 1474,    0, 1474,
 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474,
 1474, 1474, 1474, 1474, 1474, 1474, 1474,    0, 1474, 1474,
 1474, 1474,    0, 1474, 1474, 1474, 1474, 1474,    0, 1474,
 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474,
 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474,    0,
 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1488, 1474,
 1474, 1474, 1474,    0, 1474, 1474, 1474, 1474, 1474, 1474,
    0,    0, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474,
 1474,    0,    0,    0,    0,    0, 1474,    0, 1474, 1474,
 1474, 1474, 1474, 1474,    0, 1474,    0,    0,    0, 1488,
 1488, 1488, 1488, 1488,    0, 1488,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1488, 1488, 1488,
 1488,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1488,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1488,    0, 1488,    0,    0,
 1488,    0, 1488, 1488,    0,    0, 1488, 1488,    0, 1488,
    0,    0,    0,    0,    0,    0,    0, 1488, 1488, 1488,
 1488,    0, 1488,    0,    0, 1488,    0,    0, 1488,    0,
    0,    0,    0,    0,    0, 1488,    0, 1488, 1488,    0,
 1488, 1488, 1488, 1488, 1488,    0,    0, 1488,    0,    0,
 1488,    0, 1488, 1488,    0,    0, 1488, 1488, 1488,    0,
 1488, 1488, 1488, 1488, 1488, 1488, 1488,    0,    0,    0,
 1488, 1488, 1488, 1488, 1488,    0,    0,    0, 1488,    0,
    0,    0,    0,    0,    0,    0, 1488, 1488, 1488, 1488,
 1488, 1488,    0,    0,    0, 1488, 1488,    0, 1488,    0,
 1488,    0, 1488, 1488, 1488,    0, 1488,    0, 1488, 1488,
 1488,    0, 1488, 1488, 1488, 1488, 1488,    0, 1488, 1488,
    0,    0,    0,    0, 1488,    0, 1488, 1488,    0,    0,
 1488, 1488, 1488,    0,    0, 1488,    0, 1488,    0,    0,
 1488, 1488, 1488, 1488,    0, 1488,    0, 1488,    0, 1488,
 1488, 1488, 1488, 1488,    0,    0, 1488, 1488, 1488,    0,
 1488, 1488,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1488, 1488, 1488,    0, 1488, 1488, 1488,    0, 1488,
    0,    0,    0, 1488,    0, 1488, 1488, 1488, 1488,    0,
 1488,    0, 1488, 1488, 1488, 1488, 1488, 1488, 1488, 1488,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1488,
 1488,    0, 1488, 1488, 1488,    0,    0,    0,    0, 1488,
 1488, 1488, 1488, 1488,    0, 1488,    0,    0, 1488, 1488,
    0,    0,    0, 1488, 1488,    0,    0, 1488, 1488, 1488,
 1488, 1488, 1488, 1488, 1488, 1488,    0, 1488,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1488, 1488, 1488,
 1488, 1488, 1488, 1488, 1488, 1488, 1488, 1488, 1488, 1488,
 1488, 1488, 1488, 1488, 1488, 1488, 1488, 1488,    0, 1488,
 1488, 1488, 1488, 1488, 1488,    0, 1488, 1488, 1488, 1488,
    0, 1488,    0, 1488, 1488, 1488, 1488, 1488, 1488, 1488,
 1488, 1488, 1488, 1488, 1488, 1488, 1488, 1488, 1488, 1488,
 1488,    0, 1488, 1488, 1488, 1488,    0, 1488, 1488, 1488,
 1488, 1488,    0, 1488, 1488, 1488, 1488, 1488, 1488, 1488,
 1488, 1488, 1488, 1488, 1488, 1488, 1488, 1488, 1488, 1488,
 1488, 1488, 1488,    0, 1488, 1488, 1488, 1488, 1488, 1488,
 1488, 1488, 1486, 1488, 1488, 1488, 1488,    0, 1488, 1488,
 1488, 1488, 1488, 1488,    0,    0, 1488, 1488, 1488, 1488,
 1488, 1488, 1488, 1488, 1488,    0,    0,    0,    0,    0,
 1488,    0, 1488, 1488, 1488, 1488, 1488, 1488,    0, 1488,
    0,    0,    0, 1486, 1486, 1486, 1486, 1486,    0, 1486,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1486, 1486, 1486, 1486,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1486,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1486,
    0, 1486,    0,    0, 1486,    0, 1486, 1486,    0,    0,
 1486, 1486,    0, 1486,    0,    0,    0,    0,    0,    0,
    0, 1486, 1486,    0, 1486,    0, 1486,    0,    0, 1486,
    0,    0, 1486,    0,    0,    0,    0,    0,    0, 1486,
    0, 1486, 1486,    0, 1486, 1486, 1486, 1486, 1486,    0,
    0, 1486,    0,    0, 1486,    0, 1486, 1486,    0,    0,
 1486, 1486, 1486,    0, 1486, 1486, 1486, 1486, 1486, 1486,
 1486,    0,    0,    0, 1486, 1486, 1486, 1486, 1486,    0,
    0,    0, 1486,    0,    0,    0,    0,    0,    0,    0,
 1486, 1486, 1486, 1486, 1486, 1486,    0,    0,    0, 1486,
 1486,    0, 1486,    0, 1486,    0, 1486, 1486, 1486,    0,
 1486,    0, 1486, 1486, 1486,    0, 1486, 1486, 1486, 1486,
 1486,    0, 1486, 1486,    0,    0,    0,    0, 1486,    0,
 1486, 1486,    0,    0, 1486, 1486, 1486,    0,    0, 1486,
    0, 1486,    0,    0, 1486, 1486, 1486, 1486,    0, 1486,
    0, 1486,    0, 1486, 1486, 1486, 1486, 1486,    0,    0,
 1486, 1486, 1486,    0, 1486, 1486,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1486, 1486, 1486,    0, 1486,
 1486, 1486,    0, 1486,    0,    0,    0, 1486,    0, 1486,
 1486, 1486, 1486,    0, 1486,    0, 1486, 1486, 1486, 1486,
 1486, 1486, 1486, 1486,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1486, 1486,    0, 1486, 1486, 1486,    0,
    0,    0,    0, 1486, 1486, 1486, 1486, 1486,    0, 1486,
    0,    0, 1486, 1486,    0,    0,    0, 1486, 1486,    0,
    0, 1486, 1486, 1486, 1486, 1486, 1486, 1486, 1486, 1486,
    0, 1486,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1486, 1486, 1486, 1486, 1486, 1486, 1486, 1486, 1486,
 1486, 1486, 1486, 1486, 1486, 1486, 1486, 1486, 1486, 1486,
 1486, 1486,    0, 1486, 1486, 1486, 1486, 1486, 1486,    0,
 1486, 1486, 1486, 1486,    0, 1486,    0, 1486, 1486, 1486,
 1486, 1486, 1486, 1486, 1486, 1486, 1486, 1486, 1486, 1486,
 1486, 1486, 1486, 1486, 1486,    0, 1486, 1486, 1486, 1486,
    0, 1486, 1486, 1486, 1486, 1486,    0, 1486, 1486, 1486,
 1486, 1486, 1486, 1486, 1486, 1486, 1486, 1486, 1486, 1486,
 1486, 1486, 1486, 1486, 1486, 1486, 1486,    0, 1486, 1486,
 1486, 1486, 1486, 1486, 1486, 1486, 1485, 1486, 1486, 1486,
 1486,    0, 1486, 1486, 1486, 1486, 1486, 1486,    0,    0,
 1486, 1486, 1486, 1486, 1486, 1486, 1486, 1486, 1486,    0,
    0,    0,    0,    0, 1486,    0, 1486, 1486, 1486, 1486,
 1486, 1486,    0, 1486,    0,    0,    0, 1485, 1485, 1485,
 1485, 1485,    0, 1485,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1485, 1485, 1485, 1485,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1485,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1485,    0, 1485,    0,    0, 1485,    0,
 1485, 1485,    0,    0, 1485, 1485,    0, 1485,    0,    0,
    0,    0,    0,    0,    0, 1485, 1485,    0, 1485,    0,
 1485,    0,    0, 1485,    0,    0, 1485,    0,    0,    0,
    0,    0,    0, 1485,    0, 1485, 1485,    0, 1485, 1485,
 1485, 1485, 1485,    0,    0, 1485,    0,    0, 1485,    0,
 1485, 1485,    0,    0, 1485, 1485, 1485,    0, 1485, 1485,
 1485, 1485, 1485, 1485, 1485,    0,    0,    0, 1485, 1485,
 1485, 1485, 1485,    0,    0,    0, 1485,    0,    0,    0,
    0,    0,    0,    0, 1485, 1485, 1485, 1485, 1485, 1485,
    0,    0,    0, 1485, 1485,    0, 1485,    0, 1485,    0,
 1485, 1485, 1485,    0, 1485,    0, 1485, 1485, 1485,    0,
 1485, 1485, 1485, 1485, 1485,    0, 1485, 1485,    0,    0,
    0,    0, 1485,    0, 1485, 1485,    0,    0, 1485, 1485,
 1485,    0,    0, 1485,    0, 1485,    0,    0, 1485, 1485,
 1485, 1485,    0, 1485,    0, 1485,    0, 1485, 1485, 1485,
 1485, 1485,    0,    0, 1485, 1485, 1485,    0, 1485, 1485,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1485,
 1485, 1485,    0, 1485, 1485, 1485,    0, 1485,    0,    0,
    0, 1485,    0, 1485, 1485, 1485, 1485,    0, 1485,    0,
 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1485, 1485,    0,
 1485, 1485, 1485,    0,    0,    0,    0, 1485, 1485, 1485,
 1485, 1485,    0, 1485,    0,    0, 1485, 1485,    0,    0,
    0, 1485, 1485,    0,    0, 1485, 1485, 1485, 1485, 1485,
 1485, 1485, 1485, 1485,    0, 1485,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1485, 1485, 1485, 1485, 1485,
 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485,
 1485, 1485, 1485, 1485, 1485, 1485,    0, 1485, 1485, 1485,
 1485, 1485, 1485,    0, 1485, 1485, 1485, 1485,    0, 1485,
    0, 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485,
 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485,    0,
 1485, 1485, 1485, 1485,    0, 1485, 1485, 1485, 1485, 1485,
    0, 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485,
 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485,
 1485,    0, 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485,
 1491, 1485, 1485, 1485, 1485,    0, 1485, 1485, 1485, 1485,
 1485, 1485,    0,    0, 1485, 1485, 1485, 1485, 1485, 1485,
 1485, 1485, 1485,    0,    0,    0,    0,    0, 1485,    0,
 1485, 1485, 1485, 1485, 1485, 1485,    0, 1485,    0,    0,
    0, 1491, 1491, 1491, 1491, 1491,    0, 1491,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1491,
 1491, 1491, 1491,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1491,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1491,    0, 1491,
    0,    0, 1491,    0, 1491, 1491,    0,    0, 1491, 1491,
    0, 1491,    0,    0,    0,    0,    0,    0,    0, 1491,
 1491,    0, 1491,    0, 1491,    0,    0, 1491,    0,    0,
 1491,    0,    0,    0,    0,    0,    0, 1491,    0, 1491,
 1491,    0, 1491, 1491, 1491, 1491, 1491,    0,    0, 1491,
    0,    0, 1491,    0, 1491, 1491,    0,    0, 1491, 1491,
 1491,    0, 1491, 1491, 1491, 1491, 1491, 1491, 1491,    0,
    0,    0, 1491, 1491, 1491, 1491, 1491,    0,    0,    0,
 1491,    0,    0,    0,    0,    0,    0,    0, 1491, 1491,
 1491, 1491, 1491, 1491,    0,    0,    0, 1491, 1491,    0,
 1491,    0, 1491,    0, 1491, 1491, 1491,    0, 1491,    0,
 1491, 1491, 1491,    0, 1491, 1491, 1491, 1491, 1491,    0,
 1491, 1491,    0,    0,    0,    0, 1491,    0, 1491, 1491,
    0,    0, 1491, 1491, 1491,    0,    0, 1491,    0, 1491,
    0,    0, 1491, 1491, 1491, 1491,    0, 1491,    0, 1491,
    0, 1491, 1491, 1491, 1491, 1491,    0,    0, 1491, 1491,
 1491,    0, 1491, 1491,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1491, 1491, 1491,    0, 1491, 1491, 1491,
    0, 1491,    0,    0,    0, 1491,    0, 1491, 1491, 1491,
 1491,    0, 1491,    0, 1491, 1491, 1491, 1491, 1491, 1491,
 1491, 1491,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1491, 1491,    0, 1491, 1491, 1491,    0,    0,    0,
    0, 1491, 1491, 1491, 1491, 1491,    0, 1491,    0,    0,
 1491, 1491,    0,    0,    0, 1491, 1491,    0,    0, 1491,
 1491, 1491, 1491, 1491, 1491, 1491, 1491, 1491,    0, 1491,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1491,
 1491, 1491, 1491, 1491, 1491, 1491, 1491, 1491, 1491, 1491,
 1491, 1491, 1491, 1491, 1491, 1491, 1491, 1491, 1491, 1491,
    0, 1491, 1491, 1491, 1491, 1491, 1491,    0, 1491, 1491,
 1491, 1491,    0, 1491,    0, 1491, 1491, 1491, 1491, 1491,
 1491, 1491, 1491, 1491, 1491, 1491, 1491, 1491, 1491, 1491,
 1491, 1491, 1491,    0, 1491, 1491, 1491, 1491,    0, 1491,
 1491, 1491, 1491, 1491,    0, 1491, 1491, 1491, 1491, 1491,
 1491, 1491, 1491, 1491, 1491, 1491, 1491, 1491, 1491, 1491,
 1491, 1491, 1491, 1491, 1491,    0, 1491, 1491, 1491, 1491,
 1491, 1491, 1491, 1491, 1492, 1491, 1491, 1491, 1491,    0,
 1491, 1491, 1491, 1491, 1491, 1491,    0,    0, 1491, 1491,
 1491, 1491, 1491, 1491, 1491, 1491, 1491,    0,    0,    0,
    0,    0, 1491,    0, 1491, 1491, 1491, 1491, 1491, 1491,
    0, 1491,    0,    0,    0, 1492, 1492, 1492, 1492, 1492,
    0, 1492,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1492, 1492, 1492, 1492,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1492,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1492,    0, 1492,    0,    0, 1492,    0, 1492, 1492,
    0,    0, 1492, 1492,    0, 1492,    0,    0,    0,    0,
    0,    0,    0, 1492, 1492,    0, 1492,    0, 1492,    0,
    0, 1492,    0,    0, 1492,    0,    0,    0,    0,    0,
    0, 1492,    0, 1492, 1492,    0, 1492, 1492, 1492, 1492,
 1492,    0,    0, 1492,    0,    0, 1492,    0, 1492, 1492,
    0,    0, 1492, 1492, 1492,    0, 1492, 1492, 1492, 1492,
 1492, 1492, 1492,    0,    0,    0, 1492, 1492, 1492, 1492,
 1492,    0,    0,    0, 1492,    0,    0,    0,    0,    0,
    0,    0, 1492, 1492, 1492, 1492, 1492, 1492,    0,    0,
    0, 1492, 1492,    0, 1492,    0, 1492,    0, 1492, 1492,
 1492,    0, 1492,    0, 1492, 1492, 1492,    0, 1492, 1492,
 1492, 1492, 1492,    0, 1492, 1492,    0,    0,    0,    0,
 1492,    0, 1492, 1492,    0,    0, 1492, 1492, 1492,    0,
    0, 1492,    0, 1492,    0,    0, 1492, 1492, 1492, 1492,
    0, 1492,    0, 1492,    0, 1492, 1492, 1492, 1492, 1492,
    0,    0, 1492, 1492, 1492,    0, 1492, 1492,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1492, 1492, 1492,
    0, 1492, 1492, 1492,    0, 1492,    0,    0,    0, 1492,
    0, 1492, 1492, 1492, 1492,    0, 1492,    0, 1492, 1492,
 1492, 1492, 1492, 1492, 1492, 1492,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1492, 1492,    0, 1492, 1492,
 1492,    0,    0,    0,    0, 1492, 1492, 1492, 1492, 1492,
    0, 1492,    0,    0, 1492, 1492,    0,    0,    0, 1492,
 1492,    0,    0, 1492, 1492, 1492, 1492, 1492, 1492, 1492,
 1492, 1492,    0, 1492,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1492, 1492, 1492, 1492, 1492, 1492, 1492,
 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492,
 1492, 1492, 1492, 1492,    0, 1492, 1492, 1492, 1492, 1492,
 1492,    0, 1492, 1492, 1492, 1492,    0, 1492,    0, 1492,
 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492,
 1492, 1492, 1492, 1492, 1492, 1492, 1492,    0, 1492, 1492,
 1492, 1492,    0, 1492, 1492, 1492, 1492, 1492,    0, 1492,
 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492,
 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492,    0,
 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1487, 1492,
 1492, 1492, 1492,    0, 1492, 1492, 1492, 1492, 1492, 1492,
    0,    0, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492,
 1492,    0,    0,    0,    0,    0, 1492,    0, 1492, 1492,
 1492, 1492, 1492, 1492,    0, 1492,    0,    0,    0, 1487,
    0, 1487, 1487, 1487,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1487, 1487, 1487,
 1487,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1487,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1487,    0, 1487,    0,    0,
 1487,    0, 1487, 1487,    0,    0, 1487, 1487,    0, 1487,
    0,    0,    0,    0,    0,    0,    0, 1487, 1487,    0,
 1487,    0, 1487,    0,    0, 1487,    0,    0, 1487,    0,
    0,    0,    0,    0,    0, 1487,    0, 1487, 1487,    0,
 1487, 1487, 1487, 1487, 1487,    0,    0, 1487,    0,    0,
 1487,    0, 1487, 1487,    0,    0, 1487, 1487, 1487,    0,
 1487, 1487, 1487, 1487, 1487, 1487, 1487,    0,    0,    0,
 1487, 1487, 1487, 1487, 1487,    0,    0,    0, 1487,    0,
    0,    0,    0,    0,    0,    0, 1487, 1487, 1487, 1487,
 1487, 1487,    0,    0,    0, 1487, 1487,    0, 1487,    0,
 1487,    0, 1487, 1487, 1487,    0, 1487,    0, 1487, 1487,
 1487,    0, 1487, 1487, 1487, 1487, 1487,    0, 1487, 1487,
    0,    0,    0,    0, 1487,    0, 1487, 1487,    0,    0,
 1487, 1487, 1487,    0,    0, 1487,    0, 1487,    0,    0,
 1487, 1487, 1487, 1487,    0, 1487,    0, 1487,    0, 1487,
 1487, 1487, 1487, 1487,    0,    0, 1487, 1487, 1487,    0,
 1487, 1487,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1487, 1487, 1487,    0, 1487, 1487, 1487,    0, 1487,
    0,    0,    0, 1487,    0, 1487, 1487, 1487, 1487,    0,
 1487,    0, 1487, 1487, 1487, 1487, 1487, 1487, 1487, 1487,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1487,
 1487,    0, 1487, 1487, 1487,    0,    0,    0,    0, 1487,
 1487, 1487, 1487, 1487,    0, 1487,    0,    0, 1487, 1487,
    0,    0,    0, 1487, 1487,    0,    0, 1487, 1487, 1487,
 1487, 1487, 1487, 1487, 1487, 1487,    0, 1487,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1487, 1487, 1487,
 1487, 1487, 1487, 1487, 1487, 1487, 1487, 1487, 1487, 1487,
 1487, 1487, 1487, 1487, 1487, 1487, 1487, 1487,    0, 1487,
 1487, 1487, 1487, 1487, 1487,    0, 1487, 1487, 1487, 1487,
    0, 1487,    0, 1487, 1487, 1487, 1487, 1487, 1487, 1487,
 1487, 1487, 1487, 1487, 1487, 1487, 1487, 1487, 1487, 1487,
 1487,    0, 1487, 1487, 1487, 1487,    0, 1487, 1487, 1487,
 1487, 1487,    0, 1487, 1487, 1487, 1487, 1487, 1487, 1487,
 1487, 1487, 1487, 1487, 1487, 1487, 1487, 1487, 1487, 1487,
 1487, 1487, 1487,    0, 1487, 1487, 1487, 1487, 1487, 1487,
 1487, 1487, 1490, 1487, 1487, 1487, 1487,    0, 1487, 1487,
 1487, 1487, 1487, 1487,    0,    0, 1487, 1487, 1487, 1487,
 1487, 1487, 1487, 1487, 1487,    0,    0,    0,    0,    0,
 1487,    0, 1487, 1487, 1487, 1487, 1487, 1487,    0, 1487,
    0,    0,    0, 1490,    0, 1490, 1490, 1490,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1490, 1490, 1490, 1490,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1490,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1490,
    0, 1490,    0,    0, 1490,    0, 1490, 1490,    0,    0,
 1490, 1490,    0, 1490,    0,    0,    0,    0,    0,    0,
    0, 1490, 1490,    0, 1490,    0, 1490,    0,    0, 1490,
    0,    0, 1490,    0,    0,    0,    0,    0,    0, 1490,
    0, 1490, 1490,    0, 1490, 1490, 1490, 1490, 1490,    0,
    0, 1490,    0,    0, 1490,    0, 1490, 1490,    0,    0,
 1490, 1490, 1490,    0, 1490, 1490, 1490, 1490, 1490, 1490,
 1490,    0,    0,    0, 1490, 1490, 1490, 1490, 1490,    0,
    0,    0, 1490,    0,    0,    0,    0,    0,    0,    0,
 1490, 1490, 1490, 1490, 1490, 1490,    0,    0,    0, 1490,
 1490,    0, 1490,    0, 1490,    0, 1490, 1490, 1490,    0,
 1490,    0, 1490, 1490, 1490,    0, 1490, 1490, 1490, 1490,
 1490,    0, 1490, 1490,    0,    0,    0,    0, 1490,    0,
 1490, 1490,    0,    0, 1490, 1490, 1490,    0,    0, 1490,
    0, 1490,    0,    0, 1490, 1490, 1490, 1490,    0, 1490,
    0, 1490,    0, 1490, 1490, 1490, 1490, 1490,    0,    0,
 1490, 1490, 1490,    0, 1490, 1490,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1490, 1490, 1490,    0, 1490,
 1490, 1490,    0, 1490,    0,    0,    0, 1490,    0, 1490,
 1490, 1490, 1490,    0, 1490,    0, 1490, 1490, 1490, 1490,
 1490, 1490, 1490, 1490,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1490, 1490,    0, 1490, 1490, 1490,    0,
    0,    0,    0, 1490, 1490, 1490, 1490, 1490,    0, 1490,
    0,    0, 1490, 1490,    0,    0,    0, 1490, 1490,    0,
    0, 1490, 1490, 1490, 1490, 1490, 1490, 1490, 1490, 1490,
    0, 1490,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1490, 1490, 1490, 1490, 1490, 1490, 1490, 1490, 1490,
 1490, 1490, 1490, 1490, 1490, 1490, 1490, 1490, 1490, 1490,
 1490, 1490,    0, 1490, 1490, 1490, 1490, 1490, 1490,    0,
 1490, 1490, 1490, 1490,    0, 1490,    0, 1490, 1490, 1490,
 1490, 1490, 1490, 1490, 1490, 1490, 1490, 1490, 1490, 1490,
 1490, 1490, 1490, 1490, 1490,    0, 1490, 1490, 1490, 1490,
    0, 1490, 1490, 1490, 1490, 1490,    0, 1490, 1490, 1490,
 1490, 1490, 1490, 1490, 1490, 1490, 1490, 1490, 1490, 1490,
 1490, 1490, 1490, 1490, 1490, 1490, 1490,    0, 1490, 1490,
 1490, 1490, 1490, 1490, 1490, 1490, 1467, 1490, 1490, 1490,
 1490,    0, 1490, 1490, 1490, 1490, 1490, 1490,    0,    0,
 1490, 1490, 1490, 1490, 1490, 1490, 1490, 1490, 1490,    0,
    0,    0,    0,    0, 1490,    0, 1490, 1490, 1490, 1490,
 1490, 1490,    0, 1490,    0,    0,    0, 1467,    0,    0,
 1467,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1467, 1467, 1467, 1467,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1467,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1467,    0, 1467,    0,    0, 1467,    0,
 1467, 1467,    0,    0, 1467, 1467,    0, 1467,    0,    0,
    0,    0,    0,    0,    0, 1467, 1467,    0, 1467,    0,
 1467,    0,    0, 1467,    0,    0, 1467,    0,    0,    0,
    0,    0,    0, 1467,    0, 1467, 1467,    0, 1467, 1467,
 1467, 1467, 1467,    0,    0, 1467,    0,    0, 1467,    0,
 1467, 1467,    0,    0, 1467, 1467, 1467,    0, 1467, 1467,
 1467, 1467, 1467, 1467, 1467,    0,    0,    0, 1467, 1467,
 1467, 1467, 1467,    0,    0,    0, 1467,    0,    0,    0,
    0,    0,    0,    0, 1467, 1467, 1467, 1467, 1467, 1467,
    0,    0,    0, 1467, 1467,    0, 1467,    0, 1467,    0,
 1467, 1467, 1467,    0, 1467,    0, 1467, 1467, 1467,    0,
 1467, 1467, 1467, 1467, 1467,    0, 1467, 1467,    0,    0,
    0,    0, 1467,    0, 1467, 1467,    0,    0, 1467, 1467,
 1467,    0,    0, 1467,    0, 1467,    0,    0, 1467, 1467,
 1467, 1467,    0, 1467,    0, 1467,    0, 1467, 1467, 1467,
 1467, 1467,    0,    0, 1467, 1467, 1467,    0, 1467, 1467,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1467,
 1467, 1467,    0, 1467, 1467, 1467,    0, 1467,    0,    0,
    0, 1467,    0, 1467, 1467, 1467, 1467,    0, 1467,    0,
 1467, 1467, 1467, 1467, 1467, 1467, 1467, 1467,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1467, 1467,    0,
 1467, 1467, 1467,    0,    0,    0,    0, 1467, 1467, 1467,
 1467, 1467,    0, 1467,    0,    0, 1467, 1467,    0,    0,
    0, 1467, 1467,    0,    0, 1467, 1467, 1467, 1467, 1467,
 1467, 1467, 1467, 1467,    0, 1467,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1467, 1467, 1467, 1467, 1467,
 1467, 1467, 1467, 1467, 1467, 1467, 1467, 1467, 1467, 1467,
 1467, 1467, 1467, 1467, 1467, 1467,    0, 1467, 1467, 1467,
 1467, 1467, 1467,    0, 1467, 1467, 1467, 1467,    0, 1467,
    0, 1467, 1467, 1467, 1467, 1467, 1467, 1467, 1467, 1467,
 1467, 1467, 1467, 1467, 1467, 1467, 1467, 1467, 1467,    0,
 1467, 1467, 1467, 1467,    0, 1467, 1467, 1467, 1467, 1467,
    0, 1467, 1467, 1467, 1467, 1467, 1467, 1467, 1467, 1467,
 1467, 1467, 1467, 1467, 1467, 1467, 1467, 1467, 1467, 1467,
 1467,    0, 1467, 1467, 1467, 1467, 1467, 1467, 1467, 1467,
 1372, 1467, 1467, 1467, 1467,    0, 1467, 1467, 1467, 1467,
 1467, 1467,    0,    0, 1467, 1467, 1467, 1467, 1467, 1467,
 1467, 1467, 1467,    0,    0,    0,    0,    0, 1467,    0,
 1467, 1467, 1467, 1467, 1467, 1467,    0, 1467,    0,    0,
    0, 1372,    0,    0, 1372,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1372,
 1372, 1372, 1372,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1372,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1372,    0, 1372,
    0,    0, 1372,    0, 1372, 1372,    0,    0, 1372, 1372,
    0, 1372,    0,    0,    0,    0,    0,    0,    0, 1372,
 1372,    0, 1372,    0, 1372,    0,    0, 1372,    0,    0,
 1372,    0,    0,    0,    0,    0,    0, 1372,    0, 1372,
 1372,    0, 1372, 1372, 1372, 1372, 1372,    0,    0, 1372,
    0,    0, 1372,    0, 1372, 1372,    0,    0, 1372, 1372,
 1372,    0, 1372, 1372, 1372, 1372, 1372, 1372, 1372,    0,
    0,    0, 1372, 1372, 1372, 1372, 1372,    0,    0,    0,
 1372,    0,    0,    0,    0,    0,    0,    0, 1372, 1372,
 1372, 1372, 1372, 1372,    0,    0,    0, 1372, 1372,    0,
 1372,    0, 1372,    0, 1372, 1372, 1372,    0, 1372,    0,
 1372, 1372, 1372,    0, 1372, 1372, 1372, 1372, 1372,    0,
 1372, 1372,    0,    0,    0,    0, 1372,    0, 1372, 1372,
    0,    0, 1372, 1372, 1372,    0,    0, 1372,    0, 1372,
    0,    0, 1372, 1372, 1372, 1372,    0, 1372,    0, 1372,
    0, 1372, 1372, 1372, 1372, 1372,    0,    0, 1372, 1372,
 1372,    0, 1372, 1372,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1372, 1372, 1372,    0, 1372, 1372, 1372,
    0, 1372,    0,    0,    0, 1372,    0, 1372, 1372, 1372,
 1372,    0, 1372,    0, 1372, 1372, 1372, 1372, 1372, 1372,
 1372, 1372,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1372, 1372,    0, 1372, 1372, 1372,    0,    0,    0,
    0, 1372, 1372, 1372, 1372, 1372,    0, 1372,    0,    0,
 1372, 1372,    0,    0,    0, 1372, 1372,    0,    0, 1372,
 1372, 1372, 1372, 1372, 1372, 1372, 1372, 1372,    0, 1372,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1372,
 1372, 1372, 1372, 1372, 1372, 1372, 1372, 1372, 1372, 1372,
 1372, 1372, 1372, 1372, 1372, 1372, 1372, 1372, 1372, 1372,
    0, 1372, 1372, 1372, 1372, 1372, 1372,    0, 1372, 1372,
 1372, 1372,    0, 1372,    0, 1372, 1372, 1372, 1372, 1372,
 1372, 1372, 1372, 1372, 1372, 1372, 1372, 1372, 1372, 1372,
 1372, 1372, 1372,    0, 1372, 1372, 1372, 1372,    0, 1372,
 1372, 1372, 1372, 1372,    0, 1372, 1372, 1372, 1372, 1372,
 1372, 1372, 1372, 1372, 1372, 1372, 1372, 1372, 1372, 1372,
 1372, 1372, 1372, 1372, 1372,    0, 1372, 1372, 1372, 1372,
 1372, 1372, 1372, 1372, 1355, 1372, 1372, 1372, 1372,    0,
 1372, 1372, 1372, 1372, 1372, 1372,    0,    0, 1372, 1372,
 1372, 1372, 1372, 1372, 1372, 1372, 1372,    0,    0,    0,
    0,    0, 1372,    0, 1372, 1372, 1372, 1372, 1372, 1372,
    0, 1372,    0,    0,    0, 1355,    0,    0, 1355,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1355, 1355, 1355, 1355,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1355,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1355,    0, 1355,    0,    0, 1355,    0, 1355, 1355,
    0,    0, 1355, 1355,    0, 1355,    0,    0,    0,    0,
    0,    0,    0, 1355, 1355,    0, 1355,    0, 1355,    0,
    0, 1355,    0,    0, 1355,    0,    0,    0,    0,    0,
    0, 1355,    0, 1355, 1355,    0, 1355, 1355, 1355, 1355,
 1355,    0,    0, 1355,    0,    0, 1355,    0, 1355, 1355,
    0,    0, 1355, 1355, 1355,    0, 1355, 1355, 1355, 1355,
 1355, 1355, 1355,    0,    0,    0, 1355,    0, 1355, 1355,
 1355,    0,    0,    0, 1355,    0,    0,    0,    0,    0,
    0,    0, 1355, 1355, 1355, 1355, 1355, 1355,    0,    0,
    0, 1355, 1355,    0, 1355,    0, 1355,    0, 1355, 1355,
 1355,    0, 1355,    0, 1355, 1355, 1355,    0, 1355, 1355,
 1355, 1355, 1355,    0, 1355, 1355,    0,    0,    0,    0,
 1355,    0, 1355, 1355,    0,    0, 1355, 1355, 1355,    0,
    0, 1355,    0, 1355,    0,    0, 1355, 1355, 1355, 1355,
    0, 1355,    0, 1355,    0, 1355, 1355, 1355, 1355, 1355,
    0,    0, 1355, 1355, 1355,    0, 1355, 1355,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1355, 1355, 1355,
    0, 1355, 1355, 1355,    0, 1355,    0,    0,    0, 1355,
    0, 1355, 1355, 1355, 1355,    0, 1355,    0, 1355, 1355,
 1355, 1355, 1355, 1355, 1355, 1355,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1355, 1355,    0, 1355, 1355,
 1355,    0,    0,    0,    0, 1355, 1355, 1355, 1355, 1355,
    0, 1355,    0,    0, 1355, 1355,    0,    0,    0, 1355,
 1355,    0,    0, 1355, 1355, 1355, 1355, 1355, 1355, 1355,
 1355, 1355,    0, 1355,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1355, 1355, 1355, 1355, 1355, 1355, 1355,
 1355, 1355, 1355, 1355, 1355, 1355, 1355, 1355, 1355, 1355,
 1355, 1355, 1355, 1355,    0, 1355, 1355, 1355, 1355, 1355,
 1355,    0, 1355, 1355, 1355, 1355,    0, 1355,    0, 1355,
 1355, 1355, 1355, 1355, 1355, 1355, 1355, 1355, 1355, 1355,
 1355, 1355, 1355, 1355, 1355, 1355, 1355,    0, 1355, 1355,
 1355, 1355,    0, 1355, 1355, 1355, 1355, 1355,    0, 1355,
 1355, 1355, 1355, 1355, 1355, 1355, 1355, 1355, 1355, 1355,
 1355, 1355, 1355, 1355, 1355, 1355, 1355, 1355, 1355,    0,
 1355, 1355, 1355, 1355, 1355, 1355, 1355, 1355, 1374, 1355,
 1355, 1355, 1355,    0, 1355, 1355, 1355, 1355, 1355, 1355,
    0,    0, 1355, 1355, 1355, 1355, 1355, 1355, 1355, 1355,
 1355,    0,    0,    0,    0,    0, 1355,    0, 1355, 1355,
 1355, 1355, 1355, 1355,    0, 1355,    0,    0,    0, 1374,
    0,    0, 1374,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1374, 1374, 1374,
 1374,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1374,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1374,    0, 1374,    0,    0,
 1374,    0, 1374, 1374,    0,    0, 1374, 1374,    0, 1374,
    0,    0,    0,    0,    0,    0,    0, 1374, 1374,    0,
 1374,    0, 1374,    0,    0, 1374,    0,    0, 1374,    0,
    0,    0,    0,    0,    0, 1374,    0, 1374, 1374,    0,
 1374, 1374, 1374, 1374, 1374,    0,    0, 1374,    0,    0,
 1374,    0, 1374, 1374,    0,    0, 1374, 1374, 1374,    0,
 1374, 1374, 1374, 1374, 1374, 1374, 1374,    0,    0,    0,
 1374,    0, 1374, 1374, 1374,    0,    0,    0, 1374,    0,
    0,    0,    0,    0,    0,    0, 1374, 1374, 1374, 1374,
 1374, 1374,    0,    0,    0, 1374, 1374,    0, 1374,    0,
 1374,    0, 1374, 1374, 1374,    0, 1374,    0, 1374, 1374,
 1374,    0, 1374, 1374, 1374, 1374, 1374,    0, 1374, 1374,
    0,    0,    0,    0, 1374,    0, 1374, 1374,    0,    0,
 1374, 1374, 1374,    0,    0, 1374,    0, 1374,    0,    0,
 1374, 1374, 1374, 1374,    0, 1374,    0, 1374,    0, 1374,
 1374, 1374, 1374, 1374,    0,    0, 1374, 1374, 1374,    0,
 1374, 1374,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1374, 1374, 1374,    0, 1374, 1374, 1374,    0, 1374,
    0,    0,    0, 1374,    0, 1374, 1374, 1374, 1374,    0,
 1374,    0, 1374, 1374, 1374, 1374, 1374, 1374, 1374, 1374,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1374,
 1374,    0, 1374, 1374, 1374,    0,    0,    0,    0, 1374,
 1374, 1374, 1374, 1374,    0, 1374,    0,    0, 1374, 1374,
    0,    0,    0, 1374, 1374,    0,    0, 1374, 1374, 1374,
 1374, 1374, 1374, 1374, 1374, 1374,    0, 1374,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1374, 1374, 1374,
 1374, 1374, 1374, 1374, 1374, 1374, 1374, 1374, 1374, 1374,
 1374, 1374, 1374, 1374, 1374, 1374, 1374, 1374,    0, 1374,
 1374, 1374, 1374, 1374, 1374,    0, 1374, 1374, 1374, 1374,
    0, 1374,    0, 1374, 1374, 1374, 1374, 1374, 1374, 1374,
 1374, 1374, 1374, 1374, 1374, 1374, 1374, 1374, 1374, 1374,
 1374,    0, 1374, 1374, 1374, 1374,    0, 1374, 1374, 1374,
 1374, 1374,    0, 1374, 1374, 1374, 1374, 1374, 1374, 1374,
 1374, 1374, 1374, 1374, 1374, 1374, 1374, 1374, 1374, 1374,
 1374, 1374, 1374,    0, 1374, 1374, 1374, 1374, 1374, 1374,
 1374, 1374, 1375, 1374, 1374, 1374, 1374,    0, 1374, 1374,
 1374, 1374, 1374, 1374,    0,    0, 1374, 1374, 1374, 1374,
 1374, 1374, 1374, 1374, 1374,    0,    0,    0,    0,    0,
 1374,    0, 1374, 1374, 1374, 1374, 1374, 1374,    0, 1374,
    0,    0,    0, 1375,    0,    0, 1375,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1375, 1375, 1375, 1375,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1375,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1375,
    0, 1375,    0,    0, 1375,    0, 1375, 1375,    0,    0,
 1375, 1375,    0, 1375,    0,    0,    0,    0,    0,    0,
    0, 1375, 1375,    0, 1375,    0, 1375,    0,    0, 1375,
    0,    0, 1375,    0,    0,    0,    0,    0,    0, 1375,
    0, 1375, 1375,    0, 1375, 1375, 1375, 1375, 1375,    0,
    0, 1375,    0,    0, 1375,    0, 1375, 1375,    0,    0,
 1375, 1375, 1375,    0, 1375, 1375, 1375, 1375, 1375, 1375,
 1375,    0,    0,    0, 1375,    0, 1375, 1375, 1375,    0,
    0,    0, 1375,    0,    0,    0,    0,    0,    0,    0,
 1375, 1375, 1375, 1375, 1375, 1375,    0,    0,    0, 1375,
 1375,    0, 1375,    0, 1375,    0, 1375, 1375, 1375,    0,
 1375,    0, 1375, 1375, 1375,    0, 1375, 1375, 1375, 1375,
 1375,    0, 1375, 1375,    0,    0,    0,    0, 1375,    0,
 1375, 1375,    0,    0, 1375, 1375, 1375,    0,    0, 1375,
    0, 1375,    0,    0, 1375, 1375, 1375, 1375,    0, 1375,
    0, 1375,    0, 1375, 1375, 1375, 1375, 1375,    0,    0,
 1375, 1375, 1375,    0, 1375, 1375,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1375, 1375, 1375,    0, 1375,
 1375, 1375,    0, 1375,    0,    0,    0, 1375,    0, 1375,
 1375, 1375, 1375,    0, 1375,    0, 1375, 1375, 1375, 1375,
 1375, 1375, 1375, 1375,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1375, 1375,    0, 1375, 1375, 1375,    0,
    0,    0,    0, 1375, 1375, 1375, 1375, 1375,    0, 1375,
    0,    0, 1375, 1375,    0,    0,    0, 1375, 1375,    0,
    0, 1375, 1375, 1375, 1375, 1375, 1375, 1375, 1375, 1375,
    0, 1375,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1375, 1375, 1375, 1375, 1375, 1375, 1375, 1375, 1375,
 1375, 1375, 1375, 1375, 1375, 1375, 1375, 1375, 1375, 1375,
 1375, 1375,    0, 1375, 1375, 1375, 1375, 1375, 1375,    0,
 1375, 1375, 1375, 1375,    0, 1375,    0, 1375, 1375, 1375,
 1375, 1375, 1375, 1375, 1375, 1375, 1375, 1375, 1375, 1375,
 1375, 1375, 1375, 1375, 1375,    0, 1375, 1375, 1375, 1375,
    0, 1375, 1375, 1375, 1375, 1375,    0, 1375, 1375, 1375,
 1375, 1375, 1375, 1375, 1375, 1375, 1375, 1375, 1375, 1375,
 1375, 1375, 1375, 1375, 1375, 1375, 1375,    0, 1375, 1375,
 1375, 1375, 1375, 1375, 1375, 1375, 1380, 1375, 1375, 1375,
 1375,    0, 1375, 1375, 1375, 1375, 1375, 1375,    0,    0,
 1375, 1375, 1375, 1375, 1375, 1375, 1375, 1375, 1375,    0,
    0,    0,    0,    0, 1375,    0, 1375, 1375, 1375, 1375,
 1375, 1375,    0, 1375,    0,    0,    0, 1380,    0,    0,
 1380,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1380, 1380, 1380, 1380,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1380,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1380,    0, 1380,    0,    0, 1380,    0,
 1380, 1380,    0,    0, 1380, 1380,    0, 1380,    0,    0,
    0,    0,    0,    0,    0, 1380, 1380,    0, 1380,    0,
 1380,    0,    0, 1380,    0,    0, 1380,    0,    0,    0,
    0,    0,    0, 1380,    0, 1380, 1380,    0, 1380, 1380,
 1380, 1380, 1380,    0,    0, 1380,    0,    0, 1380,    0,
 1380, 1380,    0,    0, 1380, 1380, 1380,    0, 1380, 1380,
 1380, 1380, 1380, 1380, 1380,    0,    0,    0, 1380,    0,
 1380, 1380, 1380,    0,    0,    0, 1380,    0,    0,    0,
    0,    0,    0,    0, 1380, 1380, 1380, 1380, 1380, 1380,
    0,    0,    0, 1380, 1380,    0, 1380,    0, 1380,    0,
 1380, 1380, 1380,    0, 1380,    0, 1380, 1380, 1380,    0,
 1380, 1380, 1380, 1380, 1380,    0, 1380, 1380,    0,    0,
    0,    0, 1380,    0, 1380, 1380,    0,    0, 1380, 1380,
 1380,    0,    0, 1380,    0, 1380,    0,    0, 1380, 1380,
 1380, 1380,    0, 1380,    0, 1380,    0, 1380, 1380, 1380,
 1380, 1380,    0,    0, 1380, 1380, 1380,    0, 1380, 1380,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1380,
 1380, 1380,    0, 1380, 1380, 1380,    0, 1380,    0,    0,
    0, 1380,    0, 1380, 1380, 1380, 1380,    0, 1380,    0,
 1380, 1380, 1380, 1380, 1380, 1380, 1380, 1380,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1380, 1380,    0,
 1380, 1380, 1380,    0,    0,    0,    0, 1380, 1380, 1380,
 1380, 1380,    0, 1380,    0,    0, 1380, 1380,    0,    0,
    0, 1380, 1380,    0,    0, 1380, 1380, 1380, 1380, 1380,
 1380, 1380, 1380, 1380,    0, 1380,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1380, 1380, 1380, 1380, 1380,
 1380, 1380, 1380, 1380, 1380, 1380, 1380, 1380, 1380, 1380,
 1380, 1380, 1380, 1380, 1380, 1380,    0, 1380, 1380, 1380,
 1380, 1380, 1380,    0, 1380, 1380, 1380, 1380,    0, 1380,
    0, 1380, 1380, 1380, 1380, 1380, 1380, 1380, 1380, 1380,
 1380, 1380, 1380, 1380, 1380, 1380, 1380, 1380, 1380,    0,
 1380, 1380, 1380, 1380,    0, 1380, 1380, 1380, 1380, 1380,
    0, 1380, 1380, 1380, 1380, 1380, 1380, 1380, 1380, 1380,
 1380, 1380, 1380, 1380, 1380, 1380, 1380, 1380, 1380, 1380,
 1380,    0, 1380, 1380, 1380, 1380, 1380, 1380, 1380, 1380,
 1382, 1380, 1380, 1380, 1380,    0, 1380, 1380, 1380, 1380,
 1380, 1380,    0,    0, 1380, 1380, 1380, 1380, 1380, 1380,
 1380, 1380, 1380,    0,    0,    0,    0,    0, 1380,    0,
 1380, 1380, 1380, 1380, 1380, 1380,    0, 1380,    0,    0,
    0, 1382,    0,    0, 1382,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1382,
 1382, 1382, 1382,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1382,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1382,    0, 1382,
    0,    0, 1382,    0, 1382, 1382,    0,    0, 1382, 1382,
    0, 1382,    0,    0,    0,    0,    0,    0,    0, 1382,
 1382,    0, 1382,    0, 1382,    0,    0, 1382,    0,    0,
 1382,    0,    0,    0,    0,    0,    0, 1382,    0, 1382,
 1382,    0, 1382, 1382, 1382, 1382, 1382,    0,    0, 1382,
    0,    0, 1382,    0, 1382, 1382,    0,    0, 1382, 1382,
 1382,    0, 1382, 1382, 1382, 1382, 1382, 1382, 1382,    0,
    0,    0, 1382,    0, 1382, 1382, 1382,    0,    0,    0,
 1382,    0,    0,    0,    0,    0,    0,    0, 1382, 1382,
 1382, 1382, 1382, 1382,    0,    0,    0, 1382, 1382,    0,
 1382,    0, 1382,    0, 1382, 1382, 1382,    0, 1382,    0,
 1382, 1382, 1382,    0, 1382, 1382, 1382, 1382, 1382,    0,
 1382, 1382,    0,    0,    0,    0, 1382,    0, 1382, 1382,
    0,    0, 1382, 1382, 1382,    0,    0, 1382,    0, 1382,
    0,    0, 1382, 1382, 1382, 1382,    0, 1382,    0, 1382,
    0, 1382, 1382, 1382, 1382, 1382,    0,    0, 1382, 1382,
 1382,    0, 1382, 1382,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1382, 1382, 1382,    0, 1382, 1382, 1382,
    0, 1382,    0,    0,    0, 1382,    0, 1382, 1382, 1382,
 1382,    0, 1382,    0, 1382, 1382, 1382, 1382, 1382, 1382,
 1382, 1382,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1382, 1382,    0, 1382, 1382, 1382,    0,    0,    0,
    0, 1382, 1382, 1382, 1382, 1382,    0, 1382,    0,    0,
 1382, 1382,    0,    0,    0, 1382, 1382,    0,    0, 1382,
 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382,    0, 1382,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1382,
 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382,
 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382,
    0, 1382, 1382, 1382, 1382, 1382, 1382,    0, 1382, 1382,
 1382, 1382,    0, 1382,    0, 1382, 1382, 1382, 1382, 1382,
 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382,
 1382, 1382, 1382,    0, 1382, 1382, 1382, 1382,    0, 1382,
 1382, 1382, 1382, 1382,    0, 1382, 1382, 1382, 1382, 1382,
 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382,
 1382, 1382, 1382, 1382, 1382,    0, 1382, 1382, 1382, 1382,
 1382, 1382, 1382, 1382, 1384, 1382, 1382, 1382, 1382,    0,
 1382, 1382, 1382, 1382, 1382, 1382,    0,    0, 1382, 1382,
 1382, 1382, 1382, 1382, 1382, 1382, 1382,    0,    0,    0,
    0,    0, 1382,    0, 1382, 1382, 1382, 1382, 1382, 1382,
    0, 1382,    0,    0,    0, 1384,    0,    0, 1384,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1384, 1384, 1384, 1384,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1384,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1384,    0, 1384,    0,    0, 1384,    0, 1384, 1384,
    0,    0, 1384, 1384,    0, 1384,    0,    0,    0,    0,
    0,    0,    0, 1384, 1384,    0, 1384,    0, 1384,    0,
    0, 1384,    0,    0, 1384,    0,    0,    0,    0,    0,
    0, 1384,    0, 1384, 1384,    0, 1384, 1384, 1384, 1384,
 1384,    0,    0, 1384,    0,    0, 1384,    0, 1384, 1384,
    0,    0, 1384, 1384, 1384,    0, 1384, 1384, 1384, 1384,
 1384, 1384, 1384,    0,    0,    0, 1384,    0, 1384, 1384,
 1384,    0,    0,    0, 1384,    0,    0,    0,    0,    0,
    0,    0, 1384, 1384, 1384, 1384, 1384, 1384,    0,    0,
    0, 1384, 1384,    0, 1384,    0, 1384,    0, 1384, 1384,
 1384,    0, 1384,    0, 1384, 1384, 1384,    0, 1384, 1384,
 1384, 1384, 1384,    0, 1384, 1384,    0,    0,    0,    0,
 1384,    0, 1384, 1384,    0,    0, 1384, 1384, 1384,    0,
    0, 1384,    0, 1384,    0,    0, 1384, 1384, 1384, 1384,
    0, 1384,    0, 1384,    0, 1384, 1384, 1384, 1384, 1384,
    0,    0, 1384, 1384, 1384,    0, 1384, 1384,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1384, 1384, 1384,
    0, 1384, 1384, 1384,    0, 1384,    0,    0,    0, 1384,
    0, 1384, 1384, 1384, 1384,    0, 1384,    0, 1384, 1384,
 1384, 1384, 1384, 1384, 1384, 1384,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1384, 1384,    0, 1384, 1384,
 1384,    0,    0,    0,    0, 1384, 1384, 1384, 1384, 1384,
    0, 1384,    0,    0, 1384, 1384,    0,    0,    0, 1384,
 1384,    0,    0, 1384, 1384, 1384, 1384, 1384, 1384, 1384,
 1384, 1384,    0, 1384,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1384, 1384, 1384, 1384, 1384, 1384, 1384,
 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384,
 1384, 1384, 1384, 1384,    0, 1384, 1384, 1384, 1384, 1384,
 1384,    0, 1384, 1384, 1384, 1384,    0, 1384,    0, 1384,
 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384,
 1384, 1384, 1384, 1384, 1384, 1384, 1384,    0, 1384, 1384,
 1384, 1384,    0, 1384, 1384, 1384, 1384, 1384,    0, 1384,
 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384,
 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384,    0,
 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1386, 1384,
 1384, 1384, 1384,    0, 1384, 1384, 1384, 1384, 1384, 1384,
    0,    0, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384,
 1384,    0,    0,    0,    0,    0, 1384,    0, 1384, 1384,
 1384, 1384, 1384, 1384,    0, 1384,    0,    0,    0, 1386,
    0,    0, 1386,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1386, 1386, 1386,
 1386,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1386,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1386,    0, 1386,    0,    0,
 1386,    0, 1386, 1386,    0,    0, 1386, 1386,    0, 1386,
    0,    0,    0,    0,    0,    0,    0, 1386, 1386,    0,
 1386,    0, 1386,    0,    0, 1386,    0,    0, 1386,    0,
    0,    0,    0,    0,    0, 1386,    0, 1386, 1386,    0,
 1386, 1386, 1386, 1386, 1386,    0,    0, 1386,    0,    0,
 1386,    0, 1386, 1386,    0,    0, 1386, 1386, 1386,    0,
 1386, 1386, 1386, 1386, 1386, 1386, 1386,    0,    0,    0,
 1386,    0, 1386, 1386, 1386,    0,    0,    0, 1386,    0,
    0,    0,    0,    0,    0,    0, 1386, 1386, 1386, 1386,
 1386, 1386,    0,    0,    0, 1386, 1386,    0, 1386,    0,
 1386,    0, 1386, 1386, 1386,    0, 1386,    0, 1386, 1386,
 1386,    0, 1386, 1386, 1386, 1386, 1386,    0, 1386, 1386,
    0,    0,    0,    0, 1386,    0, 1386, 1386,    0,    0,
 1386, 1386, 1386,    0,    0, 1386,    0, 1386,    0,    0,
 1386, 1386, 1386, 1386,    0, 1386,    0, 1386,    0, 1386,
 1386, 1386, 1386, 1386,    0,    0, 1386, 1386, 1386,    0,
 1386, 1386,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1386, 1386, 1386,    0, 1386, 1386, 1386,    0, 1386,
    0,    0,    0, 1386,    0, 1386, 1386, 1386, 1386,    0,
 1386,    0, 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1386,
 1386,    0, 1386, 1386, 1386,    0,    0,    0,    0, 1386,
 1386, 1386, 1386, 1386,    0, 1386,    0,    0, 1386, 1386,
    0,    0,    0, 1386, 1386,    0,    0, 1386, 1386, 1386,
 1386, 1386, 1386, 1386, 1386, 1386,    0, 1386,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1386, 1386, 1386,
 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386,
 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386,    0, 1386,
 1386, 1386, 1386, 1386, 1386,    0, 1386, 1386, 1386, 1386,
    0, 1386,    0, 1386, 1386, 1386, 1386, 1386, 1386, 1386,
 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386,
 1386,    0, 1386, 1386, 1386, 1386,    0, 1386, 1386, 1386,
 1386, 1386,    0, 1386, 1386, 1386, 1386, 1386, 1386, 1386,
 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386,
 1386, 1386, 1386,    0, 1386, 1386, 1386, 1386, 1386, 1386,
 1386, 1386, 1379, 1386, 1386, 1386, 1386,    0, 1386, 1386,
 1386, 1386, 1386, 1386,    0,    0, 1386, 1386, 1386, 1386,
 1386, 1386, 1386, 1386, 1386,    0,    0,    0,    0,    0,
 1386,    0, 1386, 1386, 1386, 1386, 1386, 1386,    0, 1386,
    0,    0,    0, 1379,    0,    0, 1379,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1379, 1379, 1379, 1379,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1379,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1379,
    0, 1379,    0,    0, 1379,    0, 1379, 1379,    0,    0,
 1379, 1379,    0, 1379,    0,    0,    0,    0,    0,    0,
    0, 1379, 1379,    0, 1379,    0, 1379,    0,    0, 1379,
    0,    0, 1379,    0,    0,    0,    0,    0,    0, 1379,
    0, 1379, 1379,    0, 1379, 1379, 1379,    0, 1379,    0,
    0, 1379,    0,    0, 1379,    0, 1379, 1379,    0,    0,
 1379, 1379, 1379,    0, 1379, 1379, 1379, 1379, 1379, 1379,
 1379,    0,    0,    0, 1379,    0, 1379, 1379, 1379,    0,
    0,    0, 1379,    0,    0,    0,    0,    0,    0,    0,
 1379, 1379, 1379, 1379, 1379, 1379,    0,    0,    0, 1379,
 1379,    0, 1379,    0, 1379,    0, 1379, 1379, 1379,    0,
 1379,    0, 1379, 1379, 1379,    0, 1379, 1379, 1379, 1379,
 1379,    0, 1379, 1379,    0,    0,    0,    0, 1379,    0,
 1379, 1379,    0,    0, 1379, 1379, 1379,    0,    0, 1379,
    0, 1379,    0,    0, 1379, 1379, 1379, 1379,    0, 1379,
    0, 1379,    0, 1379, 1379, 1379, 1379, 1379,    0,    0,
 1379, 1379, 1379,    0, 1379, 1379,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1379, 1379, 1379,    0, 1379,
 1379, 1379,    0, 1379,    0,    0,    0, 1379,    0, 1379,
 1379, 1379, 1379,    0, 1379,    0, 1379, 1379, 1379, 1379,
 1379, 1379, 1379, 1379,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1379, 1379,    0, 1379, 1379, 1379,    0,
    0,    0,    0, 1379, 1379, 1379, 1379, 1379,    0, 1379,
    0,    0, 1379, 1379,    0,    0,    0, 1379, 1379,    0,
    0, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
    0, 1379,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 1379, 1379,    0, 1379, 1379, 1379, 1379, 1379, 1379,    0,
 1379, 1379, 1379, 1379,    0, 1379,    0, 1379, 1379, 1379,
 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 1379, 1379, 1379, 1379, 1379,    0, 1379, 1379, 1379, 1379,
    0, 1379, 1379, 1379, 1379, 1379,    0, 1379, 1379, 1379,
 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 1379, 1379, 1379, 1379, 1379, 1379, 1379,    0, 1379, 1379,
 1379, 1379, 1379, 1379, 1379, 1379, 1381, 1379, 1379, 1379,
 1379,    0, 1379, 1379, 1379, 1379, 1379, 1379,    0,    0,
 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,    0,
    0,    0,    0,    0, 1379,    0, 1379, 1379, 1379, 1379,
 1379, 1379,    0, 1379,    0,    0,    0, 1381,    0,    0,
 1381,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1381, 1381, 1381, 1381,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1381,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1381,    0, 1381,    0,    0, 1381,    0,
 1381, 1381,    0,    0, 1381, 1381,    0, 1381,    0,    0,
    0,    0,    0,    0,    0, 1381, 1381,    0, 1381,    0,
 1381,    0,    0, 1381,    0,    0, 1381,    0,    0,    0,
    0,    0,    0, 1381,    0, 1381, 1381,    0, 1381, 1381,
 1381,    0, 1381,    0,    0, 1381,    0,    0, 1381,    0,
 1381, 1381,    0,    0, 1381, 1381, 1381,    0, 1381, 1381,
 1381, 1381, 1381, 1381, 1381,    0,    0,    0, 1381,    0,
 1381, 1381, 1381,    0,    0,    0, 1381,    0,    0,    0,
    0,    0,    0,    0, 1381, 1381, 1381, 1381, 1381, 1381,
    0,    0,    0, 1381, 1381,    0, 1381,    0, 1381,    0,
 1381, 1381, 1381,    0, 1381,    0, 1381, 1381, 1381,    0,
 1381, 1381, 1381, 1381, 1381,    0, 1381, 1381,    0,    0,
    0,    0, 1381,    0, 1381, 1381,    0,    0, 1381, 1381,
 1381,    0,    0, 1381,    0, 1381,    0,    0, 1381, 1381,
 1381, 1381,    0, 1381,    0, 1381,    0, 1381, 1381, 1381,
 1381, 1381,    0,    0, 1381, 1381, 1381,    0, 1381, 1381,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1381,
 1381, 1381,    0, 1381, 1381, 1381,    0, 1381,    0,    0,
    0, 1381,    0, 1381, 1381, 1381, 1381,    0, 1381,    0,
 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1381, 1381,    0,
 1381, 1381, 1381,    0,    0,    0,    0, 1381, 1381, 1381,
 1381, 1381,    0, 1381,    0,    0, 1381, 1381,    0,    0,
    0, 1381, 1381,    0,    0, 1381, 1381, 1381, 1381, 1381,
 1381, 1381, 1381, 1381,    0, 1381,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1381, 1381, 1381, 1381, 1381,
 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,
 1381, 1381, 1381, 1381, 1381, 1381,    0, 1381, 1381, 1381,
 1381, 1381, 1381,    0, 1381, 1381, 1381, 1381,    0, 1381,
    0, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,
 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,    0,
 1381, 1381, 1381, 1381,    0, 1381, 1381, 1381, 1381, 1381,
    0, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,
 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,
 1381,    0, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,
 1383, 1381, 1381, 1381, 1381,    0, 1381, 1381, 1381, 1381,
 1381, 1381,    0,    0, 1381, 1381, 1381, 1381, 1381, 1381,
 1381, 1381, 1381,    0,    0,    0,    0,    0, 1381,    0,
 1381, 1381, 1381, 1381, 1381, 1381,    0, 1381,    0,    0,
    0, 1383,    0,    0, 1383,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1383,
 1383, 1383, 1383,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1383,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1383,    0, 1383,
    0,    0, 1383,    0, 1383, 1383,    0,    0, 1383, 1383,
    0, 1383,    0,    0,    0,    0,    0,    0,    0, 1383,
 1383,    0, 1383,    0, 1383,    0,    0, 1383,    0,    0,
 1383,    0,    0,    0,    0,    0,    0, 1383,    0, 1383,
 1383,    0, 1383, 1383, 1383,    0, 1383,    0,    0, 1383,
    0,    0, 1383,    0, 1383, 1383,    0,    0, 1383, 1383,
 1383,    0, 1383, 1383, 1383, 1383, 1383, 1383, 1383,    0,
    0,    0, 1383,    0, 1383, 1383, 1383,    0,    0,    0,
 1383,    0,    0,    0,    0,    0,    0,    0, 1383, 1383,
 1383, 1383, 1383, 1383,    0,    0,    0, 1383, 1383,    0,
 1383,    0, 1383,    0, 1383, 1383, 1383,    0, 1383,    0,
 1383, 1383, 1383,    0, 1383, 1383, 1383, 1383, 1383,    0,
 1383, 1383,    0,    0,    0,    0, 1383,    0, 1383, 1383,
    0,    0, 1383, 1383, 1383,    0,    0, 1383,    0, 1383,
    0,    0, 1383, 1383, 1383, 1383,    0, 1383,    0, 1383,
    0, 1383, 1383, 1383, 1383, 1383,    0,    0, 1383, 1383,
 1383,    0, 1383, 1383,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1383, 1383, 1383,    0, 1383, 1383, 1383,
    0, 1383,    0,    0,    0, 1383,    0, 1383, 1383, 1383,
 1383,    0, 1383,    0, 1383, 1383, 1383, 1383, 1383, 1383,
 1383, 1383,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1383, 1383,    0, 1383, 1383, 1383,    0,    0,    0,
    0, 1383, 1383, 1383, 1383, 1383,    0, 1383,    0,    0,
 1383, 1383,    0,    0,    0, 1383, 1383,    0,    0, 1383,
 1383, 1383, 1383, 1383, 1383, 1383, 1383, 1383,    0, 1383,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1383,
 1383, 1383, 1383, 1383, 1383, 1383, 1383, 1383, 1383, 1383,
 1383, 1383, 1383, 1383, 1383, 1383, 1383, 1383, 1383, 1383,
    0, 1383, 1383, 1383, 1383, 1383, 1383,    0, 1383, 1383,
 1383, 1383,    0, 1383,    0, 1383, 1383, 1383, 1383, 1383,
 1383, 1383, 1383, 1383, 1383, 1383, 1383, 1383, 1383, 1383,
 1383, 1383, 1383,    0, 1383, 1383, 1383, 1383,    0, 1383,
 1383, 1383, 1383, 1383,    0, 1383, 1383, 1383, 1383, 1383,
 1383, 1383, 1383, 1383, 1383, 1383, 1383, 1383, 1383, 1383,
 1383, 1383, 1383, 1383, 1383,    0, 1383, 1383, 1383, 1383,
 1383, 1383, 1383, 1383, 1385, 1383, 1383, 1383, 1383,    0,
 1383, 1383, 1383, 1383, 1383, 1383,    0,    0, 1383, 1383,
 1383, 1383, 1383, 1383, 1383, 1383, 1383,    0,    0,    0,
    0,    0, 1383,    0, 1383, 1383, 1383, 1383, 1383, 1383,
    0, 1383,    0,    0,    0, 1385,    0,    0, 1385,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1385, 1385, 1385, 1385,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1385,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1385,    0, 1385,    0,    0, 1385,    0, 1385, 1385,
    0,    0, 1385, 1385,    0, 1385,    0,    0,    0,    0,
    0,    0,    0, 1385, 1385,    0, 1385,    0, 1385,    0,
    0, 1385,    0,    0, 1385,    0,    0,    0,    0,    0,
    0, 1385,    0, 1385, 1385,    0, 1385, 1385, 1385,    0,
 1385,    0,    0, 1385,    0,    0, 1385,    0, 1385, 1385,
    0,    0, 1385, 1385, 1385,    0, 1385, 1385, 1385, 1385,
 1385, 1385, 1385,    0,    0,    0, 1385,    0, 1385, 1385,
 1385,    0,    0,    0, 1385,    0,    0,    0,    0,    0,
    0,    0, 1385, 1385, 1385, 1385, 1385, 1385,    0,    0,
    0, 1385, 1385,    0, 1385,    0, 1385,    0, 1385, 1385,
 1385,    0, 1385,    0, 1385, 1385, 1385,    0, 1385, 1385,
 1385, 1385, 1385,    0, 1385, 1385,    0,    0,    0,    0,
 1385,    0, 1385, 1385,    0,    0, 1385, 1385, 1385,    0,
    0, 1385,    0, 1385,    0,    0, 1385, 1385, 1385, 1385,
    0, 1385,    0, 1385,    0, 1385, 1385, 1385, 1385, 1385,
    0,    0, 1385, 1385, 1385, 1340, 1385, 1385,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1385, 1385, 1385,
    0, 1385, 1385, 1385,    0, 1385,    0,    0,    0, 1385,
    0, 1385, 1385, 1385, 1385,    0, 1385,    0, 1385, 1385,
 1385, 1385, 1385, 1385, 1385, 1385, 1340,    0,    0, 1340,
    0,    0,    0,    0,    0, 1385, 1385,    0, 1385, 1385,
 1385,    0,    0,    0, 1340, 1385, 1385, 1385, 1385, 1385,
    0, 1385,    0,    0, 1385, 1385,    0,    0,    0, 1385,
 1385,    0,    0, 1385, 1385, 1385, 1385, 1385, 1385, 1385,
 1385, 1385,    0, 1385,    0,    0,    0,    0, 1340,    0,
    0,    0,    0, 1385, 1385, 1385, 1385, 1385, 1385, 1385,
 1385, 1385, 1385, 1385, 1385, 1385, 1385, 1385, 1385, 1385,
 1385, 1385, 1385, 1385,    0, 1385, 1385, 1385, 1385, 1385,
 1385,    0, 1385, 1385, 1385, 1385,    0, 1385,    0, 1385,
 1385, 1385, 1385, 1385, 1385, 1385, 1385, 1385, 1385, 1385,
 1385, 1385, 1385, 1385, 1385, 1385, 1385,    0, 1385, 1385,
 1385, 1385,    0, 1385, 1385, 1385, 1385, 1385,    0, 1385,
 1385, 1385, 1385, 1385, 1385, 1385, 1385, 1385, 1385, 1385,
 1385, 1385, 1385, 1385, 1385, 1385, 1385, 1385, 1385,    0,
 1385, 1385, 1385, 1385, 1385, 1385, 1385, 1385,    0, 1385,
 1385, 1385, 1385,    0, 1385, 1385, 1385, 1385, 1385, 1385,
    0,    0, 1385, 1385, 1385, 1385, 1385, 1385, 1385, 1385,
 1385,    0,    0,    0,    0,    0, 1385,    0, 1385, 1385,
 1385, 1385, 1385, 1385,    0, 1385,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1340,    0, 1340,    0,    0, 1340,    0, 1340,
 1340,    0,    0, 1340, 1340,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1340, 1340,    0, 1340,    0,    0,
    0,    0, 1340,    0,    0, 1340,    0,    0,    0,    0,
    0,    0, 1340,    0, 1340, 1340,    0, 1340, 1340, 1340,
 1340, 1340,    0,    0, 1340,    0,    0, 1340,    0, 1340,
 1340,    0,    0,    0, 1340, 1340,    0, 1340, 1340, 1340,
    0, 1340, 1340, 1340,    0,    0,    0, 1340,    0, 1340,
 1340, 1340,    0,    0,    0, 1340,    0,    0,    0,    0,
    0,    0,    0, 1340, 1340,    0, 1340,    0, 1340,    0,
    0,    0, 1340, 1340,    0, 1340,    0,    0,    0, 1340,
    0,    0,    0, 1340,    0, 1340, 1340, 1340,    0, 1340,
 1340, 1340, 1340, 1340,    0, 1340, 1340,    0,    0,    0,
    0, 1340,    0, 1340, 1340,    0,    0, 1340, 1340, 1340,
    0,    0, 1340,    0, 1340,    0,    0, 1340, 1340, 1340,
 1340,    0, 1340,    0, 1340,    0, 1340,    0, 1340, 1340,
 1340,    0,    0, 1340, 1340, 1340, 1339, 1340, 1340,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1340, 1340,
 1340,    0, 1340, 1340, 1340,    0, 1340,    0,    0,    0,
 1340,    0, 1340, 1340, 1340, 1340,    0, 1340,    0, 1340,
 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1339,    0,    0,
 1339,    0,    0,    0,    0,    0, 1340, 1340,    0, 1340,
 1340, 1340,    0,    0,    0, 1339, 1340, 1340, 1340, 1340,
 1340,    0, 1340,    0,    0, 1340, 1340,    0,    0,    0,
 1340, 1340,    0,    0, 1340, 1340, 1340, 1340, 1340, 1340,
 1340, 1340, 1340,    0, 1340,    0,    0,    0,    0, 1339,
    0,    0,    0,    0, 1340, 1340, 1340, 1340, 1340, 1340,
 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,
 1340, 1340, 1340, 1340, 1340,    0, 1340, 1340, 1340, 1340,
 1340, 1340,    0, 1340, 1340, 1340, 1340,    0, 1340,    0,
 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,
 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,    0, 1340,
 1340, 1340, 1340,    0, 1340, 1340, 1340, 1340, 1340,    0,
 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,
 1340, 1340, 1340,    0, 1340, 1340, 1340, 1340, 1340, 1340,
    0, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,    0,
 1340, 1340, 1340, 1340,    0, 1340, 1340, 1340, 1340, 1340,
 1340,    0,    0, 1340, 1340, 1340, 1340, 1340, 1340, 1340,
 1340, 1340,    0,    0,    0,    0,    0, 1340,    0, 1340,
 1340, 1340, 1340, 1340, 1340,    0, 1340,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1339,    0, 1339,    0,    0, 1339,    0,
 1339, 1339,    0,    0, 1339, 1339,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1339, 1339,    0, 1339,    0,
    0,    0,    0, 1339,    0,    0, 1339,    0,    0,    0,
    0,    0,    0, 1339,    0, 1339, 1339,    0, 1339, 1339,
 1339, 1339, 1339,    0,    0, 1339,    0,    0, 1339,    0,
 1339, 1339,    0,    0,    0, 1339, 1339,    0, 1339, 1339,
 1339,    0, 1339, 1339, 1339,    0,    0,    0, 1339,    0,
 1339, 1339, 1339,    0,    0,    0, 1339,    0,    0,    0,
    0,    0,    0,    0, 1339, 1339,    0, 1339,    0, 1339,
    0,    0,    0, 1339, 1339,    0, 1339,    0,    0,    0,
    0,    0,    0,    0, 1339,    0, 1339, 1339, 1339,    0,
 1339, 1339, 1339, 1339, 1339,    0, 1339, 1339,    0,    0,
    0,    0, 1339,    0, 1339, 1339,    0,    0, 1339, 1339,
 1339,    0,    0, 1339,    0, 1339,    0,    0, 1339, 1339,
 1339, 1339,    0, 1339,    0, 1339,    0, 1339,    0, 1339,
 1339, 1339,    0,    0, 1339, 1339, 1339, 1338, 1339, 1339,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1339,
 1339, 1339,    0, 1339, 1339, 1339,    0, 1339,    0,    0,
    0, 1339,    0, 1339, 1339, 1339, 1339,    0, 1339,    0,
 1339, 1339, 1339, 1339, 1339, 1339, 1339, 1339, 1338,    0,
    0, 1338,    0,    0,    0,    0,    0, 1339, 1339,    0,
 1339, 1339, 1339,    0,    0,    0, 1338, 1339, 1339, 1339,
 1339, 1339,    0, 1339,    0,    0, 1339, 1339,    0,    0,
    0, 1339, 1339,    0,    0, 1339, 1339, 1339, 1339, 1339,
 1339, 1339, 1339, 1339,    0, 1339,    0,    0,    0,    0,
 1338,    0,    0,    0,    0, 1339, 1339, 1339, 1339, 1339,
 1339, 1339, 1339, 1339, 1339, 1339, 1339, 1339, 1339, 1339,
 1339, 1339, 1339, 1339, 1339, 1339,    0, 1339, 1339, 1339,
 1339, 1339, 1339,    0, 1339, 1339, 1339, 1339,    0, 1339,
    0, 1339, 1339, 1339, 1339, 1339, 1339, 1339, 1339, 1339,
 1339, 1339, 1339, 1339, 1339, 1339, 1339, 1339, 1339,    0,
 1339, 1339, 1339, 1339,    0, 1339, 1339, 1339, 1339, 1339,
    0, 1339, 1339, 1339, 1339, 1339, 1339, 1339, 1339, 1339,
 1339, 1339, 1339, 1339,    0, 1339, 1339, 1339, 1339, 1339,
 1339,    0, 1339, 1339, 1339, 1339, 1339, 1339, 1339, 1339,
    0, 1339, 1339, 1339, 1339,    0, 1339, 1339, 1339, 1339,
 1339, 1339,    0,    0, 1339, 1339, 1339, 1339, 1339, 1339,
 1339, 1339, 1339,    0,    0,    0,    0,    0, 1339,    0,
 1339, 1339, 1339, 1339, 1339, 1339,    0, 1339,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1338,    0, 1338,    0,    0,    0,
    0, 1338, 1338,    0,    0, 1338, 1338,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1338, 1338,    0, 1338,
    0,    0,    0,    0, 1338,    0,    0, 1338,    0,    0,
    0,    0,    0,    0, 1338,    0, 1338, 1338,    0, 1338,
 1338, 1338, 1338, 1338,    0,    0, 1338,    0,    0, 1338,
    0, 1338, 1338,    0,    0,    0, 1338, 1338,    0, 1338,
 1338, 1338,    0, 1338, 1338, 1338,    0,    0,    0, 1338,
    0, 1338, 1338, 1338,    0,    0,    0, 1338,    0,    0,
    0,    0,    0,    0,    0, 1338, 1338,    0, 1338,    0,
 1338,    0,    0,    0, 1338, 1338,    0, 1338,    0,    0,
    0,    0,    0,    0,    0, 1338,    0, 1338, 1338, 1338,
    0, 1338, 1338, 1338, 1338, 1338,    0, 1338, 1338,    0,
    0,    0,    0, 1338,    0, 1338, 1338,    0,    0, 1338,
 1338, 1338,    0,    0, 1338,    0, 1338,    0,    0, 1338,
 1338, 1338, 1338,    0, 1338,    0, 1338,    0, 1338,    0,
 1338, 1338, 1338,    0,    0, 1338, 1338, 1338, 1192, 1338,
 1338,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1338, 1338, 1338,    0, 1338, 1338, 1338,    0, 1338,    0,
    0,    0, 1338,    0, 1338, 1338, 1338, 1338,    0, 1338,
    0, 1338, 1338, 1338, 1338, 1338, 1338, 1338, 1338, 1192,
    0,    0, 1192,    0,    0,    0,    0,    0, 1338, 1338,
    0, 1338, 1338, 1338,    0,    0,    0, 1192, 1338, 1338,
 1338, 1338, 1338,    0, 1338,    0,    0, 1338, 1338,    0,
    0,    0, 1338, 1338,    0,    0, 1338, 1338, 1338, 1338,
 1338, 1338, 1338, 1338, 1338,    0, 1338,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1338, 1338, 1338, 1338,
 1338, 1338, 1338, 1338, 1338, 1338, 1338, 1338, 1338, 1338,
 1338, 1338, 1338, 1338, 1338, 1338, 1338,    0, 1338, 1338,
 1338, 1338, 1338, 1338,    0, 1338, 1338, 1338, 1338,    0,
 1338,    0, 1338, 1338, 1338, 1338, 1338, 1338, 1338, 1338,
 1338, 1338, 1338, 1338, 1338, 1338, 1338, 1338, 1338, 1338,
    0, 1338, 1338, 1338, 1338,    0, 1338, 1338, 1338, 1338,
 1338,    0, 1338, 1338, 1338, 1338, 1338, 1338, 1338, 1338,
 1338, 1338, 1338, 1338, 1338,    0, 1338, 1338, 1338, 1338,
 1338, 1338,    0, 1338, 1338, 1338, 1338, 1338, 1338, 1338,
 1338,    0, 1338, 1338, 1338, 1338,    0, 1338, 1338, 1338,
 1338, 1338, 1338,    0,    0, 1338, 1338, 1338, 1338, 1338,
 1338, 1338, 1338, 1338,    0,    0,    0,    0,    0, 1338,
    0, 1338, 1338, 1338, 1338, 1338, 1338,    0, 1338,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1192,    0, 1192,    0,    0,
    0,    0, 1192, 1192,    0,    0, 1192, 1192,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1192, 1192,    0,
 1192,    0, 1192,    0,    0, 1192,    0,    0, 1192,    0,
    0,    0,    0,    0,    0, 1192,    0, 1192, 1192,    0,
    0,    0, 1192,    0, 1192,    0,    0, 1192,    0,    0,
 1192,    0,    0, 1192,    0,    0,    0, 1192, 1192,    0,
 1192, 1192, 1192,    0, 1192, 1192, 1192,    0,    0,    0,
 1192,    0, 1192, 1192, 1192,    0,    0,    0, 1192,    0,
    0,    0,    0,    0,    0,    0, 1192, 1192,    0, 1192,
    0, 1192,    0,    0,    0, 1192, 1192,    0, 1192,    0,
    0,    0,    0,    0,    0,    0, 1192,    0, 1192,    0,
 1192,    0, 1192, 1192, 1192, 1192, 1192,    0, 1192, 1192,
    0,    0,    0,    0, 1192,    0, 1192, 1192,    0,    0,
 1192, 1192,    0,    0,    0, 1192,    0, 1192,    0,    0,
 1192, 1192, 1192, 1192,    0, 1192,    0, 1192,    0, 1192,
 1192, 1192, 1192, 1192,    0,    0, 1162,    0, 1192,    0,
 1192, 1192,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1192,    0, 1192,    0, 1192, 1192, 1192,    0, 1192,
    0,    0,    0, 1192,    0, 1192, 1192, 1192, 1192,    0,
 1192,    0,    0,    0,    0,    0, 1162, 1162, 1192, 1192,
 1162,    0,    0,    0,    0,    0,    0,    0,    0, 1192,
 1192,    0, 1192, 1192, 1192, 1162,    0,    0,    0, 1192,
 1192, 1192, 1192, 1192,    0, 1192,    0,    0, 1192, 1192,
    0,    0,    0, 1192, 1192,    0,    0, 1192, 1192, 1192,
 1192, 1192, 1192, 1192, 1192, 1192,    0, 1192,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1192, 1192, 1192,
 1192, 1192, 1192, 1192, 1192, 1192, 1192, 1192, 1192, 1192,
 1192, 1192, 1192, 1192, 1192, 1192, 1192, 1192,    0, 1192,
 1192, 1192, 1192, 1192, 1192,    0, 1192, 1192, 1192, 1192,
    0, 1192,    0, 1192, 1192, 1192, 1192, 1192, 1192, 1192,
 1192, 1192, 1192, 1192, 1192, 1192, 1192, 1192, 1192, 1192,
 1192,    0, 1192, 1192, 1192, 1192,    0, 1192, 1192, 1192,
 1192, 1192,    0, 1192, 1192, 1192, 1192, 1192, 1192, 1192,
 1192, 1192, 1192, 1192, 1192, 1192,    0, 1192, 1192, 1192,
 1192, 1192, 1192,    0, 1192, 1192, 1192, 1192, 1192, 1192,
 1192, 1192,    0, 1192, 1192, 1192, 1192,    0, 1192, 1192,
 1192, 1192, 1192, 1192,    0,    0, 1192, 1192, 1192, 1192,
 1192, 1192, 1192, 1192, 1192,    0,    0,    0,    0,    0,
 1192,    0, 1192, 1192, 1192, 1192, 1192, 1192,    0, 1192,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1162,    0, 1162,    0,    0,    0,    0,
    0, 1162,    0,    0, 1162, 1162,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1162, 1162,    0, 1162,    0,
 1162,    0,    0, 1162,    0,    0, 1162,    0,    0,    0,
    0,    0,    0, 1162,    0, 1162, 1162,    0,    0,    0,
 1162,    0, 1162,    0,    0, 1162,    0,    0, 1162,    0,
    0, 1162,    0,    0,    0, 1162, 1162,    0, 1162, 1162,
 1162,    0, 1162, 1162, 1162,    0,    0,    0, 1162,    0,
 1162, 1162, 1162,    0,    0,    0, 1162,    0,    0,    0,
    0,    0,    0,    0, 1162, 1162,    0, 1162,    0, 1162,
    0,    0,    0, 1162, 1162,    0, 1162,    0,    0,    0,
    0,    0,    0,    0, 1162,    0, 1162,    0, 1162,    0,
 1162, 1162, 1162, 1162, 1162,    0, 1162, 1162,    0,    0,
    0,    0, 1162,    0, 1162, 1162,    0,    0, 1162, 1162,
    0,    0,    0, 1162,    0, 1162,    0,    0, 1162, 1162,
 1162, 1162,    0, 1162,    0, 1162, 1189, 1162, 1162, 1162,
 1162, 1162,    0,    0,    0,    0, 1162,    0, 1162, 1162,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1162,
    0, 1162,    0, 1162, 1162, 1162,    0, 1162,    0,    0,
    0, 1162,    0, 1162, 1162, 1162, 1162, 1189, 1162,    0,
 1189,    0,    0,    0,    0,    0, 1162, 1162,    0,    0,
    0,    0,    0,    0,    0, 1189,    0, 1162, 1162,    0,
 1162, 1162, 1162,    0,    0,    0,    0, 1162, 1162, 1162,
 1162, 1162,    0, 1162,    0,    0, 1162, 1162,    0,    0,
    0, 1162, 1162,    0,    0, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162,    0, 1162,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162,
 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162,    0, 1162,
    0, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,    0,
 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162, 1162,
    0, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162, 1162,
 1162,    0, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
    0, 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162,
 1162, 1162,    0,    0, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162,    0,    0,    0,    0,    0, 1162,    0,
 1162, 1162, 1162, 1162, 1162, 1162,    0, 1162,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1162,    0, 1162,    0,    0,    0,    0,
    0, 1162,    0,    0, 1162, 1162,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1162, 1162,    0, 1162,    0,
 1162,    0,    0, 1162,    0,    0, 1162,    0,    0,    0,
    0,    0,    0, 1162,    0, 1162, 1162,    0,    0,    0,
 1162,    0, 1162,    0,    0, 1162,    0,    0, 1189,    0,
    0, 1189,    0,    0,    0, 1162, 1162,    0, 1189, 1189,
 1162,    0, 1162, 1189, 1162,    0,    0,    0, 1189,    0,
 1162, 1189, 1162,    0,    0,    0, 1162,    0,    0,    0,
    0,    0,    0,    0, 1162, 1189,    0, 1162,    0, 1162,
    0,    0,    0, 1162, 1162,    0, 1189,    0,    0,    0,
    0,    0,    0,    0, 1189,    0, 1162,    0, 1189,    0,
 1162, 1162, 1162, 1162, 1162,    0, 1162, 1189,    0,    0,
    0,    0, 1162,    0, 1162, 1162,    0,    0, 1162, 1162,
    0,    0,    0, 1189,    0, 1162,    0,    0, 1162, 1162,
 1162, 1162,    0, 1162,    0, 1162, 1191, 1162, 1162, 1162,
 1162, 1162,    0,    0,    0,    0, 1162,    0, 1162, 1189,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1162,
    0, 1189,    0, 1189, 1162, 1162,    0, 1162,    0,    0,
    0, 1162,    0, 1162, 1162, 1162, 1162, 1191, 1162,    0,
 1191,    0,    0,    0,    0,    0, 1162, 1162,    0,    0,
    0,    0,    0,    0,    0, 1191,    0, 1162, 1162,    0,
 1162, 1162, 1162,    0,    0,    0,    0, 1162, 1162, 1189,
 1162, 1162,    0, 1162,    0,    0, 1162, 1162,    0,    0,
    0, 1162, 1162,    0,    0, 1189, 1189, 1162, 1162, 1162,
 1189, 1162, 1162, 1162,    0, 1162,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162,
 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162,    0, 1162,
    0, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,    0,
 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162, 1162,
    0, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162, 1162,
 1162,    0, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
    0, 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162,
 1162, 1162,    0,    0, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162,    0,    0,    0,    0,    0, 1162,    0,
 1162, 1162, 1162, 1162, 1162, 1162,    0, 1189,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1162,    0, 1162,    0,    0,    0,    0,
    0, 1162,    0,    0, 1162, 1162,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1162, 1162,    0, 1162,    0,
 1162,    0,    0, 1162,    0,    0, 1162,    0,    0,    0,
    0,    0,    0, 1162,    0, 1162, 1162,    0,    0,    0,
 1162,    0, 1162,    0,    0, 1162,    0,    0, 1191,    0,
    0, 1191,    0,    0,    0, 1162, 1162,    0, 1191, 1191,
 1162,    0, 1162, 1191, 1162,    0,    0,    0, 1191,    0,
 1162, 1191, 1162,    0,    0,    0, 1162,    0,    0,    0,
    0,    0,    0,    0, 1162, 1191,    0, 1162,    0, 1162,
    0,    0,    0, 1162, 1162,    0, 1191,    0,    0,    0,
    0,    0,    0,    0, 1191,    0, 1162,    0, 1191,    0,
 1162, 1162, 1162, 1162, 1162,    0, 1162, 1191,    0,    0,
    0,    0, 1162,    0, 1162, 1162,    0,    0, 1162, 1162,
    0, 1196,    0, 1191,    0, 1162,    0,    0, 1162, 1162,
 1162, 1162,    0, 1162,    0, 1162,    0, 1162, 1162, 1162,
 1162, 1162,    0,    0,    0,    0, 1162,    0, 1162, 1191,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1162,
    0, 1191,    0, 1191, 1162, 1162,    0, 1162,    0,    0,
    0, 1162,    0, 1162, 1162, 1162, 1162,    0, 1162,    0,
 1196,    0,    0,    0,    0,    0, 1162, 1162,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1162, 1162,    0,
 1162, 1162, 1162,    0,    0,    0,    0, 1162, 1162, 1191,
 1162, 1162,    0, 1162,    0,    0, 1162, 1162,    0,    0,
    0, 1162, 1162,    0,    0, 1191, 1191, 1162, 1162, 1162,
 1191, 1162, 1162, 1162,    0, 1162,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162,
 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162,    0, 1162,
    0, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,    0,
 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162, 1162,
    0, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162, 1162,
 1162,    0, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
    0, 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162,
 1162, 1162,    0,    0, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162,    0,    0,    0,    0,    0, 1162,    0,
 1162, 1162, 1162, 1162, 1162, 1162,    0, 1191, 1162,    0,
 1162,    0,    0,    0,    0,    0, 1162,    0,    0, 1162,
 1162,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1162, 1162,    0, 1162,    0, 1162,    0,    0, 1162,    0,
    0, 1162,    0,    0,    0,    0,    0,    0, 1162,    0,
 1162, 1162,    0,    0,    0, 1162,    0, 1162,    0,    0,
 1162,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1162, 1162,    0,    0,    0, 1162,    0, 1162,    0, 1162,
    0,    0,    0,    0,    0, 1162,    0, 1162,    0,    0,
    0, 1162,    0,    0,    0,    0,    0,    0,    0, 1162,
    0,    0, 1162,    0, 1162,    0,    0,    0, 1162, 1162,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1162,    0, 1196,    0, 1162, 1162, 1162, 1162, 1162,
    0, 1162, 1196,    0,    0,    0,    0, 1162,    0, 1162,
 1162,    0,    0, 1162, 1162,    0,    0, 1160,    0,    0,
 1162,    0, 1196, 1162, 1162, 1162, 1162,    0, 1162,    0,
 1162,    0, 1162, 1162, 1162, 1162, 1162,    0,    0,    0,
    0, 1162,    0, 1162,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1162,    0, 1196,    0,    0, 1162,
 1162, 1160, 1162,    0,    0,    0, 1162,    0, 1162, 1162,
 1162, 1162,    0, 1162,    0,    0, 1160,    0,    0,    0,
    0, 1162, 1162,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1162, 1162,    0, 1162, 1162, 1162,    0,    0,
    0,    0, 1162, 1162, 1196, 1162, 1162,    0, 1162,    0,
    0, 1162, 1162,    0,    0,    0, 1162, 1162,    0,    0,
    0, 1196, 1162, 1162, 1162,    0, 1162, 1162, 1162,    0,
 1162,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162,    0, 1162, 1162, 1162, 1162, 1162, 1162,    0, 1162,
 1162, 1162, 1162,    0, 1162,    0, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162,    0,
 1162, 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,    0,
 1162, 1162, 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162,
    0, 1162, 1162, 1162, 1162, 1162, 1162,    0,    0, 1162,
 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,    0,    0,
    0,    0,    0, 1162,    0, 1162, 1162, 1162, 1162, 1162,
 1162,    0,    0,    0, 1162,    0, 1162,    0,    0,    0,
    0,    0, 1162,    0,    0, 1162, 1162,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1162, 1162,    0, 1162,
    0,    0,    0,    0, 1162,    0,    0, 1162,    0,    0,
    0,    0,    0,    0, 1162,    0, 1162, 1162,    0,    0,
    0, 1162,    0, 1162,    0,    0, 1162,    0,    0,    0,
    0, 1160,    0,    0,    0,    0, 1162, 1162,    0,    0,
    0, 1162,    0, 1162,    0, 1162,    0,    0,    0, 1160,
    0, 1162,    0, 1162,    0,    0,    0, 1162,    0,    0,
    0,    0,    0,    0,    0, 1162,    0,    0, 1162,    0,
 1162,    0,    0,    0, 1162, 1162,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1162,    0,    0,
    0, 1162, 1162, 1162, 1162, 1162,    0, 1162,    0,    0,
    0,    0,    0, 1162,    0, 1162, 1162,    0,    0, 1162,
 1162,    0,    0,    0,    0,    0, 1162,    0,    0, 1162,
 1162, 1162, 1162,    0, 1162,    0, 1162,    0, 1162,    0,
 1162, 1162, 1162,    0,    0,    0,    0, 1162,    0, 1162,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1162,    0,    0,    0,    0, 1162, 1162,    0, 1162,    0,
    0,    0, 1162,    0, 1162, 1162, 1162, 1162,    0, 1162,
    0,    0,    0,    0,    0,    0,    0, 1162, 1162,    0,
    0,    0, 1138,    0,    0,  875,    0,  876, 1162, 1162,
    0, 1162, 1162, 1162,    0,    0,    0,    0, 1162, 1162,
  878, 1162, 1162,    0, 1162,  879,    0, 1162, 1162,    0,
    0,    0, 1162, 1162,    0,    0,    0,    0, 1162, 1162,
 1162,    0, 1162, 1162, 1162,    0, 1162,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162, 1162, 1162,    0, 1162, 1162,
 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162,    0,
 1162,    0, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
    0, 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162,
 1162,    0, 1162, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162, 1162,
 1162, 1162,    0, 1162, 1162, 1162, 1162, 1162, 1162, 1162,
 1162,    0, 1162, 1162, 1162, 1162,    0, 1162, 1162, 1162,
 1162, 1162, 1162,    0,    0, 1162, 1162, 1162, 1162, 1162,
 1162, 1162, 1162, 1162,    0,    0,    0,    0,    0, 1162,
    0, 1162, 1162, 1162, 1162, 1162, 1162,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  138,
    0,  139,    0,    0,    0,    0,    0,  140,    0,  740,
  141,  142,    0,    0,    0,    0,  741,    0,    0,    0,
    0,  143,  144,    0,  145,    0,  146,  742,    0,  147,
    0,    0,  148,  743,  744,    0,    0,    0,    0,  149,
    0,  150,  151,    0,    0,    0,  152,    0,  153,    0,
  745,  154,    0,    0,    0,    0,    0,    0,    0,  746,
    0,  155,  747,    0,    0,    0,  157,    0,  158,    0,
  159,    0,    0,    0,    0,    0,  160,    0,  161,    0,
    0,    0,  162,    0,    0,    0,  748,    0,  749,  750,
  163,  751,    0,  164,    0,  165,  752,    0,  753,  166,
  167,    0,    0,    0,    0,    0,  754,    0,    0,    0,
    0,    0,  168,    0,    0,    0,  170,  171,  172,  173,
  174,    0,  175,    0,  755,    0,    0,    0,  176,    0,
  177,  178,    0,    0,  179,  180,    0,    0,    0,  756,
    0,  181,    0,    0,  182,  183,  757,  185,    0,  186,
    0,  187,  758,  188,  189,  190,  191,  192,  759,    0,
    0,    0,  193,    0,  194,    0,    0,    0,  760,    0,
    0,    0,    0,    0,    0,  195,    0,    0,    0,    0,
  196,  197,  761,  762,  763,  506,  507,  199,    0,  200,
  201,  202,  203,    0,  204,  764, 1492, 1493, 1494, 1495,
 1496, 1497, 1525, 1526,  765,  766,  767,  768,  769,  770,
  771,  772,  773,  207,  774,    0,  209,  210,  211,  775,
  776,    0,  777,  778,  779,    0,  214,  215,  780,  216,
    0,    0,  217,  218,  781,  782,  783,  219,  220,    0,
    0,    0,    0,  221,  784,  223,    0,  785,  225,  226,
    0,  227,    0,  786,  787,  788,    0,  789,  790,    0,
  791,  228,  229,  230,  231,  232,  233,  792,  235,  793,
  237,  794,  795,  796,  797,  798,  799,  800,  801,  802,
  803,  804,    0,  805,  806,  807,  808,  809,  810,    0,
  811,  812,  813,  258,    0,  814,    0,  815,  816,  817,
  818,  819,  265,  266,  820, 1527,  821,  822,  823,  272,
  824,  274,  825,  276,  826,    0,  827,  828,  829,  830,
    0,  831,  832,  833,  285,  834,    0,  835,  836,  289,
  837, 1528,  292,  838,  294,  295,  296,  297,  298,  299,
    0,  839,  301,  302,  303,  304,  305,    0,  840,  307,
  308,  309,  310,  311,  312,  313,    0,  314,  315,  841,
  842,    0,  318,  319,  320,  843,  844,  845,    0,    0,
  324,  846,  847,  848,  849,  850,  851,  852,  853,  854,
    0,  855,  856,  857,  333,  858,  334,  335,  336,  337,
  338,  339,    0,    0,  859,  860,  861,  862,  863,  864,
  865,  866,  867,  868,  869,  870,  871,  872,  873,  874,
 1138,    0,    0,  875,    0,  876,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  878,    0,
    0,    0,    0,  879,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  138,    0,  139,
    0,    0,    0,    0,    0,  140,    0,  740,  141,  142,
    0,    0,    0,    0,  741,    0,    0,    0,    0,  143,
  144,    0,  145,    0,  146,  742,    0,  147,    0,    0,
  148,  743,  744,    0,    0,    0,    0,  149,    0,  150,
  151,    0,    0,    0,  152,    0,  153,    0,  745,  154,
    0,    0,    0,    0,    0,    0,    0,  746,    0,  155,
  747,    0,    0,    0,  157,    0,  158,    0,  159,    0,
    0,    0,    0,    0,  160,    0,  161,    0,    0,    0,
  162,    0,    0,    0,  748,    0,  749,  750,  163,  751,
    0,  164,    0,  165,  752,    0,  753,  166,  167,    0,
    0,    0,    0,    0,  754,    0,    0,    0,    0,    0,
  168,    0,    0,    0,  170,  171,  172,  173,  174,    0,
  175,    0,  755,    0,    0,    0,  176,    0,  177,  178,
    0,    0,  179,  180,    0,    0,    0,  756,    0,  181,
    0,    0,  182,  183,  757,  185,    0,  186,    0,  187,
  758,  188,  189,  190,  191,  192,  759,    0,    0,    0,
  193,    0,  194,    0,    0,    0,  760,    0,    0,    0,
    0,    0,    0,  195,    0,    0,    0,    0,  196,  197,
  761,  762,  763,  506,  507,  199,    0,  200,  201,  202,
  203,    0,  204,  764,    0,    0,    0,    0,    0,    0,
  205,  206,  765,  766,  767,  768,  769,  770,  771,  772,
  773,  207,  774,    0,  209,  210,  211,  775,  776,    0,
  777,  778,  779,    0,  214,  215,  780,  216,    0,    0,
  217,  218,  781,  782,  783,  219,  220,    0,    0,    0,
    0,  221,  784,  223,    0,  785,  225,  226, 1520,  227,
    0,  786,  787,  788, 1521,  789,  790, 1522,  791,  228,
  229,  230,  231,  232,  233,  792,  235,  793,  237,  794,
  795,  796,  797,  798,  799,  800,  801,  802,  803,  804,
    0,  805,  806,  807,  808,  809,  810,    0,  811,  812,
  813,  258,    0,  814,    0,  815,  816,  817,  818,  819,
  265,  266,  820,  268,  821,  822,  823,  272,  824,  274,
  825,  276,  826,    0,  827,  828,  829,  830,    0,  831,
  832,  833,  285,  834,    0,  835,  836,  289,  837,  291,
  292,  838,  294,  295,  296,  297,  298,  299,    0,  839,
  301,  302,  303,  304,  305,    0,  840,  307,  308,  309,
  310,  311,  312,  313,    0,  314,  315,  841,  842,    0,
  318,  319,  320,  843,  844,  845,    0,    0,  324,  846,
  847,  848,  849,  850,  851,  852,  853,  854,    0,  855,
  856,  857,  333,  858,  334,  335,  336,  337,  338,  339,
    0,    0,  859,  860,  861,  862,  863,  864,  865,  866,
  867,  868,  869,  870,  871,  872,  873,  874, 1138,    0,
    0,  875,    0,  876,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  878,    0,    0,    0,
    0,  879,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  138,    0,  139, 1593,    0,
    0, 1594,    0,  140,    0,  740,  141,  142,    0,    0,
    0,    0,  741,    0,    0,    0,    0,  143,  144,    0,
  145,    0,  146,  742,    0,  147,    0,    0,  148,  743,
  744,    0,    0,    0,    0,  149,    0,  150,  151,    0,
    0,    0,  152,    0,  153,    0,  745,  154,    0,    0,
    0,    0,    0,    0,    0,  746,    0,  155,  747,    0,
    0,    0,  157,    0,  158,    0,  159,    0,    0,    0,
    0,    0,  160,    0,  161,    0,    0,    0,  162,    0,
    0,    0,  748,    0,  749,  750,  163,  751,    0,  164,
    0,  165,  752,    0,  753,  166,  167,    0,    0,    0,
    0,    0,  754,    0,    0,    0,    0,    0,  168,    0,
    0,    0,  170,  171,  172,  173,  174,    0,  175,    0,
  755,    0,    0,    0,  176,    0,  177,  178,    0,    0,
  179,  180,    0,    0,    0,  756,    0,  181,    0,    0,
  182,  183,  757,  185,    0,  186, 1595,  187,  758,  188,
  189,  190,  191,  192,  759,    0,    0,    0,  193,    0,
  194,    0,    0,    0,  760,    0,    0,    0,    0,    0,
    0,  195,    0,    0,    0,    0,  196,  197,  761,  762,
  763,  506,  507,  199,    0,  200,  201,  202,  203,    0,
  204,  764,    0,    0,    0,    0,    0,    0,  205,  206,
  765,  766,  767,  768,  769,  770,  771,  772,  773,  207,
  774,    0,  209,  210,  211,  775,  776,    0,  777,  778,
  779,    0,  214,  215,  780,  216,    0,    0,  217,  218,
  781,  782,  783,  219,  220,    0,    0,    0,    0,  221,
  784,  223,    0,  785,  225,  226,    0,  227,    0,  786,
  787,  788,    0,  789,  790,    0,  791,  228,  229,  230,
  231,  232,  233,  792,  235,  793,  237,  794,  795,  796,
  797,  798,  799,  800,  801,  802,  803,  804,    0,  805,
  806,  807,  808,  809,  810,    0,  811,  812,  813,  258,
    0,  814,    0,  815,  816,  817,  818,  819,  265,  266,
  820,  268,  821,  822,  823,  272,  824,  274,  825,  276,
  826,    0,  827,  828,  829,  830,    0,  831,  832,  833,
  285,  834,    0,  835,  836,  289,  837,  291,  292,  838,
  294,  295,  296,  297,  298,  299,    0,  839,  301,  302,
  303,  304,  305,    0,  840,  307,  308,  309,  310,  311,
  312,  313,    0,  314,  315,  841,  842,    0,  318,  319,
  320,  843,  844,  845,    0,    0,  324,  846,  847,  848,
  849,  850,  851,  852,  853,  854,    0,  855,  856,  857,
  333,  858,  334,  335,  336,  337,  338,  339,    0,    0,
  859,  860,  861,  862,  863,  864,  865,  866,  867,  868,
  869,  870,  871,  872,  873,  874, 1144,    0, 1144, 1144,
    0, 1144,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1144,    0,    0,    0,    0, 1144,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1144,    0, 1144, 1144,    0,    0,    0,
    0, 1144,    0, 1144, 1144, 1144,    0,    0,    0,    0,
 1144,    0,    0,    0,    0, 1144, 1144,    0, 1144,    0,
 1144, 1144,    0, 1144,    0,    0, 1144, 1144, 1144,    0,
    0,    0,    0, 1144, 1144, 1144, 1144,    0,    0,    0,
 1144,    0, 1144,    0, 1144, 1144,    0,    0,    0,    0,
    0,    0,    0, 1144,    0, 1144, 1144,    0,    0,    0,
 1144,    0, 1144,    0, 1144,    0,    0,    0,    0,    0,
 1144,    0, 1144,    0,    0,    0, 1144,    0,    0,    0,
 1144,    0, 1144, 1144, 1144, 1144,    0, 1144,    0, 1144,
 1144,    0, 1144, 1144, 1144,    0,    0,    0,    0,    0,
 1144,    0,    0,    0,    0,    0, 1144,    0,    0,    0,
 1144, 1144, 1144, 1144, 1144,    0, 1144,    0, 1144,    0,
    0,    0, 1144,    0, 1144, 1144,    0,    0, 1144, 1144,
    0,    0,    0, 1144,    0, 1144,    0,    0, 1144, 1144,
 1144, 1144,    0, 1144,    0, 1144, 1144, 1144, 1144, 1144,
 1144, 1144, 1144,    0,    0,    0, 1144,    0, 1144,    0,
    0,    0, 1144,    0,    0,    0,    0,    0,    0, 1144,
    0,    0,    0,    0, 1144, 1144, 1144, 1144, 1144, 1144,
 1144, 1144,    0, 1144, 1144, 1144, 1144,    0, 1144, 1144,
    0,    0,    0,    0,    0,    0, 1144, 1144, 1144, 1144,
 1144, 1144, 1144, 1144, 1144, 1144, 1144, 1144, 1144,    0,
 1144, 1144,    0, 1144, 1144,    0, 1144, 1144, 1144,    0,
 1144, 1144, 1144, 1144,    0,    0, 1144, 1144, 1144, 1144,
 1144, 1144, 1144,    0,    0,    0,    0, 1144, 1144, 1144,
    0, 1144, 1144, 1144,    0, 1144,    0, 1144, 1144, 1144,
    0, 1144, 1144,    0, 1144, 1144, 1144, 1144, 1144, 1144,
 1144, 1144, 1144, 1144, 1144, 1144, 1144, 1144, 1144, 1144,
 1144, 1144, 1144, 1144, 1144, 1144,    0, 1144, 1144, 1144,
 1144, 1144, 1144,    0, 1144, 1144, 1144, 1144,    0, 1144,
    0, 1144, 1144, 1144, 1144, 1144, 1144, 1144, 1144, 1144,
 1144, 1144, 1144, 1144, 1144, 1144, 1144, 1144, 1144,    0,
 1144, 1144, 1144, 1144,    0, 1144, 1144, 1144, 1144, 1144,
    0, 1144, 1144, 1144, 1144, 1144, 1144, 1144, 1144, 1144,
 1144, 1144, 1144, 1144,    0, 1144, 1144, 1144, 1144, 1144,
 1144,    0, 1144, 1144, 1144, 1144, 1144, 1144, 1144, 1144,
    0, 1144, 1144, 1144, 1144,    0, 1144, 1144, 1144, 1144,
 1144, 1144,    0,    0, 1144, 1144, 1144, 1144, 1144, 1144,
 1144, 1144, 1144, 1144,    0, 1144, 1144, 1144, 1144, 1144,
 1144, 1144, 1144, 1144, 1144, 1144,    0,    0, 1144, 1144,
 1144, 1144, 1144, 1144, 1144, 1144, 1144, 1144, 1144, 1144,
 1144, 1144, 1144, 1144, 1138,    0,    0,  875,    0,  876,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  878,    0,    0,    0,    0,  879,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  138,    0,  139,    0,    0,    0,    0,    0,  140,
    0,  740,  141,  142,    0,    0,    0,    0,  741,    0,
    0,    0,    0,  143,  144,    0,  145,    0,  146,  742,
    0,  147, 1137,    0,  148,  743,  744,    0,    0,    0,
    0,  149,    0,  150,  151,    0,    0,    0,  152,    0,
  153,    0,  745,  154,    0,    0,    0,    0,    0,    0,
    0,  746,    0,  155,  747,    0,    0,    0,  157,    0,
  158,    0,  159,    0,    0,    0,    0,    0,  160,    0,
  161,    0,    0,    0,  162,    0,    0,    0,  748,    0,
  749,  750,  163,  751,    0,  164,    0,  165,  752,    0,
  753,  166,  167,    0,    0,    0,    0,    0,  754,    0,
    0,    0,    0,    0,  168,    0,    0,    0,  170,  171,
  172,  173,  174,    0,  175,    0,  755,    0,    0,    0,
  176,    0,  177,  178,    0,    0,  179,  180,    0,    0,
    0,  756,    0,  181,    0,    0,  182,  183,  757,  185,
    0,  186,    0,  187,  758,  188,  189,  190,  191,  192,
  759,    0,    0,    0,  193,    0,  194,    0,    0,    0,
  760,    0,    0,    0,    0,    0,    0,  195,    0,    0,
    0,    0,  196,  197,  761,  762,  763,  506,  507,  199,
    0,  200,  201,  202,  203,    0,  204,  764,    0,    0,
    0,    0,    0,    0,  205,  206,  765,  766,  767,  768,
  769,  770,  771,  772,  773,  207,  774,    0,  209,  210,
  211,  775,  776,    0,  777,  778,  779,    0,  214,  215,
  780,  216,    0,    0,  217,  218,  781,  782,  783,  219,
  220,    0,    0,    0,    0,  221,  784,  223,    0,  785,
  225,  226,    0,  227,    0,  786,  787,  788,    0,  789,
  790,    0,  791,  228,  229,  230,  231,  232,  233,  792,
  235,  793,  237,  794,  795,  796,  797,  798,  799,  800,
  801,  802,  803,  804,    0,  805,  806,  807,  808,  809,
  810,    0,  811,  812,  813,  258,    0,  814,    0,  815,
  816,  817,  818,  819,  265,  266,  820,  268,  821,  822,
  823,  272,  824,  274,  825,  276,  826,    0,  827,  828,
  829,  830,    0,  831,  832,  833,  285,  834,    0,  835,
  836,  289,  837,  291,  292,  838,  294,  295,  296,  297,
  298,  299,    0,  839,  301,  302,  303,  304,  305,    0,
  840,  307,  308,  309,  310,  311,  312,  313,    0,  314,
  315,  841,  842,    0,  318,  319,  320,  843,  844,  845,
    0,    0,  324,  846,  847,  848,  849,  850,  851,  852,
  853,  854,    0,  855,  856,  857,  333,  858,  334,  335,
  336,  337,  338,  339,    0,    0,  859,  860,  861,  862,
  863,  864,  865,  866,  867,  868,  869,  870,  871,  872,
  873,  874, 1138,    0,    0,  875,    0,  876,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  878,    0,    0,    0,    0,  879,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  138,
    0,  139,    0,    0,    0,    0,    0,  140,    0,  740,
  141,  142,    0,    0,    0,    0,  741,    0,    0,    0,
    0,  143,  144,    0,  145,    0,  146,  742,    0,  147,
    0,    0,  148,  743,  744,    0,    0,    0,    0,  149,
    0,  150,  151,    0,    0,    0,  152,    0,  153,    0,
  745,  154,    0,    0,    0,    0,    0,    0,    0,  746,
    0,  155,  747,    0,    0,    0,  157,    0,  158,    0,
  159,    0,    0,    0,    0,    0,  160,    0,  161,    0,
    0,    0,  162,    0,    0,    0,  748,    0,  749,  750,
  163,  751,    0,  164,    0,  165,  752,    0,  753,  166,
  167,    0,    0,    0,    0,    0,  754,    0,    0,    0,
    0,    0,  168,    0,    0,    0,  170,  171,  172,  173,
  174,    0,  175,    0,  755,    0,    0,    0,  176,    0,
  177,  178,    0,    0,  179,  180,    0,    0,    0,  756,
    0,  181,    0,    0,  182,  183,  757,  185,    0,  186,
    0,  187,  758,  188,  189,  190,  191,  192,  759,    0,
    0,    0,  193,    0,  194,    0,    0,    0,  760,    0,
    0,    0,    0,    0,    0,  195, 1169,    0,    0,    0,
  196,  197,  761,  762,  763,  506,  507,  199,    0,  200,
  201,  202,  203,    0,  204,  764,    0,    0,    0,    0,
    0,    0,  205,  206,  765,  766,  767,  768,  769,  770,
  771,  772,  773,  207,  774,    0,  209,  210,  211,  775,
  776,    0,  777,  778,  779,    0,  214,  215,  780,  216,
    0,    0,  217,  218,  781,  782,  783,  219,  220,    0,
    0,    0,    0,  221,  784,  223,    0,  785,  225,  226,
    0,  227,    0,  786,  787,  788,    0,  789,  790,    0,
  791,  228,  229,  230,  231,  232,  233,  792,  235,  793,
  237,  794,  795,  796,  797,  798,  799,  800,  801,  802,
  803,  804,    0,  805,  806,  807,  808,  809,  810,    0,
  811,  812,  813,  258,    0,  814,    0,  815,  816,  817,
  818,  819,  265,  266,  820,  268,  821,  822,  823,  272,
  824,  274,  825,  276,  826,    0,  827,  828,  829,  830,
    0,  831,  832,  833,  285,  834,    0,  835,  836,  289,
  837,  291,  292,  838,  294,  295,  296,  297,  298,  299,
    0,  839,  301,  302,  303,  304,  305,    0,  840,  307,
  308,  309,  310,  311,  312,  313,    0,  314,  315,  841,
  842,    0,  318,  319,  320,  843,  844,  845,    0,    0,
  324,  846,  847,  848,  849,  850,  851,  852,  853,  854,
    0,  855,  856,  857,  333,  858,  334,  335,  336,  337,
  338,  339,    0,    0,  859,  860,  861,  862,  863,  864,
  865,  866,  867,  868,  869,  870,  871,  872,  873,  874,
 1138,    0,    0,  875,    0,  876,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  878,    0,
    0,    0,    0,  879,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  138,    0,  139,
    0,    0,    0,    0,    0,  140,    0,  740,  141,  142,
    0,    0,    0,    0,  741,    0,    0,    0,    0,  143,
  144,    0,  145,    0,  146,  742,    0,  147,    0,    0,
  148,  743,  744,    0,    0,    0,    0,  149,    0,  150,
  151,    0,    0,    0,  152,    0,  153,    0,  745,  154,
    0,    0,    0,    0,    0,    0,    0,  746,    0,  155,
  747,    0,    0,    0,  157,    0,  158,    0,  159,    0,
    0,    0,    0,    0,  160,    0,  161,    0,    0,    0,
  162,    0,    0,    0,  748,    0,  749,  750,  163,  751,
    0,  164,    0,  165,  752,    0,  753,  166,  167,    0,
    0,    0,    0,    0,  754,    0,    0,    0,    0,    0,
  168,    0,    0,    0,  170,  171,  172,  173,  174,    0,
  175,    0,  755,    0,    0,    0,  176,    0,  177,  178,
    0,    0,  179,  180,    0,    0,    0,  756,    0,  181,
    0,    0,  182,  183,  757,  185,    0,  186,    0,  187,
  758,  188,  189,  190,  191,  192,  759,    0,    0,    0,
  193,    0,  194,    0,    0,    0,  760,    0,    0,    0,
    0,    0,    0,  195,    0,    0,    0,   15,  196,  197,
  761,  762,  763,  506,  507,  199,    0,  200,  201,  202,
  203,    0,  204,  764,    0,    0,    0,    0,    0,    0,
  205,  206,  765,  766,  767,  768,  769,  770,  771,  772,
  773,  207,  774,    0,  209,  210,  211,  775,  776,    0,
  777,  778,  779,    0,  214,  215,  780,  216,    0,    0,
  217,  218,  781,  782,  783,  219,  220,    0,    0,    0,
    0,  221,  784,  223,    0,  785,  225,  226,    0,  227,
    0,  786,  787,  788,    0,  789,  790,    0,  791,  228,
  229,  230,  231,  232,  233,  792,  235,  793,  237,  794,
  795,  796,  797,  798,  799,  800,  801,  802,  803,  804,
    0,  805,  806,  807,  808,  809,  810,    0,  811,  812,
  813,  258,    0,  814,    0,  815,  816,  817,  818,  819,
  265,  266,  820,  268,  821,  822,  823,  272,  824,  274,
  825,  276,  826,    0,  827,  828,  829,  830,    0,  831,
  832,  833,  285,  834,    0,  835,  836,  289,  837,  291,
  292,  838,  294,  295,  296,  297,  298,  299,    0,  839,
  301,  302,  303,  304,  305,    0,  840,  307,  308,  309,
  310,  311,  312,  313,    0,  314,  315,  841,  842,    0,
  318,  319,  320,  843,  844,  845,    0,    0,  324,  846,
  847,  848,  849,  850,  851,  852,  853,  854,    0,  855,
  856,  857,  333,  858,  334,  335,  336,  337,  338,  339,
    0,    0,  859,  860,  861,  862,  863,  864,  865,  866,
  867,  868,  869,  870,  871,  872,  873,  874, 1138,    0,
 1320,  875,    0,  876,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  878,    0,    0,    0,
    0,  879,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  138,    0,  139,    0,    0,
    0,    0,    0,  140,    0,  740,  141,  142,    0,    0,
    0,    0,  741,    0,    0,    0,    0,  143,  144,    0,
  145,    0,  146,  742,    0,  147,    0,    0,  148,  743,
  744,    0,    0,    0,    0,  149,    0,  150,  151,    0,
    0,    0,  152,    0,  153,    0,  745,  154,    0,    0,
    0,    0,    0,    0,    0,  746,    0,  155,  747,    0,
    0,    0,  157,    0,  158,    0,  159,    0,    0,    0,
    0,    0,  160,    0,  161,    0,    0,    0,  162,    0,
    0,    0,  748,    0,  749,  750,  163,  751,    0,  164,
    0,  165,  752,    0,  753,  166,  167,    0,    0,    0,
    0,    0,  754,    0,    0,    0,    0,    0,  168,    0,
    0,    0,  170,  171,  172,  173,  174,    0,  175,    0,
  755,    0,    0,    0,  176,    0,  177,  178,    0,    0,
  179,  180,    0,    0,    0,  756,    0,  181,    0,    0,
  182,  183,  757,  185,    0,  186,    0,  187,  758,  188,
  189,  190,  191,  192,  759,    0,    0,    0,  193,    0,
  194,    0,    0,    0,  760,    0,    0,    0,    0,    0,
    0,  195,    0,    0,    0,    0,  196,  197,  761,  762,
  763,  506,  507,  199,    0,  200,  201,  202,  203,    0,
  204,  764,    0,    0,    0,    0,    0,    0,  205,  206,
  765,  766,  767,  768,  769,  770,  771,  772,  773,  207,
  774,    0,  209,  210,  211,  775,  776,    0,  777,  778,
  779,    0,  214,  215,  780,  216,    0,    0,  217,  218,
  781,  782,  783,  219,  220,    0,    0,    0,    0,  221,
  784,  223,    0,  785,  225,  226,    0,  227,    0,  786,
  787,  788,    0,  789,  790,    0,  791,  228,  229,  230,
  231,  232,  233,  792,  235,  793,  237,  794,  795,  796,
  797,  798,  799,  800,  801,  802,  803,  804,    0,  805,
  806,  807,  808,  809,  810,    0,  811,  812,  813,  258,
    0,  814,    0,  815,  816,  817,  818,  819,  265,  266,
  820,  268,  821,  822,  823,  272,  824,  274,  825,  276,
  826,    0,  827,  828,  829,  830,    0,  831,  832,  833,
  285,  834,    0,  835,  836,  289,  837,  291,  292,  838,
  294,  295,  296,  297,  298,  299,    0,  839,  301,  302,
  303,  304,  305,    0,  840,  307,  308,  309,  310,  311,
  312,  313,    0,  314,  315,  841,  842,    0,  318,  319,
  320,  843,  844,  845,    0,    0,  324,  846,  847,  848,
  849,  850,  851,  852,  853,  854,    0,  855,  856,  857,
  333,  858,  334,  335,  336,  337,  338,  339,    0,    0,
  859,  860,  861,  862,  863,  864,  865,  866,  867,  868,
  869,  870,  871,  872,  873,  874, 1138, 1608,    0,  875,
    0,  876,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  878,    0,    0,    0,    0,  879,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  138,    0,  139,    0,    0,    0,    0,
    0,  140,    0,  740,  141,  142,    0,    0,    0,    0,
  741,    0,    0,    0,    0,  143,  144,    0,  145,    0,
  146,  742,    0,  147,    0,    0,  148,  743,  744,    0,
    0,    0,    0,  149,    0,  150,  151,    0,    0,    0,
  152,    0,  153,    0,  745,  154,    0,    0,    0,    0,
    0,    0,    0,  746,    0,  155,  747,    0,    0,    0,
  157,    0,  158,    0,  159,    0,    0,    0,    0,    0,
  160,    0,  161,    0,    0,    0,  162,    0,    0,    0,
  748,    0,  749,  750,  163,  751,    0,  164,    0,  165,
  752,    0,  753,  166,  167,    0,    0,    0,    0,    0,
  754,    0,    0,    0,    0,    0,  168,    0,    0,    0,
  170,  171,  172,  173,  174,    0,  175,    0,  755,    0,
    0,    0,  176,    0,  177,  178,    0,    0,  179,  180,
    0,    0,    0,  756,    0,  181,    0,    0,  182,  183,
  757,  185,    0,  186,    0,  187,  758,  188,  189,  190,
  191,  192,  759,    0,    0,    0,  193,    0,  194,    0,
    0,    0,  760,    0,    0,    0,    0,    0,    0,  195,
    0,    0,    0,    0,  196,  197,  761,  762,  763,  506,
  507,  199,    0,  200,  201,  202,  203,    0,  204,  764,
    0,    0,    0,    0,    0,    0,  205,  206,  765,  766,
  767,  768,  769,  770,  771,  772,  773,  207,  774,    0,
  209,  210,  211,  775,  776,    0,  777,  778,  779,    0,
  214,  215,  780,  216,    0,    0,  217,  218,  781,  782,
  783,  219,  220,    0,    0,    0,    0,  221,  784,  223,
    0,  785,  225,  226,    0,  227,    0,  786,  787,  788,
    0,  789,  790,    0,  791,  228,  229,  230,  231,  232,
  233,  792,  235,  793,  237,  794,  795,  796,  797,  798,
  799,  800,  801,  802,  803,  804,    0,  805,  806,  807,
  808,  809,  810,    0,  811,  812,  813,  258,    0,  814,
    0,  815,  816,  817,  818,  819,  265,  266,  820,  268,
  821,  822,  823,  272,  824,  274,  825,  276,  826,    0,
  827,  828,  829,  830,    0,  831,  832,  833,  285,  834,
    0,  835,  836,  289,  837,  291,  292,  838,  294,  295,
  296,  297,  298,  299,    0,  839,  301,  302,  303,  304,
  305,    0,  840,  307,  308,  309,  310,  311,  312,  313,
    0,  314,  315,  841,  842,    0,  318,  319,  320,  843,
  844,  845,    0,    0,  324,  846,  847,  848,  849,  850,
  851,  852,  853,  854,    0,  855,  856,  857,  333,  858,
  334,  335,  336,  337,  338,  339,    0,    0,  859,  860,
  861,  862,  863,  864,  865,  866,  867,  868,  869,  870,
  871,  872,  873,  874, 1138,    0,    0,  875,    0,  876,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  878,    0,    0,    0,    0,  879,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  138,    0,  139,    0,    0,    0,    0,    0,  140,
    0,  740,  141,  142,    0,    0,    0,    0,  741,    0,
    0,    0,    0,  143,  144,    0,  145,    0,  146,  742,
    0,  147,    0,    0,  148,  743,  744,    0,    0,    0,
    0,  149,    0,  150,  151,    0,    0,    0,  152,    0,
  153,    0,  745,  154,    0,    0,    0,    0, 1970,    0,
    0,  746,    0,  155,  747,    0,    0,    0,  157,    0,
  158,    0,  159,    0,    0,    0,    0,    0,  160,    0,
  161,    0,    0,    0,  162,    0,    0,    0,  748,    0,
  749,  750,  163,  751,    0,  164,    0,  165,  752,    0,
  753,  166,  167,    0,    0,    0,    0,    0,  754,    0,
    0,    0,    0,    0,  168,    0,    0,    0,  170,  171,
  172,  173,  174,    0,  175,    0,  755,    0,    0,    0,
  176,    0,  177,  178,    0,    0,  179,  180,    0,    0,
    0,  756,    0,  181,    0,    0,  182,  183,  757,  185,
    0,  186,    0,  187,  758,  188,  189,  190,  191,  192,
  759,    0,    0,    0,  193,    0,  194,    0,    0,    0,
  760,    0,    0,    0,    0,    0,    0,  195,    0,    0,
    0,    0,  196,  197,  761,  762,  763,  506,  507,  199,
    0,  200,  201,  202,  203,    0,  204,  764,    0,    0,
    0,    0,    0,    0,  205,  206,  765,  766,  767,  768,
  769,  770,  771,  772,  773,  207,  774,    0,  209,  210,
  211,  775,  776,    0,  777,  778,  779,    0,  214,  215,
  780,  216,    0,    0,  217,  218,  781,  782,  783,  219,
  220,    0,    0,    0,    0,  221,  784,  223,    0,  785,
  225,  226,    0,  227,    0,  786,  787,  788,    0,  789,
  790,    0,  791,  228,  229,  230,  231,  232,  233,  792,
  235,  793,  237,  794,  795,  796,  797,  798,  799,  800,
  801,  802,  803,  804,    0,  805,  806,  807,  808,  809,
  810,    0,  811,  812,  813,  258,    0,  814,    0,  815,
  816,  817,  818,  819,  265,  266,  820,  268,  821,  822,
  823,  272,  824,  274,  825,  276,  826,    0,  827,  828,
  829,  830,    0,  831,  832,  833,  285,  834,    0,  835,
  836,  289,  837,  291,  292,  838,  294,  295,  296,  297,
  298,  299,    0,  839,  301,  302,  303,  304,  305,    0,
  840,  307,  308,  309,  310,  311,  312,  313,    0,  314,
  315,  841,  842,    0,  318,  319,  320,  843,  844,  845,
    0,    0,  324,  846,  847,  848,  849,  850,  851,  852,
  853,  854,    0,  855,  856,  857,  333,  858,  334,  335,
  336,  337,  338,  339,    0,    0,  859,  860,  861,  862,
  863,  864,  865,  866,  867,  868,  869,  870,  871,  872,
  873,  874, 1138,    0,    0,  875,    0,  876,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  878,    0,    0,    0,    0,  879,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  138,
    0,  139,    0,    0,    0,    0,    0,  140,    0,  740,
  141,  142,    0,    0,    0,    0,  741,    0,    0,    0,
    0,  143,  144,    0,  145,    0,  146,  742,    0,  147,
    0,    0,  148,  743,  744,    0,    0,    0,    0,  149,
    0,  150,  151,    0,    0,    0,  152,    0,  153,    0,
  745,  154,    0,    0,    0,    0,    0,    0,    0,  746,
    0,  155,  747,    0,    0,    0,  157,    0,  158,    0,
  159,    0,    0,    0,    0,    0,  160,    0,  161,    0,
    0,    0,  162,    0,    0,    0,  748,    0,  749,  750,
  163,  751,    0,  164,    0,  165,  752,    0,  753,  166,
  167,    0,    0,    0,    0,    0,  754,    0,    0,    0,
    0,    0,  168,    0,    0,    0,  170,  171,  172,  173,
  174,    0,  175,    0,  755,    0,    0,    0,  176,    0,
  177,  178,    0,    0,  179,  180,    0,    0,    0,  756,
    0,  181,    0,    0,  182,  183,  757,  185,    0,  186,
    0,  187,  758,  188,  189,  190,  191,  192,  759,    0,
    0, 1592,  193,    0,  194,    0,    0,    0,  760,    0,
    0,    0,    0,    0,    0,  195,    0,    0,    0,    0,
  196,  197,  761,  762,  763,  506,  507,  199,    0,  200,
  201,  202,  203,    0,  204,  764,    0,    0,    0,    0,
    0,    0,  205,  206,  765,  766,  767,  768,  769,  770,
  771,  772,  773,  207,  774,    0,  209,  210,  211,  775,
  776,    0,  777,  778,  779,    0,  214,  215,  780,  216,
    0,    0,  217,  218,  781,  782,  783,  219,  220,    0,
    0,    0,    0,  221,  784,  223,    0,  785,  225,  226,
    0,  227,    0,  786,  787,  788,    0,  789,  790,    0,
  791,  228,  229,  230,  231,  232,  233,  792,  235,  793,
  237,  794,  795,  796,  797,  798,  799,  800,  801,  802,
  803,  804,    0,  805,  806,  807,  808,  809,  810,    0,
  811,  812,  813,  258,    0,  814,    0,  815,  816,  817,
  818,  819,  265,  266,  820,  268,  821,  822,  823,  272,
  824,  274,  825,  276,  826,    0,  827,  828,  829,  830,
    0,  831,  832,  833,  285,  834,    0,  835,  836,  289,
  837,  291,  292,  838,  294,  295,  296,  297,  298,  299,
    0,  839,  301,  302,  303,  304,  305,    0,  840,  307,
  308,  309,  310,  311,  312,  313,    0,  314,  315,  841,
  842,    0,  318,  319,  320,  843,  844,  845,    0,    0,
  324,  846,  847,  848,  849,  850,  851,  852,  853,  854,
    0,  855,  856,  857,  333,  858,  334,  335,  336,  337,
  338,  339,    0,    0,  859,  860,  861,  862,  863,  864,
  865,  866,  867,  868,  869,  870,  871,  872,  873,  874,
 1138, 2364,    0,  875,    0,  876,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  878,    0,
    0,    0,    0,  879,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  138,    0,  139,
    0,    0,    0,    0,    0,  140,    0,  740,  141,  142,
    0,    0,    0,    0,  741,    0,    0,    0,    0,  143,
  144,    0,  145,    0,  146,  742,    0,  147,    0,    0,
  148,  743,  744,    0,    0,    0,    0,  149,    0,  150,
  151,    0,    0,    0,  152,    0,  153,    0,  745,  154,
    0,    0,    0,    0,    0,    0,    0,  746,    0,  155,
  747,    0,    0,    0,  157,    0,  158,    0,  159,    0,
    0,    0,    0,    0,  160,    0,  161,    0,    0,    0,
  162,    0,    0,    0,  748,    0,  749,  750,  163,  751,
    0,  164,    0,  165,  752,    0,  753,  166,  167,    0,
    0,    0,    0,    0,  754,    0,    0,    0,    0,    0,
  168,    0,    0,    0,  170,  171,  172,  173,  174,    0,
  175,    0,  755,    0,    0,    0,  176,    0,  177,  178,
    0,    0,  179,  180,    0,    0,    0,  756,    0,  181,
    0,    0,  182,  183,  757,  185,    0,  186,    0,  187,
  758,  188,  189,  190,  191,  192,  759,    0,    0,    0,
  193,    0,  194,    0,    0,    0,  760,    0,    0,    0,
    0,    0,    0,  195,    0,    0,    0,    0,  196,  197,
  761,  762,  763,  506,  507,  199,    0,  200,  201,  202,
  203,    0,  204,  764,    0,    0,    0,    0,    0,    0,
  205,  206,  765,  766,  767,  768,  769,  770,  771,  772,
  773,  207,  774,    0,  209,  210,  211,  775,  776,    0,
  777,  778,  779,    0,  214,  215,  780,  216,    0,    0,
  217,  218,  781,  782,  783,  219,  220,    0,    0,    0,
    0,  221,  784,  223,    0,  785,  225,  226,    0,  227,
    0,  786,  787,  788,    0,  789,  790,    0,  791,  228,
  229,  230,  231,  232,  233,  792,  235,  793,  237,  794,
  795,  796,  797,  798,  799,  800,  801,  802,  803,  804,
    0,  805,  806,  807,  808,  809,  810,    0,  811,  812,
  813,  258,    0,  814,    0,  815,  816,  817,  818,  819,
  265,  266,  820,  268,  821,  822,  823,  272,  824,  274,
  825,  276,  826,    0,  827,  828,  829,  830,    0,  831,
  832,  833,  285,  834,    0,  835,  836,  289,  837,  291,
  292,  838,  294,  295,  296,  297,  298,  299,    0,  839,
  301,  302,  303,  304,  305,    0,  840,  307,  308,  309,
  310,  311,  312,  313,    0,  314,  315,  841,  842,    0,
  318,  319,  320,  843,  844,  845,    0,    0,  324,  846,
  847,  848,  849,  850,  851,  852,  853,  854,    0,  855,
  856,  857,  333,  858,  334,  335,  336,  337,  338,  339,
    0,    0,  859,  860,  861,  862,  863,  864,  865,  866,
  867,  868,  869,  870,  871,  872,  873,  874, 1138,    0,
    0,  875,    0,  876,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  878,    0,    0,    0,
    0,  879,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  138,    0,  139,    0,    0,
    0,    0,    0,  140,    0,  740,  141,  142,    0,    0,
    0,    0,  741,    0,    0,    0,    0,  143,  144,    0,
  145,    0,  146,  742,    0,  147,    0,    0,  148,  743,
  744,    0,    0,    0,    0,  149,    0,  150,  151,    0,
    0,    0,  152,    0,  153,    0,  745,  154,    0,    0,
    0,    0,    0,    0,    0,  746,    0,  155,  747,    0,
    0,    0,  157,    0,  158,    0,  159,    0,    0,    0,
    0,    0,  160,    0,  161,    0,    0,    0,  162,    0,
    0,    0,  748,    0,  749,  750,  163,  751,    0,  164,
    0,  165,  752,    0,  753,  166,  167,    0,    0,    0,
    0,    0,  754,    0,    0,    0,    0,    0,  168,    0,
    0,    0,  170,  171,  172,  173,  174,    0,  175,    0,
  755,    0,    0,    0,  176,    0,  177,  178,    0,    0,
  179,  180,    0,    0,    0,  756,    0,  181,    0,    0,
  182,  183,  757,  185,    0,  186,    0,  187,  758,  188,
  189,  190,  191,  192,  759,    0,    0,    0,  193,    0,
  194,    0,    0,    0,  760,    0,    0,    0,    0,    0,
    0,  195,    0,    0,    0,    0,  196,  197,  761,  762,
  763,  506,  507,  199,    0,  200,  201,  202,  203,    0,
  204,  764,    0,    0,    0,    0,    0,    0,  205,  206,
  765,  766,  767,  768,  769,  770,  771,  772,  773,  207,
  774,    0,  209,  210,  211,  775,  776,    0,  777,  778,
  779, 2456,  214,  215,  780,  216,    0,    0,  217,  218,
  781,  782,  783,  219,  220,    0,    0,    0,    0,  221,
  784,  223,    0,  785,  225,  226,    0,  227,    0,  786,
  787,  788,    0,  789,  790,    0,  791,  228,  229,  230,
  231,  232,  233,  792,  235,  793,  237,  794,  795,  796,
  797,  798,  799,  800,  801,  802,  803,  804,    0,  805,
  806,  807,  808,  809,  810,    0,  811,  812,  813,  258,
    0,  814,    0,  815,  816,  817,  818,  819,  265,  266,
  820,  268,  821,  822,  823,  272,  824,  274,  825,  276,
  826,    0,  827,  828,  829,  830,    0,  831,  832,  833,
  285,  834,    0,  835,  836,  289,  837,  291,  292,  838,
  294,  295,  296,  297,  298,  299,    0,  839,  301,  302,
  303,  304,  305,    0,  840,  307,  308,  309,  310,  311,
  312,  313,    0,  314,  315,  841,  842,    0,  318,  319,
  320,  843,  844,  845,    0,    0,  324,  846,  847,  848,
  849,  850,  851,  852,  853,  854,    0,  855,  856,  857,
  333,  858,  334,  335,  336,  337,  338,  339,    0,    0,
  859,  860,  861,  862,  863,  864,  865,  866,  867,  868,
  869,  870,  871,  872,  873,  874, 1142,    0, 1142, 1142,
    0, 1142,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1142,    0,    0,    0,    0, 1142,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1142,    0, 1142, 1142,    0,    0,    0,
    0, 1142,    0, 1142, 1142, 1142,    0,    0,    0,    0,
 1142,    0,    0,    0,    0, 1142, 1142,    0, 1142,    0,
 1142, 1142,    0, 1142,    0,    0, 1142, 1142, 1142,    0,
    0,    0,    0, 1142, 1142, 1142, 1142,    0,    0,    0,
 1142,    0, 1142,    0, 1142, 1142,    0,    0,    0,    0,
    0,    0,    0, 1142,    0, 1142, 1142,    0,    0,    0,
 1142,    0, 1142,    0, 1142,    0,    0,    0,    0,    0,
 1142,    0, 1142,    0,    0,    0, 1142,    0,    0,    0,
 1142,    0, 1142, 1142, 1142, 1142,    0, 1142,    0, 1142,
 1142,    0, 1142, 1142, 1142,    0,    0,    0,    0,    0,
 1142,    0,    0,    0,    0,    0, 1142,    0,    0,    0,
 1142, 1142, 1142, 1142, 1142,    0, 1142,    0, 1142,    0,
    0,    0, 1142,    0, 1142, 1142,    0,    0, 1142, 1142,
    0,    0,    0, 1142,    0, 1142,    0,    0, 1142, 1142,
 1142, 1142,    0, 1142,    0, 1142, 1142, 1142, 1142, 1142,
 1142, 1142, 1142,    0,    0,    0, 1142,    0, 1142,    0,
    0,    0, 1142,    0,    0,    0,    0,    0,    0, 1142,
    0,    0,    0,    0, 1142, 1142, 1142, 1142, 1142, 1142,
 1142, 1142,    0, 1142, 1142, 1142, 1142,    0, 1142, 1142,
    0,    0,    0,    0,    0,    0, 1142, 1142, 1142, 1142,
 1142, 1142, 1142, 1142, 1142, 1142, 1142, 1142, 1142,    0,
 1142,    0,    0, 1142, 1142,    0, 1142, 1142, 1142,    0,
 1142, 1142, 1142, 1142,    0,    0, 1142, 1142, 1142, 1142,
 1142, 1142, 1142,    0,    0,    0,    0, 1142, 1142, 1142,
    0, 1142, 1142, 1142,    0, 1142,    0, 1142, 1142, 1142,
    0, 1142, 1142,    0, 1142, 1142, 1142, 1142, 1142, 1142,
 1142, 1142, 1142, 1142, 1142, 1142, 1142, 1142, 1142, 1142,
 1142, 1142, 1142, 1142, 1142, 1142,    0, 1142, 1142, 1142,
 1142, 1142, 1142,    0, 1142, 1142, 1142, 1142,    0, 1142,
    0, 1142, 1142, 1142, 1142, 1142, 1142, 1142, 1142, 1142,
 1142, 1142, 1142, 1142, 1142, 1142, 1142, 1142, 1142,    0,
 1142, 1142, 1142, 1142,    0, 1142, 1142, 1142, 1142, 1142,
    0, 1142, 1142, 1142, 1142, 1142, 1142, 1142, 1142, 1142,
 1142, 1142, 1142, 1142,    0, 1142, 1142, 1142, 1142, 1142,
 1142,    0, 1142, 1142, 1142, 1142, 1142, 1142, 1142, 1142,
    0, 1142, 1142, 1142, 1142,    0, 1142, 1142, 1142, 1142,
 1142, 1142,    0,    0, 1142, 1142, 1142, 1142, 1142, 1142,
 1142, 1142, 1142, 1142,    0, 1142, 1142, 1142, 1142, 1142,
 1142, 1142, 1142, 1142, 1142, 1142,    0,    0, 1142, 1142,
 1142, 1142, 1142, 1142, 1142, 1142, 1142, 1142, 1142, 1142,
 1142, 1142, 1142, 1142, 1738,    0, 1738, 1738,    0, 1738,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1738,    0,    0,    0,    0, 1738,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1738,    0, 1738,    0,    0,    0,    0,    0, 1738,
    0, 1738, 1738, 1738,    0,    0,    0,    0, 1738,    0,
    0,    0,    0, 1738, 1738,    0, 1738,    0, 1738, 1738,
    0, 1738,    0,    0, 1738, 1738, 1738,    0,    0,    0,
    0, 1738,    0, 1738, 1738,    0,    0,    0, 1738,    0,
 1738,    0, 1738, 1738,    0,    0,    0,    0,    0,    0,
    0, 1738,    0, 1738, 1738,    0,    0,    0, 1738,    0,
 1738,    0, 1738,    0,    0,    0,    0,    0, 1738,    0,
 1738,    0,    0,    0, 1738,    0,    0,    0, 1738,    0,
 1738, 1738, 1738, 1738,    0, 1738,    0, 1738, 1738,    0,
 1738, 1738, 1738,    0,    0,    0,    0,    0, 1738,    0,
    0,    0,    0,    0, 1738,    0,    0,    0, 1738, 1738,
 1738, 1738, 1738,    0, 1738,    0, 1738,    0,    0,    0,
 1738,    0, 1738, 1738,    0,    0, 1738, 1738,    0,    0,
    0, 1738,    0, 1738,    0,    0, 1738, 1738, 1738, 1738,
    0, 1738,    0, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
 1738,    0,    0,    0, 1738,    0, 1738,    0,    0,    0,
 1738,    0,    0,    0,    0,    0,    0, 1738,    0,    0,
    0,    0, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
    0, 1738, 1738, 1738, 1738,    0, 1738, 1738,    0,    0,
    0,    0,    0,    0, 1738, 1738, 1738, 1738, 1738, 1738,
 1738, 1738, 1738, 1738, 1738, 1738, 1738,    0, 1738, 1738,
 1738, 1738, 1738,    0, 1738, 1738, 1738,    0, 1738, 1738,
 1738, 1738,    0,    0, 1738, 1738, 1738, 1738, 1738, 1738,
 1738,    0,    0,    0,    0, 1738, 1738, 1738,    0, 1738,
 1738, 1738,    0, 1738,    0, 1738, 1738, 1738,    0, 1738,
 1738,    0, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
 1738, 1738, 1738, 1738,    0, 1738, 1738, 1738, 1738, 1738,
 1738,    0, 1738, 1738, 1738, 1738,    0, 1738,    0, 1738,
 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
 1738, 1738, 1738, 1738, 1738, 1738, 1738,    0, 1738, 1738,
 1738, 1738,    0, 1738, 1738, 1738, 1738, 1738,    0, 1738,
 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
 1738, 1738,    0, 1738, 1738, 1738, 1738, 1738, 1738,    0,
 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,    0, 1738,
 1738, 1738, 1738,    0, 1738, 1738, 1738, 1738, 1738, 1738,
    0,    0, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
 1738, 1738,    0, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
 1738, 1738, 1738, 1738,    0,    0, 1738, 1738, 1738, 1738,
 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
 1738, 1738,  877,    0,    0,  875,    0,  876,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  878,    0,    0,    0,    0,  879,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  138,
    0,  139,    0,    0,    0,    0,    0,  140,    0,  740,
  141,  142,    0,    0,    0,    0,  741,    0,    0,    0,
    0,  143,  144,    0,  145,    0,  146,  742,    0,  147,
    0,    0,  148,  743,  744,    0,    0,    0,    0,  149,
    0,  150,  151,    0,    0,    0,  152,    0,  153,    0,
  745,  154,    0,    0,    0,    0,    0,    0,    0,  746,
    0,  155,  747,    0,    0,    0,  157,    0,  158,    0,
  159,    0,    0,    0,    0,    0,  160,    0,  161,    0,
    0,    0,  162,    0,    0,    0,  748,    0,  749,  750,
  163,  751,    0,  164,    0,  165,  752,    0,  753,  166,
  167,    0,    0,    0,    0,    0,  754,    0,    0,    0,
    0,    0,  168,    0,    0,    0,  170,  171,  172,  173,
  174,    0,  175,    0,  755,    0,    0,    0,  176,    0,
  177,  178,    0,    0,  179,  180,    0,    0,    0,  756,
    0,  181,    0,    0,  182,  183,  757,  185,    0,  186,
    0,  187,  758,  188,  189,  190,  191,  192,  759,    0,
    0,    0,  193,    0,  194,    0,    0,    0,  760,    0,
    0,    0,    0,    0,    0,  195,    0,    0,    0,    0,
  196,  197,  761,  762,  763,  506,  507,  199,    0,  200,
  201,  202,  203,    0,  204,  764,    0,    0,    0,    0,
    0,    0,  205,  206,  765,  766,  767,  768,  769,  770,
  771,  772,  773,  207,  774,    0,  209,  210,  211,  775,
  776,    0,  777,  778,  779,    0,  214,  215,  780,  216,
    0,    0,  217,  218,  781,  782,  783,  219,  220,    0,
    0,    0,    0,  221,  784,  223,    0,  785,  225,  226,
    0,  227,    0,  786,  787,  788,    0,  789,  790,    0,
  791,  228,  229,  230,  231,  232,  233,  792,  235,  793,
  237,  794,  795,  796,  797,  798,  799,  800,  801,  802,
  803,  804,    0,  805,  806,  807,  808,  809,  810,    0,
  811,  812,  813,  258,    0,  814,    0,  815,  816,  817,
  818,  819,  265,  266,  820,  268,  821,  822,  823,  272,
  824,  274,  825,  276,  826,    0,  827,  828,  829,  830,
    0,  831,  832,  833,  285,  834,    0,  835,  836,  289,
  837,  291,  292,  838,  294,  295,  296,  297,  298,  299,
    0,  839,  301,  302,  303,  304,  305,    0,  840,  307,
  308,  309,  310,  311,  312,  313,    0,  314,  315,  841,
  842,    0,  318,  319,  320,  843,  844,  845,    0,    0,
  324,  846,  847,  848,  849,  850,  851,  852,  853,  854,
    0,  855,  856,  857,  333,  858,  334,  335,  336,  337,
  338,  339,    0,    0,  859,  860,  861,  862,  863,  864,
  865,  866,  867,  868,  869,  870,  871,  872,  873,  874,
 1138,    0,    0,  875,    0,  876,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  878,    0,
    0,    0,    0,  879,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  138,    0,  139,
    0,    0,    0,    0,    0,  140,    0,  740,  141,  142,
    0,    0,    0,    0,  741,    0,    0,    0,    0,  143,
  144,    0,  145,    0,  146,  742,    0,  147,    0,    0,
  148,  743,  744,    0,    0,    0,    0,  149,    0,  150,
  151,    0,    0,    0,  152,    0,  153,    0,  745,  154,
    0,    0,    0,    0,    0,    0,    0,  746,    0,  155,
  747,    0,    0,    0,  157,    0,  158,    0,  159,    0,
    0,    0,    0,    0,  160,    0,  161,    0,    0,    0,
  162,    0,    0,    0,  748,    0,  749,  750,  163,  751,
    0,  164,    0,  165,  752,    0,  753,  166,  167,    0,
    0,    0,    0,    0,  754,    0,    0,    0,    0,    0,
  168,    0,    0,    0,  170,  171,  172,  173,  174,    0,
  175,    0,  755,    0,    0,    0,  176,    0,  177,  178,
    0,    0,  179,  180,    0,    0,    0,  756,    0,  181,
    0,    0,  182,  183,  757,  185,    0,  186,    0,  187,
  758,  188,  189,  190,  191,  192,  759,    0,    0,    0,
  193,    0,  194,    0,    0,    0,  760,    0,    0,    0,
    0,    0,    0,  195,    0,    0,    0,    0,  196,  197,
  761,  762,  763,  506,  507,  199,    0,  200,  201,  202,
  203,    0,  204,  764,    0,    0,    0,    0,    0,    0,
  205,  206,  765,  766,  767,  768,  769,  770,  771,  772,
  773,  207,  774,    0,  209,  210,  211,  775,  776,    0,
  777,  778,  779,    0,  214,  215,  780,  216,    0,    0,
  217,  218,  781,  782,  783,  219,  220,    0,    0,    0,
    0,  221,  784,  223,    0,  785,  225,  226,    0,  227,
    0,  786,  787,  788,    0,  789,  790,    0,  791,  228,
  229,  230,  231,  232,  233,  792,  235,  793,  237,  794,
  795,  796,  797,  798,  799,  800,  801,  802,  803,  804,
    0,  805,  806,  807,  808,  809,  810,    0,  811,  812,
  813,  258,    0,  814,    0,  815,  816,  817,  818,  819,
  265,  266,  820,  268,  821,  822,  823,  272,  824,  274,
  825,  276,  826,    0,  827,  828,  829,  830,    0,  831,
  832,  833,  285,  834,    0,  835,  836,  289,  837,  291,
  292,  838,  294,  295,  296,  297,  298,  299,    0,  839,
  301,  302,  303,  304,  305,    0,  840,  307,  308,  309,
  310,  311,  312,  313,    0,  314,  315,  841,  842,    0,
  318,  319,  320,  843,  844,  845,    0,    0,  324,  846,
  847,  848,  849,  850,  851,  852,  853,  854,    0,  855,
  856,  857,  333,  858,  334,  335,  336,  337,  338,  339,
    0,    0,  859,  860,  861,  862,  863,  864,  865,  866,
  867,  868,  869,  870,  871,  872,  873,  874, 2305,    0,
    0,  875,    0,  876,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  878,    0,    0,    0,
    0,  879,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  138,    0,  139,    0,    0,
    0,    0,    0,  140,    0,  740,  141,  142,    0,    0,
    0,    0,  741,    0,    0,    0,    0,  143,  144,    0,
  145,    0,  146,  742,    0,  147,    0,    0,  148,  743,
  744,    0,    0,    0,    0,  149,    0,  150,  151,    0,
    0,    0,  152,    0,  153,    0,  745,  154,    0,    0,
    0,    0,    0,    0,    0,  746,    0,  155,  747,    0,
    0,    0,  157,    0,  158,    0,  159,    0,    0,    0,
    0,    0,  160,    0,  161,    0,    0,    0,  162,    0,
    0,    0,  748,    0,  749,  750,  163,  751,    0,  164,
    0,  165,  752,    0,  753,  166,  167,    0,    0,    0,
    0,    0,  754,    0,    0,    0,    0,    0,  168,    0,
    0,    0,  170,  171,  172,  173,  174,    0,  175,    0,
  755,    0,    0,    0,  176,    0,  177,  178,    0,    0,
  179,  180,    0,    0,    0,  756,    0,  181,    0,    0,
  182,  183,  757,  185,    0,  186,    0,  187,  758,  188,
  189,  190,  191,  192,  759,    0,    0,    0,  193,    0,
  194,    0,    0,    0,  760,    0,    0,    0,    0,    0,
    0,  195,    0,    0,    0,    0,  196,  197,  761,  762,
  763,  506,  507,  199,    0,  200,  201,  202,  203,    0,
  204,  764,    0,    0,    0,    0,    0,    0,  205,  206,
  765,  766,  767,  768,  769,  770,  771,  772,  773,  207,
  774,    0,  209,  210,  211,  775,  776,    0,  777,  778,
  779,    0,  214,  215,  780,  216,    0,    0,  217,  218,
  781,  782,  783,  219,  220,    0,    0,    0,    0,  221,
  784,  223,    0,  785,  225,  226,    0,  227,    0,  786,
  787,  788,    0,  789,  790,    0,  791,  228,  229,  230,
  231,  232,  233,  792,  235,  793,  237,  794,  795,  796,
  797,  798,  799,  800,  801,  802,  803,  804,    0,  805,
  806,  807,  808,  809,  810,    0,  811,  812,  813,  258,
    0,  814,    0,  815,  816,  817,  818,  819,  265,  266,
  820,  268,  821,  822,  823,  272,  824,  274,  825,  276,
  826,    0,  827,  828,  829,  830,    0,  831,  832,  833,
  285,  834,    0,  835,  836,  289,  837,  291,  292,  838,
  294,  295,  296,  297,  298,  299,    0,  839,  301,  302,
  303,  304,  305,    0,  840,  307,  308,  309,  310,  311,
  312,  313,    0,  314,  315,  841,  842,    0,  318,  319,
  320,  843,  844,  845,    0,    0,  324,  846,  847,  848,
  849,  850,  851,  852,  853,  854,    0,  855,  856,  857,
  333,  858,  334,  335,  336,  337,  338,  339,    0,    0,
  859,  860,  861,  862,  863,  864,  865,  866,  867,  868,
  869,  870,  871,  872,  873,  874, 2928,    0,    0,  875,
    0,  876,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  878,    0,    0,    0,    0,  879,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  138,    0,  139,    0,    0,    0,    0,
    0,  140,    0,  740,  141,  142,    0,    0,    0,    0,
  741,    0,    0,    0,    0,  143,  144,    0,  145,    0,
  146,  742,    0,  147,    0,    0,  148,  743,  744,    0,
    0,    0,    0,  149,    0,  150,  151,    0,    0,    0,
  152,    0,  153,    0,  745,  154,    0,    0,    0,    0,
    0,    0,    0,  746,    0,  155,  747,    0,    0,    0,
  157,    0,  158,    0,  159,    0,    0,    0,    0,    0,
  160,    0,  161,    0,    0,    0,  162,    0,    0,    0,
  748,    0,  749,  750,  163,  751,    0,  164,    0,  165,
  752,    0,  753,  166,  167,    0,    0,    0,    0,    0,
  754,    0,    0,    0,    0,    0,  168,    0,    0,    0,
  170,  171,  172,  173,  174,    0,  175,    0,  755,    0,
    0,    0,  176,    0,  177,  178,    0,    0,  179,  180,
    0,    0,    0,  756,    0,  181,    0,    0,  182,  183,
  757,  185,    0,  186,    0,  187,  758,  188,  189,  190,
  191,  192,  759,    0,    0,    0,  193,    0,  194,    0,
    0,    0,  760,    0,    0,    0,    0,    0,    0,  195,
    0,    0,    0,    0,  196,  197,  761,  762,  763,  506,
  507,  199,    0,  200,  201,  202,  203,    0,  204,  764,
    0,    0,    0,    0,    0,    0,  205,  206,  765,  766,
  767,  768,  769,  770,  771,  772,  773,  207,  774,    0,
  209,  210,  211,  775,  776,    0,  777,  778,  779,    0,
  214,  215,  780,  216,    0,    0,  217,  218,  781,  782,
  783,  219,  220,    0,    0,    0,    0,  221,  784,  223,
    0,  785,  225,  226,    0,  227,    0,  786,  787,  788,
    0,  789,  790,    0,  791,  228,  229,  230,  231,  232,
  233,  792,  235,  793,  237,  794,  795,  796,  797,  798,
  799,  800,  801,  802,  803,  804,    0,  805,  806,  807,
  808,  809,  810,    0,  811,  812,  813,  258,    0,  814,
    0,  815,  816,  817,  818,  819,  265,  266,  820,  268,
  821,  822,  823,  272,  824,  274,  825,  276,  826,    0,
  827,  828,  829,  830,    0,  831,  832,  833,  285,  834,
    0,  835,  836,  289,  837,  291,  292,  838,  294,  295,
  296,  297,  298,  299,    0,  839,  301,  302,  303,  304,
  305,    0,  840,  307,  308,  309,  310,  311,  312,  313,
    0,  314,  315,  841,  842,    0,  318,  319,  320,  843,
  844,  845,    0,    0,  324,  846,  847,  848,  849,  850,
  851,  852,  853,  854,    0,  855,  856,  857,  333,  858,
  334,  335,  336,  337,  338,  339,    0,    0,  859,  860,
  861,  862,  863,  864,  865,  866,  867,  868,  869,  870,
  871,  872,  873,  874, 1138,    0,    0,  875,    0,  876,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  878,    0,    0,    0,    0,  879,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  138,    0,  139,    0,    0,    0,    0,    0,  140,
    0,  740,  141,  142,    0,    0,    0,    0,  741,    0,
    0,    0,    0,  143,  144,    0,  145,    0,  146,  742,
    0,  147,    0,    0,  148,  743,  744,    0,    0,    0,
    0,  149,    0,  150,  151,    0,    0,    0,  152,    0,
  153,    0,  745,  154,    0,    0,    0,    0,    0,    0,
    0,  746,    0,  155,  747,    0,    0,    0,  157,    0,
  158,    0,  159,    0,    0,    0,    0,    0,  160,    0,
  161,    0,    0,    0,  162,    0,    0,    0,  748,    0,
  749,  750,  163,  751,    0,  164,    0,  165,  752,    0,
  753,  166,  167,    0,    0,    0,    0,    0,  754,    0,
    0,    0,    0,    0,  168,    0,    0,    0,  170,  171,
  172,  173,  174,    0,  175,    0,  755,    0,    0,    0,
  176,    0,  177,  178,    0,    0,  179,  180,    0,    0,
    0,  756,    0,  181,    0,    0,  182,  183,  757,  185,
    0,  186,    0,  187,  758,  188,  189,  190,  191,  192,
  759,    0,    0,    0,  193,    0,  194,    0,    0,    0,
  760,    0,    0,    0,    0,    0,    0,  195,    0,    0,
    0,    0,  196,  197,  761,  762,  763,  506,  507,  199,
    0,  200,  201,  202,  203,    0,  204,  764,    0,    0,
    0,    0,    0,    0,  205,  206,  765,  766,  767,  768,
  769,  770,  771,  772,  773,  207,  774,    0,  209,  210,
  211,  775,  776,    0,  777,  778,  779,    0,  214,  215,
  780,  216,    0,    0,  217,  218,  781,  782,  783,  219,
  220,    0,    0,    0,    0,  221,  784,  223,    0,  785,
  225,  226,    0,  227,    0,  786,  787,  788,    0,  789,
  790,    0,  791,  228,  229,  230,  231,  232,  233,  792,
  235,  793,  237,  794,  795,  796,  797,  798,  799,  800,
  801,  802,  803,  804,    0,  805,  806,  807,  808,  809,
  810,    0,  811,  812,  813,  258,    0,  814,    0,  815,
  816,  817,  818,  819,  265,  266,  820,  268,  821,  822,
  823,  272,  824,  274,  825,  276,  826,    0,  827,  828,
  829,  830,    0,  831,  832,  833,  285,  834,    0,  835,
  836,  289,  837,  291,  292,  838,  294,  295,  296,  297,
  298,  299,    0,  839,  301,  302, 3365,  304,  305,    0,
  840,  307,  308,  309,  310,  311,  312,  313,    0,  314,
  315,  841,  842,    0,  318,  319,  320,  843,  844,  845,
    0,    0,  324,  846,  847,  848,  849,  850,  851,  852,
  853,  854,    0,  855,  856,  857,  333,  858,  334,  335,
  336,  337,  338,  339,    0,    0,  859,  860,  861,  862,
  863,  864,  865,  866,  867,  868,  869,  870,  871,  872,
  873,  874, 1738,    0,    0, 1738,    0, 1738,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1738,    0,    0,    0,    0, 1738,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1738,
    0, 1738,    0,    0,    0,    0,    0, 1738,    0, 1738,
 1738, 1738,    0,    0,    0,    0, 1738,    0,    0,    0,
    0, 1738, 1738,    0, 1738,    0, 1738, 1738,    0, 1738,
    0,    0, 1738, 1738, 1738,    0,    0,    0,    0, 1738,
    0, 1738, 1738,    0,    0,    0, 1738,    0, 1738,    0,
 1738, 1738,    0,    0,    0,    0,    0,    0,    0, 1738,
    0, 1738, 1738,    0,    0,    0, 1738,    0, 1738,    0,
 1738,    0,    0,    0,    0,    0, 1738,    0, 1738,    0,
    0,    0, 1738,    0,    0,    0, 1738,    0, 1738, 1738,
 1738, 1738,    0, 1738,    0, 1738, 1738,    0, 1738, 1738,
 1738,    0,    0,    0,    0,    0, 1738,    0,    0,    0,
    0,    0, 1738,    0,    0,    0, 1738, 1738, 1738, 1738,
 1738,    0, 1738,    0, 1738,    0,    0,    0, 1738,    0,
 1738, 1738,    0,    0, 1738, 1738,    0,    0,    0, 1738,
    0, 1738,    0,    0, 1738, 1738, 1738, 1738,    0, 1738,
    0, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,    0,
    0,    0, 1738,    0, 1738,    0,    0,    0, 1738,    0,
    0,    0,    0,    0,    0, 1738,    0,    0,    0,    0,
 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,    0, 1738,
 1738, 1738, 1738,    0, 1738, 1738,    0,    0,    0,    0,
    0,    0, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
 1738, 1738, 1738, 1738, 1738,    0, 1738, 1738, 1738, 1738,
 1738,    0, 1738, 1738, 1738,    0, 1738, 1738, 1738, 1738,
    0,    0, 1738, 1738, 1738, 1738, 1738, 1738, 1738,    0,
    0,    0,    0, 1738, 1738, 1738,    0, 1738, 1738, 1738,
    0, 1738,    0, 1738, 1738, 1738,    0, 1738, 1738,    0,
 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
 1738, 1738,    0, 1738, 1738, 1738, 1738, 1738, 1738,    0,
 1738, 1738, 1738, 1738,    0, 1738,    0, 1738, 1738, 1738,
 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
 1738, 1738, 1738, 1738, 1738,    0, 1738, 1738, 1738, 1738,
    0, 1738, 1738, 1738, 1738, 1738,    0, 1738, 1738, 1738,
 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
    0, 1738, 1738, 1738, 1738, 1738, 1738,    0, 1738, 1738,
 1738, 1738, 1738, 1738, 1738, 1738,    0, 1738, 1738, 1738,
 1738,    0, 1738, 1738, 1738, 1738, 1738, 1738,    0,    0,
 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
    0, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
 1738, 1738,    0,    0, 1738, 1738, 1738, 1738, 1738, 1738,
 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738, 1738,
 1377,    0,    0, 1377,    0, 1377,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1377,    0,
    0,    0,    0, 1377,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1377,    0, 1377,
    0,    0,    0,    0,    0, 1377,    0, 1377, 1377, 1377,
    0,    0,    0,    0, 1377,    0,    0,    0,    0, 1377,
 1377,    0, 1377,    0, 1377, 1377,    0, 1377,    0,    0,
 1377, 1377, 1377,    0,    0,    0,    0, 1377,    0, 1377,
 1377,    0,    0,    0, 1377,    0, 1377,    0, 1377, 1377,
    0,    0,    0,    0,    0,    0,    0, 1377,    0, 1377,
 1377,    0,    0,    0, 1377,    0, 1377,    0, 1377,    0,
    0,    0,    0,    0, 1377,    0, 1377,    0,    0,    0,
 1377,    0,    0,    0, 1377,    0, 1377, 1377, 1377, 1377,
    0, 1377,    0, 1377, 1377,    0, 1377, 1377, 1377,    0,
    0,    0,    0,    0, 1377,    0,    0,    0,    0,    0,
 1377,    0,    0,    0, 1377, 1377, 1377, 1377, 1377,    0,
 1377,    0, 1377,    0,    0,    0, 1377,    0, 1377, 1377,
    0,    0, 1377, 1377,    0,    0,    0, 1377,    0, 1377,
    0,    0, 1377, 1377, 1377, 1377,    0, 1377,    0, 1377,
 1377, 1377, 1377, 1377, 1377, 1377, 1377,    0,    0,    0,
 1377,    0, 1377,    0,    0,    0, 1377,    0,    0,    0,
    0,    0,    0, 1377,    0,    0,    0,    0, 1377, 1377,
 1377, 1377, 1377, 1377, 1377, 1377,    0, 1377, 1377, 1377,
 1377,    0, 1377, 1377,    0,    0,    0,    0,    0,    0,
 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377,
 1377, 1377, 1377,    0, 1377, 1377, 1377, 1377, 1377,    0,
 1377, 1377, 1377,    0, 1377, 1377, 1377, 1377,    0,    0,
 1377, 1377, 1377, 1377, 1377, 1377, 1377,    0,    0,    0,
    0, 1377, 1377, 1377,    0, 1377, 1377, 1377,    0, 1377,
    0, 1377, 1377, 1377,    0, 1377, 1377,    0, 1377, 1377,
 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377,
 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377,
    0, 1377, 1377, 1377, 1377, 1377, 1377,    0, 1377, 1377,
 1377, 1377,    0, 1377,    0, 1377, 1377, 1377, 1377, 1377,
 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377,
 1377, 1377, 1377,    0, 1377, 1377, 1377, 1377,    0, 1377,
 1377, 1377, 1377, 1377,    0, 1377, 1377, 1377, 1377, 1377,
 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377,    0, 1377,
 1377, 1377, 1377, 1377, 1377,    0, 1377, 1377, 1377, 1377,
 1377, 1377, 1377, 1377,    0, 1377, 1377, 1377, 1377,    0,
 1377, 1377, 1377, 1377, 1377, 1377,    0,    0, 1377, 1377,
 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377,    0, 1377,
 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377,
    0,    0, 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377,
 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1377, 1212,    0,
    0,  875,    0,  876,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  878,    0,    0,    0,
    0,  879,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  138,    0,  139,    0,    0,
    0,    0,    0,  140,    0,  740,  141,  142,    0,    0,
    0,    0,  741,    0,    0,    0,    0,  143,  144,    0,
  145,    0,  146,  742,    0,  147,    0,    0,  148,  743,
  744,    0,    0,    0,    0,  149,    0,  150,  151,    0,
    0,    0,  152,    0,  153,    0,    0,  154,    0,    0,
    0,    0,    0,    0,    0,  746,    0,  155,  747,    0,
    0,    0,  157,    0,  158,    0,  159,    0,    0,    0,
    0,    0,  160,    0,  161,    0,    0,    0,  162,    0,
    0,    0,  748,    0,  749,  750,  163,  751,    0,  164,
    0,  165,  752,    0,  753,  166,  167,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  168,    0,
    0,    0,  170,  171,  172,  173,  174,    0,  175,    0,
  755,    0,    0,    0,  176,    0,  177,  178,    0,    0,
  179,  180,    0,    0,    0,  756,    0,  181,    0,    0,
  182,  183,  184,  185,    0,  186,    0,  187,  758,  188,
  189,  190,  191,  192,  759,    0,    0,    0,  193,    0,
  194,    0,    0,    0,  760,    0,    0,    0,    0,    0,
    0,  195,    0,    0,    0,   15,  196,  197,  761,  762,
  763,  506,  507,  199,    0,  200,  201,  202,  203,    0,
  204,  764,    0,    0,    0,    0,    0,    0,  205,  206,
  765,  766,  767,  768,  769,  770,  771,  772,  773,  207,
  774,    0,  209,  210,  211,  775,  776,    0,  777,  778,
  779,    0,  214,  215,  780,  216,    0,    0,  217,  218,
    0,    0,    0,  219,  220,    0,    0,    0,    0,  221,
  784,  223,    0,  785,  225,  226,    0,  227,    0,  786,
  787,  788,    0,  789,  790,    0,  791,  228,  229,  230,
  231,  232,  233,  792,  235,  793,  237,  794,  795,  796,
  797,  798,  799,  800,  801,  802,  803,  804,    0,  805,
  806,  807,  808,  809,  810,    0,  811,  812,  813,  258,
    0,  814,    0,  815,  816,  817,  818,  819,  265,  266,
  820,  268,  821,  822,  823,  272,  824,  274,  825,  276,
  826,    0,  827,  828,  829,  830,    0,  831,  832,  833,
  285,  834,    0,  835,  836,  289,  837,  291,  292,  838,
  294,  295,  296,  297,  298,  299,    0,  839,  301,  302,
  303,  304,  305,    0,  840,  307,  308,  309,  310,  311,
  312,  313,    0,  314,  315,  841,  842,    0,  318,  319,
  320,  843,  844,  845,    0,    0,  324,  846,  847,  848,
  849,  850,  851,  852,  853,  854,    0,  855,  856,  857,
  333,  858,  334,  335,  336,  337,  338,  339,    0,    0,
  859,  860,  861,  862,  863,  864,  865,  866,  867,  868,
  869,  870,  871,  872,  873,  874, 1212,    0,    0,  875,
    0,  876,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  878,    0,    0,    0,    0,  879,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  138,    0,  139,    0,    0,    0,    0,
    0,  140,    0,  740,  141,  142,    0,    0,    0,    0,
  741,    0,    0,    0,    0,  143,  144,    0,  145,    0,
  146,  742,    0,  147,    0,    0,  148,  743,  744,    0,
    0,    0,    0,  149,    0,  150,  151,    0,    0,    0,
  152,    0,  153,    0,    0,  154,    0,    0,    0,    0,
    0,    0,    0,  746,    0,  155,  747,    0,    0,    0,
  157,    0,  158,    0,  159,    0,    0,    0,    0,    0,
  160,    0,  161,    0,    0,    0,  162,    0,    0,    0,
  748,    0,  749,  750,  163,  751,    0,  164,    0,  165,
  752,    0,  753,  166,  167,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  168,    0,    0,    0,
  170,  171,  172,  173,  174,    0,  175,    0,  755,    0,
    0,    0,  176,    0,  177,  178,    0,    0,  179,  180,
    0,    0,    0,  756,    0,  181,    0,    0,  182,  183,
  184,  185,    0,  186,    0,  187,  758,  188,  189,  190,
  191,  192,  759,    0,    0,    0,  193,    0,  194,    0,
    0,    0,  760,    0,    0,    0,    0,    0,    0,  195,
    0,    0,    0,    0,  196,  197,  761,  762,  763,  506,
  507,  199,    0,  200,  201,  202,  203,    0,  204,  764,
    0,    0,    0,    0,    0,    0,  205,  206,  765,  766,
  767,  768,  769,  770,  771,  772,  773,  207,  774,    0,
  209,  210,  211,  775,  776,    0,  777,  778,  779,    0,
  214,  215,  780,  216,    0,    0,  217,  218,    0,    0,
    0,  219,  220,    0,    0,    0,    0,  221,  784,  223,
    0,  785,  225,  226,    0,  227,    0,  786,  787,  788,
    0,  789,  790,    0,  791,  228,  229,  230,  231,  232,
  233,  792,  235,  793,  237,  794,  795,  796,  797,  798,
  799,  800,  801,  802,  803,  804,    0,  805,  806,  807,
  808,  809,  810,    0,  811,  812,  813,  258,    0,  814,
    0,  815,  816,  817,  818,  819,  265,  266,  820,  268,
  821,  822,  823,  272,  824,  274,  825,  276,  826,    0,
  827,  828,  829,  830,    0,  831,  832,  833,  285,  834,
    0,  835,  836,  289,  837,  291,  292,  838,  294,  295,
  296,  297,  298,  299,    0,  839,  301,  302,  303,  304,
  305,    0,  840,  307,  308,  309,  310,  311,  312,  313,
    0,  314,  315,  841,  842,    0,  318,  319,  320,  843,
  844,  845,    0,    0,  324,  846,  847,  848,  849,  850,
  851,  852,  853,  854,    0,  855,  856,  857,  333,  858,
  334,  335,  336,  337,  338,  339,    0,    0,  859,  860,
  861,  862,  863,  864,  865,  866,  867,  868,  869,  870,
  871,  872,  873,  874, 1573,    0,    0,  875,    0,  876,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  878,    0,    0,    0,    0,  879,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  138,    0,  139,    0,    0,    0,    0,    0,  140,
    0,  740,  141,  142,    0,    0,    0,    0,  741,    0,
    0,    0,    0,  143,  144,    0,  145,    0,  146,  742,
    0,  147,    0,    0,  148,  743,  744,    0,    0,    0,
    0,  149,    0,  150,  151,    0,    0,    0,  152,    0,
  153,    0,    0,  154,    0,    0,    0,    0,    0,    0,
    0,  746,    0,  155,  747,    0,    0,    0,  157,    0,
  158,    0,  159,    0,    0,    0,    0,    0,  160,    0,
  161,    0,    0,    0,  162,    0,    0,    0,  748,    0,
  749,  750,  163,  751,    0,  164,    0,  165,  752,    0,
  753,  166,  167,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  168,    0,    0,    0,  170,  171,
  172,  173,  174,    0,  175,    0,  755,    0,    0,    0,
  176,    0,  177,  178,    0,    0,  179,  180,    0,    0,
    0,  756,    0,  181,    0,    0,  182,  183,  184,  185,
    0,  186,    0,  187,  758,  188,  189,  190,  191,  192,
  759,    0,    0,    0,  193,    0,  194,    0,    0,    0,
  760,    0,    0,    0,    0,    0,    0,  195,    0,    0,
    0,    0,  196,  197,  761,  762,  763,  506,  507,  199,
    0,  200,  201,  202,  203, 1223,  204,  764,    0,    0,
    0,    0,    0,    0,  205,  206,  765,  766,  767,  768,
  769,  770,  771,  772,  773,  207,  774,    0,  209,  210,
  211,  775,  776,    0,  777,  778,  779,    0,  214,  215,
  780,  216,    0,    0,  217,  218,    0,    0,    0,  219,
  220,    0,    0,    0,    0,  221,  784,  223,    0,  785,
  225,  226,    0,  227,    0,  786,  787,  788,    0,  789,
  790,    0,  791,  228,  229,  230,  231,  232,  233,  792,
  235,  793,  237,  794,  795,  796,  797,  798,  799,  800,
  801,  802,  803,  804,    0,  805,  806,  807,  808,  809,
  810,    0,  811,  812,  813,  258,    0,  814,    0,  815,
  816,  817,  818,  819,  265,  266,  820,  268,  821,  822,
  823,  272,  824,  274,  825,  276,  826,    0,  827,  828,
  829,  830,    0,  831,  832,  833,  285,  834,    0,  835,
  836,  289,  837,  291,  292,  838,  294,  295,  296,  297,
  298,  299,    0,  839,  301,  302,  303,  304,  305,    0,
  840,  307,  308,  309,  310,  311,  312,  313,    0,  314,
  315,  841,  842,    0,  318,  319,  320,  843,  844,  845,
    0,    0,  324,  846,  847,  848,  849,  850,  851,  852,
  853,  854,    0,  855,  856,  857,  333,  858,  334,  335,
  336,  337,  338,  339,    0,    0,  859,  860,  861,  862,
  863,  864,  865,  866,  867,  868,  869,  870,  871,  872,
  873,  874, 1929,    0, 1929,    0,    0,    0,    0,    0,
 1929,    0,    0, 1929, 1929,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1929, 1929,    0, 1929,    0, 1929,
    0,    0, 1929,    0,    0, 1929,    0,    0,    0,    0,
    0,    0, 1929,    0, 1929, 1929,    0,    0,    0, 1929,
    0, 1929,    0,    0, 1929,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1929, 1929,    0,    0,    0, 1929,
    0, 1929,    0, 1929, 1929,    0,    0,    0,    0, 1929,
    0, 1929,    0,    0,    0, 1929,    0,    0,    0,    0,
    0,    0,    0, 1929,    0,    0, 1929,    0, 1929,    0,
    0,    0, 1929, 1929,    0, 1929,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1929,    0, 1929,    0, 1929,
 1929, 1929, 1929, 1929,    0, 1929,    0,    0,    0,    0,
    0, 1929,    0, 1929, 1929,    0,    0, 1929, 1929,    0,
    0,    0,    0,    0, 1929,    0,    0, 1929, 1929, 1929,
 1929,    0, 1929,    0, 1929,    0, 1929, 1929, 1929, 1929,
 1929,    0,    0,    0,    0, 1929,    0, 1929,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1929, 1222,
    0,    0,    0, 1929, 1929,    0, 1929,    0,    0,    0,
 1929,    0, 1929, 1929, 1929, 1929,    0, 1929,    0,    0,
    0,    0,    0,    0,    0, 1929, 1929,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1929, 1929,    0, 1929,
 1929, 1929,    0,    0,    0,    0, 1929, 1929,    0, 1929,
 1929,    0, 1929,    0,    0, 1929, 1929,    0,    0,    0,
 1929, 1929,    0,    0,    0,    0, 1929, 1929, 1929,    0,
 1929, 1929, 1929,    0, 1929,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1929, 1929, 1929, 1929, 1929, 1929,
 1929, 1929, 1929, 1929, 1929, 1929, 1929, 1929, 1929, 1929,
 1929, 1929, 1929, 1929, 1929,    0, 1929, 1929, 1929, 1929,
 1929, 1929,    0, 1929, 1929, 1929, 1929,    0, 1929,    0,
 1929, 1929, 1929, 1929, 1929, 1929, 1929, 1929, 1929, 1929,
 1929, 1929, 1929, 1929, 1929, 1929, 1929, 1929,    0, 1929,
 1929, 1929, 1929,    0, 1929, 1929, 1929, 1929, 1929,    0,
 1929, 1929, 1929, 1929, 1929, 1929, 1929, 1929, 1929, 1929,
 1929, 1929, 1929,    0, 1929, 1929, 1929, 1929, 1929, 1929,
    0, 1929, 1929, 1929, 1929, 1929, 1929, 1929, 1929,    0,
 1929, 1929, 1929, 1929,    0, 1929, 1929, 1929, 1929, 1929,
 1929,    0,    0, 1929, 1929, 1929, 1929, 1929, 1929, 1929,
 1929, 1929,    0,    0,    0,    0,    0, 1929,    0, 1929,
 1929, 1929, 1929, 1929, 1929,    0, 1833,    0, 1833,    0,
    0,    0,    0,    0, 1833,    0,    0, 1833, 1833,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1833, 1833,
    0, 1833,    0, 1833,    0,    0, 1833,    0,    0, 1833,
    0,    0,    0,    0,    0,    0, 1833,    0, 1833, 1833,
    0,    0,    0, 1833,    0, 1833,    0,    0, 1833,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1833, 1833,
    0,    0,    0, 1833,    0, 1833,    0, 1833, 1833,    0,
    0,    0,    0, 1833,    0, 1833,    0,    0,    0, 1833,
    0,    0,    0,    0,    0,    0,    0, 1833,    0,    0,
 1833,    0, 1833,    0,    0,    0, 1833, 1833,    0, 1833,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1833,
    0, 1833,    0, 1833, 1833, 1833, 1833, 1833,    0, 1833,
    0,    0,    0,    0,    0, 1833,    0, 1833, 1833,    0,
    0, 1833, 1833,    0,    0,    0,    0,    0, 1833,    0,
    0, 1833, 1833, 1833, 1833,    0, 1833,    0, 1833,    0,
 1833, 1833, 1833, 1833, 1833,    0,    0,    0,    0, 1833,
    0, 1833,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1833,    0, 1566,    0,    0, 1833, 1833,    0,
 1833,    0,    0,    0, 1833,    0, 1833, 1833, 1833, 1833,
    0, 1833,  878,    0,    0,    0,    0,    0,    0, 1833,
 1833,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1833, 1833,    0, 1833, 1833, 1833,    0,    0,    0,    0,
 1833, 1833,    0, 1833, 1833,    0, 1833,    0,    0, 1833,
 1833,    0,    0,    0, 1833, 1833,    0,    0,    0,    0,
 1833, 1833, 1833,    0, 1833, 1833, 1833,    0, 1833,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1833, 1833,
 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833,    0,
 1833, 1833, 1833, 1833, 1833, 1833,    0, 1833, 1833, 1833,
 1833,    0, 1833,    0, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1833,    0, 1833, 1833, 1833, 1833,    0, 1833, 1833,
 1833, 1833, 1833,    0, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1833, 1833, 1833, 1833, 1833, 1833,    0, 1833, 1833,
 1833, 1833, 1833, 1833,    0, 1833, 1833, 1833, 1833, 1833,
 1833, 1833, 1833,    0, 1833, 1833, 1833, 1833,    0, 1833,
 1833, 1833, 1833, 1833, 1833,    0,    0, 1833, 1833, 1833,
 1833, 1833, 1833, 1833, 1833, 1833,    0,    0,    0,    0,
    0, 1833,    0, 1833, 1833, 1833, 1833, 1833, 1833,    0,
    0,  138,    0,  139,    0,    0,    0,    0,    0,  140,
    0,    0,  141,  142,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  143,  144,    0,  145,    0,  146,    0,
    0,  147,    0,    0,  148,    0,    0,    0,    0,    0,
    0,  149,    0,  150,  151,    0,    0,    0,  152,    0,
  153,    0,    0,  154,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  155,  156,    0,    0,    0,  157,    0,
  158,    0,  159,    0,    0,    0,    0,    0,  160,    0,
  161,    0,    0,    0,  162,    0,    0,    0,    0,    0,
    0,    0,  163,    0,    0,  164,    0,  165,    0,    0,
    0,  166,  167,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  168,    0,    0,    0,  170,  171,
  172,  173,  174,    0,  175,    0,    0,    0,    0,    0,
  176,    0,  177,  178,    0,    0,  179,  180,    0,    0,
    0,    0,    0,  181,    0,    0,  182,  183,  184,  185,
    0,  186,    0,  187,    0,  188,  189,  190,  191,  192,
    0,    0,    0,    0,  193,    0,  194,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  195, 1273,    0,
    0,    0,  196,  197,    0,  198,    0,    0,    0,  199,
    0,  200,  201,  202,  203,    0,  204,    0,    0,    0,
    0,    0,    0,    0,  205,  206,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  207,  208,    0,  209,  210,
  211,    0,    0,    0,    0,  212,  213,    0,  214,  215,
    0,  216,    0,    0,  217,  218,    0,    0,    0,  219,
  220,    0,    0,    0,    0,  221,  222,  223,    0,  224,
  225,  226,    0,  227,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  228,  229,  230,  231,  232,  233,  234,
  235,  236,  237,  238,  239,  240,  241,  242,  243,  244,
  245,  246,  247,  248,    0,  249,  250,  251,  252,  253,
  254,    0,  255,  256,  257,  258,    0,  259,    0,  260,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,    0,  278,  279,
  280,  281,    0,  282,  283,  284,  285,  286,    0,  287,
  288,  289,  290,  291,  292,  293,  294,  295,  296,  297,
  298,  299,    0,  300,  301,  302,  303,  304,  305,    0,
  306,  307,  308,  309,  310,  311,  312,  313,    0,  314,
  315,  316,  317,    0,  318,  319,  320,  321,  322,  323,
    0,    0,  324,  325,  326,  327,  328,  329,  330,  331,
  332,    0,    0,    0,    0,    0,  333,    0,  334,  335,
  336,  337,  338,  339,    0,  138,    0,  139,    0,    0,
    0,    0,    0,  140,    0,    0,  141,  142,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  143,  144,    0,
  145,    0,  146,    0,    0,  147,    0,    0,  148,    0,
    0,    0,    0,    0,    0,  149,    0,  150,  151,    0,
    0,    0,  152,    0,  153,    0,    0,  154,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  155,  156,    0,
    0,    0,  157,    0,  158,    0,  159,    0,    0,    0,
    0,    0,  160,    0,  161,    0,    0,    0,  162,    0,
    0,    0,    0,    0,    0,    0,  163,    0,    0,  164,
    0,  165,    0,    0,    0,  166,  167,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  168,    0,
    0,    0,  170,  171,  172,  173,  174,    0,  175,    0,
    0,    0,    0,    0,  176,    0,  177,  178,    0,    0,
  179,  180,    0,    0,    0,    0,    0,  181,    0,    0,
  182,  183,  184,  185,    0,  186,    0,  187,    0,  188,
  189,  190,  191,  192,    0,    0,    0,    0,  193,    0,
  194,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  195, 1273,    0,    0,   15,  196,  197,    0,  198,
    0,    0,    0,  199,    0,  200,  201,  202,  203,    0,
  204,    0,    0,    0,    0,    0,    0,    0,  205,  206,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  207,
  208,    0,  209,  210,  211,    0,    0,    0,    0,  212,
  213,    0,  214,  215,    0,  216,    0,    0,  217,  218,
    0,    0,    0,  219,  220,    0,    0,    0,    0,  221,
  222,  223,    0,  224,  225,  226,    0,  227,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  228,  229,  230,
  231,  232,  233,  234,  235,  236,  237,  238,  239,  240,
  241,  242,  243,  244,  245,  246,  247,  248,    0,  249,
  250,  251,  252,  253,  254,    0,  255,  256,  257,  258,
    0,  259,    0,  260,  261,  262,  263,  264,  265,  266,
  267,  268,  269,  270,  271,  272,  273,  274,  275,  276,
  277,    0,  278,  279,  280,  281,    0,  282,  283,  284,
  285,  286,    0,  287,  288,  289,  290,  291,  292,  293,
  294,  295,  296,  297,  298,  299,    0,  300,  301,  302,
  303,  304,  305,    0,  306,  307,  308,  309,  310,  311,
  312,  313,    0,  314,  315,  316,  317,    0,  318,  319,
  320,  321,  322,  323,    0,    0,  324,  325,  326,  327,
  328,  329,  330,  331,  332,    0,    0,    0,    0,    0,
  333,    0,  334,  335,  336,  337,  338,  339,    0,  138,
    0,  139,    0,    0,    0,    0,    0,  140,    0,    0,
  141,  142,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  143,  144,    0,  145,    0,  146,    0,    0,  147,
    0,    0,  148,    0,    0,    0,    0,    0,    0,  149,
    0,  150,  151,    0,    0,    0,  152,    0,  153,    0,
    0,  154,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  155,  156,    0,    0,    0,  157,    0,  158,    0,
  159,    0,    0,    0,    0,    0,  160,    0,  161,    0,
    0,    0,  162,    0,    0,    0,    0,    0,    0,    0,
  163,    0,    0,  164,    0,  165,    0,    0,    0,  166,
  167,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  168,    0,    0,    0,  170,  171,  172,  173,
  174,    0,  175,    0,    0,    0,    0,    0,  176,    0,
  177,  178,    0,    0,  179,  180,    0,    0,    0,    0,
    0,  181,    0,    0,  182,  183,  184,  185,    0,  186,
    0,  187,    0,  188,  189,  190,  191,  192,    0,    0,
    0,    0,  193,    0,  194,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  195,  676,    0,    0,    0,
  196,  197,    0,  198,    0,    0,    0,  199,    0,  200,
  201,  202,  203,    0,  204,    0,    0,    0,    0,    0,
    0,    0,  205,  206,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  207,  208,    0,  209,  210,  211,    0,
    0,    0,    0,  212,  213,    0,  214,  215,    0,  216,
    0,    0,  217,  218,    0,    0,    0,  219,  220,    0,
    0,    0,    0,  221,  222,  223,    0,  224,  225,  226,
    0,  227,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  228,  229,  230,  231,  232,  233,  234,  235,  236,
  237,  238,  239,  240,  241,  242,  243,  244,  245,  246,
  247,  248,    0,  249,  250,  251,  252,  253,  254,    0,
  255,  256,  257,  258,    0,  259,    0,  260,  261,  262,
  263,  264,  265,  266,  267,  268,  269,  270,  271,  272,
  273,  274,  275,  276,  277,    0,  278,  279,  280,  281,
    0,  282,  283,  284,  285,  286,    0,  287,  288,  289,
  290,  291,  292,  293,  294,  295,  296,  297,  298,  299,
    0,  300,  301,  302,  303,  304,  305,    0,  306,  307,
  308,  309,  310,  311,  312,  313,    0,  314,  315,  316,
  317,    0,  318,  319,  320,  321,  322,  323,    0,    0,
  324,  325,  326,  327,  328,  329,  330,  331,  332,    0,
    0,    0,    0,    0,  333,    0,  334,  335,  336,  337,
  338,  339,    0,  138,    0,  139,    0,    0,    0,    0,
    0,  140,    0,    0,  141,  142,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  143, 2744,    0,  145,    0,
  146,    0,    0,  147,    0,    0,  148,    0,    0,    0,
    0,    0,    0,  149,    0,  150,  151,    0,    0,    0,
  152,    0,  153,    0,    0,  154,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  155,  156,    0,    0,    0,
  157,    0,  158,    0,  159,    0,    0,    0,    0,    0,
  160,    0,  161,    0,    0,    0,  162,    0,    0,    0,
    0,    0,    0,    0,  163,    0,    0,  164,    0,  165,
    0,    0,    0,  166,  167,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  168,    0,    0,    0,
  170,  171,  172,  173,  174,    0,  175,    0,    0,    0,
    0,    0,  176,    0,  177,  178,    0,    0,  179,  180,
    0,    0,    0,    0,    0,  181,    0,    0,  182,  183,
  184,  185,    0,  186,    0,  187,    0,  188,  189,  190,
  191,  192,    0,    0,    0,    0,  193,    0,  194,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  195,
    0, 2107,    0,    0,  196,  197,    0,  198,    0,    0,
    0,  199,    0,  200,  201,  202,  203,    0,  204,    0,
    0,    0,    0,    0,    0,    0,  205,  206,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  207,  208,    0,
  209,  210,  211,    0,    0,    0,    0,  212,  213,    0,
  214,  215,    0,  216,    0,    0,  217,  218,    0,    0,
    0,  219,  220,    0,    0,    0,    0,  221,  222,  223,
    0,  224,  225,  226,    0,  227,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  228,  229,  230,  231,  232,
  233,  234,  235,  236,  237,  238,  239,  240,  241,  242,
  243,  244,  245,  246,  247,  248,    0,  249,  250,  251,
  252,  253,  254,    0,  255,  256,  257,  258,    0,  259,
    0,  260,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,    0,
  278,  279,  280,  281,    0,  282,  283,  284,  285,  286,
    0,  287,  288,  289,  290,  291,  292,  293,  294,  295,
  296,  297,  298,  299,    0,  300,  301,  302,  303,  304,
  305,    0,  306,  307,  308,  309,  310,  311,  312,  313,
    0,  314,  315,  316,  317,    0,  318,  319,  320,  321,
  322,  323,    0,    0,  324,  325,  326,  327,  328,  329,
  330,  331,  332,    0,    0,    0,    0,    0,  333,    0,
  334,  335,  336,  337,  338,  339,  138,    0,  139,    0,
    0,    0,    0,    0,  140,    0,    0,  141,  142,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  143,  144,
    0,  145,    0,  146,    0,    0,  147,    0,    0,  148,
    0,  744,    0,    0,    0,    0,  149,    0,  150,  151,
    0,    0,    0,  152,    0,  153,    0,    0,  154,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  155,  156,
    0,    0,    0,  157,    0,  158,    0,  159,    0,    0,
    0,    0,    0,  160,    0,  161,    0,    0,    0,  162,
    0,    0,    0,    0,    0,    0,    0,  163,    0,    0,
  164,    0,  165,    0,    0,    0,  166,  167,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  168,
    0,    0,    0,  170,  171,  172,  173,  174,    0,  175,
    0,    0,    0,    0,    0,  176,    0,  177,  178,    0,
    0,  179,  180,    0,    0,    0,    0,    0,  181,    0,
    0,  182,  183,  184,  185,    0,  186,    0,  187,    0,
  188,  189,  190,  191,  192,    0,    0,    0,    0,  193,
    0,  194,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  195,    0,    0,    0,    0,  196,  197, 1131,
  198,    0,    0,    0,  199,    0,  200,  201,  202,  203,
    0,  204,    0,    0,    0,    0,    0,    0,    0,  205,
  206,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  207,  208,    0,  209,  210,  211,    0,    0,    0,    0,
  212,  213,    0,  214,  215,    0,  216,    0,    0,  217,
  218,    0,    0,    0,  219,  220,    0,    0,    0,    0,
  221,  222,  223,    0,  224,  225,  226,    0,  227,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  228,  229,
  230,  231,  232,  233,  234,  235,  236,  237,  238,  239,
  240,  241,  242,  243,  244,  245,  246,  247,  248,    0,
  249,  250,  251,  252,  253,  254,    0,  255,  256,  257,
  258,    0,  259,    0,  260,  261,  262,  263,  264,  265,
  266,  267,  268,  269,  270,  271,  272,  273,  274,  275,
  276,  277,    0,  278,  279,  280,  281,    0,  282,  283,
  284,  285,  286,    0,  287,  288,  289,  290,  291,  292,
  293,  294,  295,  296,  297,  298,  299,    0,  300,  301,
  302,  303,  304,  305,    0,  306,  307,  308,  309,  310,
  311,  312,  313,    0,  314,  315,  316,  317,    0,  318,
  319,  320,  321,  322,  323,    0,    0,  324,  325,  326,
  327,  328,  329,  330,  331,  332,    0,    0,    0,    0,
    0,  333,  858,  334,  335,  336,  337,  338,  339,    0,
    0,  138,    0,  139,    0,    0,    0,    0,    0,  140,
    0,    0,  141,  142,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  143,  144,    0,  145,    0,  146,    0,
    0,  147,    0,    0,  148,    0,    0,    0,    0,    0,
    0,  149,    0,  150,  151,    0,    0,    0,  152,    0,
  153,    0,    0,  154,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  155,  156,    0,    0,    0,  157,    0,
  158,    0,  159,    0,    0,    0,    0,    0,  160,    0,
  161,    0,    0,    0,  162,    0,    0,    0,    0,    0,
    0,    0,  163,    0,    0,  164,    0,  165,    0,    0,
    0,  166,  167,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  168,    0,    0,    0,  170,  171,
  172,  173,  174,    0,  175,    0,    0,    0,    0,    0,
  176,    0,  177,  178,    0,    0,  179,  180,    0,    0,
    0,    0,    0,  181,    0,    0,  182,  183,  184,  185,
    0,  186,    0,  187,    0,  188,  189,  190,  191,  192,
    0,    0,    0,    0,  193,    0,  194,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  195,    0,    0,
    0,    0,  196,  197,    0,  198,  522,    0,    0,  199,
    0,  200,  201,  202,  203,  600,  204,    0,    0,    0,
    0,    0,    0,    0,  205,  206,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  207,  208,    0,  209,  210,
  211,    0,    0,    0,    0,  212,  213,    0,  214,  215,
    0,  216,    0,    0,  217,  218,    0,    0,    0,  219,
  220,    0,    0,    0,    0,  221,  222,  223,    0,  224,
  225,  226,    0,  227,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  228,  229,  230,  231,  232,  233,  234,
  235,  236,  237,  238,  239,  240,  241,  242,  243,  244,
  245,  246,  247,  248,    0,  249,  250,  251,  252,  253,
  254,    0,  255,  256,  257,  258,    0,  259,    0,  260,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,    0,  278,  279,
  280,  281,    0,  282,  283,  284,  285,  286,    0,  287,
  288,  289,  290,  291,  292,  293,  294,  295,  296,  297,
  298,  299,    0,  300,  301,  302,  303,  304,  305,    0,
  306,  307,  308,  309,  310,  311,  312,  313,    0,  314,
  315,  316,  317,    0,  318,  319,  320,  321,  322,  323,
    0,    0,  324,  325,  326,  327,  328,  329,  330,  331,
  332,    0,    0,    0,    0,    0,  333,    0,  334,  335,
  336,  337,  338,  339,  600,    0,  600,    0,    0,    0,
    0,    0,  600,    0,    0,  600,  600,  600,    0,    0,
    0,    0,    0,    0,    0,    0,  600,  600,    0,  600,
    0,  600,    0,    0,  600,    0,    0,  600,    0,    0,
    0,    0,    0,  600,  600,    0,  600,  600,    0,    0,
  600,  600,    0,  600,  600,    0,  600,    0,    0,  600,
    0,    0,    0,    0,    0,    0,  600,  600,    0,    0,
    0,  600,  600,  600,    0,  600,    0,  600,    0,    0,
    0,  600,    0,  600,    0,    0,    0,  600,    0,    0,
    0,    0,    0,  600,    0,  600,  600,    0,  600,    0,
  600,    0,  600,    0,  600,  600,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  600,    0,    0,
    0,  600,  600,  600,  600,  600,    0,  600,    0,  600,
  600,    0,    0,  600,    0,  600,  600,    0,    0,  600,
  600,    0,    0,    0,  600,    0,  600,  600,    0,  600,
  600,  600,  600,    0,  600,    0,  600,    0,  600,  600,
  600,  600,  600,    0,    0,    0,    0,  600,    0,  600,
    0,    0,  600,    0,    0,    0,    0,    0,    0,    0,
  600,  600,    0,  600,  600,  600,  600,    0,  600,    0,
    0,    0,  600,    0,  600,  600,  600,  600, 1752,  600,
  600,    0,    0,    0,    0,    0,    0,  600,  600,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  600,  600,
    0,  600,  600,  600,    0,    0,    0,    0,  600,  600,
    0,  600,  600,    0,  600,    0,    0,  600,  600,    0,
    0,    0,  600,  600,  600,  600,  600,    0,  600,  600,
  600,    0,  600,  600,  600,    0,  600,    0,  600,  600,
  600,    0,  600,  600,    0,  600,  600,  600,  600,  600,
  600,  600,  600,  600,  600,  600,  600,  600,  600,  600,
  600,  600,  600,  600,  600,  600,  600,    0,  600,  600,
  600,  600,  600,  600,    0,  600,  600,  600,  600,    0,
  600,    0,  600,  600,  600,  600,  600,  600,  600,  600,
  600,  600,  600,  600,  600,  600,  600,  600,  600,  600,
    0,  600,  600,  600,  600,    0,  600,  600,  600,  600,
  600,    0,  600,  600,  600,  600,  600,  600,  600,  600,
  600,  600,  600,  600,  600,    0,  600,  600,  600,  600,
  600,  600,    0,  600,  600,  600,  600,  600,  600,  600,
  600,    0,  600,  600,  600,  600,    0,  600,  600,  600,
  600,  600,  600,  600,    0,  600,  600,  600,  600,  600,
  600,  600,  600,  600,    0,    0,    0,    0,    0,  600,
    0,  600,  600,  600,  600,  600,  600,  138,    0,  139,
    0,    0,    0,    0,    0,  140,    0,    0,  141,  142,
 1368,    0,    0,    0,    0,    0,    0,    0,    0,  143,
  144,    0,  145,    0,  146,    0,    0,  147,    0,    0,
  148,    0,    0,    0,    0,    0,    5,  149,    0,  150,
  151,    0,    0,    0,  152,    0, 1738, 1739,    0, 1740,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  155,
  156,    0,    0,    0, 1741, 1742,  158,    0,  159,    0,
    9,    0,    0,    0,  160,    0,  161,    0,    0,    0,
  162,    0,    0,    0,    0,    0,  749,    0,  163,  751,
    0,  164,    0,  165,    0,   10,    0,  166,  167,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  168,    0,    0,    0,  170,  171,  172,  173,  174,    0,
  175,    0,  755, 1743,    0,    0,  176,    0,  177,  178,
    0,    0,  179,  180,    0,    0,    0,  756,    0,  181,
    0,    0,  182,  183,  184,  185,    0,  186,    0,  187,
    0,  188,  189,  190,  191, 1744,    0,    0,    0,    0,
  193,    0,  194,    0,    0,   14,    0,    0,    0,    0,
    0,    0,    0,  195, 2172,    0,    0,   15,  196,  197,
    0,  762,    0,    0,    0,  199,    0,  200,  201,  202,
  203, 1752,  204,  764,    0,    0,    0,    0,    0,    0,
  205,  206,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1745,  774,    0,  209,  210,  211,    0,    0,    0,
    0,  212,  213,    0,  214,  215,    0,  216,    0,    0,
  217, 1746,    0,    0,    0,  219,  220, 1747, 1748, 1749,
    0,  221,  222,  223,    0,  224,  225,  226,    0,  227,
    0,  786,  787,  788,    0,  789,  790,    0,  791,  228,
  229,  230,  231,  232,  233,  792,  235,  793,  237,  794,
  795,  796,  797,  798,  799,  800,  801,  802,  803,  804,
    0,  805,  806,  807,  808,  809,  254,    0,  811,  812,
  813,  258,    0,  814,    0,  260,  816,  817,  818,  819,
  265,  266,  820,  268,  821,  822,  823,  272,  824,  274,
  825,  276,  826,    0,  827,  828,  829,  830,    0,  831,
  832,  833,  285,  834,    0,  835,  836,  289,  837,  291,
  292,  838,  294,  295,  296,  297,  298,  299,    0,  839,
  301,  302,  303,  304,  305,    0,  840,  307, 1750,  309,
  310,  311,  312,  313,    0,  314,  315,  841,  842,    0,
  318,  319,  320,  843,  844,  845, 1751,    0,  324,  325,
  326,  327,  328,  329,  330,  331,  332,    0,    0,    0,
    0,    0,  333,    0,  334,  335,  336,  337,  338,  339,
  138,    0,  139,    0,    0,    0,    0,    0,  140,    0,
    0,  141,  142, 1368,    0,    0,    0,    0,    0,    0,
    0,    0,  143,  144,    0,  145,    0,  146,    0,    0,
  147,    0,    0,  148,    0,    0,    0,    0,    0,    5,
  149,    0,  150,  151,    0,    0,    0,  152,    0, 1738,
 1739,    0, 1740,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  155,  156,    0,    0,    0, 1741, 1742,  158,
    0,  159,    0,    9,    0,    0,    0,  160,    0,  161,
    0,    0,    0,  162,    0,    0,    0,    0,    0,  749,
    0,  163,  751,    0,  164,    0,  165,    0,   10,    0,
  166,  167,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  168,    0,    0,    0,  170,  171,  172,
  173,  174,    0,  175,    0,  755, 1743,    0,    0,  176,
    0,  177,  178,    0,    0,  179,  180,    0,    0,    0,
  756,    0,  181,    0,    0,  182,  183,  184,  185,    0,
  186,    0,  187,    0,  188,  189,  190,  191, 1744,    0,
    0,    0,    0,  193,    0,  194,    0,    0,   14,    0,
    0,    0,    0,    0,    0,    0,  195,    0,    0,    0,
   15,  196,  197,    0,  762,    0,    0,    0,  199,    0,
  200,  201,  202,  203,  878,  204,  764,    0,    0,    0,
    0,    0,    0,  205,  206,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1745,  774,    0,  209,  210,  211,
    0,    0,    0,    0,  212,  213,    0,  214,  215,    0,
  216,    0,    0,  217, 1746,    0,    0,    0,  219,  220,
 1747, 1748, 1749,    0,  221,  222,  223,    0,  224,  225,
  226,    0,  227,    0,  786,  787,  788,    0,  789,  790,
    0,  791,  228,  229,  230,  231,  232,  233,  792,  235,
  793,  237,  794,  795,  796,  797,  798,  799,  800,  801,
  802,  803,  804,    0,  805,  806,  807,  808,  809,  254,
    0,  811,  812,  813,  258,    0,  814,    0,  260,  816,
  817,  818,  819,  265,  266,  820,  268,  821,  822,  823,
  272,  824,  274,  825,  276,  826,    0,  827,  828,  829,
  830,    0,  831,  832,  833,  285,  834,    0,  835,  836,
  289,  837,  291,  292,  838,  294,  295,  296,  297,  298,
  299,    0,  839,  301,  302,  303,  304,  305,    0,  840,
  307, 1750,  309,  310,  311,  312,  313,    0,  314,  315,
  841,  842,    0,  318,  319,  320,  843,  844,  845, 1751,
    0,  324,  325,  326,  327,  328,  329,  330,  331,  332,
    0,    0,    0,    0,    0,  333,    0,  334,  335,  336,
  337,  338,  339,  138,    0,  139,    0,    0,    0,    0,
    0,  140,    0,    0,  141,  142,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  143,  144,    0,  145,    0,
  146,    0,    0,  147,    0,    0,  148,    0,    0,    0,
    0,    0,    0,  149,    0,  150,  151,    0,    0,    0,
  152,    0,  153,    0,    0,  154,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  155,  156,    0,    0,    0,
  157,    0,  158,    0,  159,    0,    0,    0,    0,    0,
  160,    0,  161,    0,    0,    0,  162,    0,    0,    0,
    0,    0,    0,    0,  163,    0,    0,  164,    0,  165,
    0,    0,    0,  166,  167,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  168,    0,    0,    0,
  170,  171,  172,  173,  174,    0,  175,    0,    0,    0,
    0,    0,  176,    0,  177,  178,    0,    0,  179,  180,
    0,    0,    0,    0,    0,  181,    0,    0,  182,  183,
  184,  185,    0,  186,    0,  187,    0,  188,  189,  190,
  191,  192,    0,    0,    0,    0,  193,    0,  194,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  195,
    0,    0,    0,    0,  196,  197,    0,  198,    0,    0,
    0,  199,    0,  200,  201,  202,  203,    0,  204,    0,
    0,    0,    0,    0,    0,    0,  205,  206,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  207,  208,    0,
  209,  210,  211,    0,    0,    0,    0,  212,  213,    0,
  214,  215,    0,  216,    0,    0,  217,  218,    0,    0,
    0,  219,  220,    0,    0,    0,    0,  221,  222,  223,
    0,  224,  225,  226,    0,  227,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  228,  229,  230,  231,  232,
  233,  234,  235,  236,  237,  238,  239,  240,  241,  242,
  243,  244,  245,  246,  247,  248,    0,  249,  250,  251,
  252,  253,  254,    0,  255,  256,  257,  258,    0,  259,
    0,  260,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,    0,
  278,  279,  280,  281,    0,  282,  283,  284,  285,  286,
    0,  287,  288,  289,  290,  291,  292,  293,  294,  295,
  296,  297,  298,  299,    0,  300,  301,  302,  303,  304,
  305,    0,  306,  307,  308,  309,  310,  311,  312,  313,
    0,  314,  315,  316,  317,    0,  318,  319,  320,  321,
  322,  323,    0,    0,  324,  325,  326,  327,  328,  329,
  330,  331,  332,    0,    0,    0,    0,    0,  333,    0,
  334,  335,  336,  337,  338,  339, 1796, 1796, 1736, 1796,
 1796, 1796,    0,    0,    0,    0,    0, 1797, 1797, 1737,
 1797, 1797, 1797,    0, 1796, 1796, 1796,    0,    0,    0,
    0,    0,    0,    0,    0, 1797, 1797, 1797,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1796,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1797,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1842, 1842, 1734, 1842,
 1842, 1842,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1842, 1842, 1842,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1842,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1796,    0,    0,    0,
    0,    0,    0,    0,    0, 1796,    0, 1797,    0,    0,
    0, 1796,    0,    0,    0, 1796, 1797,    0, 1796,    0,
    0,    0, 1797,    0,    0,    0, 1797,    0,    0, 1797,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1796, 1865, 1865, 1735, 1865, 1865, 1865, 1796,
    0,    0,    0, 1797,    0,    0, 1842, 1796,    0,    0,
 1797, 1865, 1865, 1865,    0, 1842,    0,    0, 1797,    0,
    0, 1842,    0,    0, 1796, 1842, 1796,    0, 1842,    0,
    0,    0,    0,    0,    0, 1797, 1796, 1797, 1796, 1796,
 1796,    0, 1865,    0,    0, 1796,    0, 1797,    0, 1797,
 1797, 1797,    0,    0,    0,    0, 1797,    0,    0,    0,
    0,    0, 1842,    0,    0,    0,    0,    0,    0, 1842,
    0,    0,    0,    0,    0,    0,    0, 1842,    0,    0,
    0,    0,    0,    0,    0,    0, 1796,    0,    0,    0,
    0,    0,    0,    0, 1842,    0, 1842, 1797,    0,    0,
    0,    0,    0,    0,    0,    0, 1842,    0, 1842, 1842,
 1842,    0,    0,    0,    0, 1842,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1796, 1796,
 1796, 1796, 1796, 1796, 1796, 1796,    0,    0,    0, 1797,
 1797, 1797, 1797, 1797, 1797, 1797, 1797, 1877, 1877,    0,
 1877, 1877, 1877,    0,    0,    0, 1842,    0,    0,    0,
    0,    0,    0,    0, 1877, 1877, 1877, 1877,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1877,    0, 1842, 1842,
 1842, 1842, 1842, 1842, 1842, 1842,    0,    0,    0,    0,
    0,    0,    0, 1865,    0,    0,    0,    0,    0,    0,
    0,    0, 1865,    0,    0,    0,    0,    0, 1865,    0,
    0,    0, 1865,    0,    0, 1865,    0, 1796,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1797,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1796,    0,    0,    0,    0,    0, 1865,
    0,    0, 1796,    0, 1797,    0, 1865,    0,    0,    0,
    0,    0,    0, 1797, 1865,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1865,    0, 1865,    0,    0,    0, 1842,    0,    0,
    0,    0,    0, 1865,    0, 1865, 1865, 1865,    0,    0,
    0,    0, 1865,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1842,    0,    0,    0,    0,    0,    0,
    0,    0, 1842,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1865,    0,    0,    0, 1877,    0, 1877,
    0,    0,    0,    0,    0,    0, 1877,    0,    0,    0,
    0,    0, 1877,    0,    0,    0, 1877,    0,    0, 1877,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1865, 1865, 1865, 1865, 1865,
 1865, 1865, 1865,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1877,    0,    0,    0,    0,    0,    0,
 1877,    0,    0,    0,    0,    0,    0, 1877, 1877,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1877,    0, 1877,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1877,    0, 1877,
 1877, 1877,    0, 1877,    0,    0, 1877,    0,    0,    0,
    0,    0,    0,    0,    0, 1877,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1865,    0,    0, 1877,    0,    0,
    0,    0,    0,  138,    0,  139,    0,    0,    0,    0,
    0,  140,    0,    0,  141,  142,    0,    0,    0,    0,
 1865,    0, 1877,    0,    0,  143,  144,    0,  145, 1865,
  146,    0,    0,  147,    0, 1877,  148,    0,    0,    0,
    0,    0,    0,  149,    0,  150,  151,    0,    0,    0,
  152,    0,  153,    0,    0,  154,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  155,  156,    0,    0,    0,
  157,    0,  158,    0,  159,    0,    0,    0,    0,    0,
  160,    0,  161,    0,    0,    0,  162,    0,    0,    0,
    0,    0,    0,    0,  163,    0,    0,  164,    0,  165,
    0,    0,    0,  166,  167,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  168,    0,    0,    0,
  170,  171,  172,  173,  174,    0,  175,    0,    0,    0,
    0,    0,  176,    0,  177,  178,    0,    0,  179,  180,
    0,    0,    0,    0,    0,  181,    0,    0,  182,  183,
  184,  185,    0,  186,    0,  187,    0,  188,  189,  190,
  191,  192,    0,    0,    0,    0,  193,    0,  194,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  195,
    0,    0,    0, 1877,  196,  197,    0,  198,    0,    0,
    0,  199,  377,  200,  201,  202,  203,  378,  204,  379,
  380,  381,  382,  383,  384,  385,  205,  206,  386,  387,
  388,  389,  390,    0,    0,  391,  392,  207,  208,  393,
  209,  210,  211,  394,  395,  396,  397,  212,  213,  398,
  214,  215,  399,  216,  400,  401,  217,  218,  402,  403,
  404,  219,  220,  405,  406,  407,  408,  221,  222,  223,
  409,  224,  225,  226,  410,  227,  411,  412,  413,  414,
  415,  416,  417,  418,  419,  228,  229,  230,  231,  232,
  233,  234,  235,  236,  237,  238,  239,  240,  241,  242,
  243,  244,  245,  246,  247,  248,  420,  249,  250,  251,
  252,  253,  254,  421,  255,  256,  257,  258,  422,  259,
  423,  260,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,  424,
  278,  279,  280,  281,  425,  282,  283,  284,  285,  286,
  426,  287,  288,  289,  290,  291,  292,  293,  294,  295,
  296,  297,  298,  299,  427,  300,  301,  302,  303,  304,
  305,    0,  306,  307,  308,  309,  310,  311,  312,  313,
  428,  314,  315,  316,  317,  429,  318,  319,  320,  321,
  322,  323,  430,  431,  324,  325,  326,  327,  328,  329,
  330,  331,  332,  432,  433,  434,  435,  436,  333,  437,
  334,  335,  336,  337,  338,  339,  438,  439,  440,  441,
  442,  443,  444,  445,  446,  447,  448,  449,  450,  451,
  452,  453,  454,  455,  890,    0,  890,    0,    0,    0,
    0,    0,  890,    0,    0,  890,  890,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  890,  890,    0,  890,
    0,  890,    0,    0,  890,    0,    0,  890,    0,    0,
    0,    0,    0,    0,  890,    0,  890,  890,    0,    0,
    0,  890,    0,  890,    0,    0,  890,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  890,  890,    0,    0,
    0,  890,    0,  890,    0,  890,    0,    0,    0,    0,
    0,  890,    0,  890,    0,    0,    0,  890,    0,    0,
    0,    0,    0,    0,    0,  890,    0,    0,  890,    0,
  890,    0,    0,    0,  890,  890,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  890,    0,    0,
    0,  890,  890,  890,  890,  890,    0,  890,    0,    0,
    0,    0,    0,  890,    0,  890,  890,    0,    0,  890,
  890,    0,    0,    0,    0,    0,  890,    0,    0,  890,
  890,  890,  890,    0,  890,    0,  890,    0,  890,  890,
  890,  890,  890,    0,    0,    0,    0,  890,    0,  890,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  890,    0,    0,    0,    0,  890,  890,    0,  890,    0,
    0,    0,  890,  890,  890,  890,  890,  890,    0,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,    0,    0,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,    0,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
  890,  890,  890,  890,  890, 1749,    0, 1749,    0,    0,
    0,    0,    0, 1749,    0,    0, 1749, 1749,    0,    0,
 1749,    0,    0, 1749,    0,    0,    0, 1749, 1749,    0,
 1749,    0, 1749,    0,    0, 1749,    0, 1751, 1749, 1749,
    0, 1749,    0,    0,    0, 1749,    0, 1749, 1749,    0,
    0,    0, 1749,    0, 1749,    0,    0, 1749,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1749, 1749,    0,
    0,    0, 1749,    0, 1749,    0, 1749,    0,    0, 1749,
    0,    0, 1749,    0, 1749, 1749, 1749, 1749, 1749, 1749,
 1749, 1749,    0, 1749,    0,    0, 1749,    0,    0, 1749,
    0, 1749,    0,    0,    0, 1749, 1749, 1749,    0, 1749,
    0, 1751,    0,    0,    0,    0,    0,    0, 1749,    0,
    0,    0, 1749, 1749, 1749, 1749, 1749,    0, 1749,    0,
    0,    0,    0,    0, 1749,    0, 1749, 1749, 1749,    0,
 1749, 1749,    0,    0,    0,    0,    0, 1749,    0,    0,
 1749, 1749, 1749, 1749, 1749, 1749,    0, 1749,    0, 1749,
 1749, 1749, 1749, 1749,    0,    0,    0,    0, 1749,    0,
 1749,    0,    0,    0,    0,    0, 1749,    0,    0,    0,
    0, 1749,    0,    0,    0,    0, 1749, 1749,    0, 1749,
    0,    0,    0, 1749,    0, 1749, 1749, 1749, 1749,    0,
 1749,    0,    0,    0,    0,    0,    0,    0, 1749, 1749,
 1749, 1749,    0,    0,    0,    0,    0,    0,    0, 1749,
 1749,    0, 1749, 1749, 1749,    0,    0, 1749,    0, 1749,
 1749,    0, 1749, 1749,    0, 1749,    0,    0, 1749, 1749,
    0,    0,    0, 1749, 1749,    0,    0,    0,    0, 1749,
 1749, 1749,    0, 1749, 1749, 1749,    0, 1749,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1749, 1749, 1749,
 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749,
 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749,    0, 1749,
 1749, 1749, 1749, 1749, 1749,    0, 1749, 1749, 1749, 1749,
    0, 1749,    0, 1749, 1749, 1749, 1749, 1749, 1749, 1749,
 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749,
 1749,    0, 1749, 1749, 1749, 1749,    0, 1749, 1749, 1749,
 1749, 1749,    0, 1749, 1749, 1749, 1749, 1749, 1749, 1749,
 1749, 1749, 1749, 1749, 1749, 1749,    0, 1749, 1749, 1749,
 1749, 1749, 1749,    0, 1749, 1749, 1749, 1749, 1749, 1749,
 1749, 1749,    0, 1749, 1749, 1749, 1749, 1751, 1749, 1749,
 1749, 1749, 1749, 1749,    0,    0, 1749, 1749, 1749, 1749,
 1749, 1749, 1749, 1749, 1749,    0, 1749,    0,    0,    0,
 1749,    0, 1749, 1749, 1749, 1749, 1749, 1749,  138,    0,
  139,    0,    0,    0,    0,    0,  140,    0,    0,  141,
  142,    0,    0, 1056,    0,    0, 1057,    0,    0,    0,
  143,  144,    0,  145,    0,  146,    0,    0,  147,    0,
    0,  148, 1058,    0, 1059,    0,    0,    0,  149,    0,
  150,  151,    0,    0,    0,  152,    0,  153,    0,    0,
  154,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  155,  156,    0,    0,    0,  157,    0,  158,    0,  159,
    0,    0, 1060,    0,    0,  160,    0,  161, 1061, 1062,
 1063,  162, 1064, 1065, 1066,    0, 1067,    0,    0,  163,
    0,    0,  164,    0,  165,    0,    0,    0,  166,  167,
 1068,    0, 1069,    0,    0,    0,    0,    0,    0,    0,
    0,  168,    0,    0,    0,  170,  171,  172,  173,  174,
    0,  175,    0,    0,    0,    0,    0,  176,    0,  177,
  178, 1070,    0,  179,  180,    0,    0,    0,    0,    0,
  181,    0,    0,  182,  183,  184,  185, 1071,  186,    0,
  187,    0,  188,  189,  190,  191,  192,    0,    0,    0,
    0,  193,    0,  194,    0,    0,    0,    0,    0, 1072,
    0,    0,    0,    0,  195,    0,    0,    0,    0,  196,
  197,    0,  198,    0,    0,    0,  199,    0,  200,  201,
  202,  203,    0, 2147,    0,    0,    0,    0,    0,    0,
    0,  205,  206, 1073, 1074,    0,    0,    0,    0,    0,
    0,    0,  207,  208,    0,  209,  210,  211,    0,    0,
 1075,    0,  212,  213,    0,  214,  215,    0,  216,    0,
    0,  217,  218,    0,    0,    0,  219,  220,    0,    0,
    0,    0,  221,  222,  223,    0,  224,  225,  226,    0,
  227,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  228,  229,  230,  231,  232,  233,  234,  235,  236,  237,
  238,  239,  240,  241,  242,  243,  244,  245,  246,  247,
  248,    0,  249,  250,  251,  252,  253,  254,    0,  255,
  256,  257,  258,    0,  259,    0,  260,  261,  262,  263,
  264,  265,  266,  267,  268,  269,  270,  271,  272,  273,
  274,  275,  276,  277,    0,  278,  279,  280,  281,    0,
  282,  283,  284,  285,  286,    0,  287,  288,  289,  290,
  291,  292,  293,  294,  295,  296,  297,  298,  299,    0,
  300,  301,  302,  303,  304,  305,    0,  306,  307,  308,
  309,  310,  311,  312,  313,    0,  314,  315,  316,  317,
    0,  318,  319,  320,  321,  322,  323,    0,    0,  324,
  325,  326,  327,  328,  329,  330,  331,  332,    0, 1076,
    0,    0,    0,  333,    0,  334,  335,  336,  337,  338,
  339,  138,    0,  139,    0,    0,    0,    0,    0,  140,
    0,    0,  141,  142,    0,    0, 1056,    0,    0, 1057,
    0,    0,    0,  143,  144,    0,  145,    0,  146,    0,
    0,  147,    0,    0,  148, 1058,    0, 1059,    0,    0,
    0,  149,    0,  150,  151,    0,    0,    0,  152,    0,
  153,    0,    0,  154,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  155,  156,    0,    0,    0,  157,    0,
  158,    0,  159,    0,    0, 1060,    0,    0,  160,    0,
  161, 1061, 1062, 1063,  162, 1064, 1065, 1066,    0, 1067,
    0,    0,  163,    0,    0,  164,    0,  165,    0,    0,
    0,  166,  167, 1068,    0, 1069,    0,    0,    0,    0,
    0,    0,    0,    0,  168,    0,    0,    0,  170,  171,
  172,  173,  174,    0,  175,    0,    0,    0,    0,    0,
  176,    0,  177,  178, 1070,    0,  179,  180,    0,    0,
    0,    0,    0,  181,    0,    0,  182,  183,  184,  185,
 1071,  186,    0,  187,    0,  188,  189,  190,  191,  192,
    0,    0,    0,    0,  193,    0,  194,    0,    0,    0,
    0,    0, 1072,    0,    0,    0,    0,  195,    0,    0,
    0,    0,  196,  197,    0,  198,    0,    0,    0,  199,
    0,  200,  201,  202,  203,    0, 2294,    0,    0,    0,
    0,    0,    0,    0,  205,  206, 1073, 1074,    0,    0,
    0,    0,    0,    0,    0,  207,  208,    0,  209,  210,
  211,    0,    0, 1075,    0,  212,  213,    0,  214,  215,
    0,  216,    0,    0,  217,  218,    0,    0,    0,  219,
  220,    0,    0,    0,    0,  221,  222,  223,    0,  224,
  225,  226,    0,  227,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  228,  229,  230,  231,  232,  233,  234,
  235,  236,  237,  238,  239,  240,  241,  242,  243,  244,
  245,  246,  247,  248,    0,  249,  250,  251,  252,  253,
  254,    0,  255,  256,  257,  258,    0,  259,    0,  260,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,    0,  278,  279,
  280,  281,    0,  282,  283,  284,  285,  286,    0,  287,
  288,  289,  290,  291,  292,  293,  294,  295,  296,  297,
  298,  299,    0,  300,  301,  302,  303,  304,  305,    0,
  306,  307,  308,  309,  310,  311,  312,  313,    0,  314,
  315,  316,  317,    0,  318,  319,  320,  321,  322,  323,
    0,    0,  324,  325,  326,  327,  328,  329,  330,  331,
  332,    0, 1076,    0,    0,    0,  333,    0,  334,  335,
  336,  337,  338,  339,  138,    0,  139,    0,    0,    0,
    0,    0,  140,    0,    0,  141,  142,    0,    0, 1056,
    0,    0, 1057,    0,    0,    0,  143, 2744,    0,  145,
    0,  146,    0,    0,  147,    0,    0,  148, 1058,    0,
 1059,    0,    0,    0,  149,    0,  150,  151,    0,    0,
    0,  152,    0,  153,    0,    0,  154,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  155,  156,    0,    0,
    0,  157,    0,  158,    0,  159,    0,    0, 1060,    0,
    0,  160,    0,  161, 1061, 1062, 1063,  162, 1064, 1065,
 1066,    0, 1067,    0,    0,  163,    0,    0,  164,    0,
  165,    0,    0,    0,  166,  167, 1068,    0, 1069,    0,
    0,    0,    0,    0,    0,    0,    0,  168,    0,    0,
    0,  170,  171,  172,  173,  174,    0,  175,    0,    0,
    0,    0,    0,  176,    0,  177,  178, 1070,    0,  179,
  180,    0,    0,    0,    0,    0,  181,    0,    0,  182,
  183,  184,  185, 1071,  186,    0,  187,    0,  188,  189,
  190,  191,  192,    0,    0,    0,    0,  193,    0,  194,
    0,    0,    0,    0,    0, 1072,    0,    0,    0,    0,
  195,    0,    0,    0,    0,  196,  197,    0,  198,    0,
    0,    0,  199,    0,  200,  201,  202,  203,    0,  204,
    0,    0,    0,    0,    0,    0,    0,  205,  206, 1073,
 1074,    0,    0,    0,    0,    0,    0,    0,  207,  208,
    0,  209,  210,  211,    0,    0, 1075,    0,  212,  213,
    0,  214,  215,    0,  216,    0,    0,  217,  218,    0,
    0,    0,  219,  220,    0,    0,    0,    0,  221,  222,
  223,    0,  224,  225,  226,    0,  227,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  228,  229,  230,  231,
  232,  233,  234,  235,  236,  237,  238,  239,  240,  241,
  242,  243,  244,  245,  246,  247,  248,    0,  249,  250,
  251,  252,  253,  254,    0,  255,  256,  257, 2745,    0,
  259,    0,  260,  261,  262,  263,  264,  265,  266,  267,
  268,  269,  270,  271,  272,  273,  274,  275,  276,  277,
    0,  278,  279,  280,  281,    0,  282,  283,  284,  285,
  286,    0,  287,  288,  289,  290,  291,  292,  293,  294,
  295,  296,  297,  298,  299,    0,  300,  301,  302,  303,
  304,  305,    0,  306,  307,  308,  309,  310,  311,  312,
  313,    0,  314,  315,  316,  317,    0,  318,  319,  320,
  321,  322,  323,    0,    0,  324,  325,  326,  327,  328,
  329,  330,  331,  332,    0, 1076,    0,    0,    0,  333,
    0,  334,  335,  336,  337,  338,  339,  138,    0,  139,
    0,    0,    0,    0,    0,  140,    0,    0,  141,  142,
    0,    0, 1056,    0,    0, 1057,    0,    0,    0,  143,
  144,    0,  145,    0,  146,    0,    0,  147,    0,    0,
  148, 1058,    0, 1059,    0,    0,    0,  149,    0,  150,
  151,    0,    0,    0,  152,    0,  153,    0,    0,  154,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  155,
  156,    0,    0,    0,  157,    0,  158,    0,  159,    0,
    0, 1060,    0,    0,  160,    0,  161, 1061, 1062, 1063,
  162, 1064, 1065, 1066,    0, 1067,    0,    0,  163,    0,
    0,  164,    0,  165,    0,    0,    0,  166,  167, 1068,
    0, 1069,    0,    0,    0,    0,    0,    0,    0,    0,
  168,    0,    0,    0,  170,  171,  172,  173,  174,    0,
  175,    0,    0,    0,    0,    0,  176,    0,  177,  178,
 1070,    0,  179,  180,    0,    0,    0,    0,    0,  181,
    0,    0,  182,  183,  184,  185, 1071,  186,    0,  187,
    0,  188,  189,  190,  191,  192,    0,    0,    0,    0,
  193,    0,  194,    0,    0,    0,    0,    0, 1072,    0,
    0,    0,    0,  195,    0,    0,    0,    0,  196,  197,
    0,  198,    0,    0,    0,  199,    0,  200,  201,  202,
  203,    0,  204,    0,    0,    0,    0,    0,    0,    0,
  205,  206, 1073, 1074,    0,    0,    0,    0,    0,    0,
    0,  207,  208,    0,  209,  210,  211,    0,    0, 1075,
    0,  212,  213,    0,  214,  215,    0,  216,    0,    0,
  217,  218,    0,    0,    0,  219,  220,    0,    0,    0,
    0,  221,  222,  223,    0,  224,  225,  226,    0,  227,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  228,
  229,  230,  231,  232,  233,  234,  235,  236,  237,  238,
  239,  240,  241,  242,  243,  244,  245,  246,  247,  248,
    0,  249,  250,  251,  252,  253,  254,    0,  255,  256,
  257,  258,    0,  259,    0,  260,  261,  262,  263,  264,
  265,  266,  267,  268,  269,  270,  271,  272,  273,  274,
  275,  276,  277,    0,  278,  279,  280,  281,    0,  282,
  283,  284,  285,  286,    0,  287,  288,  289,  290,  291,
  292,  293,  294,  295,  296,  297,  298,  299,    0,  300,
  301,  302,  303,  304,  305,    0,  306,  307,  308,  309,
  310,  311,  312,  313,    0,  314,  315,  316,  317,    0,
  318,  319,  320,  321,  322,  323,    0,    0,  324,  325,
  326,  327,  328,  329,  330,  331,  332,    0, 1076,    0,
    0,    0,  333,    0,  334,  335,  336,  337,  338,  339,
   44,    0,   44,   32,   32,    0,    0,    0,   44,    0,
    0,   44,   44,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   44,   44,    0,   44,    0,   44,    0,   32,
   44,    0,    0,   44,    0,    0,    0,    0,    0,   32,
   44,    0,   44,   44,   32,    0,    0,   44,    0,   44,
   32,    0,   44,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   44,   44,    0,    0,    0,   44,    0,   44,
    0,   44,    0,   32,    0,    0,    0,   44,    0,   44,
    0,    0,    0,   44,    0,    0,    0,    0,    0,    0,
    0,   44,    0,    0,   44,    0,   44,    0,    0,    0,
   44,   44,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   44,    0,    0,    0,   44,   44,   44,
   44,   44,    0,   44,    0,    0,    0,    0,    0,   44,
    0,   44,   44,    0,   32,   44,   44,    0,    0,    0,
    0,    0,   44,   32,    0,   44,   44,   44,   44,    0,
   44,    0,   44,    0,   44,   44,   44,   44,   44,    0,
    0,    0,    0,   44,    0,   44,    0,    0,   32,    0,
    0,    0,    0,    0,    0,    0,   44,    0,    0,    0,
    0,   44,   44,    0,   44,    0,    0,    0,   44,    0,
   44,   44,   44,   44,    0,   44,    0,    0,    0,    0,
    0,    0,    0,   44,   44,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   44,   44,    0,   44,   44,   44,
    0,    0,    0,    0,   44,   44,    0,   44,   44,    0,
   44,    0,    0,   44,   44,    0,    0,    0,   44,   44,
    0,    0,    0,    0,   44,   44,   44,    0,   44,   44,
   44,    0,   44,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   44,   44,   44,   44,   44,   44,   44,   44,
   44,   44,   44,   44,   44,   44,   44,   44,   44,   44,
   44,   44,   44,    0,   44,   44,   44,   44,   44,   44,
    0,   44,   44,   44,   44,    0,   44,    0,   44,   44,
   44,   44,   44,   44,   44,   44,   44,   44,   44,   44,
   44,   44,   44,   44,   44,   44,    0,   44,   44,   44,
   44,    0,   44,   44,   44,   44,   44,    0,   44,   44,
   44,   44,   44,   44,   44,   44,   44,   44,   44,   44,
   44,    0,   44,   44,   44,   44,   44,   44,    0,   44,
   44,   44,   44,   44,   44,   44,   44,    0,   44,   44,
   44,   44,    0,   44,   44,   44,   44,   44,   44,    0,
    0,   44,   44,   44,   44,   44,   44,   44,   44,   44,
    0,    0,    0,    0,    0,    0,    0,   44,   44,   44,
   44,   44,   44,  121,    0,  121,    0,  119,    0,    0,
    0,  121,    0,    0,  121,  121,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  121,  121,    0,  121,    0,
  121,    0,  119,  121,    0,    0,  121,    0,    0,    0,
    0,    0,  119,  121,    0,  121,  121,  119,    0,    0,
  121,    0,  121,  119,    0,  121,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  121,  121,    0,    0,    0,
  121,    0,  121,    0,  121,    0,  119,    0,    0,    0,
  121,    0,  121,    0,    0,    0,  121,    0,    0,    0,
    0,    0,    0,    0,  121,    0,    0,  121,    0,  121,
    0,    0,    0,  121,  121,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  121,    0,    0,    0,
  121,  121,  121,  121,  121,    0,  121,    0,    0,    0,
    0,    0,  121,    0,  121,  121,    0,  119,  121,  121,
    0,    0,    0,    0,    0,  121,  119,    0,  121,  121,
  121,  121,    0,  121,    0,  121,    0,  121,  121,  121,
  121,  121,    0,    0,    0,    0,  121,    0,  121,    0,
    0,  119,    0,    0,    0,    0,    0,    0,    0,  121,
    0,    0,    0,    0,  121,  121,    0,  121,    0,    0,
    0,  121,    0,  121,  121,  121,  121,    0,  121,    0,
    0,    0,    0,    0,    0,    0,  121,  121,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  121,  121,    0,
  121,  121,  121,    0,    0,    0,    0,  121,  121,    0,
  121,  121,    0,  121,    0,    0,  121,  121,    0,    0,
    0,  121,  121,    0,    0,    0,    0,  121,  121,  121,
    0,  121,  121,  121,    0,  121,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  121,  121,  121,  121,  121,
  121,  121,  121,  121,  121,  121,  121,  121,  121,  121,
  121,  121,  121,  121,  121,  121,    0,  121,  121,  121,
  121,  121,  121,    0,  121,  121,  121,  121,    0,  121,
    0,  121,  121,  121,  121,  121,  121,  121,  121,  121,
  121,  121,  121,  121,  121,  121,  121,  121,  121,    0,
  121,  121,  121,  121,    0,  121,  121,  121,  121,  121,
    0,  121,  121,  121,  121,  121,  121,  121,  121,  121,
  121,  121,  121,  121,    0,  121,  121,  121,  121,  121,
  121,    0,  121,  121,  121,  121,  121,  121,  121,  121,
    0,  121,  121,  121,  121,    0,  121,  121,  121,  121,
  121,  121,    0,    0,  121,  121,  121,  121,  121,  121,
  121,  121,  121,    0,    0,    0,    0,    0,    0,    0,
  121,  121,  121,  121,  121,  121,  138,    0,  139,    0,
    0,    0,    0,    0,  140,    0,    0,  141,  142,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  143,  144,
    0,  145,    0,  146,    0,    0,  147,    0,    0,  148,
    0,    0,    0,    0,    0,    0,  149,    0,  150,  151,
    0,    0,    0,  152,    0,  153,    0,    0,  154,    0,
    0,    0,    0,    0,    0, 2874,    0,    0,  155,  156,
    0, 2875,    0,  157,    0,  158,    0,  159,    0,    0,
    0,    0,    0,  160,    0,  161,    0,    0,    0,  162,
    0,    0,    0,    0,    0,    0,    0,  163,    0,    0,
  164,    0,  165,    0,    0,    0,  166,  167,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  168,
    0,    0,    0,  170,  171,  172,  173,  174,    0,  175,
    0,    0,    0,    0,    0,  176, 2876,  177,  178,    0,
    0,  179,  180,    0,    0,    0,    0,    0,  181,    0,
    0,  182,  183,  184,  185,    0,  186,    0,  187,    0,
  188,  189,  190,  191,  192,    0,    0,    0,    0,  193,
 2877,  194,    0,    0,    0, 2878,    0,    0,    0,    0,
    0, 2879,  195,    0,    0,    0,    0,  196,  197,    0,
  198,    0,    0,    0,  199,    0,  200,  201,  202, 2880,
    0,  204,    0,    0,    0,    0,    0,    0,    0,  205,
  206,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  207,  208,    0,  209,  210,  211,    0,    0,    0,    0,
  212,  213,    0,  214,  215,    0,  216,    0,    0,  217,
  218,    0,    0,    0,  219,  220,    0,    0,    0,    0,
  221,  222,  223,    0,  224,  225,  226,    0,  227,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  228,  229,
  230,  231,  232,  233,  234,  235,  236,  237,  238,  239,
  240,  241,  242,  243,  244,  245,  246,  247,  248,    0,
  249,  250,  251,  252,  253,  254,    0,  255,  256,  257,
  258,    0,  259,    0,  260,  261,  262,  263,  264,  265,
  266,  267,  268,  269,  270,  271,  272,  273,  274,  275,
  276,  277,    0,  278,  279,  280,  281,    0,  282,  283,
  284,  285,  286,    0,  287,  288,  289,  290,  291,  292,
  293,  294,  295,  296,  297,  298,  299,    0,  300,  301,
  302,  303,  304,  305,    0,  306,  307,  308,  309,  310,
  311,  312,  313,    0, 2881,  315,  316,  317,    0,  318,
  319,  320,  321,  322,  323,    0,    0,  324,  325,  326,
  327,  328,  329,  330,  331,  332,    0,    0,    0,    0,
    0,  333,    0,  334,  335,  336,  337,  338,  339,  138,
    0,  139,    0,    0,    0,    0,    0,  140,    0,    0,
  141,  142,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  143,  144,    0,  145,    0,  146,    0,    0,  147,
    0,    0,  148,    0,    0,    0,    0,    0,    0,  149,
    0,  150,  151,    0,    0,    0,  152,    0,  153,    0,
    0,  154,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  155,  156,    0,    0,    0,  157,    0,  158,    0,
  159, 2999,    0,    0,    0,    0,  160,    0,  161,    0,
    0,    0,  162,    0,    0,    0,    0,    0,    0,    0,
  163,    0,    0,  164,    0,  165,    0,    0,    0,  166,
  167,    0, 3000,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  168,    0, 3001,    0,  170,  171,  172,  173,
  174,    0,  175,    0,    0,    0,    0,    0,  176,    0,
  177,  178,    0,    0,  179,  180,    0,    0,    0,    0,
    0,  181,    0,    0,  182,  183,  184,  185,    0,  186,
    0,  187,    0,  188,  189,  190,  191,  192,    0,    0,
    0,    0,  193,    0,  194,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  195,    0,    0,    0,    0,
  196,  197,    0,  198,    0,    0,    0,  199,    0,  200,
  201,  202,  203,    0,  204,    0,    0,    0,    0,    0,
    0,    0,  205,  206,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  207,  208,    0,  209,  210,  211,    0,
    0,    0,    0,  212,  213,    0,  214,  215,    0,  216,
    0,    0,  217,  218,    0,    0,    0,  219,  220,    0,
    0,    0,    0,  221,  222,  223,    0,  224,  225,  226,
    0,  227,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  228,  229,  230,  231,  232,  233,  234,  235,  236,
  237,  238,  239,  240,  241,  242,  243,  244,  245,  246,
  247,  248,    0,  249,  250,  251,  252,  253,  254,    0,
  255,  256,  257,  258,    0,  259,    0,  260,  261,  262,
  263,  264,  265,  266,  267,  268,  269,  270,  271,  272,
  273,  274,  275,  276,  277,    0,  278,  279,  280,  281,
    0,  282,  283,  284,  285,  286,    0,  287,  288,  289,
  290,  291,  292,  293,  294,  295,  296,  297,  298,  299,
    0,  300,  301,  302,  303,  304,  305,    0,  306,  307,
  308,  309,  310,  311,  312,  313,    0,  314,  315,  316,
  317,    0,  318,  319,  320,  321,  322,  323,    0,    0,
  324,  325,  326,  327,  328,  329,  330,  331,  332,    0,
    0,    0,    0,    0,  333,    0,  334,  335,  336,  337,
  338,  339,  138,    0,  139,    0,    0,    0, 3100,    0,
  140,    0,    0,  141,  142,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  143,  144,    0,  145,    0,  146,
    0,    0,  147,    0,    0,  148,    0,    0,    0,    0,
    0,    0,  149,    0,  150,  151,    0,    0,    0,  152,
    0,  153,    0,    0,  154,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  155,  156,    0, 3101,    0,  157,
    0,  158,    0,  159,    0,    0,    0,    0,    0,  160,
    0,  161,    0,    0,    0,  162,    0,    0,    0,    0,
    0,    0,    0,  163,    0,    0,  164,    0,  165,    0,
    0,    0,  166,  167,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  168,    0,    0,    0,  170,
  171,  172,  173,  174,    0,  175,    0,    0,    0,    0,
    0,  176,    0,  177,  178,    0,    0,  179,  180,    0,
    0,    0,    0,    0,  181,    0,    0,  182,  183,  184,
  185,    0,  186,    0,  187,    0,  188,  189,  190,  191,
  192,    0,    0,    0,    0,  193,    0,  194,    0,    0,
    0, 3102,    0,    0,    0,    0,    0,    0,  195,    0,
    0,    0,    0,  196,  197,    0,  198,    0,    0,    0,
  199,    0,  200,  201,  202,  203,    0,  204,    0,    0,
    0,    0,    0,    0,    0,  205,  206,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  207,  208,    0,  209,
  210,  211,    0,    0,    0,    0,  212,  213,    0,  214,
  215,    0,  216,    0,    0,  217,  218,    0,    0,    0,
  219,  220,    0,    0,    0,    0,  221,  222,  223,    0,
  224,  225,  226,    0,  227,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  228,  229,  230,  231,  232,  233,
  234,  235,  236,  237,  238,  239,  240,  241,  242,  243,
  244,  245,  246,  247,  248,    0,  249,  250,  251,  252,
  253,  254,    0,  255,  256,  257,  258,    0,  259,    0,
  260,  261,  262,  263,  264,  265,  266,  267,  268,  269,
  270,  271,  272,  273,  274,  275,  276,  277,    0,  278,
  279,  280,  281,    0,  282,  283,  284,  285,  286,    0,
  287,  288,  289,  290,  291,  292,  293,  294,  295,  296,
  297,  298,  299,    0,  300,  301,  302,  303,  304,  305,
    0,  306,  307,  308,  309,  310,  311,  312,  313,    0,
  314,  315,  316,  317,    0,  318,  319,  320,  321,  322,
  323,    0,    0,  324,  325,  326,  327,  328,  329,  330,
  331,  332,    0,    0,    0,    0,    0,  333,    0,  334,
  335,  336,  337,  338,  339,  138,    0,  139,    0,    0,
    0,    0,    0,  140,    0,    0,  141,  142,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  143,  144,    0,
  145,    0,  146,    0,    0,  147,    0,    0,  148,    0,
  744,    0,    0,    0,    0,  149,    0,  150,  151,    0,
    0,    0,  152,    0,  153,    0,    0,  154,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  155,  156,    0,
    0,    0,  157,    0,  158,    0,  159,    0,    0,    0,
    0,    0,  160,    0,  161,    0,    0,    0,  162,    0,
    0,    0,    0,    0,    0,    0,  163,    0,    0,  164,
    0,  165,    0,    0,    0,  166,  167,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  168,    0,
    0,    0,  170,  171,  172,  173,  174,    0,  175,    0,
    0,    0,    0,    0,  176,    0,  177,  178,    0,    0,
  179,  180,    0,    0,    0,    0,    0,  181,    0,    0,
  182,  183,  184,  185,    0,  186,    0,  187,    0,  188,
  189,  190,  191,  192,    0,    0,    0,    0,  193,    0,
  194,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  195,    0,    0,    0,    0,  196,  197,    0,  198,
    0,    0,    0,  199,    0,  200,  201,  202,  203,    0,
  204,    0,    0,    0,    0,    0,    0,    0,  205,  206,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  207,
  208,    0,  209,  210,  211,    0,    0,    0,    0,  212,
  213,    0,  214,  215,    0,  216,    0,    0,  217,  218,
    0,    0,    0,  219,  220,    0,    0,    0,    0,  221,
  222,  223,    0,  224,  225,  226,    0,  227,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  228,  229,  230,
  231,  232,  233,  234,  235,  236,  237,  238,  239,  240,
  241,  242,  243,  244,  245,  246,  247,  248,    0,  249,
  250,  251,  252,  253,  254,    0,  255,  256,  257,  258,
    0,  259,    0,  260,  261,  262,  263,  264,  265,  266,
  267,  268,  269,  270,  271,  272,  273,  274,  275,  276,
  277,    0,  278,  279,  280,  281,    0,  282,  283,  284,
  285,  286,    0,  287,  288,  289,  290,  291,  292,  293,
  294,  295,  296,  297,  298,  299,    0,  300,  301,  302,
  303,  304,  305,    0,  306,  307,  308,  309,  310,  311,
  312,  313,    0,  314,  315,  316,  317,    0,  318,  319,
  320,  321,  322,  323,    0,    0,  324,  325,  326,  327,
  328,  329,  330,  331,  332,    0,    0,    0,    0,    0,
  333,  858,  334,  335,  336,  337,  338,  339,  138,    0,
  139,    0,    0,    0,    0,    0,  140,    0,    0,  141,
  142,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  143,  144,    0,  145,    0,  146,    0,    0,  147,    0,
    0,  148,    0,    0,    0,    0,    0,    0,  149,    0,
  150,  151,    0,    0,    0,  152,    0,  153,    0,    0,
  154,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  155,  156,    0,    0,    0,  157,    0,  158,    0,  159,
    0,    0,    0,    0,    0,  160,    0,  161,    0,    0,
    0,  162,    0,    0,    0,    0,    0,    0,    0,  163,
    0,    0,  164,    0,  165,    0,    0,    0,  166,  167,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  168,    0,    0,    0,  170,  171,  172,  173,  174,
    0,  175,    0,    0,    0,    0,    0,  176,    0,  177,
  178,    0,    0,  179,  180,    0,    0,    0,    0,    0,
  181,    0,    0,  182,  183,  184,  185,    0,  186,    0,
  187,    0,  188,  189,  190,  191,  192,    0,    0,    0,
    0,  193,    0,  194,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  195,    0,    0,    0,    0,  196,
  197,    0,  198,    0,  506,  507,  199,    0,  200,  201,
  202,  203,    0,  204,    0,    0,    0,    0,    0,    0,
    0,  205,  206,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  207,  208,    0,  209,  210,  211,    0,    0,
    0,    0,  212,  213,    0,  214,  215,    0,  216,    0,
    0,  217,  218,    0,    0,    0,  219,  220,    0,    0,
    0,    0,  221,  222,  223,    0,  224,  225,  226,    0,
  227,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  228,  229,  230,  231,  232,  233,  234,  235,  236,  237,
  238,  239,  240,  241,  242,  243,  244,  245,  246,  247,
  248,    0,  249,  250,  251,  252,  253,  254,    0,  255,
  256,  257,  258,    0,  259,    0,  260,  261,  262,  263,
  264,  265,  266,  267,  268,  269,  270,  271,  272,  273,
  274,  275,  276,  277,    0,  278,  279,  280,  281,    0,
  282,  283,  284,  285,  286,    0,  287,  288,  289,  290,
  291,  292,  293,  294,  295,  296,  297,  298,  299,    0,
  300,  301,  302,  303,  304,  305,    0,  306,  307,  308,
  309,  310,  311,  312,  313,    0,  314,  315,  316,  317,
    0,  318,  319,  320,  321,  322,  323,    0,    0,  324,
  325,  326,  327,  328,  329,  330,  331,  332,    0,    0,
    0,    0,    0,  333,    0,  334,  335,  336,  337,  338,
  339,  138,    0,  139,    0,    0,    0,    0,    0,  140,
    0,    0,  141,  142,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  143,  144,    0,  145,    0,  146,    0,
    0,  147,    0,    0,  148,    0,    0,    0,    0,    0,
    0,  149,    0,  150,  151,    0,    0,    0,  152,    0,
  153,    0,    0,  154,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  155,  156,    0,    0,    0,  157,    0,
  158,    0,  159,    0,    0,    0,    0,    0,  160, 1465,
  161,    0,    0,    0,  162,    0,    0,    0,    0,    0,
    0,    0,  163,    0,    0,  164,    0,  165,    0, 1466,
    0,  166,  167,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  168,    0,    0,    0,  170,  171,
  172,  173,  174,    0,  175,    0,    0,    0,    0,    0,
  176,    0,  177,  178,    0,    0,  179,  180,    0,    0,
    0,    0,    0,  181,    0,    0,  182,  183,  184,  185,
    0,  186,    0, 2827,    0,  188,  189,  190,  191,  192,
    0,    0,    0,    0,  193,    0,  194,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  195,    0,    0,
    0,    0,  196,  197,    0,  198,    0,    0,    0,  199,
    0,  200,  201,  202,  203,    0,  204,    0,    0,    0,
    0,    0,    0,    0,  205,  206,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  207,  208,    0,  209,  210,
  211,    0,    0,    0,    0,  212,  213,    0,  214,  215,
    0,  216,    0,    0,  217,  218,    0,    0,    0,  219,
  220,    0,    0,    0,    0,  221,  222,  223,    0,  224,
  225,  226,    0,  227,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  228,  229,  230,  231,  232,  233,  234,
  235,  236,  237,  238,  239,  240,  241,  242,  243,  244,
  245,  246,  247,  248,    0,  249,  250,  251,  252,  253,
  254,    0,  255,  256,  257,  258,    0, 2828,    0,  260,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,    0,  278,  279,
  280,  281,    0,  282,  283,  284,  285,  286,    0,  287,
  288,  289,  290,  291,  292,  293,  294,  295,  296,  297,
  298,  299,    0,  300,  301,  302,  303,  304,  305,    0,
  306,  307,  308,  309,  310,  311,  312,  313,    0,  314,
  315,  316,  317,    0,  318,  319,  320,  321,  322,  323,
    0,    0,  324,  325,  326,  327,  328,  329,  330,  331,
  332,    0,    0,    0,    0,    0,  333,    0,  334,  335,
  336,  337,  338,  339,  138,    0,  139,    0,    0,    0,
    0,    0,  140,    0,    0,  141,  142,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  143,  144,    0,  145,
    0,  146,    0,    0,  147,    0,    0,  148,    0,    0,
    0,    0,    0,    0,  149,    0,  150,  151,    0,    0,
    0,  152,    0,  153,    0,    0,  154,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  155,  156,    0, 3101,
    0,  157,    0,  158,    0,  159,    0,    0,    0,    0,
    0,  160,    0,  161,    0,    0,    0,  162,    0,    0,
    0,    0,    0,    0,    0,  163,    0,    0,  164,    0,
  165,    0,    0,    0,  166,  167,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  168,    0,    0,
    0,  170,  171,  172,  173,  174,    0,  175,    0,    0,
    0,    0,    0,  176,    0,  177,  178,    0,    0,  179,
  180,    0,    0,    0,    0,    0,  181,    0,    0,  182,
  183,  184,  185,    0,  186,    0,  187,    0,  188,  189,
  190,  191,  192,    0,    0,    0,    0,  193,    0,  194,
    0,    0,    0, 3102,    0,    0,    0,    0,    0,    0,
  195,    0,    0,    0,    0,  196,  197,    0,  198,    0,
    0,    0,  199,    0,  200,  201,  202,  203,    0,  204,
    0,    0,    0,    0,    0,    0,    0,  205,  206,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  207,  208,
    0,  209,  210,  211,    0,    0,    0,    0,  212,  213,
    0,  214,  215,    0,  216,    0,    0,  217,  218,    0,
    0,    0,  219,  220,    0,    0,    0,    0,  221,  222,
  223,    0,  224,  225,  226,    0,  227,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  228,  229,  230,  231,
  232,  233,  234,  235,  236,  237,  238,  239,  240,  241,
  242,  243,  244,  245,  246,  247,  248,    0,  249,  250,
  251,  252,  253,  254,    0,  255,  256,  257,  258,    0,
  259,    0,  260,  261,  262,  263,  264,  265,  266,  267,
  268,  269,  270,  271,  272,  273,  274,  275,  276,  277,
    0,  278,  279,  280,  281,    0,  282,  283,  284,  285,
  286,    0,  287,  288,  289,  290,  291,  292,  293,  294,
  295,  296,  297,  298,  299,    0,  300,  301,  302,  303,
  304,  305,    0,  306,  307,  308,  309,  310,  311,  312,
  313,    0,  314,  315,  316,  317,    0,  318,  319,  320,
  321,  322,  323,    0,    0,  324,  325,  326,  327,  328,
  329,  330,  331,  332,    0,    0,    0,    0,    0,  333,
    0,  334,  335,  336,  337,  338,  339,  138,    0,  139,
    0,    0,    0,    0,    0,  140,    0,    0,  141,  142,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  143,
  144,    0,  145,    0,  146,    0,    0,  147,    0,    0,
  148,    0,    0,    0,    0,    0,    0,  149,    0,  150,
  151,    0,    0,    0,  152,    0,  153,    0,    0,  154,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  155,
  156,    0,    0,    0,  157,    0,  158,    0,  159,    0,
    0,    0,    0,    0,  160,    0,  161,    0,    0,    0,
  162,    0,    0,    0,    0,    0,    0,    0,  163,    0,
    0,  164,    0,  165,    0,    0,    0,  166,  167,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  168,  169,    0,    0,  170,  171,  172,  173,  174,    0,
  175,    0,    0,    0,    0,    0,  176,    0,  177,  178,
    0,    0,  179,  180,    0,    0,    0,    0,    0,  181,
    0,    0,  182,  183,  184,  185,    0,  186,    0,  187,
    0,  188,  189,  190,  191,  192,    0,    0,    0,    0,
  193,    0,  194,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  195,    0,    0,    0,    0,  196,  197,
    0,  198,    0,    0,    0,  199,    0,  200,  201,  202,
  203,    0,  204,    0,    0,    0,    0,    0,    0,    0,
  205,  206,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  207,  208,    0,  209,  210,  211,    0,    0,    0,
    0,  212,  213,    0,  214,  215,    0,  216,    0,    0,
  217,  218,    0,    0,    0,  219,  220,    0,    0,    0,
    0,  221,  222,  223,    0,  224,  225,  226,    0,  227,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  228,
  229,  230,  231,  232,  233,  234,  235,  236,  237,  238,
  239,  240,  241,  242,  243,  244,  245,  246,  247,  248,
    0,  249,  250,  251,  252,  253,  254,    0,  255,  256,
  257,  258,    0,  259,    0,  260,  261,  262,  263,  264,
  265,  266,  267,  268,  269,  270,  271,  272,  273,  274,
  275,  276,  277,    0,  278,  279,  280,  281,    0,  282,
  283,  284,  285,  286,    0,  287,  288,  289,  290,  291,
  292,  293,  294,  295,  296,  297,  298,  299,    0,  300,
  301,  302,  303,  304,  305,    0,  306,  307,  308,  309,
  310,  311,  312,  313,    0,  314,  315,  316,  317,    0,
  318,  319,  320,  321,  322,  323,    0,    0,  324,  325,
  326,  327,  328,  329,  330,  331,  332,    0,    0,    0,
    0,    0,  333,    0,  334,  335,  336,  337,  338,  339,
  138,    0,  139,    0,    0,    0,    0,    0,  140,    0,
    0,  141,  142,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  143,  144,    0,  145,    0,  146,    0,    0,
  147,    0,    0,  148,    0,    0,    0,    0,    0,    0,
  149,    0,  150,  151,    0,    0,    0,  152,    0,  153,
    0,    0,  154,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  155,  156,    0,    0,    0,  157,    0,  158,
    0,  159,    0,    0,    0,    0,    0,  160,    0,  161,
    0,    0,    0,  162,    0,    0,    0,    0,    0,    0,
    0,  163,    0,    0,  164,    0,  165,    0,    0,    0,
  166,  167,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  168,    0,    0,    0,  170,  171,  172,
  173,  174,    0,  175,    0,    0,    0,    0,    0,  176,
    0,  177,  178,    0,    0,  179,  180,    0,    0,    0,
    0,    0,  181,    0,    0,  182,  183,  184,  185,    0,
  186,    0,  187,    0,  188,  189,  190,  191,  192,    0,
    0,    0,    0,  193,    0,  194,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  195,    0,    0,    0,
    0,  196,  197,    0,  198,    0,    0,    0,  199,    0,
  200,  201,  202,  203,    0,  204,    0,    0,    0,    0,
    0,    0,    0,  205,  206,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  207,  208,    0,  209,  210,  211,
    0,    0,    0,    0,  212,  213,    0,  214,  215,    0,
  216,    0,    0,  217,  218,    0,    0,    0,  219,  220,
    0,    0,    0,    0,  221,  222,  223,    0,  224,  225,
  226,    0,  227,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  228,  229,  230,  231,  232,  233,  234,  235,
  236,  237,  238,  239,  240,  241,  242,  243,  244,  245,
  246,  247,  248,    0,  249,  250,  251,  252,  253,  254,
    0,  255,  256,  257,  258,    0,  259,    0,  260,  261,
  262,  263,  264,  265,  266,  267,  268,  269,  270,  271,
  272,  273,  274,  275,  276,  277,  345,  278,  279,  280,
  281,    0,  282,  283,  284,  285,  286,    0,  287,  288,
  289,  290,  291,  292,  293,  294,  295,  296,  297,  298,
  299,    0,  300,  301,  302,  303,  304,  305,    0,  306,
  307,  308,  309,  310,  311,  312,  313,    0,  314,  315,
  316,  317,    0,  318,  319,  320,  321,  322,  323,    0,
    0,  324,  325,  326,  327,  328,  329,  330,  331,  332,
    0,    0,    0,    0,    0,  333,    0,  334,  335,  336,
  337,  338,  339,  138,    0,  139,    0,    0,    0,    0,
    0,  140,    0,    0,  141,  142,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  143,  144,    0,  145, 2190,
  146,    0,    0,  147,    0,    0,  148,    0,    0,    0,
    0,    0,    0,  149,    0,  150,  151,    0,    0,    0,
  152,    0,  153,    0,    0,  154,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  155,  156,    0,    0,    0,
  157,    0,  158,    0,  159,    0,    0,    0,    0,    0,
  160,    0,  161,    0,    0,    0,  162,    0,    0,    0,
    0,    0,    0,    0,  163,    0,    0,  164,    0,  165,
    0,    0,    0,  166,  167,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  168,    0,    0,    0,
  170,  171,  172,  173,  174,    0,  175,    0,    0,    0,
    0,    0,  176,    0,  177,  178,    0,    0,  179,  180,
    0,    0,    0,    0,    0,  181,    0,    0,  182,  183,
  184,  185,    0,  186,    0,  187,    0,  188,  189,  190,
  191,  192,    0,    0,    0,    0,  193,    0,  194,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  195,
    0,    0,    0,    0,  196,  197,    0,  198,    0,    0,
    0,  199,    0,  200,  201,  202,  203,    0,  204,    0,
    0,    0,    0,    0,    0,    0,  205,  206,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  207,  208,    0,
  209,  210,  211,    0,    0,    0,    0,  212,  213,    0,
  214,  215,    0,  216,    0,    0,  217,  218,    0,    0,
    0,  219,  220,    0,    0,    0,    0,  221,  222,  223,
    0,  224,  225,  226,    0,  227,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  228,  229,  230,  231,  232,
  233,  234,  235,  236,  237,  238,  239,  240,  241,  242,
  243,  244,  245,  246,  247,  248,    0,  249,  250,  251,
  252,  253,  254,    0,  255,  256,  257,  258,    0,  259,
    0,  260,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,    0,
  278,  279,  280,  281,    0,  282,  283,  284,  285,  286,
    0,  287,  288,  289,  290,  291,  292,  293,  294,  295,
  296,  297,  298,  299,    0,  300,  301,  302,  303,  304,
  305,    0,  306,  307,  308,  309,  310,  311,  312,  313,
    0,  314,  315,  316,  317,    0,  318,  319,  320,  321,
  322,  323,    0,    0,  324,  325,  326,  327,  328,  329,
  330,  331,  332,    0,    0,    0,    0,    0,  333,    0,
  334,  335,  336,  337,  338,  339,  138,    0,  139,    0,
    0,    0,    0,    0,  140,    0,    0,  141,  142,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  143,  144,
    0,  145, 2481,  146,    0,    0,  147,    0,    0,  148,
    0,    0,    0,    0,    0,    0,  149,    0,  150,  151,
    0,    0,    0,  152,    0,  153,    0,    0,  154,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  155,  156,
    0,    0,    0,  157,    0,  158,    0,  159,    0,    0,
    0,    0,    0,  160,    0,  161,    0,    0,    0,  162,
    0,    0,    0,    0,    0,    0,    0,  163,    0,    0,
  164,    0,  165,    0,    0,    0,  166,  167,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  168,
    0,    0,    0,  170,  171,  172,  173,  174,    0,  175,
    0,    0,    0,    0,    0,  176,    0,  177,  178,    0,
    0,  179,  180,    0,    0,    0,    0,    0,  181,    0,
    0,  182,  183,  184,  185,    0,  186,    0,  187,    0,
  188,  189,  190,  191,  192,    0,    0,    0,    0,  193,
    0,  194,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  195,    0,    0,    0,    0,  196,  197,    0,
  198,    0,    0,    0,  199,    0,  200,  201,  202,  203,
    0,  204,    0,    0,    0,    0,    0,    0,    0,  205,
  206,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  207,  208,    0,  209,  210,  211,    0,    0,    0,    0,
  212,  213,    0,  214,  215,    0,  216,    0,    0,  217,
  218,    0,    0,    0,  219,  220,    0,    0,    0,    0,
  221,  222,  223,    0,  224,  225,  226,    0,  227,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  228,  229,
  230,  231,  232,  233,  234,  235,  236,  237,  238,  239,
  240,  241,  242,  243,  244,  245,  246,  247,  248,    0,
  249,  250,  251,  252,  253,  254,    0,  255,  256,  257,
  258,    0,  259,    0,  260,  261,  262,  263,  264,  265,
  266,  267,  268,  269,  270,  271,  272,  273,  274,  275,
  276,  277,    0,  278,  279,  280,  281,    0,  282,  283,
  284,  285,  286,    0,  287,  288,  289,  290,  291,  292,
  293,  294,  295,  296,  297,  298,  299,    0,  300,  301,
  302,  303,  304,  305,    0,  306,  307,  308,  309,  310,
  311,  312,  313,    0,  314,  315,  316,  317,    0,  318,
  319,  320,  321,  322,  323,    0,    0,  324,  325,  326,
  327,  328,  329,  330,  331,  332,    0,    0,    0,    0,
    0,  333,    0,  334,  335,  336,  337,  338,  339,  138,
    0,  139,    0,    0,    0,    0,    0,  140,    0,    0,
  141,  142,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  143,  144,    0,  145,    0,  146,    0,    0,  147,
    0,    0,  148,    0,    0,    0,    0,    0,    0,  149,
    0,  150,  151,    0,    0,    0,  152,    0,  153,    0,
    0,  154, 2568,    0,    0,    0,    0,    0,    0,    0,
    0,  155,  156,    0,    0,    0,  157,    0,  158,    0,
  159,    0,    0,    0,    0,    0,  160,    0,  161,    0,
    0,    0,  162,    0,    0,    0,    0,    0,    0,    0,
  163,    0,    0,  164,    0,  165,    0,    0,    0,  166,
  167,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  168,    0,    0,    0,  170,  171,  172,  173,
  174,    0,  175,    0,    0,    0,    0,    0,  176,    0,
  177,  178,    0,    0,  179,  180,    0,    0,    0,    0,
    0,  181,    0,    0,  182,  183,  184,  185,    0,  186,
    0,  187,    0,  188,  189,  190,  191,  192,    0,    0,
    0,    0,  193,    0,  194,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  195,    0,    0,    0,    0,
  196,  197,    0,  198,    0,    0,    0,  199,    0,  200,
  201,  202,  203,    0,  204,    0,    0,    0,    0,    0,
    0,    0,  205,  206,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  207,  208,    0,  209,  210,  211,    0,
    0,    0,    0,  212,  213,    0,  214,  215,    0,  216,
    0,    0,  217,  218,    0,    0,    0,  219,  220,    0,
    0,    0,    0,  221,  222,  223,    0,  224,  225,  226,
    0,  227,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  228,  229,  230,  231,  232,  233,  234,  235,  236,
  237,  238,  239,  240,  241,  242,  243,  244,  245,  246,
  247,  248,    0,  249,  250,  251,  252,  253,  254,    0,
  255,  256,  257,  258,    0,  259,    0,  260,  261,  262,
  263,  264,  265,  266,  267,  268,  269,  270,  271,  272,
  273,  274,  275,  276,  277,    0,  278,  279,  280,  281,
    0,  282,  283,  284,  285,  286,    0,  287,  288,  289,
  290,  291,  292,  293,  294,  295,  296,  297,  298,  299,
    0,  300,  301,  302,  303,  304,  305,    0,  306,  307,
  308,  309,  310,  311,  312,  313,    0,  314,  315,  316,
  317,    0,  318,  319,  320,  321,  322,  323,    0,    0,
  324,  325,  326,  327,  328,  329,  330,  331,  332,    0,
    0,    0,    0,    0,  333,    0,  334,  335,  336,  337,
  338,  339,  138,    0,  139,    0,    0,    0,    0,    0,
  140,    0,    0,  141,  142,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  143,  144,    0,  145,    0,  146,
    0,    0,  147,    0,    0,  148,    0,    0,    0,    0,
    0,    0,  149,    0,  150,  151,    0,    0,    0,  152,
    0,  153,    0,    0,  154,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  155,  156,    0,    0,    0,  157,
    0,  158,    0,  159,    0,    0,    0,    0,    0,  160,
    0,  161,    0,    0,    0,  162,    0,    0,    0,    0,
    0,    0,    0,  163,    0,    0,  164,    0,  165,    0,
    0,    0,  166,  167,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  168,    0,    0,    0,  170,
  171,  172,  173,  174,    0,  175,    0,    0,    0,    0,
    0,  176,    0,  177,  178,    0,    0,  179,  180,    0,
    0,    0,    0,    0,  181,    0,    0,  182,  183,  184,
  185,    0,  186,    0,  187,    0,  188,  189,  190,  191,
  192,    0,    0,    0,    0,  193,    0,  194,    0,    0,
    0, 2667,    0,    0,    0,    0,    0,    0,  195,    0,
    0,    0,    0,  196,  197,    0,  198,    0,    0,    0,
  199,    0,  200,  201,  202,  203,    0,  204,    0,    0,
    0,    0,    0,    0,    0,  205,  206,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  207,  208,    0,  209,
  210,  211,    0,    0,    0,    0,  212,  213,    0,  214,
  215,    0,  216,    0,    0,  217,  218,    0,    0,    0,
  219,  220,    0,    0,    0,    0,  221,  222,  223,    0,
  224,  225,  226,    0,  227,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  228,  229,  230,  231,  232,  233,
  234,  235,  236,  237,  238,  239,  240,  241,  242,  243,
  244,  245,  246,  247,  248,    0,  249,  250,  251,  252,
  253,  254,    0,  255,  256,  257,  258,    0,  259,    0,
  260,  261,  262,  263,  264,  265,  266,  267,  268,  269,
  270,  271,  272,  273,  274,  275,  276,  277,    0,  278,
  279,  280,  281,    0,  282,  283,  284,  285,  286,    0,
  287,  288,  289,  290,  291,  292,  293,  294,  295,  296,
  297,  298,  299,    0,  300,  301,  302,  303,  304,  305,
    0,  306,  307,  308,  309,  310,  311,  312,  313,    0,
  314,  315,  316,  317,    0,  318,  319,  320,  321,  322,
  323,    0,    0,  324,  325,  326,  327,  328,  329,  330,
  331,  332,    0,    0,    0,    0,    0,  333,    0,  334,
  335,  336,  337,  338,  339,  138,    0,  139,    0,    0,
    0,    0,    0,  140,    0,    0,  141,  142,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  143,  144,    0,
  145,    0,  146,    0,    0,  147,    0,    0,  148,    0,
    0,    0,    0,    0,    0,  149,    0,  150,  151,    0,
    0,    0,  152,    0,  153,    0,    0,  154,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  155,  156,    0,
    0,    0,  157,    0,  158,    0,  159,    0,    0,    0,
    0,    0,  160,    0,  161,    0,    0,    0,  162,    0,
    0,    0,    0,    0,    0,    0,  163,    0,    0,  164,
    0,  165,    0,    0,    0,  166,  167,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  168,    0,
    0,    0,  170,  171,  172,  173,  174,    0,  175,    0,
    0,    0,    0,    0,  176,    0,  177,  178,    0,    0,
  179,  180,    0,    0,    0,    0,    0,  181,    0,    0,
  182,  183,  184,  185,    0,  186,    0,  187,    0,  188,
  189,  190,  191,  192,    0,    0,    0,    0,  193,    0,
  194,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  195,    0,    0,    0,    0,  196,  197,    0,  198,
    0,    0,    0,  199,    0,  200,  201,  202,  203, 2717,
  204,    0,    0,    0,    0,    0,    0,    0,  205,  206,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  207,
  208,    0,  209,  210,  211,    0,    0,    0,    0,  212,
  213,    0,  214,  215,    0,  216,    0,    0,  217,  218,
    0,    0,    0,  219,  220,    0,    0,    0,    0,  221,
  222,  223,    0,  224,  225,  226,    0,  227,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  228,  229,  230,
  231,  232,  233,  234,  235,  236,  237,  238,  239,  240,
  241,  242,  243,  244,  245,  246,  247,  248,    0,  249,
  250,  251,  252,  253,  254,    0,  255,  256,  257,  258,
    0,  259,    0,  260,  261,  262,  263,  264,  265,  266,
  267,  268,  269,  270,  271,  272,  273,  274,  275,  276,
  277,    0,  278,  279,  280,  281,    0,  282,  283,  284,
  285,  286,    0,  287,  288,  289,  290,  291,  292,  293,
  294,  295,  296,  297,  298,  299,    0,  300,  301,  302,
  303,  304,  305,    0,  306,  307,  308,  309,  310,  311,
  312,  313,    0,  314,  315,  316,  317,    0,  318,  319,
  320,  321,  322,  323,    0,    0,  324,  325,  326,  327,
  328,  329,  330,  331,  332,    0,    0,    0,    0,    0,
  333,    0,  334,  335,  336,  337,  338,  339,  138,    0,
  139,    0,    0,    0,    0,    0,  140,    0,    0,  141,
  142,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  143,  144,    0,  145,    0,  146,    0,    0,  147,    0,
    0,  148,    0,    0,    0,    0,    0,    0,  149,    0,
  150,  151,    0,    0,    0,  152,    0,  153,    0,    0,
  154,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  155,  156,    0,    0,    0,  157,    0,  158,    0,  159,
    0,    0,    0,    0,    0,  160,    0,  161,    0,    0,
    0,  162,    0,    0,    0,    0,    0,    0,    0,  163,
    0,    0,  164,    0,  165,    0,    0,    0,  166,  167,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  168,    0,    0,    0,  170,  171,  172,  173,  174,
    0,  175,    0,    0,    0,    0,    0,  176,    0,  177,
  178,    0,    0,  179,  180,    0,    0,    0,    0,    0,
  181,    0,    0,  182,  183,  184,  185,    0,  186,    0,
  187,    0,  188,  189,  190,  191,  192,    0,    0,    0,
    0,  193,    0,  194,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  195,    0,    0,    0,    0,  196,
  197,    0,  198,    0,    0,    0,  199,    0,  200,  201,
  202,  203, 2834,  204,    0,    0,    0,    0,    0,    0,
    0,  205,  206,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  207,  208,    0,  209,  210,  211,    0,    0,
    0,    0,  212,  213,    0,  214,  215,    0,  216,    0,
    0,  217,  218,    0,    0,    0,  219,  220,    0,    0,
    0,    0,  221,  222,  223,    0,  224,  225,  226,    0,
  227,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  228,  229,  230,  231,  232,  233,  234,  235,  236,  237,
  238,  239,  240,  241,  242,  243,  244,  245,  246,  247,
  248,    0,  249,  250,  251,  252,  253,  254,    0,  255,
  256,  257,  258,    0,  259,    0,  260,  261,  262,  263,
  264,  265,  266,  267,  268,  269,  270,  271,  272,  273,
  274,  275,  276,  277,    0,  278,  279,  280,  281,    0,
  282,  283,  284,  285,  286,    0,  287,  288,  289,  290,
  291,  292,  293,  294,  295,  296,  297,  298,  299,    0,
  300,  301,  302,  303,  304,  305,    0,  306,  307,  308,
  309,  310,  311,  312,  313,    0,  314,  315,  316,  317,
    0,  318,  319,  320,  321,  322,  323,    0,    0,  324,
  325,  326,  327,  328,  329,  330,  331,  332,    0,    0,
    0,    0,    0,  333,    0,  334,  335,  336,  337,  338,
  339,  138,    0,  139,    0,    0,    0,    0,    0,  140,
    0,    0,  141,  142,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  143,  144,    0,  145,    0,  146,    0,
    0,  147,    0,    0,  148,    0,    0,    0,    0,    0,
    0,  149,    0,  150,  151, 3112,    0,    0,  152,    0,
  153,    0,    0,  154,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  155,  156,    0,    0,    0,  157,    0,
  158,    0,  159,    0,    0,    0,    0,    0,  160,    0,
  161,    0,    0,    0,  162,    0,    0,    0,    0,    0,
    0,    0,  163,    0,    0,  164,    0,  165,    0,    0,
    0,  166,  167,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  168,    0,    0,    0,  170,  171,
  172,  173,  174,    0,  175,    0,    0,    0,    0,    0,
  176,    0,  177,  178,    0,    0,  179,  180,    0,    0,
    0,    0,    0,  181,    0,    0,  182,  183,  184,  185,
    0,  186,    0,  187,    0,  188,  189,  190,  191,  192,
    0,    0,    0,    0,  193,    0,  194,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  195,    0,    0,
    0,    0,  196,  197,    0,  198,    0,    0,    0,  199,
    0,  200,  201,  202,  203,    0,  204,    0,    0,    0,
    0,    0,    0,    0,  205,  206,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  207,  208,    0,  209,  210,
  211,    0,    0,    0,    0,  212,  213,    0,  214,  215,
    0,  216,    0,    0,  217,  218,    0,    0,    0,  219,
  220,    0,    0,    0,    0,  221,  222,  223,    0,  224,
  225,  226,    0,  227,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  228,  229,  230,  231,  232,  233,  234,
  235,  236,  237,  238,  239,  240,  241,  242,  243,  244,
  245,  246,  247,  248,    0,  249,  250,  251,  252,  253,
  254,    0,  255,  256,  257,  258,    0,  259,    0,  260,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,    0,  278,  279,
  280,  281,    0,  282,  283,  284,  285,  286,    0,  287,
  288,  289,  290,  291,  292,  293,  294,  295,  296,  297,
  298,  299,    0,  300,  301,  302,  303,  304,  305,    0,
  306,  307,  308,  309,  310,  311,  312,  313,    0,  314,
  315,  316,  317,    0,  318,  319,  320,  321,  322,  323,
    0,    0,  324,  325,  326,  327,  328,  329,  330,  331,
  332,    0,    0,    0,    0,    0,  333,    0,  334,  335,
  336,  337,  338,  339,  138,    0,  139,    0,    0,    0,
    0,    0,  140,    0,    0,  141,  142,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  143,  144,    0,  145,
    0,  146,    0,    0,  147,    0,    0,  148,    0,    0,
    0,    0,    0,    0,  149,    0,  150,  151,    0,    0,
    0,  152,    0,  153,    0,    0,  154,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  155,  156,    0,    0,
    0,  157,    0,  158,    0,  159,    0,    0,    0,    0,
    0,  160,    0,  161,    0,    0,    0,  162,    0,    0,
    0,    0,    0,    0,    0,  163,    0,    0,  164,    0,
  165,    0,    0,    0,  166,  167,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  168,    0,    0,
    0,  170,  171,  172,  173,  174,    0,  175,    0,    0,
    0,    0,    0,  176,    0,  177,  178,    0,    0,  179,
  180,    0,    0,    0,    0,    0,  181,    0,    0,  182,
  183,  184,  185,    0,  186,    0,  187,    0,  188,  189,
  190,  191,  192,    0,    0,    0,    0,  193,    0,  194,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  195,    0,    0,    0,    0,  196,  197,    0,  198,    0,
 3200,    0,  199,    0,  200,  201,  202,  203,    0,  204,
    0,    0,    0,    0,    0,    0,    0,  205,  206,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  207,  208,
    0,  209,  210,  211,    0,    0,    0,    0,  212,  213,
    0,  214,  215,    0,  216,    0,    0,  217,  218,    0,
    0,    0,  219,  220,    0,    0,    0,    0,  221,  222,
  223,    0,  224,  225,  226,    0,  227,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  228,  229,  230,  231,
  232,  233,  234,  235,  236,  237,  238,  239,  240,  241,
  242,  243,  244,  245,  246,  247,  248,    0,  249,  250,
  251,  252,  253,  254,    0,  255,  256,  257,  258,    0,
  259,    0,  260,  261,  262,  263,  264,  265,  266,  267,
  268,  269,  270,  271,  272,  273,  274,  275,  276,  277,
    0,  278,  279,  280,  281,    0,  282,  283,  284,  285,
  286,    0,  287,  288,  289,  290,  291,  292,  293,  294,
  295,  296,  297,  298,  299,    0,  300,  301,  302,  303,
  304,  305,    0,  306,  307,  308,  309,  310,  311,  312,
  313,    0,  314,  315,  316,  317,    0,  318,  319,  320,
  321,  322,  323,    0,    0,  324,  325,  326,  327,  328,
  329,  330,  331,  332,    0,    0,    0,    0,    0,  333,
    0,  334,  335,  336,  337,  338,  339,  138,    0,  139,
    0,    0,    0,    0,    0,  140,    0,    0,  141,  142,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  143,
  144,    0,  145,    0,  146,    0,    0,  147,    0,    0,
  148,    0,    0,    0,    0,    0,    0,  149,    0,  150,
  151,    0,    0,    0,  152,    0,  153,    0,    0,  154,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  155,
  156,    0,    0,    0,  157,    0,  158,    0,  159,    0,
    0,    0,    0,    0,  160,    0,  161,    0,    0,    0,
  162,    0,    0,    0,    0,    0,    0,    0,  163,    0,
    0,  164,    0,  165,    0,    0,    0,  166,  167,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  168,    0,    0,    0,  170,  171,  172,  173,  174,    0,
  175,    0,    0,    0,    0,    0,  176,    0,  177,  178,
    0,    0,  179,  180,    0,    0,    0,    0,    0,  181,
    0,    0,  182,  183,  184,  185,    0,  186,    0,  187,
    0,  188,  189,  190,  191,  192,    0,    0,    0,    0,
  193,    0,  194,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  195,    0,    0,    0,    0,  196,  197,
    0,  198,    0,    0,    0,  199,    0,  200,  201,  202,
  203,    0,  204,    0,    0,    0,    0,    0,    0,    0,
  205,  206,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  207,  208,    0,  209,  210,  211,    0,    0,    0,
    0,  212,  213,    0,  214,  215,    0,  216,    0,    0,
  217,  218,    0,    0,    0,  219,  220,    0,    0,    0,
    0,  221,  222,  223,    0,  224,  225,  226,    0,  227,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  228,
  229,  230,  231,  232,  233,  234,  235,  236,  237,  238,
  239,  240,  241,  242,  243,  244,  245,  246,  247,  248,
    0,  249,  250,  251,  252,  253,  254,    0,  255,  256,
  257,  258,    0,  259,    0,  260,  261,  262,  263,  264,
  265,  266,  267,  268,  269,  270,  271,  272,  273,  274,
  275,  276,  277,    0,  278,  279,  280,  281,    0,  282,
  283,  284,  285,  286,    0,  287,  288,  289,  290,  291,
  292,  293,  294,  295,  296,  297,  298,  299,    0,  300,
  301,  302,  303,  304,  305,    0,  306,  307,  308,  309,
  310,  311,  312,  313,    0,  314,  315,  316,  317,    0,
  318,  319,  320,  321,  322,  323,    0,    0,  324,  325,
  326,  327,  328,  329,  330,  331,  332,    0,    0,    0,
    0,    0,  333,    0,  334,  335,  336,  337,  338,  339,
  138,    0,  139,    0,    0,    0,    0,    0,  140,    0,
    0,  141,  142,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  143,  144,    0,  145,    0,  146,    0,    0,
  147,    0,    0,  148,    0,    0,    0,    0,    0,    0,
  149,    0,  150,  151,    0,    0,    0,  152,    0,  153,
    0,    0,  154,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  155,  156,    0,    0,    0,  157,    0,  158,
    0,  159,    0,    0,    0,    0,    0,  160,    0,  161,
    0,    0,    0,  162,    0,    0,    0,    0,    0,    0,
    0,  163,    0,    0,  164,    0,  165,    0,    0,    0,
  166,  167,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  168,    0,    0,    0,  170,  171,  172,
  173,  174,    0,  175,    0,    0,    0,    0,    0,  176,
    0,  177,  178,    0,    0,  179,  180,    0,    0,    0,
    0,    0,  181,    0,    0,  182,  183,  184,  185,    0,
  186,    0,  187,    0,  188,  189,  190,  191,  192,    0,
    0,    0,    0,  193,    0,  194,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  195,    0,    0,    0,
    0,  196,  197,    0,  198,    0,    0,    0,  199,    0,
  200,  201,  202,  203,    0,  204,    0,    0,    0,    0,
    0,    0,    0,  205,  206,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  207,  208,    0,  209,  210,  211,
    0,    0,    0,    0,  212,  213,    0,  214,  215,    0,
  216,    0,    0,  217,  218,    0,    0,    0,  219,  220,
    0,    0,    0,    0,  221,  222,  223,    0,  224,  225,
  226,    0,  227,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  228,  229,  230,  231,  232,  233,  234,  235,
  236,  237,  238,  239,  240,  241,  242,  243,  244,  245,
  246,  247,  248,    0,  249,  250,  251,  252,  253,  254,
    0,  255,  256,  257,  258,    0,  259,    0,  260,  261,
  262,  263,  264,  265,  266,  267,  268,  269,  270,  271,
  272,  273,  274,  275,  276,  277,    0,  278,  279,  280,
  281,    0,  282,  283,  284,  285,  286,    0,  287,  288,
  289,  290,  291,  292,  293,  294,  295,  296,  297,  298,
  299,    0,  300,  301,  302,  303,  304,  305,    0,  306,
  542,  308,  309,  310,  311,  312,  313,    0,  314,  315,
  316,  317,    0,  318,  319,  320,  321,  322,  323,    0,
    0,  324,  325,  326,  327,  328,  329,  330,  331,  332,
    0,    0,    0,    0,    0,  333,    0,  334,  335,  336,
  337,  338,  339,  138,    0,  139,    0,    0,    0,    0,
    0,  140,    0,    0,  141,  142,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  143,  144,    0,  145,    0,
  146,    0,    0,  147,    0,    0,  148,    0,    0,    0,
    0,    0,    0,  149,    0,  150,  151,    0,    0,    0,
  152,    0,  153,    0,    0,  154,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  155,  156,    0,    0,    0,
  157,    0,  158,    0,  159,    0,    0,    0,    0,    0,
  160,    0,  161,    0,    0,    0,  162,    0,    0,    0,
    0,    0,    0,    0,  163,    0,    0,  164,    0,  165,
    0,    0,    0,  166,  167,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  168,    0,    0,    0,
  170,  171,  172,  173,  174,    0,  175,    0,    0,    0,
    0,    0,  176,    0,  177,  178,    0,    0,  179,  180,
    0,    0,    0,    0,    0,  181,    0,    0,  182,  183,
  184,  185,    0,  186,    0,  187,    0,  188,  189,  190,
  191,  192,    0,    0,    0,    0,  193,    0,  194,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  195,
    0,    0,    0,    0,  196,  197,    0,  198,    0,    0,
    0,  199,    0,  200,  201,  202,  203,    0,  204,    0,
    0,    0,    0,    0,    0,    0,  205,  206,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  207,  208,    0,
  209,  210,  211,    0,    0,    0,    0,  212,  213,    0,
  214,  215,    0,  216,    0,    0,  217,  218,    0,    0,
    0,  219,  220,    0,    0,    0,    0,  221,  222,  223,
    0,  224,  225,  226,    0,  227,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  228,  229,  230,  231,  232,
  233,  234,  235,  236,  237,  238,  239,  240,  241,  242,
  243,  244,  245,  246,  247,  248,    0,  249,  250,  251,
  252,  253,  254,    0,  255,  256,  257,  258,    0,  259,
    0,  260,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,    0,
  278,  279,  280,  281,    0,  282,  283,  284,  285,  286,
    0,  287,  288,  289,  290,  291,  292,  293,  294,  295,
  296,  297,  298,  299,    0,  300,  301,  302,  303,  304,
  305,    0,  306,  572,  308,  309,  310,  311,  312,  313,
    0,  314,  315,  316,  317,    0,  318,  319,  320,  321,
  322,  323,    0,    0,  324,  325,  326,  327,  328,  329,
  330,  331,  332,    0,    0,    0,    0,    0,  333,    0,
  334,  335,  336,  337,  338,  339,  138,    0,  139,    0,
    0,    0,    0,    0,  140,    0,    0,  141,  142,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  143,  144,
    0,  145,    0,  146,    0,    0,  147,    0,    0,  148,
    0,    0,    0,    0,    0,    0,  149,    0,  150,  151,
    0,    0,    0,  152,    0,  153,    0,    0,  154,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  155,  156,
    0,    0,    0,  157,    0,  158,    0,  159,    0,    0,
    0,    0,    0,  160,    0,  161,    0,    0,    0,  162,
    0,    0,    0,    0,    0,    0,    0,  163,    0,    0,
  164,    0,  165,    0,    0,    0,  166,  167,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  168,
    0,    0,    0,  170,  171,  172,  173,  174,    0,  175,
    0,    0,    0,    0,    0,  176,    0,  177,  178,    0,
    0,  179,  180,    0,    0,    0,    0,    0,  181,    0,
    0,  182,  183,  184,  185,    0,  186,    0,  187,    0,
  188,  189,  190,  191,  192,    0,    0,    0,    0,  193,
    0,  194,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  195,    0,    0,    0,    0,  196,  197,    0,
  198,    0,    0,    0,  199,    0,  200,  201,  202,  203,
    0,  204,    0,    0,    0,    0,    0,    0,    0,  205,
  206,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  207,  208,    0,  209,  210,  211,    0,    0,    0,    0,
  212,  213,    0,  214,  215,    0,  216,    0,    0,  217,
  218,    0,    0,    0,  219,  220,    0,    0,    0,    0,
  221,  222,  223,    0,  224,  225,  226,    0,  227,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  228,  229,
  230,  231,  232,  233,  234,  235,  236,  237,  238,  239,
  240,  241,  242,  243,  244,  245,  246,  247,  248,    0,
  249,  250,  251,  252,  253,  254,    0,  255,  256,  257,
  258,    0,  259,    0,  260,  261,  262,  263,  264,  265,
  266,  267,  268,  269,  270,  271,  272,  273,  274,  275,
  276,  277,    0,  278,  279,  280,  281,    0,  282,  283,
  284,  285,  286,    0,  287,  288,  289,  290,  291,  292,
  293,  294,  295,  296,  297,  298,  299,    0,  300,  301,
  302,  303,  304,  305,    0,  306,  606,  308,  309,  310,
  311,  312,  313,    0,  314,  315,  316,  317,    0,  318,
  319,  320,  321,  322,  323,    0,    0,  324,  325,  326,
  327,  328,  329,  330,  331,  332,    0,    0,    0,    0,
    0,  333,    0,  334,  335,  336,  337,  338,  339, 1032,
    0, 1032,    0,    0,    0,    0,    0, 1032,    0,    0,
 1032, 1032,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1032, 1032,    0, 1032,    0, 1032,    0,    0, 1032,
    0,    0, 1032,    0,    0,    0,    0,    0,    0, 1032,
    0, 1032, 1032,    0,    0,    0, 1032,    0, 1032,    0,
    0, 1032,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1032, 1032,    0,    0,    0, 1032,    0, 1032,    0,
 1032,    0,    0,    0,    0,    0, 1032,    0, 1032,    0,
    0,    0, 1032,    0,    0,    0,    0,    0,    0,    0,
 1032,    0,    0, 1032,    0, 1032,    0,    0,    0, 1032,
 1032,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1032,    0,    0,    0, 1032, 1032, 1032, 1032,
 1032,    0, 1032,    0,    0,    0,    0,    0, 1032,    0,
 1032, 1032,    0,    0, 1032, 1032,    0,    0,    0,    0,
    0, 1032,    0,    0, 1032, 1032, 1032, 1032,    0, 1032,
    0, 1032,    0, 1032, 1032, 1032, 1032, 1032,    0,    0,
    0,    0, 1032,    0, 1032,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1032,    0,    0,    0,    0,
 1032, 1032,    0, 1032,    0,    0,    0, 1032,    0, 1032,
 1032, 1032, 1032,    0, 1032,    0,    0,    0,    0,    0,
    0,    0, 1032, 1032,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1032, 1032,    0, 1032, 1032, 1032,    0,
    0,    0,    0, 1032, 1032,    0, 1032, 1032,    0, 1032,
    0,    0, 1032, 1032,    0,    0,    0, 1032, 1032,    0,
    0,    0,    0, 1032, 1032, 1032,    0, 1032, 1032, 1032,
    0, 1032,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032,
 1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032,
 1032, 1032,    0, 1032, 1032, 1032, 1032, 1032, 1032,    0,
 1032, 1032, 1032, 1032,    0, 1032,    0, 1032, 1032, 1032,
 1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032,
 1032, 1032, 1032, 1032, 1032,    0, 1032, 1032, 1032, 1032,
    0, 1032, 1032, 1032, 1032, 1032,    0, 1032, 1032, 1032,
 1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032,
    0, 1032, 1032, 1032, 1032, 1032, 1032,    0, 1032, 1032,
 1032, 1032, 1032, 1032, 1032, 1032,    0, 1032, 1032, 1032,
 1032,    0, 1032, 1032, 1032, 1032, 1032, 1032,    0,    0,
 1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032, 1032,    0,
    0,    0,    0,    0, 1032,    0, 1032, 1032, 1032, 1032,
 1032, 1032, 1114,    0, 1114,    0,    0,    0,    0,    0,
 1114,    0,    0, 1114, 1114,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1114, 1114,    0, 1114,    0, 1114,
    0,    0, 1114,    0,    0, 1114,    0,    0,    0,    0,
    0,    0, 1114,    0, 1114, 1114,    0,    0,    0, 1114,
    0, 1114,    0,    0, 1114,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1114, 1114,    0,    0,    0, 1114,
    0, 1114,    0, 1114,    0,    0,    0,    0,    0, 1114,
    0, 1114,    0,    0,    0, 1114,    0,    0,    0,    0,
    0,    0,    0, 1114,    0,    0, 1114,    0, 1114,    0,
    0,    0, 1114, 1114,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1114,    0,    0,    0, 1114,
 1114, 1114, 1114, 1114,    0, 1114,    0,    0,    0,    0,
    0, 1114,    0, 1114, 1114,    0,    0, 1114, 1114,    0,
    0,    0,    0,    0, 1114,    0,    0, 1114, 1114, 1114,
 1114,    0, 1114,    0, 1114,    0, 1114, 1114, 1114, 1114,
 1114,    0,    0,    0,    0, 1114,    0, 1114,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1114,    0,
    0,    0,    0, 1114, 1114,    0, 1114,    0,    0,    0,
 1114,    0, 1114, 1114, 1114, 1114,    0, 1114,    0,    0,
    0,    0,    0,    0,    0, 1114, 1114,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1114, 1114,    0, 1114,
 1114, 1114,    0,    0,    0,    0, 1114, 1114,    0, 1114,
 1114,    0, 1114,    0,    0, 1114, 1114,    0,    0,    0,
 1114, 1114,    0,    0,    0,    0, 1114, 1114, 1114,    0,
 1114, 1114, 1114,    0, 1114,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1114, 1114, 1114, 1114, 1114, 1114,
 1114, 1114, 1114, 1114, 1114, 1114, 1114, 1114, 1114, 1114,
 1114, 1114, 1114, 1114, 1114,    0, 1114, 1114, 1114, 1114,
 1114, 1114,    0, 1114, 1114, 1114, 1114,    0, 1114,    0,
 1114, 1114, 1114, 1114, 1114, 1114, 1114, 1114, 1114, 1114,
 1114, 1114, 1114, 1114, 1114, 1114, 1114, 1114,    0, 1114,
 1114, 1114, 1114,    0, 1114, 1114, 1114, 1114, 1114,    0,
 1114, 1114, 1114, 1114, 1114, 1114, 1114, 1114, 1114, 1114,
 1114, 1114, 1114,    0, 1114, 1114, 1114, 1114, 1114, 1114,
    0, 1114, 1114, 1114, 1114, 1114, 1114, 1114, 1114,    0,
 1114, 1114, 1114, 1114,    0, 1114, 1114, 1114, 1114, 1114,
 1114,    0,    0, 1114, 1114, 1114, 1114, 1114, 1114, 1114,
 1114, 1114,    0,    0,    0,    0,    0, 1114,    0, 1114,
 1114, 1114, 1114, 1114, 1114, 1112,    0, 1112,    0,    0,
    0,    0,    0, 1112,    0,    0, 1112, 1112,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1112, 1112,    0,
 1112,    0, 1112,    0,    0, 1112,    0,    0, 1112,    0,
    0,    0,    0,    0,    0, 1112,    0, 1112, 1112,    0,
    0,    0, 1112,    0, 1112,    0,    0, 1112,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1112, 1112,    0,
    0,    0, 1112,    0, 1112,    0, 1112,    0,    0,    0,
    0,    0, 1112,    0, 1112,    0,    0,    0, 1112,    0,
    0,    0,    0,    0,    0,    0, 1112,    0,    0, 1112,
    0, 1112,    0,    0,    0, 1112, 1112,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1112,    0,
    0,    0, 1112, 1112, 1112, 1112, 1112,    0, 1112,    0,
    0,    0,    0,    0, 1112,    0, 1112, 1112,    0,    0,
 1112, 1112,    0,    0,    0,    0,    0, 1112,    0,    0,
 1112, 1112, 1112, 1112,    0, 1112,    0, 1112,    0, 1112,
 1112, 1112, 1112, 1112,    0,    0,    0,    0, 1112,    0,
 1112,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1112,    0,    0,    0,    0, 1112, 1112,    0, 1112,
    0,    0,    0, 1112,    0, 1112, 1112, 1112, 1112,    0,
 1112,    0,    0,    0,    0,    0,    0,    0, 1112, 1112,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1112,
 1112,    0, 1112, 1112, 1112,    0,    0,    0,    0, 1112,
 1112,    0, 1112, 1112,    0, 1112,    0,    0, 1112, 1112,
    0,    0,    0, 1112, 1112,    0,    0,    0,    0, 1112,
 1112, 1112,    0, 1112, 1112, 1112,    0, 1112,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1112, 1112, 1112,
 1112, 1112, 1112, 1112, 1112, 1112, 1112, 1112, 1112, 1112,
 1112, 1112, 1112, 1112, 1112, 1112, 1112, 1112,    0, 1112,
 1112, 1112, 1112, 1112, 1112,    0, 1112, 1112, 1112, 1112,
    0, 1112,    0, 1112, 1112, 1112, 1112, 1112, 1112, 1112,
 1112, 1112, 1112, 1112, 1112, 1112, 1112, 1112, 1112, 1112,
 1112,    0, 1112, 1112, 1112, 1112,    0, 1112, 1112, 1112,
 1112, 1112,    0, 1112, 1112, 1112, 1112, 1112, 1112, 1112,
 1112, 1112, 1112, 1112, 1112, 1112,    0, 1112, 1112, 1112,
 1112, 1112, 1112,    0, 1112, 1112, 1112, 1112, 1112, 1112,
 1112, 1112,    0, 1112, 1112, 1112, 1112,    0, 1112, 1112,
 1112, 1112, 1112, 1112,    0,    0, 1112, 1112, 1112, 1112,
 1112, 1112, 1112, 1112, 1112,    0,    0,    0,    0,    0,
 1112,    0, 1112, 1112, 1112, 1112, 1112, 1112,  514,    0,
  514,    0,    0,    0,    0,    0,  514,    0,    0,  514,
  514,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  514,  514,    0,  514,    0,  514,    0,    0,  514,    0,
    0,  514,    0,    0,    0,    0,    0,    0,  514,    0,
  514,  514,    0,    0,    0,  514,    0,  514,    0,    0,
  514,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  514,  514,    0,    0,    0,  514,    0,  514,    0,  514,
    0,    0,    0,    0,    0,  514,    0,  514,    0,    0,
    0,  514,    0,    0,    0,    0,    0,    0,    0,  514,
    0,    0,  514,    0,  514,    0,    0,    0,  514,  514,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  514,    0,    0,    0,  514,  514,  514,  514,  514,
    0,  514,    0,    0,    0,    0,    0,  514,    0,  514,
  514,    0,    0,  514,  514,    0,    0,    0,    0,    0,
  514,    0,    0,  514,  514,  514,  514,    0,  514,    0,
  514,    0,  514,  514,  514,  514,  514,    0,    0,    0,
    0,  514,    0,  514,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  514,    0,    0,    0,    0,  514,
  514,    0,  514,    0,    0,    0,  514,    0,  514,  514,
  514,  514,    0,  514,    0,    0,    0,    0,    0,    0,
    0,  514,  514,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  514,  514,    0,  514,  514,  514,    0,    0,
    0,    0,  514,  514,    0,  514,  514,    0,  514,    0,
    0,  514,  514,    0,    0,    0,  514,  514,    0,    0,
    0,    0,  514,  514,  514,    0,  514,  514,  514,    0,
  514,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  514,  514,  514,  514,  514,  514,  514,  514,  514,  514,
  514,  514,  514,  514,  514,  514,  514,  514,  514,  514,
  514,    0,  514,  514,  514,  514,  514,  514,    0,  514,
  514,  514,  514,    0,  514,    0,  514,  514,  514,  514,
  514,  514,  514,  514,  514,  514,  514,  514,  514,  514,
  514,  514,  514,  514,    0,  514,  514,  514,  514,    0,
  514,  514,  514,  514,  514,    0,  514,  514,  514,  514,
  514,  514,  514,  514,  514,  514,  514,  514,  514,    0,
  514,  514,  514,  514,  514,  514,    0,  514,  514,  514,
  514,  514,  514,  514,  514,    0,  514,  514,  514,  514,
    0,  514,  514,  514,  514,  514,  514,    0,    0,  514,
  514,  514,  514,  514,  514,  514,  514,  514,    0,    0,
    0,    0,    0,  514,    0,  514,  514,  514,  514,  514,
  514,  157,    0,  157,    0,    0,    0,    0,    0,  157,
    0,    0,  157,  157,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  157,  157,    0,  157,    0,  157,    0,
    0,  157,    0,    0,  157,    0,    0,    0,    0,    0,
    0,  157,    0,  157,  157,    0,    0,    0,  157,    0,
  157,    0,    0,  157,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  157,  157,    0,    0,    0,  157,    0,
  157,    0,  157,    0,    0,    0,    0,    0,  157,    0,
  157,    0,    0,    0,  157,    0,    0,    0,    0,    0,
    0,    0,  157,    0,    0,  157,    0,  157,    0,    0,
    0,  157,  157,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  157,    0,    0,    0,  157,  157,
  157,  157,  157,    0,  157,    0,    0,    0,    0,    0,
  157,    0,  157,  157,    0,    0,  157,  157,    0,    0,
    0,    0,    0,  157,    0,    0,  157,  157,  157,  157,
    0,  157,    0,  157,    0,  157,  157,  157,  157,  157,
    0,    0,    0,    0,  157,    0,  157,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  157,    0,    0,
    0,    0,  157,  157,    0,  157,    0,    0,    0,  157,
    0,  157,  157,  157,  157,    0,  157,    0,    0,    0,
    0,    0,    0,    0,  157,  157,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  157,  157,    0,  157,  157,
  157,    0,    0,    0,    0,  157,  157,    0,  157,  157,
    0,  157,    0,    0,  157,  157,    0,    0,    0,  157,
  157,    0,    0,    0,    0,  157,  157,  157,    0,  157,
  157,  157,    0,  157,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  157,  157,  157,  157,  157,  157,  157,
  157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
  157,  157,  157,  157,    0,  157,  157,  157,  157,  157,
  157,    0,  157,  157,  157,  157,    0,  157,    0,  157,
  157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
  157,  157,  157,  157,  157,  157,  157,    0,  157,  157,
  157,  157,    0,  157,  157,  157,  157,  157,    0,  157,
  157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
  157,  157,    0,  157,  157,  157,  157,  157,  157,    0,
  157,  157,  157,  157,  157,  157,  157,  157,    0,  157,
  157,  157,  157,    0,  157,  157,  157,  157,  157,  157,
    0,    0,  157,  157,  157,  157,  157,  157,  157,  157,
  157,    0,    0,    0,    0,    0,  157,    0,  157,  157,
  157,  157,  157,  157,   60,    0,   60,    0,    0,    0,
    0,    0,   60,    0,    0,   60,   60,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   60,   60,    0,   60,
    0,   60,    0,    0,   60,    0,    0,   60,    0,    0,
    0,    0,    0,    0,   60,    0,   60,   60,    0,    0,
    0,   60,    0,   60,    0,    0,   60,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   60,   60,    0,    0,
    0,   60,    0,   60,    0,   60,    0,    0,    0,    0,
    0,   60,    0,   60,    0,    0,    0,   60,    0,    0,
    0,    0,    0,    0,    0,   60,    0,    0,   60,    0,
   60,    0,    0,    0,   60,   60,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   60,    0,    0,
    0,   60,   60,   60,   60,   60,    0,   60,    0,    0,
    0,    0,    0,   60,    0,   60,   60,    0,    0,   60,
   60,    0,    0,    0,    0,    0,   60,    0,    0,   60,
   60,   60,   60,    0,   60,    0,   60,    0,   60,   60,
   60,   60,   60,    0,    0,    0,    0,   60,    0,   60,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   60,    0,    0,    0,    0,   60,   60,    0,   60,    0,
    0,    0,   60,    0,   60,   60,   60,   60,    0,   60,
    0,    0,    0,    0,    0,    0,    0,   60,   60,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   60,   60,
    0,   60,   60,   60,    0,    0,    0,    0,   60,   60,
    0,   60,   60,    0,   60,    0,    0,   60,   60,    0,
    0,    0,   60,   60,    0,    0,    0,    0,   60,   60,
   60,    0,   60,   60,   60,    0,   60,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   60,   60,   60,   60,
   60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
   60,   60,   60,   60,   60,   60,   60,    0,   60,   60,
   60,   60,   60,   60,    0,   60,   60,   60,   60,    0,
   60,    0,   60,   60,   60,   60,   60,   60,   60,   60,
   60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
    0,   60,   60,   60,   60,    0,   60,   60,   60,   60,
   60,    0,   60,   60,   60,   60,   60,   60,   60,   60,
   60,   60,   60,   60,   60,    0,   60,   60,   60,   60,
   60,   60,    0,   60,   60,   60,   60,   60,   60,   60,
   60,    0,   60,   60,   60,   60,    0,   60,   60,   60,
   60,   60,   60,    0,    0,   60,   60,   60,   60,   60,
   60,   60,   60,   60,    0,    0,    0,    0,    0,   60,
    0,   60,   60,   60,   60,   60,   60,  138,    0,  139,
    0,    0,    0,    0,    0,  140,    0,    0,  141,  142,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  143,
  144,    0,  145,    0,  146,    0,    0,  147,    0,    0,
  148,    0,    0,    0,    0,    0,    0,  149,    0,  150,
  151,    0,    0,    0,  152,    0,  153,    0,    0,  154,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  155,
  156,    0,    0,    0,  157,    0,  158,    0,  159,    0,
    0,    0,    0,    0,  160,    0,  161,    0,    0,    0,
  162,    0,    0,    0,    0,    0,    0,    0,  163,    0,
    0,  164,    0,  165,    0,    0,    0,  166,  167,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  168,    0,    0,    0,  170,  171,  172,  173,  174,    0,
  175,    0,    0,    0,    0,    0,  176,    0,  177,  178,
    0,    0,  179,  180,    0,    0,    0,    0,    0,  181,
    0,    0,  182,  183,  184,  185,    0,  186,    0,  187,
    0,  188,  189,  190,  191,  192,    0,    0,    0,    0,
  193,    0,  194,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  195,    0,    0,    0,    0,  196,  197,
    0,  198,    0,    0,    0,  199,    0,  200,  201,  202,
  203,    0,  204,    0,    0,    0,    0,    0,    0,    0,
  205,  206,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  207,  208,    0,  209,  210,  211,    0,    0,    0,
    0,  212,  213,    0,  214,  215,    0,  216,    0,    0,
  217,  218,    0,    0,    0,  219,  220,    0,    0,    0,
    0,  221,  222,  223,    0,  224,  225,  226,    0,  227,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  229,  230,  231,  232,  233,  234,  235,  236,  237,  238,
  239,  240,  241,  242,  243,  244,  245,  246,  247,  248,
    0,  249,  250,  251,  252,  253,  254,    0,  255,  256,
  257,  258,    0,  259,    0,  260,  261,  262,  263,  264,
  265,  266,  267,  268,  269,  270,  271,  272,  273,  274,
  275,  276,  277,    0,  278,  279,  280,  281,    0,  282,
  283,  284,  285,  286,    0,  287,  288,  289,  290,  291,
  292,  293,  294,  295,  296,  297,  298,  299,    0,  300,
  301,  302,  303,  304,  305,    0,  306,  307,  308,  309,
  310,  311,  312,  313,    0,  314,  315,  316,  317,    0,
  318,  319,  320,  321,  322,  323,    0,    0,  324,  325,
  326,  327,  328,  329,  330,  331,  332,    0,    0,    0,
    0,    0,  333,    0,  334,  335,  336,  337,  338,  339,
  138,    0,  139,    0,    0,    0,    0,    0,  140,    0,
    0,  141,  142,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  143,  144,    0,  145,    0,  146,    0,    0,
  147,    0,    0,  148,    0,    0,    0,    0,    0,    0,
  149,    0,  150,  151,    0,    0,    0,  152,    0,  153,
    0,    0,  154,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  155,  156,    0,    0,    0,  157,    0,  158,
    0,  159,    0,    0,    0,    0,    0,  160,    0,  161,
    0,    0,    0,  162,    0,    0,    0,    0,    0,    0,
    0,  163,    0,    0,  164,    0,  165,    0,    0,    0,
  166,  167,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  168,    0,    0,    0,  170,  171,  172,
  173,  174,    0,  175,    0,    0,    0,    0,    0,  176,
    0,  177,  178,    0,    0,  179,  180,    0,    0,    0,
    0,    0,  181,    0,    0,  182,  183,  184,  185,    0,
  186,    0,  187,    0,  188,  189,  190,  191,  192,    0,
    0,    0,    0,  193,    0,  194,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  195,    0,    0,    0,
    0,  196,  197,    0,  198,    0,    0,    0,  199,    0,
  200,  201,  202,  203,    0,  204,    0,    0,    0,    0,
    0,    0,    0,  205,  206,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  207,  208,    0,  209,  210,  211,
    0,    0,    0,    0,  212,  213,    0,  214,  215,    0,
  216,    0,    0,  217,  218,    0,    0,    0,  219,  220,
    0,    0,    0,    0,  221,  222,  223,    0,  224,  225,
  226,    0,  227,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  228,  229,  230,  231,  232,  233,  234,  235,
  236,  237,  238,  239,  240,  241,  242,  243,  244,  245,
  246,  247,  248,    0,  249,  250,  251,  252,  253,  254,
    0,  255,  256,  257,  258,    0,  259,    0,  260,  261,
  262,  263,  264,  265,  266,  267,  268,  269,  270,  271,
  272,  273,  274,  275,  276,  277,    0,  278,  279,  280,
  281,    0,  282,  283,  284,  285,  286,    0,  287,  288,
  289,  290,  291,  292,  293,  294,    0,  296,  297,  298,
  299,    0,  300,  301,  302,  303,  304,  305,    0,  306,
  307,  308,  309,  310,  311,  312,  313,    0,  314,  315,
  316,  317,    0,  318,  319,  320,  321,  322,  323,    0,
    0,  324,  325,  326,  327,  328,  329,  330,  331,  332,
    0,    0,    0,    0,    0,  333,    0,  334,  335,  336,
  337,  338,  339,  138,    0,  139,    0,    0,    0,    0,
    0,  140,    0,    0,  141,  142,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  143,  144,    0,  145,    0,
  146,    0,    0,  147,    0,    0,  148,    0,    0,    0,
    0,    0,    0,  149,    0,  150,  151,    0,    0,    0,
  152,    0,  153,    0,    0,  154,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  155,  156,    0,    0,    0,
  157,    0,  158,    0,  159,    0,    0,    0,    0,    0,
  160,    0,  161,    0,    0,    0,  162,    0,    0,    0,
    0,    0,    0,    0,  163,    0,    0,  164,    0,  165,
    0,    0,    0,  166,  167,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  168,    0,    0,    0,
  170,  171,  172,  173,  174,    0,  175,    0,    0,    0,
    0,    0,  176,    0,  177,  178,    0,    0,  179,  180,
    0,    0,    0,    0,    0,  181,    0,    0,  182,  183,
  184,  185,    0,  186,    0,  187,    0,  188,  189,  190,
  191,  192,    0,    0,    0,    0,  193,    0,  194,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  195,
    0,    0,    0,    0,  196,  197,    0,  198,    0,    0,
    0,  199,    0,  200,  201,  202,  203,    0,  204,    0,
    0,    0,    0,    0,    0,    0,  205,  206,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  207,  208,    0,
  209,    0,  211,    0,    0,    0,    0,  212,  213,    0,
  214,    0,    0,  216,    0,    0,  217,  218,    0,    0,
    0,  219,  220,    0,    0,    0,    0,  221,  222,  223,
    0,    0,  225,  226,    0,  227,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  228,  229,  230,  231,  232,
  233,  234,  235,  236,  237,  238,  239,  240,  241,  242,
  243,  244,  245,  246,  247,  248,    0,  249,  250,  251,
  252,  253,  254,    0,  255,  256,  257,  258,    0,  259,
    0,  260,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,    0,
  278,  279,  280,  281,    0,  282,  283,  284,  285,  286,
    0,  287,  288,  289,  290,  291,  292,  293,  294,  295,
  296,  297,  298,  299,    0,  300,  301,  302,  303,  304,
  305,    0,  306,  307,  308,  309,  310,  311,  312,  313,
    0,  314,  315,  316,  317,    0,    0,    0,    0,  321,
  322,  323,    0,    0,  324,  325,  326,  327,  328,  329,
  330,  331,  332,    0,    0,    0,    0,    0,  333,    0,
  334,  335,  336,  337,  338,  339,
};
static int yycheck[] = {                                      14,
   15,  590,   17,    0,  990,   63,  121,  729,  668,  110,
   81,  637,  638,  113, 1027,   67,  114,   71,  726,   70,
   73,   81,   14,  716,   15, 1038,  126,  877,  877,  715,
  669, 1329, 1368,  691,  479,  637,  638, 1169,   92, 1368,
  691,   94,  691, 1175, 1367, 1010, 1722,   62,   63,  107,
   65,   66,   67,   68,   69,   70,   71,   72,   73,   74,
  112, 1463,   77,  117,  590,  116,  119,   82,   83,   84,
   85,  948,   87, 1040,   89,   90, 1299,   92,   93,   94,
   95,   96,  654, 1010,   99, 1010,   82, 1710,  103, 2096,
  105,  106,  107, 1224,  109,  110,  111,  112,  113, 1954,
  115,  116,  117,  118,  119,  120,  121, 1454, 1826,  124,
 1756,  126, 1798,  105,  129,  130, 1273,  689,  133,   77,
   66,  136, 1325,  115, 1415,  875,  876,  877,   74, 2054,
 2185, 2056, 1795,  646,   14, 1415, 2214, 2215,  130, 1566,
 1415,   99, 1415, 1349, 2234, 1142, 1415, 2123, 1035, 1724,
  676, 1378, 1456,  694, 1347,  962, 1120, 1576,  720, 1585,
 1013, 2288, 1010, 1823, 2370,  111,  124, 2120,  126,  630,
  631,    0,    0,  489,  120,   87,    0,   84,   99, 1913,
  363, 1933,   42, 1389, 1411, 1374,  529,  133, 1811,   69,
  540, 1418,   98, 1420,   93,   44,   44, 2781,    0,    0,
 1257,    0, 1703,    0,    0, 1092,    0,    0,    0,   89,
   40,   44,   44, 1397,  260,   44,   59,  123, 1399,    0,
  570,    0,    0,   45, 2575,  105,   44,  960, 1396, 2380,
   59,   59,   40,   63,   45,   59,    0,  355, 2229, 1459,
   45,    0,   40, 1183, 1184,    0,  278,  280, 2399,  129,
  130, 2204,  264,   41,   44,   63,   44,   59,   59,    0,
   59,    0,   59,   59,  325,   59,   59,   59,   45, 2475,
    0,   59,   59,   61,   44, 1303,  296, 1704,   59, 2665,
   59,   59,   44,   40,    0,   44,   95,  571,   44, 1138,
  364,    0,   61, 2820, 1016,   59,   41,  306,   44, 1224,
   59,  268, 2939,   41,   59, 1232,   44, 1915, 1158,   44,
  319,  282,    0, 2368,  364,  496,  273,  321,   59,   91,
   59,    0,  260,    0,    0,  262,    0,  268,  262,   59,
  345,  500,    0,  264, 1020,  350,  351,  352,  353,  354,
  355,  356,  357,   59,  359, 1747, 1748, 1749,  363,  276,
   59,    0,  507,   41,  345,  363,   44, 3327,    0,  374,
 1046,  462,  500,    0,  877,   41,  398,   41,  348,  307,
  393,   59, 2578,  296,  275,    0, 1226, 1509, 3382,  307,
   59,    0,   59,   59, 1010,   59,  296,  347, 1138,  460,
 2070,   59,   41,  401, 1614,   44,  419,   41,  330,   41,
   44,  359,    0,  263, 1915, 1255, 1256,  330,  316,  295,
   59, 1288,  353, 3383,  302,  264,  264,   59, 3422,  316,
 1756,  264,   59, 2478, 1914,   44, 1914, 1756,    0,  584,
  314,   41,  412,  364,   59, 1566,  337,  364,  359,  447,
   59,  353,  446, 3080,  351,  516,  547,  462, 2538,   41,
 1415,  735,    0, 1656,  555, 2131, 1164,  356, 1166, 2314,
 2987,   59, 1212,  644,  990,  264,  433,  310,  264,    0,
  316, 1307,  443,  444,  354, 1311,  264,  264, 1228,  387,
 1316,  418,  651, 1055,  418, 2540, 2872,   59, 1415,  277,
  387,  448,   41,  425,  295, 1345,    0,  506, 1248, 1249,
 1250, 1251, 1252,  275, 2222,  264, 2224,  295,    0,  437,
  560,   59,  650,    0,  474,  425,   40,  258,  551, 1651,
  259,  364,  310,  310,   40,  264,  295,  542,   59,  270,
  269, 1688,  547,  585,   44,  273, 1049, 2688, 2689,  340,
  555,  387, 2485,  352,  290,    0,  434, 2523,  357,  258,
 2541,  571,  584,  627,   41,   59,  571,  572,  314,  304,
  301,  270,  303, 1296,    0,  295,  304,   59,  622,    0,
  585,  310,   59, 1704, 1794,  590,  264,  592, 1300,  594,
  595,  593,  700, 2009,  542,  340,  647,  419,  264, 1529,
  264,  606,  301,   44,  303, 2946,  642,  332,  368,  590,
  393,  592,  435,  594,   59, 2024,  344,  622,    0,    0,
  340, 2112,  442,  394,  572,  630,  631,  632,  633,  437,
  442,  258,  264,   59,  312, 1138,  419,  295,   59,  427,
  394,  442,  434,  270,  442, 1692,  312,  442,  696, 1152,
  711, 1566,  434,  382,  332,  264, 1159,  701,  606,   41,
   41,  711,  442,   44, 1581,  434,  332,  395,  332,  257,
  401,  676,  467, 1691,  301,  442,  303,   59,   59,  684,
  312,  723,  340,  430, 2282,  437, 1673,  393,  437, 1387,
  357,  696,  697,  698,  699,  700,  701,  702,  703, 1291,
  332,  706,  401, 2820, 2821,  496,  627,    0,  713, 1212,
 1408,  716,  717,  500,  642,  720,    0,  615,  723, 1298,
  448,  726, 2392, 2864, 2865, 2866, 2867, 2868, 2869, 2870,
  735,  713,  519,  321, 1573,  519, 1576,  519,  326,    0,
  372, 1915, 1921, 2485,   42, 1916,  596, 3321, 1703,  381,
  519,  519, 3093, 3094,  593,  593, 1914,   41,  706,  437,
 2177,  395,  698, 2180, 1462,  304,   59,  703,  644, 1109,
 1273,  437,  372,  437,  401,   59,  496, 1453,  340,  615,
   41, 2282, 1298,    0,  957, 1118, 1703,  264, 1703, 1704,
  372,  423,  380,  298,  627,  706,  646,  699,   59, 1105,
  697, 2281, 1305, 2281,  593,  437,  484,  593,  396,  705,
 2776,  296,  257,  702,  314, 1655, 2749, 2862,  363,    0,
  264,  499,  500, 2547,   41,  363, 2759, 3023,  437,  648,
  648, 1347,  258, 1573,  648,  312,  295,  264,  496,  344,
 1402,  519,   59,  264,  483, 1585,  340,  717, 2791,  627,
 3078,  372, 1368,  519,  944,  332, 1682, 1683,  299,  949,
   41, 1312, 1705,   44, 1315, 1703,    0,  499,  500, 2062,
 2987, 2184, 2522,  878, 1390,  301,  321,  264,   59,  610,
  611,  326,  264, 1435, 2005,   59,  400,  519,  279,  310,
  372,  387, 1689,   44,  400,  483, 2305,  878,    0,  381,
 1431, 2920,  438, 1857, 2520,  443,  444,   41,  264,  295,
  295,  610,  611,  427, 3055, 3056, 3057, 3058, 3059, 3060,
 3061,  427,  983,  437, 2071,   59,  316,    0,  302,  303,
  312,  437, 2497, 2546, 2117,  380,    0,  389,  296,  944,
  426, 2357,  480,  332,  949,  298, 2559, 2241, 3176,  303,
  332,  396,  957, 1388,  340,  407,  961,   59,  312,  344,
  437,  382,  260, 1024,  450,   59,  389,   61,  395,  974,
 1031, 1032, 1849,  651, 1024,  401,    0,  387,  319,  500,
  264, 1031, 1032,  610,  611,  990,   59,  368,  526,  301,
  296,  344,   59,  419,  296,   59, 2841,  387,  519,    0,
  298,  949,    0,  264,  592,  501,  594,  595, 2974, 1444,
 2227,  364,  368, 2230,  264, 2232,  439,   41,  500,  651,
   44, 1002,  499,  500,  380, 1030,  452, 3072,  312,  567,
   41,  422,  332,   44, 1095,   59, 2158,  519,  483, 2026,
   41,  334,  519,   41, 2240, 2462,  400,  264,  332, 3129,
   61,  312, 3071, 1114, 1115,  437, 2177,  645,   59, 2180,
  434,   59,    0,    0, 1114, 1115, 3294,  425,    0,   93,
 1573,  332,  413, 1576,  619,  519,   59, 2743, 1726,  420,
  490,  437,  436,  264,  488,    0,  571, 1703, 2724,  401,
 2005,  961,  551,    0,  450,  312,  389,    0, 2734,  392,
  554,   59,  483,   41,  974,  322,  323,  316,   42,  450,
  496,  372,  368,   47,  407,  332,  284,  499,    0,  425,
 1960,   59,   59,  425,  578,  299,   41,   59, 1826,    0,
  264,  312,  519,  306,  639,  640,  641,  519,   41,  290,
  433, 1146, 1247,    0,   59,  395,  319,  592, 1153,  594,
  595,  332,   59,  437, 2770,  372,   59, 2773,  273, 1809,
 1843, 3006,  423,    0,  381,    0,    0, 1258, 2449, 2450,
   41,   59,    0, 1752,  651, 1851,  437,   59,  387, 2449,
 2450, 1810, 3250, 1273, 2449, 2450, 2449, 2450,   59, 2029,
 2449, 2450,  296, 2060,  487,   59,  301,  264,  332, 2202,
  645,  295,   59,  264, 1796, 2398,  423,  302,  303,   59,
  340, 1861,  276,  277,  507,  499,  500, 1153, 1930, 1224,
  437, 3266,   59, 3268,   59,   59,  330,  520,   59,  344,
   44,   59,  299, 2570, 1863,  519, 1752,  263,  499,  500,
 1756,  312, 1247, 1224,  412, 2248, 1307,  259, 2924,  310,
 1311,  316, 1257, 1258,  335, 1316,  437,  269,  519,   45,
 1822,  388, 2177,  264,    0, 2180,  264, 1272, 1273, 2009,
 2923, 1257,   58, 1364,  355, 1365,  403,   63, 2425,   93,
  306,  264,  499,  500,  295, 1933,  639,  640,  641,  257,
 3135,  317, 1933, 1298, 1933, 2931,  401, 1302, 1303,  420,
  364, 1362,  519,  437,  257,  259,  264, 1312,  649,    0,
 1315,  312, 1362,  443,  444,  269, 1302, 1298,  499,  500,
 2442,  425,  387,   59,    0, 1273,  264,  310,  409, 1334,
 2643,  332,  312,  506,  332, 1423, 1424, 1425,  519,  434,
   44, 2462, 1347,  277,  276,  277,  474,  281,  372,  264,
  400, 2473,  310,  279,  363,  295,  368,  264,  326, 1364,
 1365,  264, 1367, 1368,  429,  436, 1347,  651,   59,  401,
  394,  389,  264,  326,  312,  503,  264,   41, 3086,  312,
   44, 1367,  264,   59,  410, 1390,  426, 1368, 3303,   93,
  651, 1396, 1397,  264,  332,   59,    0,   61, 2724,  283,
  264,  258,  316,  310, 2116, 2724, 3403,  258, 2734,  312,
  261,  295,  395,  270,  368, 2734,    0,  332,  310,  540,
  323,  439,  310,  257, 2737,    0,  547,  264,  310,  332,
 1435, 3428,  364,  264,  651,  264,  437,   41,  295,  437,
   44,  312,  280,  369,  301, 3081,  303,    0,  276,  277,
  301,  322,  323, 1458,  596,   59, 3092, 1462, 1463,  301,
    0,  332,  393,  301,    0, 2305, 2305,  400,  332,  372,
  651,  480,  553,  310, 2811,   59,  368,  261,  381,  310,
  364,  310,  295,  340,   59,  442,  368,  321,  554, 2446,
 2447,  348,  326, 2706, 2449, 2450,  422, 3110,    0,  437,
  382,  372, 3417,  436,  368,  291,   59,  276,   44, 1514,
  381,  276,  578,  439,  283,  276,  380,  526,  519,   59,
  423, 2024, 2362,   59, 2222,  258, 2224,  316,  363,  372,
    0,  368, 2449, 2450,  437, 2127,  364,  270,   44,  368,
  382, 3177, 2409, 2935,  401,  382,  380, 2462,  313,  316,
 3186,  364,  423, 2675,   59,  412,  271,   59,  567,  401,
 1565, 1566,  396,  401,  435, 2305,  437, 1657,  301,  284,
  303,   41,  264,  437,   44,  596,    0,  419, 1514, 1565,
  423,  519,  258, 2705,    0, 1566,  450,   93, 1458,   59,
  329,   44,  257,  344,  270,  450,  499,  500, 1688, 2575,
  264, 2117,  475,  364, 1709, 2931,    0,    0,  443,  444,
  325,  637, 2931,  277,  452,    0,  519, 2357,  310,  295,
  385, 1682, 1683,   93,  385,  301,  401,  303,  499,  500,
  391,  295,  505, 2654,  264,   59,    0,  352,  264,  496,
   93, 2644,    0,   59,    0,  480,  310,  312,  519,  483,
 2212, 2243, 1657,  447,  440,  449,  442,  443,  444,  424,
  264,  326, 3193,  424,  340,   59,   59,  280,  401,  507,
  303,  442,  348,  330,   59,    0,  462,  463,    0,  312,
  310,  467,  468, 1688,  310,   41, 1691, 1692,   44,  264,
 1738,  526,  443,  444,  264,   59,  467,  412,   45, 1704,
  364,   59,  105,   59, 1709,    0, 1692,   44,  312, 1690,
 3376,   58, 2424,  551,  500, 1720,   63,    0,  322,  323,
 1725, 2371, 2420, 1704,  264,  401,  276,  130,  332,   40,
 1735,  335,  567, 1738,   59,  310,  412,   59,  368, 1725,
 1688, 1746, 1747, 1748, 1749, 1750,  265, 1752,  651, 1735,
  334, 1756,  382,  610,  611, 3081, 2439, 1845,  592,  264,
  594,  595, 3081,  313,   59,    0, 3092,  400,  372,  382,
  310, 1752, 3308, 3092,  425, 1756,   59,  381,  297,  363,
  651,  277,   41,   42,   43,  281,   45, 1792,   47,    0,
 1795,   42,   43,  368,   45,  264,   47, 1802, 2801, 1804,
 2803,  437, 2305,  436, 3340,  389,  419,  382,  392, 1795,
  363,  645, 2247,  587, 2249,  265, 1802,    0, 1804,  423,
  496,  427,  264,  407,   59, 3138,  507,  332,  368,    0,
    0,  435,  401,  437,    0,  385,  372, 2485, 1843,  452,
 3371,  310,  382, 2278, 2485,  381, 2485,  297,   59,  433,
 2498, 3177,  475,  639,  640,    0,  587, 1862, 3177,    0,
 3186,   44,  485,  368,  650,  596, 3397, 3186,  310, 3261,
  264,  264,   59,   44,  424,  380,   59,  610,  611,  329,
 1862, 2721,  505,  598,  264, 3416,  264,  259,   59,   59,
  443,  444,    0,   59,  507,  499,  500,  269,  434,  435,
 3431, 1746,  372,  487, 2554, 1750, 3194, 2557,  264, 1914,
 1915,    0,  427,    0,   59,  519,  310,  310,   59,    0,
   40, 2897,  437,  507,  394,  261, 2555,  480, 1933, 2558,
  310,    0,  437, 2525,  610,  611,  520,    0,  551,  264,
 3355,  407, 3357,    0,  291,  450, 2037, 1933, 2038,   59,
  286,   59,   41,  260,   41,   44,  312,   44,    0,  315,
  276,  443,    0,  627,  500,  301,  322,  323,  264,  264,
   59,  327,   59,  526,  368,  368,  332,  584,   59,  335,
 2070, 2071,  310,  519,   41,  310,    0,   44,  382,  382,
   59,  298, 2040,  349,  312,  296,   59,  620,  621,  622,
 2005, 2006,   59,  417,  360, 3026, 3027, 3028, 3029, 3030,
 3031, 3032,  368,  261,  567,  310,  372,   59,  277, 2045,
 2006,   59,  281,  329, 2005,  381,  277, 2032,  328,  330,
  281, 2036, 2037, 2038, 2039, 2040, 2041, 2042,  286, 2144,
  475,  397,  260,  368,   59,   59, 2032,  651,  364, 2075,
  485,  435,  315,  301, 2036, 2081, 2061,  382,  483, 2575,
 2121, 2122,  418,   46,  327, 2070, 2071,  423, 2073,  385,
  483, 2121, 2122,  368, 2914,  391,  260,  264,  434,  435,
  298,  437,  264, 1006,  488, 1008,  349,  382,  258, 2928,
  391, 2039, 2073,  440,    0,  442,  443,  444,  419,  400,
  270,  261,  260,  263,  258, 2041, 2042,  475,  424,  310,
  311,  260, 2117,  260,  298,  462,  463,  485,   59,  264,
  467,  468, 2070, 2071,  425,  295,  286,  483,  310, 2805,
  264,  301,  332,  303,  397,   41, 2117,  505,   44, 2144,
  298,  301,  260,  499,  500,  332,  475,  301,  504,  298,
  315,  298,  417,   59,  264, 2216,  485, 2218, 2219,  443,
  444,   46,  327,  519, 2269,  310, 2216,  401, 2218, 2219,
  340,  369, 2177,   58, 2218, 2180,   61,  264,  348, 2184,
  298,  368, 2894, 2188,  349, 2190,  368,   41, 2928,  371,
   44, 2178,  316,  380, 3316,  360, 2177,    0, 2184, 2180,
  382, 2262, 2188,  368, 2265, 2266, 2267,  264, 2724,  487,
  612,  613, 2262, 2218, 2219, 2265, 2266, 2267, 2734, 2224,
  376,  377,  332,  368, 3346,  312,   41,    0, 2289,   44,
   41,  401,  397,   44,  264,  322,  323,  382,   41, 2289,
  379,   44,  412, 2859,  379,  332,  367,  401,  335,  264,
  437, 3254,  620,  621,  622,  312,   59,   41,  368,  333,
   44,  273,   41,  450, 2269,  419,  323,  519,   41,   40,
  380,   44,    0,  475,  476,  332, 2281, 2282, 2142, 2143,
  310,   60,   61,   62,   41,  372,   59,   44,   41,   59,
   59,   44,  639,  640,  381,  651,  401,   41,  452, 1148,
   44, 1150, 2392,  443,  444,    0, 1155, 1156,  304,  590,
 2401, 1160, 2402,   41,  294,  372,  264,  332,  483,  600,
  601, 3324,   41,  264,  381,   44,  496,  437,  437,   41,
   41,   59,   44,   44,  648, 2425,  423, 1186,  368,  504,
  450,  371, 2449, 2450,    0,   40,   41,   46,  435,   44,
  437,   41,  382,  368,   44,   41, 2404,    0,   44,   58,
   59,  264,   61,   46,   59,  380,  423,  261,  268,  263,
  276,  277, 2047, 2048,  280,   58,   59,  283,   61,   41,
  437, 2897,   44,  270, 2389,  437, 2391, 2392, 3086,  295,
  596,  332,  286,   46,  282, 2400, 2401, 2402, 2403, 2404,
 2405, 2406,  296,   59, 2492,   58,   59,  301,   61,  264,
 2391,   41,  499,  500,   44, 2931,   59,  381, 2400,  340,
 2425,  340,  437, 3106,  440, 2928,  442,  368,   40,  646,
   40,    0,  519,   46, 2439,  450,  330,   40, 2526,  380,
  610,  611,  499,  500, 2392,   58,   59, 2452,   61,  443,
   41,  467,  468,   44,   40, 2403,   41, 2462,  364,   44,
   41,   41,  519,   44,   44,   41, 2452, 2528,   44, 2405,
 2406,   40,   41,   40,   40,   44, 2481, 2425, 2528,  385,
 2485, 2462,   40,  262,   40,  391,    0,  306,   41, 2494,
   59,   44,  271, 2498,  264,  264,  437,  316,   41, 2485,
  319,   44,   40,  276,  277,  284,   40,  280, 2494,  450,
  283, 2516, 2498,   41, 2519,  306,   44,   41,  424,   40,
   44, 3171,  295,   58,   40,  316,   61,   41,  319,   46,
   44,  425,   46,  443,  443,  314,  264,   46,   40,  318,
   41,   58,   59,   44,   61,   59,  325,   61, 2553,   58,
   59,   40,   61,   41,  333,   41,   44,   41,   44, 2564,
   44,   40,  332,  332,  651, 3081,   40, 2553,  387,  264,
 2575,  350,   40,  352,   41, 3287, 3092,   44,  394,   41,
 2585, 2586,   44,  362,  312,  364,  365,  366,   60,   61,
   62,  364,  371, 3433,  651,  323,  387, 3437,  368,  368,
 2586,   40,  421, 2585,  332,   41,  347,  426,   44, 2653,
  380,  380,  385,  432,   40,   91,   41,  312,  391,   44,
  315,   44,   41, 2667,    0,   44,  417,  322,  323,   40,
  421,    0,  327,  412,   40,   40, 2641,  332, 2643,  295,
  335,  432, 3292,   41,  372,  551,   44,   41, 2653,   41,
   44,  424,   44,  381,  349, 2641,   41, 2643,   40,   44,
   41, 3177, 2667,   44,  614,  360,   41,  437,  437,   44,
 3186,  368,   41,  368, 2679,   44,  315,  372,   46,   41,
  450,  450,   44,   59,  340,   40,  381,  506,  327,   40,
   59,  334,  348, 2698,   40,  423,  335, 3289, 2679, 3291,
 1649,   40,  397, 1652,   40, 2710,   40,  276,  277,  437,
  349,   40, 2717,   40,  283,  506, 2698,   40,  315, 2724,
  363,  360,  378,   40,  380,   40,  295,   40,  423, 2734,
  327, 2717, 2737,  552, 2822,   40,   40,   40,   40,   40,
  435,   40,  437, 2724,   40,  401,  389,   40, 2809,  392,
  264, 2737,  349, 2734,   40,   40,   40,  261,  397, 2809,
  727,  552,   40,  360,  407, 2826, 2771,   40,   40,   40,
  426,  499,  500,   40,   40,   40, 2826,  596,  551,   40,
   40,   40,  286, 2874,   46,  299, 2876,  754,  483,   46,
  433,  519,  296,  370,  450,  364,  615,  301,  370,  271,
  397,   40,  333, 3382,  499,  500,   61,  333,   46,  504,
  777,  333,  284,   60,   61,   62,  385,  499,   40,  598,
  295,  357,  391,  270,  615,   40,  330, 2832,  273, 2834,
  348, 2875,  382,  437, 2878,  446, 2877, 2880,   40,  384,
  496,  430,  430, 3422,  487,   40,  318,  341, 2834,   40,
 2832,  295,   40,  325,   91,  424,   40,   40,  270,  442,
  378,  333,  380,  368,  507,  504, 3382,  374,  367, 2874,
 2875, 2876, 2877, 2878, 2879, 2880, 2881,  520,  350,  372,
  352,  312, 2887,  401,   41,   41, 2891,  391,   41,   41,
  362,   46, 2897,  365,  366,  264,  400,   40,  437,  419,
   40, 2989,  315,  386, 2965,  368, 3422,  504,  426,  261,
  368,  368,  290,   40,  327, 2965,   46,  257, 2923,  295,
 2981,  425,  260,  651,  312,  312, 2931, 2988,   44,  333,
 2935, 2981,  450, 2881,  286,  314,  349, 2923, 2988, 2926,
  412,   44,  333,  312,  296,   46,  315,  360,   44,  301,
 2931,  495,  509,  322,  323,  368,  651, 2962,  327,  496,
  437,  612,  495,  332,  340,   41,  335,  395,  371,   44,
  371,  371,  348,  437, 2979,  596,   40,  483,  330,  303,
  349,  321,  551,  401,  397,  437,  326,  348,  371,  609,
 3034,  360, 2997, 2646, 2647, 2648, 2649, 2650, 2651,  368,
   40,   40,  378,  372,  380,  355,   41,   41,    0,  500,
   41,   44,  381,   41,  314, 2997,  454,  455,  456,  457,
  458,  459,  460,  461,  271,  401,   41,  994,  397, 3034,
  997,   41,  418,   44,   46, 1002, 3084,  284, 1005,  391,
  380,   44, 1009,   44,   41,  262, 1013,   44,  400,   41,
  426,  314,   44,  333,  423,  419,  396,   40,  277, 3064,
   41, 3066,  616,   60,   61,   62,  435,   59,  437, 3074,
   40,  318,  417,  425,  450,  395, 3081,  419,  325, 3084,
 3085,   44, 3064,  401, 3066,   44,  333, 3092, 3074,  419,
 3132,  504,   44,   41,    0, 3100,   41,  373,  314, 3104,
 3081, 3106,  335,  350,  335,  352,   41, 3112,  290,  435,
  368, 3092,  368,  484,  483,  362,  368,  364,  365,  366,
  496,  275,  340,   59,  419,  563,  598, 3132, 3133,  340,
  499,  500,  340, 3138,  590,  504,    0,   40,  277,  303,
   59,   41,  332,  483,   44, 3206,  332, 3133,   58,  419,
  519,  589, 3138,   59,  442,  276, 3206,  451, 3219,   41,
   60,   61,   62,   59, 3269,  412,   59,   58,  414, 3219,
   41, 1138, 3177,   41,   41,   61,   40,   41,  401,  490,
   44, 3186, 1149,  607,  645,  607,  314, 1154,  303,  395,
  304, 1158,   40,  303,  418,   59, 3177,   61,  419, 3204,
   41, 1168, 1169,   41,  262, 3186, 1173, 1174, 1175,    0,
 1177, 1178, 1179, 1180, 1181, 1182, 1183,  314, 1185,  273,
 1187,   40, 1189, 1190, 1191, 1192, 1193,   91,  264, 1196,
 1197, 1198, 1199, 1200, 1201, 1202, 1203, 1204, 1205, 1206,
 1207, 1208, 1209, 1210, 1211,  263,  263,  335,  314,   40,
   41,  314,  592,   44,  594,  595, 3261, 3262,  351,  417,
 1227,   44, 3304,  322, 3269,  262,  401, 1234,   59,  523,
   61,    0, 1239,  524,  271,  369,  521, 3282, 1245, 1246,
 3262,   40,  651,  276,  276,  277, 1253,  284,    0,  344,
  275,  283, 2900, 2901, 2902, 2903, 2904, 2905,  344, 3304,
   91, 3343,  367,  295,   40,  619,  332,  289,  420,  434,
  371,  371,  399,  358,  371,  371,   41,   41,  371,  371,
  370,  318, 3327,   40,  446,  646,  446,   59,  325,   41,
   59,   59,   44,   44, 1301,  303,  333,  367, 3343,   41,
   41,   41,  434,   41,   41,  419,  419,   59,  419,   61,
  419,  598,  419,  350,  522,  352,  273,  419,  323,  431,
  411,  369,  262,    0,  336,  362,  344,  364,  365,  366,
  419,  271,  364, 3378,  371,  312,   40, 3382, 3383,   91,
  427,   41,  490,  299,  284,  299,  273,  364,    0,  295,
  364, 3396,  528,  385,  258,    0,  295,   40,  425,  391,
  264, 3382,  330,  425,   41,  330,  296,   44,  296,  273,
  646,  275,  276,  277, 3396,  412,  280, 3422,  318,  283,
  325,   41,   59,   41,   40,  325,  405,   60,   61,   62,
  314,  295,  424,  333,  340,  357,   41,  301,    0,   44,
  304, 3422,  348,  450,  450,   40,  310,   59,   40,  314,
  350,   41,  352,   61,   59,  446,   61,   40,   44,  314,
  314,  314,  362,  314,  364,  365,  366,  258,  314,  314,
  314,  371,  378,  264,  380,  431,   40,  395,   41,   40,
  344,  314,  273,   41,  275,  276,  277,  418,    0,  280,
  627,  280,  283,  264,  344,  401,  275,   59,  340,  442,
  364,  344,  368,   40,  295,  304, 1473, 1474,  303, 1476,
  301, 1478,  412,  304,  418, 1482, 1483, 1484, 1485,  310,
  426,  385,   63, 1490, 1491,  321,  273,  391,   44,   41,
  370,  395,   44,  434,  312,   44,    0,  401,   46,  299,
 1507,  401, 1509,  336,  450,   41,  258,   59,  336,   61,
  273,  278,  264,  344,  344,  419,   41, 1524,   46,  551,
  424,  273,  418,  275,  276,  277, 1533, 1534,  280,  370,
  264,  283,   41,  364,  443,  264,  302,   41,  299,   91,
   44,  483,  295,  295,  448,   61,   41,  357,  452,  301,
  496,   40,  304,  560,  385,   59,   40,   61,  310,  289,
  391,  598,  264,  567,  395,  334, 1573,  391,  500,  582,
  401,  509,  448,  266,  561,  500,  264,  426,  376,  329,
 1587,  329, 1589,  628,  310, 1592,   40,   91,  419,  262,
   40,  283,  344,  424,  363,  420,  386,  368,  271,  276,
  277,  603,  330,  420,  418,  401,  283,  605,  368,  368,
   41,  284,  364,  258,  418,  296,  425,  448,  295,  264,
  389,  452,  336,  392,  330,   44,  401,   40,  273,  445,
  427,   40,  277,  385,  427,  280,    0,  264,  407,  391,
  329,   40,  400,  395, 1651,  318,  400,  551,  264,  401,
  295,  264,  325,  400,  400,  270,  301,  333,  598,  304,
  333,  270,  395,  303,  433,  310,   40,  419,   41,  335,
  314,  340,  424,   40,  303,  303,   41,  350,  434,  352,
  264,  368,  334, 1690,  290,  335, 1693,  364, 1695,  362,
  289,  364,  365,  366,   41,  303,  448,   59, 1705,  344,
  452,   41,   59,  442,   59,   59,  258,   59,  385,   59,
  303,  363,  264,  395,  391,   41,   41,   61,  487,  364,
  551,  273,   59,  627,  276,  277,   59,   40,  280,  314,
  303,  283,  334,   41,   41,  614, 1743,  389,  507,  412,
  392,  264,  314,  295, 1751,  314,  418,  424,  299,  301,
  395,  520,  304,  264,  258,  407,  401,    0,  310,  476,
  264,  363,  442,  442,  519,  642,   46,   46,   41,  273,
   41,  305,  276,  277,  419,  305,  280,   46,  305,  283,
   44,  433,  264,    0,  364,  305,   41,  389,  519,  363,
  392,  295,  344,    0,   44,  363,  627,  301,   41,  551,
  304,   44,  551,  448,  593,  407,  310,  452,  593,  264,
   46, 1664,  364, 1287, 1287, 1287,   59, 2381,   61, 2382,
 1287, 2383, 2891, 3034, 3034, 2061, 1287, 2409, 1288,    0,
 2887,  433, 1462,  385,   41,  487, 2285,   44, 2821,  391,
  344, 2987,   59,  395,  350, 2797, 2968, 2747,   91,  401,
 3338,  703,   59,   74,   61,  507, 2194, 3118,    0, 2776,
  364, 2213, 3249,  354,  974, 2271, 2553,  419,  520, 2798,
   41, 3198,  424,   44,  551,  627, 3340, 3427, 2553, 3388,
 3373,  385, 3372, 3138, 3170,  487, 2737,  391,   59, 2738,
   61,  395, 1457,  606, 1916, 2939,  448,  401, 1028,   41,
  452, 1918,   44, 3383, 3295,  507,  551, 2178, 2178, 3384,
 1750, 3091, 2174, 3180,    0,  419, 1613,   59,  520,   61,
  424, 1259,  300, 2641, 1907,  598, 1439, 1721,  306,  674,
 1121, 1938, 2187, 1804, 1420, 2230, 1350, 1944,  316,  132,
 1091,   45, 1949, 2082,  448, 1952, 1953, 1954,  452, 2411,
 2416,  329, 1959, 1410, 1961, 3064,  345,  987,  633, 1690,
  594, 1968,  640, 1970, 2671, 1273, 1973, 1974, 1975, 1976,
 2074, 3069, 1979, 1650, 1981, 1141, 1983, 3378, 1985, 2997,
 1693,  644,  627,  334, 1991, 1992, 1993, 1994, 1995, 1996,
 1997, 1998, 1999, 2000, 2001, 2002, 2097,    0,    0,  551,
 3050,    0, 3050,    0,    0, 2012, 3319,  962, 2258,  387,
 2017, 1236,  363,  718, 2021,  258, 1586, 3204,  682,  735,
 1433,  264,    0, 3100, 1333, 1703, 1255, 2785,  109, 2842,
  273, 1978, 2224,  276,  277, 2481,    0,  280,  389,  417,
  283,  392, 2879,  421,  131, 2076, 1130,  551,  426, 1270,
 2575,  258,  295, 2408,  432, 3376,  407,  264,  301, 3098,
 1912,  304, 3267,   41, 3342, 2484,   44,  310,  275,  276,
  277, 2714,  450,  280, 1041,  627,  283,   41,   12, 2674,
   44,   59,  433,   61, 3224, 3286, 1023,  258,  295,   -1,
   -1,   -1,   -1,  264,  301,   59, 2103,   -1,   -1,   -1,
   -1,  344,   -1,  310,  275,  276,  277,   -1,   -1,  280,
   -1,   -1,  283,   -1,   -1,   -1,  258,  334,   -1,   -1,
   -1,  364,  264,  627,  295,   -1,   -1,   -1,  506,   -1,
  301,  509,   -1,  275,  276,  277,  487,   -1,  280,  310,
   -1,  283,  385,   -1,   -1,   -1,  363,   -1,  391, 2156,
   -1, 2158,  395,  295,   -1,   -1,  507,  364,  401,  301,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  310,  520,
   -1,   -1,  389,   -1,   -1,  392,  419,   -1,  385,   -1,
   -1,  424,   -1,   -1,  391,   -1,   -1,  291,   -1,   -1,
  407,   -1,  399,  364,  401,   -1,   -1,   -1,   -1,   60,
   61,   62,   -1,    0,   -1,  448,   -1,  414,   -1,  452,
   -1,   -1,  419,  317,  385,   -1,  433,  424,  596,   -1,
  391,   -1,  364,   -1,   -1,   -1,   -1,   -1,  399,   -1,
  401,   -1,   -1,   -1,   -1,   -1,   -1,  615,   -1,   -1,
  344,   -1,   -1,  385,   41,  452,   -1,   44,  419,  391,
   -1,   -1,   -1,  424,   41,   42,   43,   44,   45,  401,
   47,   -1,   59,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  487,   -1,   -1,   60,   61,   62,   -1,  419,   -1,   -1,
  258,  452,  424,   -1,   -1,   -1,  264,   -1,   -1,   -1,
  507,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  276,  277,
   -1,   -1,  280,  520,   91,  283,  410, 2314,  551,   -1,
  452,   -1,  276,  277, 2321, 2322,   -1,  295,   -1,  283,
   -1, 2328,  426,  301,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  310,   -1,   -1,   -1,  440,   -1,  442,  443,
  444,   -1,   -1,   -1,  551,   -1,   -1,   -1, 2355,   -1,
   -1, 2358,   -1, 2360,   -1,   -1,   -1,   -1,  462,  463,
  464,  465,  466,  467,  468,  469,  470,   -1,   -1,   -1,
   -1,   -1,   -1,  477,  478,   -1,   -1,   -1,   -1,   -1,
  551,   -1,  486,   -1,  627,   -1,  364,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   41,   -1,   -1,   44,
  364,  262,   -1,  264,  368,   -1,   -1,  385,   -1,  551,
  271,   -1,   -1,  391,   -1,   60,   61,   62,   -1,   -1,
  627,  385,   -1,  401,   -1,   -1,   -1,  391,   -1,   -1,
   -1,   -1,   -1,   -1,   -1, 2442,   -1,   -1,   -1,   -1,
   -1,  419,   -1,   -1,   -1,   -1,  424,   -1,   41,   -1,
   -1,   44,   -1,   -1,   -1,   -1,  627,  318,   -1,   -1,
  424,   -1,   -1,   -1,  325,   -1, 2473,   60,   61,   62,
   -1,   -1,  333,   -1,  452,  262,   -1,   -1,   -1,  276,
  277,   -1,   -1,   -1,  271,  627,  283,   -1,   -1,  350,
  277,  352,   -1,   -1,  281,   -1,   -1,  284,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   41,   -1,   -1,   44,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  483,
   -1,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,
   -1,  318,   41,  637,   -1,  639,  640,  641,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,   -1,  364,   -1,   -1,
   -1,   -1,   -1,  551,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371, 2592,   -1, 2594,  385, 2596,
   -1,   -1,   -1, 2600,  391,   -1,   -1,   -1, 2605, 2606,
 2607, 2608, 2609,   -1,   -1,   -1,   -1, 2614,   -1, 2616,
   -1, 2618,    0,   -1,   -1,   -1,   41,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,  271,  424, 2635,   -1,
   -1,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  627,
   -1,   -1,    0,   41,   -1,   -1,   44,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1, 2675,  262,
   -1,   59,   -1,  318,   -1,   -1,   -1,   -1,  271,   -1,
  325,   -1,   -1,   -1,   -1,   -1,  483,   -1,  333,   -1,
   -1,  284,   -1,   41,   -1,   -1,   44, 2704, 2705,   -1,
   -1, 2690,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   59,   -1,   -1,   -1, 2722,   -1,  362,   -1,  364,
  365,  366,   -1, 2730, 2731,  318,  371,  262,   -1,   -1,
   -1,   41,  325,   -1,   -1,    0,  271,  598,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,    0,  284,
   60,   61,   62,  262,   -1, 2762,   -1,  350,   -1,  352,
   -1,   41,  271,   -1,   -1,   -1,   -1,  412,   -1,  362,
   -1,  364,  365,  366,   -1,  284,   41,   -1,  371,   44,
   60,   61,   62,  318,   -1,   -1,   -1,   -1,   -1,   41,
  325,   -1,   44,   -1,   59,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,  312,   -1,   -1,   -1,   59,   -1,  318,
   -1,  598,   -1,   -1,   -1,  350,  325,  352,  605,  412,
   -1,   -1,   -1,   -1,  333,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1, 2841, 2842,  371,  262,   -1,   -1,
   -1,  350,   -1,  352,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,  284,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,   -1, 2873,   -1,   -1,   -1,  276,  277,
   -1,   -1,   -1,  318,   -1,  283, 2885,   -1,   -1,   -1,
  325,   -1,   -1,  412,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1, 2906, 2907,   -1,
   -1, 2928,    0,   -1,   -1,  350,   -1,  352,  276,  277,
   -1,   -1,   -1,   -1,   -1,  283,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,  262,  598,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  271,   40,   41,   -1,   43,   44,   45,   46,   -1,
   -1,   -1,   -1,   -1,  284,   -1,  364,   -1,   -1, 2986,
   58,   59,  262,   -1,   -1,   63,   -1,  412,   -1,   -1,
   -1,  271,   -1,   -1,   -1,   -1,   -1,  385,   -1, 3006,
   -1,   -1,   -1,  391,  284,  598,   -1, 3014,  318, 3016,
   -1,  276,  277,   -1,   -1,  325,  364,   -1,  283,   -1,
   -1,   -1,   -1,  333,  276,  277,   -1,   -1,   -1,   -1,
  295,  283,   -1,   -1,   -1,   -1,  424,  385,  318,   -1,
  350,   -1,  352,  391,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,  362,  333,  364,  365,  366,   -1,   -1,   -1,
   -1,  371, 3069,  598,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,  262,   -1,  424,  265,   -1,   -1,
   -1,   -1,  362,  271,  364,  365,  366,   -1,   -1,  598,
   -1,  371,   -1,   -1,   -1,  483,  284,   -1,   -1,  364,
   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  385,   -1,   -1,   -1,   -1,   -1,  391,   -1, 3135,   -1,
  318,   -1,  412,  385,   -1,  483,   -1,  325,   -1,  391,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
 3139, 3140, 3141, 3142, 3143, 3144, 3145,   -1,   -1,  424,
   -1,   -1,  350,   -1,  352, 3154, 3155, 3156, 3157, 3158,
 3159, 3160,  424,  598,  362,   -1,  364,  365,  366,  257,
   -1,  259,   -1,  371,   -1,   -1,  264,  265,   -1,  267,
  268,  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,  285,   -1,  287,
   -1,   -1,  290,  291,  292,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  412,   -1,  304,   -1,  306,   -1,
  308,  309,   -1,   -1,  312,   -1,   -1,  315,   -1,  317,
   -1,  319,  320,   -1,  322,  323,  324,   -1,  326,  327,
  328,   -1,   -1,   -1,  332,   -1,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,  346,  347,
  348,  349,   -1,  351,   -1,  353,  354,   -1,  356,  357,
  358,   -1,  360,   -1,   -1,   -1,  364,   -1,  598,   -1,
  368, 3298,  370, 3300,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,  382,   -1,   -1,   -1,  386, 3316,
  388,  389,   -1,   -1,  392,  393,  394,   -1,  598,  397,
 3327,  399, 3329, 3330,  402,  403,  404,  405,   -1,  407,
   -1,  409,  410,  411,  412,  413,  414,  415,  416, 3346,
   -1,   -1,  420,   -1,  422,  423,   -1,   -1,  426,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,  435,   -1,  437,
  438,  439,  440,  441,  442,  443,  444,  445,   -1,  447,
  448,  449,  450,   -1,  452,  453,   -1, 3384, 3385, 3386,
   -1,   -1,  460,  461,  462,  463,  464,  465,  466,  467,
  468,  469,  470,  471,  472,   -1,  474,  475,  476,  477,
  478,   -1,  480,  481,  482,  483,  484,  485,  486,  487,
  598,   -1,  490,  491,  492,  493,  494,  495,  496,   -1,
   -1,  499,  500,  501,  502,  503,  504,  505,  506,  507,
   -1,  509,   -1,  511,  512,  513,   -1,  515,  516,   -1,
  518,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
   -1,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,   -1,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,    0,
  628,  629,  630,  631,  632,  633,  634,  635,  636,  637,
   -1,  639,  640,  641,  642,  643,  644,  645,  646,  647,
  648,  649,   -1,  651,  652,  653,  654,  655,  656,  657,
  658,  659,  660,  661,  662,  663,  664,  665,  666,  667,
   41,   42,   43,   44,   45,   -1,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,
   61,   62,  272,   -1,   -1,  275,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  275,   -1,  287,   -1,   -1,
   -1,  291,   -1,  293,   -1,   -1,   -1,   -1,   -1,   -1,
  290,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  300,   -1,   -1,   -1,   -1,   -1,  306,   -1,   -1,   -1,
   -1,  311,   -1,   -1,   -1,   -1,  316,   -1,   -1,  319,
   -1,  331,   -1,   -1,   -1,   -1,   -1,  337,  338,  339,
   -1,  341,  342,  343,   -1,  345,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  359,
   -1,  361,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  368,  379,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  390,   -1,   -1,   -1,   -1,   -1,   -1,  387,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  406,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  417,  428,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  432,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  450,   -1,  462,  463,   -1,   -1,  257,  258,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,  479,
  271,   -1,   -1,   -1,   -1,  276,  277,   -1,  279,  280,
  281,  282,  283,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
  301,  302,  303,  304,  305,  306,  506,   -1,  309,  509,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,  385,  386,    0,  388,  389,   -1,
  391,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
  401,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,  615,   -1,  418,  419,  420,
   -1,  422,  423,  424,   -1,   -1,   -1,   41,  638,   -1,
   44,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   59,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   41,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   60,   61,   62,  495,  496,   41,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   60,   61,   62,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,   -1,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   -1,   41,   42,   43,   44,   45,   -1,
   47,   -1,  276,  277,   -1,   -1,   -1,   -1,   -1,  283,
   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
  364,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,  385,   -1,  318,   -1,   -1,   -1,  391,   -1,   -1,
  325,  350,   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,  350,   -1,  352,   -1,   -1,
  424,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
  257,  258,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,  276,
  277,   -1,  279,  280,  281,  282,  283,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,  301,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,  385,  386,
    0,  388,  389,   -1,  391,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,  401,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,  598,
   -1,  418,  419,  420,   -1,  422,  423,  424,   -1,   -1,
   -1,   41,   -1,   -1,   44,   -1,  433,  434,  435,   -1,
  437,  438,  439,  598,  441,   -1,   -1,   -1,  445,   59,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   41,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   60,   61,   62,  495,  496,
   41,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,
   61,   62,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,   -1,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,  276,  277,   -1,   -1,
   -1,   -1,   -1,  283,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,  364,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,  385,   -1,  318,   -1,   -1,
   -1,  391,   -1,   -1,  325,  350,   -1,  352,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,
   -1,  352,   -1,   -1,  424,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,    0,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,  598,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,
  433,  434,  435,   -1,  437,  438,  439,  598,  441,   -1,
   -1,   -1,  445,   59,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   41,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   60,
   61,   62,  495,  496,   41,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   60,   61,   62,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
  276,  277,   -1,   -1,   -1,   -1,   -1,  283,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,  364,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,  385,
   -1,  318,   -1,   -1,   -1,  391,   -1,   -1,  325,  350,
   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,  350,   -1,  352,   -1,   -1,  424,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,    0,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,  598,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   41,
   -1,   -1,   44,   -1,  433,  434,  435,   -1,  437,  438,
  439,  598,  441,   -1,   -1,   -1,  445,   59,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   41,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   60,   61,   62,  495,  496,   41,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,  276,  277,   -1,   -1,   -1,   -1,
   -1,  283,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,  364,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,  385,   -1,  318,   -1,   -1,   -1,  391,
   -1,   -1,  325,  350,   -1,  352,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,   -1,  352,
   -1,   -1,  424,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,  598,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,  598,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   41,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   60,   61,   62,
  495,  496,   41,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   60,   61,   62,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,  261,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  278,   -1,   58,   59,   60,
   61,   62,   -1,  286,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  294,   -1,  296,   -1,   -1,   -1,   -1,  301,  262,
   -1,   -1,   -1,   -1,  307,   -1,   -1,   -1,  271,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,  321,   -1,
   -1,  284,   -1,  262,   -1,   -1,   -1,  330,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,  355,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,   -1,  352,
   -1,   -1,   -1,  396,  333,  398,   -1,   -1,  401,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  425,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,  437,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  473,   -1,   -1,  412,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,  488,  489,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,  510,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,  598,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,  598,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   41,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   60,   61,   62,  495,  496,   41,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   60,   61,   62,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,  350,   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,  598,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,  598,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   41,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   60,   61,   62,  495,  496,
   41,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,
   61,   62,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,  350,   -1,  352,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,  598,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,  598,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   41,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   60,
   61,   62,  495,  496,   41,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   60,   61,   62,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,
   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,  598,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,  598,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   41,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   60,   61,   62,  495,  496,   41,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,  350,   -1,  352,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,  598,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,  598,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   41,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   60,   61,   62,
  495,  496,   41,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   60,   61,   62,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,   -1,  352,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,  598,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,  598,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   41,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   60,   61,   62,  495,  496,   41,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   60,   61,   62,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,  350,   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,  598,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,  598,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   41,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   60,   61,   62,  495,  496,
   41,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,
   61,   62,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,  350,   -1,  352,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,  598,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,  598,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   41,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   60,
   61,   62,  495,  496,   41,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   60,   61,   62,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,
   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,  598,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,  598,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   41,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   60,   61,   62,  495,  496,   41,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,  350,   -1,  352,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,  598,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,  598,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   41,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   60,   61,   62,
  495,  496,   41,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   60,   61,   62,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,   -1,  352,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,  598,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,  598,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   41,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   60,   61,   62,  495,  496,   41,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   60,   61,   62,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,  350,   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,  598,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,  598,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   41,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   60,   61,   62,  495,  496,
   41,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,
   61,   62,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,  350,   -1,  352,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,  598,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,  598,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   41,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   60,
   61,   62,  495,  496,   41,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   60,   61,   62,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,
   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,  598,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,  598,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   41,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   60,   61,   62,  495,  496,   41,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,  350,   -1,  352,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,  598,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,  598,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   41,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   60,   61,   62,
  495,  496,   41,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   60,   61,   62,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,   -1,  352,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,  598,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,  598,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   41,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   60,   61,   62,  495,  496,   41,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   60,   61,   62,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,  350,   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,  598,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,  598,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   41,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   60,   61,   62,  495,  496,
   41,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,
   61,   62,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,  350,   -1,  352,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,  598,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,  598,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   41,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   60,
   61,   62,  495,  496,   41,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   60,   61,   62,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,
   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,  598,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,  598,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   41,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   60,   61,   62,  495,  496,   41,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,  350,   -1,  352,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,  598,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,  598,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   41,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   60,   61,   62,
  495,  496,   41,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   60,   61,   62,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,   -1,  352,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,  598,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,  598,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   41,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   60,   61,   62,  495,  496,   41,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   60,   61,   62,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,  272,   -1,   -1,  275,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,  350,   -1,  352,  291,   -1,  293,   -1,  333,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,  331,   -1,  371,   -1,   -1,   -1,
  337,  338,  339,   -1,  341,  342,  343,   -1,  345,   -1,
   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  359,   -1,  361,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,  390,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,  406,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,  428,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,  462,  463,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,  479,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,  598,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,  598,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   60,
   61,   62,   -1,   -1,  471,  472,   41,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   60,   61,   62,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  638,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   58,   59,   60,   61,   62,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,  350,
  325,  352,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,  419,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,  598,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,  598,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   44,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   60,
   61,   62,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,
   59,   60,   61,   62,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,  264,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,  284,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,  318,  364,  365,
  366,   -1,   -1,   -1,  325,  371,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,  412,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,  598,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,  598,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   44,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   58,   59,   60,   61,   62,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,  284,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,  314,   -1,   -1,
  362,  318,  364,  365,  366,   -1,   -1,   -1,  325,  371,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
  412,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,  598,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,  598,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   44,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   60,   61,   62,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,   59,   60,
   61,   62,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,  284,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,  314,   -1,   -1,  362,  318,  364,  365,  366,   -1,
   -1,   -1,  325,  371,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,  412,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
  598,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,  598,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   44,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   60,   61,   62,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   58,   59,   60,   61,   62,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,  284,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,  312,   -1,   -1,   -1,   -1,  362,  318,
  364,  365,  366,   -1,   -1,   -1,  325,  371,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,  412,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,  598,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,  598,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   44,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   60,   61,   62,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   60,   61,   62,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   58,   59,   60,   61,   62,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,  284,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,  314,
   -1,   -1,  362,  318,  364,  365,  366,   -1,   -1,   -1,
  325,  371,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,  412,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,  598,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,  598,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   44,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   60,
   61,   62,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,
   59,   60,   61,   62,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,  284,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,  318,  364,  365,
  366,   -1,   -1,   -1,  325,  371,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,  412,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,  598,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,  598,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   44,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   58,   59,   60,   61,   62,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,  284,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,  318,  364,  365,  366,   -1,   -1,   -1,  325,  371,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
  412,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,  598,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,  598,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   44,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   60,   61,   62,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,   59,   60,
   61,   62,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,  284,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,  318,  364,  365,  366,   -1,
   -1,   -1,  325,  371,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,  412,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
  598,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,  598,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   44,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   58,   59,   60,   61,   62,  272,  271,   -1,  275,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,  287,   -1,   -1,   -1,  291,   -1,  293,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  272,   -1,   -1,
  275,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,  287,   -1,   -1,  331,  291,   -1,  293,  333,
   -1,  337,  338,  339,   -1,  341,  342,  343,   -1,  345,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,  359,   -1,  361,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,  331,  371,   -1,   -1,
   -1,   -1,  337,  338,  339,   -1,  341,  342,  343,   -1,
  345,   -1,   -1,   -1,  390,   -1,   -1,   -1,   -1,  395,
   -1,   -1,   -1,   -1,  359,   -1,  361,   -1,   -1,   -1,
  406,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,
   -1,   -1,   -1,   -1,  379,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  428,   -1,   -1,  390,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  406,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  462,  463,   -1,   -1,
  257,   -1,  259,  428,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,  479,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,  462,  463,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,  479,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,  598,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,  638,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   44,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   60,   61,   62,  638,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   58,   59,   60,   61,   62,
  272,  271,   -1,  275,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,  287,   -1,   -1,   -1,  291,
   -1,  293,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  272,   -1,   -1,  275,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,  331,
  291,   -1,  293,  333,   -1,  337,  338,  339,   -1,  341,
  342,  343,   -1,  345,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,  359,   -1,  361,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
  331,  371,   -1,   -1,   -1,   -1,  337,  338,  339,   -1,
  341,  342,  343,   -1,  345,   -1,   -1,   -1,  390,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  359,   -1,
  361,   -1,   -1,   -1,  406,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  428,   -1,   -1,  390,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  406,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  462,  463,   -1,   -1,  257,   -1,  259,  428,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,  479,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,  462,  463,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,  479,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,  598,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,  638,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   44,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   60,   61,   62,  638,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,
   59,   60,   61,   62,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  275,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  300,   -1,   -1,   -1,   -1,   -1,  306,   -1,
   -1,   -1,  318,  311,   -1,   -1,   -1,   -1,  316,  325,
   -1,  319,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  387,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  417,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  432,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  450,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,  506,   -1,
  309,  509,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,  598,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,  615,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   44,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   58,   59,   60,   61,   62,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  275,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  300,   -1,   -1,   -1,
   -1,   -1,  306,   -1,   -1,   -1,  318,  311,   -1,   -1,
   -1,   -1,  316,  325,   -1,  319,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  387,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  417,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  432,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  450,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,  506,   -1,  309,  509,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,  598,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,  615,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   44,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,   59,   60,
   61,   62,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  300,   -1,   -1,   -1,   -1,
   91,  306,   93,   -1,   -1,  310,  311,   -1,   -1,   -1,
   -1,  316,   -1,   -1,  319,   -1,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,  329,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  387,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  402,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  417,   -1,  412,   -1,  421,   -1,   -1,   -1,
   -1,  426,   -1,   -1,   -1,   -1,   -1,  432,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  450,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,  506,   -1,   -1,  509,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,  552,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,  596,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
  598,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
  615,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   44,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   58,   59,   60,   61,   62,   -1,  271,   -1,   -1,
  300,   -1,   -1,   -1,   -1,   -1,  306,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,  316,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,  329,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  387,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  417,   -1,   -1,
   -1,  421,   -1,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,  432,   -1,   -1,   -1,   -1,   -1,  412,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  450,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,  506,   -1,   -1,  509,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,  596,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,  615,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,  598,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   44,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   60,   61,   62,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   58,   59,   60,   61,   62,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,  598,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   44,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,
   59,   60,   61,   62,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,  598,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   44,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   58,   59,   60,   61,   62,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,  598,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   44,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,   59,   60,
   61,   62,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
  598,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   44,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   58,   59,   60,   61,   62,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,  598,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   44,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   60,   61,   62,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   58,   59,   60,   61,   62,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,  598,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   44,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,
   59,   60,   61,   62,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,  598,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   44,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   58,   59,   60,   61,   62,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,  598,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   44,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,   59,   60,
   61,   62,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
  598,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   58,   59,   60,   61,   62,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  454,  455,  456,  457,  458,  459,  460,  461,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,  563,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,  589,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,  598,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   60,
   61,   62,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   60,   61,   62,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   58,   59,   60,   61,   62,
  271,   -1,  262,   -1,   -1,   -1,   -1,  275,   -1,   -1,
   -1,  271,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
  288,   -1,  290,   -1,  284,   -1,   -1,   -1,   91,   -1,
   93,   -1,  300,   -1,   -1,   -1,   -1,   -1,  306,   -1,
   -1,   -1,  310,   -1,   -1,  305,   -1,  318,  316,   -1,
   -1,  319,   -1,   -1,  325,   -1,   -1,   -1,  318,   -1,
   -1,  329,  333,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,  362,  352,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  387,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  417,
   -1,   -1,  412,  421,   -1,   -1,   -1,   -1,  426,   -1,
   -1,   -1,   -1,   -1,  432,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  450,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,  506,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,  552,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,  569,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,  598,  596,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,  598,  402,
  403,  404,  405,   -1,  407,   -1,  409,  615,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   60,   61,   62,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   -1,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   58,
   59,   60,   61,   62,  271,   -1,   -1,   -1,   -1,   -1,
   -1,  275,   -1,   -1,   -1,   -1,   -1,  284,  275,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,  290,   93,   -1,  300,   -1,   -1,   -1,
   -1,   -1,  306,  300,   -1,   -1,   -1,   -1,   -1,  306,
   -1,  318,  316,  310,  311,   -1,   -1,   -1,  325,  316,
   -1,   -1,  319,   -1,   -1,  329,  333,   -1,   -1,   -1,
   -1,   -1,  329,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  379,  387,   -1,   -1,   -1,   -1,   -1,   -1,
  387,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,  419,  417,   -1,   -1,   -1,  421,   -1,   -1,
  417,   -1,  426,   -1,  421,   -1,   -1,   -1,  432,  426,
   -1,   -1,   -1,   -1,   -1,  432,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  450,   -1,   -1,   -1,
   -1,   -1,   -1,  450,  451,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,  506,  302,  303,  304,  305,  306,   -1,  506,
  309,   -1,  509,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,  598,  596,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,  615,  411,  412,  413,  414,  415,   -1,  615,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,  275,   -1,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,  290,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,  300,
   -1,   -1,   -1,   -1,   -1,  306,   -1,   -1,   -1,   -1,
  311,   -1,  275,   -1,   -1,  316,   -1,   -1,  319,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,  290,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  300,   -1,   -1,
   -1,   -1,   -1,  306,   -1,   -1,   -1,   -1,  311,   -1,
   -1,   -1,   -1,  316,   -1,   -1,  319,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  368,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  387,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  417,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  387,   -1,   -1,   -1,   -1,   -1,
   -1,  432,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  450,
   -1,   -1,   -1,   -1,  417,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  432,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  450,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,  506,  271,   -1,  509,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,  506,  309,   -1,  509,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,  615,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,  615,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,  275,   -1,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,  290,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,  300,   -1,   -1,   -1,   -1,   -1,  306,
   -1,   -1,   -1,   -1,  311,  290,   -1,   -1,   -1,  316,
   -1,   -1,  319,   -1,   -1,  300,   -1,   -1,   -1,   -1,
   91,  306,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  316,   -1,   -1,  319,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  387,   -1,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  387,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  417,   -1,   -1,   -1,   -1,   -1,   -1,  402,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  432,   -1,   -1,   -1,   -1,
   -1,   -1,  417,   -1,   -1,   -1,  421,   -1,   -1,  424,
   -1,  426,   -1,  450,   -1,   -1,   -1,  432,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  450,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,  506,
  271,   -1,  509,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,  506,   -1,   -1,  509,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,  552,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,  615,  380,
  381,  596,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
  615,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   -1,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   -1,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   -1,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   -1,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   -1,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   -1,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   -1,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   -1,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   -1,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   -1,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,   42,
   43,   44,   45,   -1,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,   -1,  606,  607,  608,  609,  610,  611,  612,
  613,  614,  615,  616,  617,  618,    0,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   41,   42,   43,
   44,   45,   -1,   47,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
  454,  455,  456,  457,  458,  459,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,  503,
  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
    0,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,
   -1,   41,   42,   43,   44,   45,   46,   47,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,
  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,  454,  455,  456,  457,  458,  459,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,
  500,  501,  502,  503,  504,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,    0,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
   -1,  651,   -1,   -1,   -1,   41,   42,   43,   44,   45,
   -1,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,  455,
  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,  499,  500,  501,  502,  503,  504,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,    0,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,
   42,   43,   44,   45,   -1,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,  281,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,  454,  455,  456,  457,  458,  459,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,
  502,  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,    0,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,   -1,  651,
   -1,   -1,   -1,   41,   42,   43,   44,   45,   -1,   47,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,  454,  455,  456,  457,
  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,  499,  500,  501,  502,  503,  504,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,    0,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,   -1,  651,   -1,   -1,   -1,   41,   42,   43,
   44,   45,   -1,   47,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
  454,  455,  456,  457,  458,  459,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,  503,
  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
    0,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,
   -1,   41,   42,   43,   44,   45,   -1,   47,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,  454,  455,  456,  457,  458,  459,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,
  500,  501,  502,  503,  504,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,    0,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
   -1,  651,   -1,   -1,   -1,   41,   42,   43,   44,   45,
   -1,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,  455,
  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,  499,  500,  501,  502,  503,  504,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,    0,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,
   -1,   43,   44,   45,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,  454,  455,  456,  457,  458,  459,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,
  502,  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,    0,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,   -1,  651,
   -1,   -1,   -1,   41,   -1,   43,   44,   45,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,  454,  455,  456,  457,
  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,  499,  500,  501,  502,  503,  504,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,    0,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,   -1,  651,   -1,   -1,   -1,   41,   -1,   -1,
   44,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
  454,  455,  456,  457,  458,  459,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,  503,
  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
    0,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,
   -1,   41,   -1,   -1,   44,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,  454,  455,  456,  457,  458,  459,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,
  500,  501,  502,  503,  504,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,    0,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
   -1,  651,   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,  455,
  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,  499,  500,  501,  502,  503,  504,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,    0,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,
   -1,   -1,   44,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,   -1,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,  454,  455,  456,  457,  458,  459,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,
  502,  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,    0,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,   -1,  651,
   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,   -1,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,  454,  455,  456,  457,
  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,  499,  500,  501,  502,  503,  504,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,    0,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,   -1,  651,   -1,   -1,   -1,   41,   -1,   -1,
   44,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,   -1,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
  454,  455,  456,  457,  458,  459,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,  503,
  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
    0,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,
   -1,   41,   -1,   -1,   44,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,   -1,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,  454,  455,  456,  457,  458,  459,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,
  500,  501,  502,  503,  504,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,    0,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
   -1,  651,   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,  455,
  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,  499,  500,  501,  502,  503,  504,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,    0,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,
   -1,   -1,   44,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,   -1,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,  454,  455,  456,  457,  458,  459,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,
  502,  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,    0,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,   -1,  651,
   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,   -1,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,   -1,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,  454,  455,  456,  457,
  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,  499,  500,  501,  502,  503,  504,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,    0,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,   -1,  651,   -1,   -1,   -1,   41,   -1,   -1,
   44,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,   -1,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
  454,  455,  456,  457,  458,  459,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,  503,
  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
    0,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,
   -1,   41,   -1,   -1,   44,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,   -1,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,  454,  455,  456,  457,  458,  459,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,
  500,  501,  502,  503,  504,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,    0,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
   -1,  651,   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,    0,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,  455,
  456,  457,  458,  459,  460,  461,   41,   -1,   -1,   44,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   59,  481,  482,  483,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,  499,  500,  501,  502,  503,  504,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   93,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,   -1,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,   -1,  319,  320,   -1,  322,  323,  324,
   -1,  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,   -1,   -1,  364,
   -1,   -1,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,   -1,  413,  414,
  415,   -1,   -1,  418,  419,  420,    0,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   41,   -1,   -1,
   44,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   59,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   93,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,   -1,  599,  600,  601,  602,  603,  604,
   -1,  606,  607,  608,  609,  610,  611,  612,  613,   -1,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
   -1,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,   -1,  319,  320,   -1,  322,  323,
  324,   -1,  326,  327,  328,   -1,   -1,   -1,  332,   -1,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,   -1,  413,
  414,  415,   -1,   -1,  418,  419,  420,    0,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
  454,  455,  456,  457,  458,  459,  460,  461,   41,   -1,
   -1,   44,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   59,  481,  482,  483,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,  503,
  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   93,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,   -1,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,   -1,  319,  320,   -1,  322,
  323,  324,   -1,  326,  327,  328,   -1,   -1,   -1,  332,
   -1,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,   -1,
  413,  414,  415,   -1,   -1,  418,  419,  420,    0,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   41,
   -1,   -1,   44,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   59,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,   -1,  599,  600,  601,  602,
  603,  604,   -1,  606,  607,  608,  609,  610,  611,  612,
  613,   -1,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
   -1,   -1,  264,  265,   -1,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,   -1,  315,   -1,   -1,   -1,  319,  320,   -1,
  322,  323,  324,   -1,  326,  327,  328,   -1,   -1,   -1,
  332,   -1,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  368,   -1,  370,   -1,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,    0,   -1,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,  435,   -1,  437,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,   -1,   -1,   -1,   -1,   40,   41,  460,  461,
   44,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   59,   -1,   -1,   -1,  481,
  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,
  502,  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,   -1,  651,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
   -1,  315,   -1,   -1,   -1,  319,  320,   -1,  322,  323,
  324,   -1,  326,  327,  328,   -1,   -1,   -1,  332,   -1,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  368,   -1,  370,   -1,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,    0,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   41,  452,   -1,
   44,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,  503,
  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
   -1,  315,   -1,   -1,   -1,  319,  320,   -1,  322,  323,
  324,   -1,  326,  327,  328,   -1,   -1,   -1,  332,   -1,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  368,   -1,  370,   -1,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,    0,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   41,  452,   -1,
   44,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,  503,
  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
   -1,  315,   -1,   -1,   -1,  319,  320,   -1,  322,  323,
  324,   -1,  326,  327,  328,   -1,   -1,   -1,  332,   -1,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  368,   -1,  370,   -1,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,    0,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
   59,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,  503,
  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,   -1,  651,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,    0,   -1,   -1,
  399,   -1,  401,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,  435,   -1,   -1,  438,
  439,   44,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,   -1,   59,   -1,   -1,   -1,
   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
   -1,  500,  501,  502,  503,   -1,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,   -1,
  599,  600,  601,  602,  603,  604,   -1,  606,  607,  608,
  609,  610,  611,  612,  613,   -1,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,   -1,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,  314,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,  332,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,   -1,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,
   -1,   -1,   40,   -1,   -1,   43,   -1,   45,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
   58,  484,  485,   -1,  487,   63,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,
  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,   -1,  599,  600,  601,  602,
  603,  604,   -1,  606,  607,  608,  609,  610,  611,  612,
  613,   -1,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,
  268,  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,  285,   -1,  287,
   -1,   -1,  290,  291,  292,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
  308,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,  346,  347,
  348,  349,   -1,  351,   -1,  353,  354,   -1,  356,  357,
  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,  382,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,  410,  411,  412,  413,  414,  415,  416,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,  426,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,  440,  441,  442,  443,  444,  445,   -1,  447,
  448,  449,  450,   -1,  452,  453,  454,  455,  456,  457,
  458,  459,  460,  461,  462,  463,  464,  465,  466,  467,
  468,  469,  470,  471,  472,   -1,  474,  475,  476,  477,
  478,   -1,  480,  481,  482,   -1,  484,  485,  486,  487,
   -1,   -1,  490,  491,  492,  493,  494,  495,  496,   -1,
   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,
   -1,  509,   -1,  511,  512,  513,   -1,  515,  516,   -1,
  518,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
   -1,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,   -1,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,  637,
   -1,  639,  640,  641,  642,  643,  644,  645,  646,  647,
  648,  649,   -1,   -1,  652,  653,  654,  655,  656,  657,
  658,  659,  660,  661,  662,  663,  664,  665,  666,  667,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,  508,  509,
   -1,  511,  512,  513,  514,  515,  516,  517,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,   40,   -1,
   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,   -1,   -1,
   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,  260,   -1,
   -1,  263,   -1,  265,   -1,  267,  268,  269,   -1,   -1,
   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,  285,   -1,  287,   -1,   -1,  290,  291,
  292,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,  308,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,  344,   -1,  346,  347,  348,  349,   -1,  351,
   -1,  353,  354,   -1,  356,  357,  358,   -1,   -1,   -1,
   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
  382,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,  408,  409,  410,  411,
  412,  413,  414,  415,  416,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,  440,  441,
  442,  443,  444,  445,   -1,  447,  448,  449,  450,   -1,
  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,
  462,  463,  464,  465,  466,  467,  468,  469,  470,  471,
  472,   -1,  474,  475,  476,  477,  478,   -1,  480,  481,
  482,   -1,  484,  485,  486,  487,   -1,   -1,  490,  491,
  492,  493,  494,  495,  496,   -1,   -1,   -1,   -1,  501,
  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,  511,
  512,  513,   -1,  515,  516,   -1,  518,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,  637,   -1,  639,  640,  641,
  642,  643,  644,  645,  646,  647,  648,  649,   -1,   -1,
  652,  653,  654,  655,  656,  657,  658,  659,  660,  661,
  662,  663,  664,  665,  666,  667,   40,   -1,   42,   43,
   -1,   45,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,  260,   -1,   -1,   -1,
   -1,  265,   -1,  267,  268,  269,   -1,   -1,   -1,   -1,
  274,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,  285,   -1,  287,   -1,   -1,  290,  291,  292,   -1,
   -1,   -1,   -1,  297,  298,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,  308,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  317,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
  344,   -1,  346,  347,  348,  349,   -1,  351,   -1,  353,
  354,   -1,  356,  357,  358,   -1,   -1,   -1,   -1,   -1,
  364,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,  382,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,  410,  411,  412,  413,
  414,  415,  416,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,  440,  441,  442,  443,
  444,  445,   -1,  447,  448,  449,  450,   -1,  452,  453,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,  462,  463,
  464,  465,  466,  467,  468,  469,  470,  471,  472,   -1,
  474,  475,   -1,  477,  478,   -1,  480,  481,  482,   -1,
  484,  485,  486,  487,   -1,   -1,  490,  491,  492,  493,
  494,  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,
   -1,  505,  506,  507,   -1,  509,   -1,  511,  512,  513,
   -1,  515,  516,   -1,  518,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,  637,   -1,  639,  640,  641,  642,  643,
  644,  645,  646,  647,  648,  649,   -1,   -1,  652,  653,
  654,  655,  656,  657,  658,  659,  660,  661,  662,  663,
  664,  665,  666,  667,   40,   -1,   -1,   43,   -1,   45,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,  267,  268,  269,   -1,   -1,   -1,   -1,  274,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,  285,
   -1,  287,  288,   -1,  290,  291,  292,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,  308,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  317,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,
  346,  347,  348,  349,   -1,  351,   -1,  353,  354,   -1,
  356,  357,  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,  382,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,  410,  411,  412,  413,  414,  415,
  416,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,  440,  441,  442,  443,  444,  445,
   -1,  447,  448,  449,  450,   -1,  452,  453,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,  462,  463,  464,  465,
  466,  467,  468,  469,  470,  471,  472,   -1,  474,  475,
  476,  477,  478,   -1,  480,  481,  482,   -1,  484,  485,
  486,  487,   -1,   -1,  490,  491,  492,  493,  494,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,  511,  512,  513,   -1,  515,
  516,   -1,  518,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,  637,   -1,  639,  640,  641,  642,  643,  644,  645,
  646,  647,  648,  649,   -1,   -1,  652,  653,  654,  655,
  656,  657,  658,  659,  660,  661,  662,  663,  664,  665,
  666,  667,   40,   -1,   -1,   43,   -1,   45,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,
  268,  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,  285,   -1,  287,
   -1,   -1,  290,  291,  292,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
  308,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,  346,  347,
  348,  349,   -1,  351,   -1,  353,  354,   -1,  356,  357,
  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,  382,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,  410,  411,  412,  413,  414,  415,  416,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,  426,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,   -1,   -1,   -1,
  438,  439,  440,  441,  442,  443,  444,  445,   -1,  447,
  448,  449,  450,   -1,  452,  453,   -1,   -1,   -1,   -1,
   -1,   -1,  460,  461,  462,  463,  464,  465,  466,  467,
  468,  469,  470,  471,  472,   -1,  474,  475,  476,  477,
  478,   -1,  480,  481,  482,   -1,  484,  485,  486,  487,
   -1,   -1,  490,  491,  492,  493,  494,  495,  496,   -1,
   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,
   -1,  509,   -1,  511,  512,  513,   -1,  515,  516,   -1,
  518,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
   -1,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,   -1,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,  637,
   -1,  639,  640,  641,  642,  643,  644,  645,  646,  647,
  648,  649,   -1,   -1,  652,  653,  654,  655,  656,  657,
  658,  659,  660,  661,  662,  663,  664,  665,  666,  667,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,  437,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,   40,   -1,
   42,   43,   -1,   45,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,   -1,   -1,
   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,  267,  268,  269,   -1,   -1,
   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,  285,   -1,  287,   -1,   -1,  290,  291,
  292,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,  308,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,  344,   -1,  346,  347,  348,  349,   -1,  351,
   -1,  353,  354,   -1,  356,  357,  358,   -1,   -1,   -1,
   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
  382,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,  410,  411,
  412,  413,  414,  415,  416,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,  440,  441,
  442,  443,  444,  445,   -1,  447,  448,  449,  450,   -1,
  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,
  462,  463,  464,  465,  466,  467,  468,  469,  470,  471,
  472,   -1,  474,  475,  476,  477,  478,   -1,  480,  481,
  482,   -1,  484,  485,  486,  487,   -1,   -1,  490,  491,
  492,  493,  494,  495,  496,   -1,   -1,   -1,   -1,  501,
  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,  511,
  512,  513,   -1,  515,  516,   -1,  518,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,  637,   -1,  639,  640,  641,
  642,  643,  644,  645,  646,  647,  648,  649,   -1,   -1,
  652,  653,  654,  655,  656,  657,  658,  659,  660,  661,
  662,  663,  664,  665,  666,  667,   40,   41,   -1,   43,
   -1,   45,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,  267,  268,  269,   -1,   -1,   -1,   -1,
  274,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,  285,   -1,  287,   -1,   -1,  290,  291,  292,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,  308,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  317,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
  344,   -1,  346,  347,  348,  349,   -1,  351,   -1,  353,
  354,   -1,  356,  357,  358,   -1,   -1,   -1,   -1,   -1,
  364,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,  382,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,  410,  411,  412,  413,
  414,  415,  416,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,  440,  441,  442,  443,
  444,  445,   -1,  447,  448,  449,  450,   -1,  452,  453,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,  462,  463,
  464,  465,  466,  467,  468,  469,  470,  471,  472,   -1,
  474,  475,  476,  477,  478,   -1,  480,  481,  482,   -1,
  484,  485,  486,  487,   -1,   -1,  490,  491,  492,  493,
  494,  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,
   -1,  505,  506,  507,   -1,  509,   -1,  511,  512,  513,
   -1,  515,  516,   -1,  518,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,  637,   -1,  639,  640,  641,  642,  643,
  644,  645,  646,  647,  648,  649,   -1,   -1,  652,  653,
  654,  655,  656,  657,  658,  659,  660,  661,  662,  663,
  664,  665,  666,  667,   40,   -1,   -1,   43,   -1,   45,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,  267,  268,  269,   -1,   -1,   -1,   -1,  274,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,  285,
   -1,  287,   -1,   -1,  290,  291,  292,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,  308,  309,   -1,   -1,   -1,   -1,  314,   -1,
   -1,  317,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,
  346,  347,  348,  349,   -1,  351,   -1,  353,  354,   -1,
  356,  357,  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,  382,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,  410,  411,  412,  413,  414,  415,
  416,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,  440,  441,  442,  443,  444,  445,
   -1,  447,  448,  449,  450,   -1,  452,  453,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,  462,  463,  464,  465,
  466,  467,  468,  469,  470,  471,  472,   -1,  474,  475,
  476,  477,  478,   -1,  480,  481,  482,   -1,  484,  485,
  486,  487,   -1,   -1,  490,  491,  492,  493,  494,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,  511,  512,  513,   -1,  515,
  516,   -1,  518,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,  637,   -1,  639,  640,  641,  642,  643,  644,  645,
  646,  647,  648,  649,   -1,   -1,  652,  653,  654,  655,
  656,  657,  658,  659,  660,  661,  662,  663,  664,  665,
  666,  667,   40,   -1,   -1,   43,   -1,   45,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,
  268,  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,  285,   -1,  287,
   -1,   -1,  290,  291,  292,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
  308,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,  346,  347,
  348,  349,   -1,  351,   -1,  353,  354,   -1,  356,  357,
  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,  382,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,  410,  411,  412,  413,  414,  415,  416,   -1,
   -1,  419,  420,   -1,  422,   -1,   -1,   -1,  426,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,  440,  441,  442,  443,  444,  445,   -1,  447,
  448,  449,  450,   -1,  452,  453,   -1,   -1,   -1,   -1,
   -1,   -1,  460,  461,  462,  463,  464,  465,  466,  467,
  468,  469,  470,  471,  472,   -1,  474,  475,  476,  477,
  478,   -1,  480,  481,  482,   -1,  484,  485,  486,  487,
   -1,   -1,  490,  491,  492,  493,  494,  495,  496,   -1,
   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,
   -1,  509,   -1,  511,  512,  513,   -1,  515,  516,   -1,
  518,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
   -1,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,   -1,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,  637,
   -1,  639,  640,  641,  642,  643,  644,  645,  646,  647,
  648,  649,   -1,   -1,  652,  653,  654,  655,  656,  657,
  658,  659,  660,  661,  662,  663,  664,  665,  666,  667,
   40,   41,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,   40,   -1,
   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,   -1,   -1,
   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,  267,  268,  269,   -1,   -1,
   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,  285,   -1,  287,   -1,   -1,  290,  291,
  292,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,  308,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,  344,   -1,  346,  347,  348,  349,   -1,  351,
   -1,  353,  354,   -1,  356,  357,  358,   -1,   -1,   -1,
   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
  382,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,  410,  411,
  412,  413,  414,  415,  416,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,  440,  441,
  442,  443,  444,  445,   -1,  447,  448,  449,  450,   -1,
  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,
  462,  463,  464,  465,  466,  467,  468,  469,  470,  471,
  472,   -1,  474,  475,  476,  477,  478,   -1,  480,  481,
  482,  483,  484,  485,  486,  487,   -1,   -1,  490,  491,
  492,  493,  494,  495,  496,   -1,   -1,   -1,   -1,  501,
  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,  511,
  512,  513,   -1,  515,  516,   -1,  518,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,  637,   -1,  639,  640,  641,
  642,  643,  644,  645,  646,  647,  648,  649,   -1,   -1,
  652,  653,  654,  655,  656,  657,  658,  659,  660,  661,
  662,  663,  664,  665,  666,  667,   40,   -1,   42,   43,
   -1,   45,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,  260,   -1,   -1,   -1,
   -1,  265,   -1,  267,  268,  269,   -1,   -1,   -1,   -1,
  274,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,  285,   -1,  287,   -1,   -1,  290,  291,  292,   -1,
   -1,   -1,   -1,  297,  298,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,  308,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  317,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
  344,   -1,  346,  347,  348,  349,   -1,  351,   -1,  353,
  354,   -1,  356,  357,  358,   -1,   -1,   -1,   -1,   -1,
  364,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,  382,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,  410,  411,  412,  413,
  414,  415,  416,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,  440,  441,  442,  443,
  444,  445,   -1,  447,  448,  449,  450,   -1,  452,  453,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,  462,  463,
  464,  465,  466,  467,  468,  469,  470,  471,  472,   -1,
  474,   -1,   -1,  477,  478,   -1,  480,  481,  482,   -1,
  484,  485,  486,  487,   -1,   -1,  490,  491,  492,  493,
  494,  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,
   -1,  505,  506,  507,   -1,  509,   -1,  511,  512,  513,
   -1,  515,  516,   -1,  518,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,  637,   -1,  639,  640,  641,  642,  643,
  644,  645,  646,  647,  648,  649,   -1,   -1,  652,  653,
  654,  655,  656,  657,  658,  659,  660,  661,  662,  663,
  664,  665,  666,  667,   40,   -1,   42,   43,   -1,   45,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,  267,  268,  269,   -1,   -1,   -1,   -1,  274,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,  285,
   -1,  287,   -1,   -1,  290,  291,  292,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,  308,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  317,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,
  346,  347,  348,  349,   -1,  351,   -1,  353,  354,   -1,
  356,  357,  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,  382,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,  410,  411,  412,  413,  414,  415,
  416,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,  440,  441,  442,  443,  444,  445,
   -1,  447,  448,  449,  450,   -1,  452,  453,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,  462,  463,  464,  465,
  466,  467,  468,  469,  470,  471,  472,   -1,  474,  475,
  476,  477,  478,   -1,  480,  481,  482,   -1,  484,  485,
  486,  487,   -1,   -1,  490,  491,  492,  493,  494,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,  511,  512,  513,   -1,  515,
  516,   -1,  518,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,  637,   -1,  639,  640,  641,  642,  643,  644,  645,
  646,  647,  648,  649,   -1,   -1,  652,  653,  654,  655,
  656,  657,  658,  659,  660,  661,  662,  663,  664,  665,
  666,  667,   40,   -1,   -1,   43,   -1,   45,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,
  268,  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,  285,   -1,  287,
   -1,   -1,  290,  291,  292,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
  308,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,  346,  347,
  348,  349,   -1,  351,   -1,  353,  354,   -1,  356,  357,
  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,  382,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,  410,  411,  412,  413,  414,  415,  416,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,  426,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,  440,  441,  442,  443,  444,  445,   -1,  447,
  448,  449,  450,   -1,  452,  453,   -1,   -1,   -1,   -1,
   -1,   -1,  460,  461,  462,  463,  464,  465,  466,  467,
  468,  469,  470,  471,  472,   -1,  474,  475,  476,  477,
  478,   -1,  480,  481,  482,   -1,  484,  485,  486,  487,
   -1,   -1,  490,  491,  492,  493,  494,  495,  496,   -1,
   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,
   -1,  509,   -1,  511,  512,  513,   -1,  515,  516,   -1,
  518,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
   -1,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,   -1,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,  637,
   -1,  639,  640,  641,  642,  643,  644,  645,  646,  647,
  648,  649,   -1,   -1,  652,  653,  654,  655,  656,  657,
  658,  659,  660,  661,  662,  663,  664,  665,  666,  667,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,   40,   -1,
   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,   -1,   -1,
   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,  267,  268,  269,   -1,   -1,
   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,  285,   -1,  287,   -1,   -1,  290,  291,
  292,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,  308,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,  344,   -1,  346,  347,  348,  349,   -1,  351,
   -1,  353,  354,   -1,  356,  357,  358,   -1,   -1,   -1,
   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
  382,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,  410,  411,
  412,  413,  414,  415,  416,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,  440,  441,
  442,  443,  444,  445,   -1,  447,  448,  449,  450,   -1,
  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,
  462,  463,  464,  465,  466,  467,  468,  469,  470,  471,
  472,   -1,  474,  475,  476,  477,  478,   -1,  480,  481,
  482,   -1,  484,  485,  486,  487,   -1,   -1,  490,  491,
  492,  493,  494,  495,  496,   -1,   -1,   -1,   -1,  501,
  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,  511,
  512,  513,   -1,  515,  516,   -1,  518,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,  637,   -1,  639,  640,  641,
  642,  643,  644,  645,  646,  647,  648,  649,   -1,   -1,
  652,  653,  654,  655,  656,  657,  658,  659,  660,  661,
  662,  663,  664,  665,  666,  667,   40,   -1,   -1,   43,
   -1,   45,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,  267,  268,  269,   -1,   -1,   -1,   -1,
  274,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,  285,   -1,  287,   -1,   -1,  290,  291,  292,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,  308,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  317,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
  344,   -1,  346,  347,  348,  349,   -1,  351,   -1,  353,
  354,   -1,  356,  357,  358,   -1,   -1,   -1,   -1,   -1,
  364,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,  382,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,  410,  411,  412,  413,
  414,  415,  416,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,  440,  441,  442,  443,
  444,  445,   -1,  447,  448,  449,  450,   -1,  452,  453,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,  462,  463,
  464,  465,  466,  467,  468,  469,  470,  471,  472,   -1,
  474,  475,  476,  477,  478,   -1,  480,  481,  482,   -1,
  484,  485,  486,  487,   -1,   -1,  490,  491,  492,  493,
  494,  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,
   -1,  505,  506,  507,   -1,  509,   -1,  511,  512,  513,
   -1,  515,  516,   -1,  518,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,  637,   -1,  639,  640,  641,  642,  643,
  644,  645,  646,  647,  648,  649,   -1,   -1,  652,  653,
  654,  655,  656,  657,  658,  659,  660,  661,  662,  663,
  664,  665,  666,  667,   40,   -1,   -1,   43,   -1,   45,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,  267,  268,  269,   -1,   -1,   -1,   -1,  274,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,  285,
   -1,  287,   -1,   -1,  290,  291,  292,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,  308,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  317,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,
  346,  347,  348,  349,   -1,  351,   -1,  353,  354,   -1,
  356,  357,  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,  382,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,  410,  411,  412,  413,  414,  415,
  416,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,  440,  441,  442,  443,  444,  445,
   -1,  447,  448,  449,  450,   -1,  452,  453,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,  462,  463,  464,  465,
  466,  467,  468,  469,  470,  471,  472,   -1,  474,  475,
  476,  477,  478,   -1,  480,  481,  482,   -1,  484,  485,
  486,  487,   -1,   -1,  490,  491,  492,  493,  494,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,  511,  512,  513,   -1,  515,
  516,   -1,  518,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,  637,   -1,  639,  640,  641,  642,  643,  644,  645,
  646,  647,  648,  649,   -1,   -1,  652,  653,  654,  655,
  656,  657,  658,  659,  660,  661,  662,  663,  664,  665,
  666,  667,   40,   -1,   -1,   43,   -1,   45,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,
  268,  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,  285,   -1,  287,
   -1,   -1,  290,  291,  292,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
  308,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,  346,  347,
  348,  349,   -1,  351,   -1,  353,  354,   -1,  356,  357,
  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,  382,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,  410,  411,  412,  413,  414,  415,  416,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,  426,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,  440,  441,  442,  443,  444,  445,   -1,  447,
  448,  449,  450,   -1,  452,  453,   -1,   -1,   -1,   -1,
   -1,   -1,  460,  461,  462,  463,  464,  465,  466,  467,
  468,  469,  470,  471,  472,   -1,  474,  475,  476,  477,
  478,   -1,  480,  481,  482,   -1,  484,  485,  486,  487,
   -1,   -1,  490,  491,  492,  493,  494,  495,  496,   -1,
   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,
   -1,  509,   -1,  511,  512,  513,   -1,  515,  516,   -1,
  518,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
   -1,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,   -1,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,  637,
   -1,  639,  640,  641,  642,  643,  644,  645,  646,  647,
  648,  649,   -1,   -1,  652,  653,  654,  655,  656,  657,
  658,  659,  660,  661,  662,  663,  664,  665,  666,  667,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,   40,   -1,
   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,   -1,   -1,
   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,  267,  268,  269,   -1,   -1,
   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,  285,   -1,  287,   -1,   -1,  290,  291,
  292,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,  344,   -1,  346,  347,  348,  349,   -1,  351,
   -1,  353,  354,   -1,  356,  357,  358,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
  382,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,  410,  411,
  412,  413,  414,  415,  416,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,  437,  438,  439,  440,  441,
  442,  443,  444,  445,   -1,  447,  448,  449,  450,   -1,
  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,
  462,  463,  464,  465,  466,  467,  468,  469,  470,  471,
  472,   -1,  474,  475,  476,  477,  478,   -1,  480,  481,
  482,   -1,  484,  485,  486,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,
  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,  511,
  512,  513,   -1,  515,  516,   -1,  518,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,  637,   -1,  639,  640,  641,
  642,  643,  644,  645,  646,  647,  648,  649,   -1,   -1,
  652,  653,  654,  655,  656,  657,  658,  659,  660,  661,
  662,  663,  664,  665,  666,  667,   40,   -1,   -1,   43,
   -1,   45,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,  267,  268,  269,   -1,   -1,   -1,   -1,
  274,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,  285,   -1,  287,   -1,   -1,  290,  291,  292,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  317,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
  344,   -1,  346,  347,  348,  349,   -1,  351,   -1,  353,
  354,   -1,  356,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,  382,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,  410,  411,  412,  413,
  414,  415,  416,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,  440,  441,  442,  443,
  444,  445,   -1,  447,  448,  449,  450,   -1,  452,  453,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,  462,  463,
  464,  465,  466,  467,  468,  469,  470,  471,  472,   -1,
  474,  475,  476,  477,  478,   -1,  480,  481,  482,   -1,
  484,  485,  486,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,
   -1,  505,  506,  507,   -1,  509,   -1,  511,  512,  513,
   -1,  515,  516,   -1,  518,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,  637,   -1,  639,  640,  641,  642,  643,
  644,  645,  646,  647,  648,  649,   -1,   -1,  652,  653,
  654,  655,  656,  657,  658,  659,  660,  661,  662,  663,
  664,  665,  666,  667,   40,   -1,   -1,   43,   -1,   45,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,  267,  268,  269,   -1,   -1,   -1,   -1,  274,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,  285,
   -1,  287,   -1,   -1,  290,  291,  292,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  317,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,
  346,  347,  348,  349,   -1,  351,   -1,  353,  354,   -1,
  356,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,  382,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,  410,  411,  412,  413,  414,  415,
  416,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,  440,  441,  442,  443,  444,  445,
   -1,  447,  448,  449,  450,   40,  452,  453,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,  462,  463,  464,  465,
  466,  467,  468,  469,  470,  471,  472,   -1,  474,  475,
  476,  477,  478,   -1,  480,  481,  482,   -1,  484,  485,
  486,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,  511,  512,  513,   -1,  515,
  516,   -1,  518,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,  637,   -1,  639,  640,  641,  642,  643,  644,  645,
  646,  647,  648,  649,   -1,   -1,  652,  653,  654,  655,
  656,  657,  658,  659,  660,  661,  662,  663,  664,  665,
  666,  667,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,  329,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   40,
   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,   -1,  599,  600,  601,  602,  603,  604,
   -1,  606,  607,  608,  609,  610,  611,  612,  613,   -1,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,  329,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,
  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   40,   -1,   -1,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   58,   -1,   -1,   -1,   -1,   -1,   -1,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,
  501,  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,   -1,  599,  600,
  601,  602,  603,  604,   -1,  606,  607,  608,  609,  610,
  611,  612,  613,   -1,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   40,   -1,
   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   40,   -1,   -1,  437,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,
  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,   -1,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,
  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,
  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   40,   -1,   -1,   -1,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
   -1,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,   -1,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   42,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,
   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,
  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   45,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,
  501,  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,   -1,  599,  600,
  601,  602,  603,  604,   -1,  606,  607,  608,  609,  610,
  611,  612,  613,   -1,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,  643,  644,  645,  646,  647,  648,  649,   -1,
   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,   -1,  441,  442,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   58,  452,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,  270,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,  296,  297,   -1,  299,  300,   -1,   -1,
  303,  304,   -1,  306,  307,   -1,  309,   -1,   -1,  312,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,
   -1,  324,  325,  326,   -1,  328,   -1,  330,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,  346,   -1,  348,  349,   -1,  351,   -1,
  353,   -1,  355,   -1,  357,  358,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,  382,
  383,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,  397,   -1,  399,  400,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,  425,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,   -1,  436,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   58,  452,
  453,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,  497,  498,  499,   -1,  501,  502,
  503,   -1,  505,  506,  507,   -1,  509,   -1,  511,  512,
  513,   -1,  515,  516,   -1,  518,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,   -1,  599,  600,  601,  602,
  603,  604,   -1,  606,  607,  608,  609,  610,  611,  612,
  613,   -1,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,  626,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,
  270,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,  296,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,  307,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,
  320,   -1,   -1,   -1,  324,  325,  326,   -1,  328,   -1,
  330,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,  346,   -1,  348,  349,
   -1,  351,   -1,  353,   -1,  355,   -1,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,  383,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,  425,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,   -1,   -1,  437,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   58,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,  497,  498,  499,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,  626,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,  270,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,  296,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
  307,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,  325,  326,
   -1,  328,   -1,  330,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,  346,
   -1,  348,  349,   -1,  351,   -1,  353,   -1,  355,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,  382,  383,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,  425,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   58,  452,  453,   -1,   -1,   -1,
   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
  497,  498,  499,   -1,  501,  502,  503,   -1,  505,  506,
  507,   -1,  509,   -1,  511,  512,  513,   -1,  515,  516,
   -1,  518,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,   -1,  599,  600,  601,  602,  603,  604,   -1,  606,
  607,  608,  609,  610,  611,  612,  613,   -1,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,  626,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,
   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,   42,   43,   44,   45,
   46,   47,   -1,   -1,   -1,   -1,   -1,   42,   43,   44,
   45,   46,   47,   -1,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   91,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   42,   43,   44,   45,
   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   91,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  271,   -1,  262,   -1,   -1,
   -1,  277,   -1,   -1,   -1,  281,  271,   -1,  284,   -1,
   -1,   -1,  277,   -1,   -1,   -1,  281,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   42,   43,   44,   45,   46,   47,  325,
   -1,   -1,   -1,  318,   -1,   -1,  262,  333,   -1,   -1,
  325,   60,   61,   62,   -1,  271,   -1,   -1,  333,   -1,
   -1,  277,   -1,   -1,  350,  281,  352,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,  350,  362,  352,  364,  365,
  366,   -1,   91,   -1,   -1,  371,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,  412,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  454,  455,
  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   42,   43,   -1,
   45,   46,   47,   -1,   -1,   -1,  412,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,  454,  455,
  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
   -1,   -1,  281,   -1,   -1,  284,   -1,  563,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  563,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  589,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,  598,   -1,  589,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,  598,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,  563,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  589,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  598,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,   -1,  262,   -1,  264,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,   -1,   -1,  281,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,  332,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  380,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  563,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
  589,   -1,  437,   -1,   -1,  279,  280,   -1,  282,  598,
  284,   -1,   -1,  287,   -1,  450,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,  598,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,  446,  447,  448,  449,  450,  451,  452,  453,
  454,  455,  456,  457,  458,  459,  460,  461,  462,  463,
  464,  465,  466,   -1,   -1,  469,  470,  471,  472,  473,
  474,  475,  476,  477,  478,  479,  480,  481,  482,  483,
  484,  485,  486,  487,  488,  489,  490,  491,  492,  493,
  494,  495,  496,  497,  498,  499,  500,  501,  502,  503,
  504,  505,  506,  507,  508,  509,  510,  511,  512,  513,
  514,  515,  516,  517,  518,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
  544,  545,  546,  547,  548,  549,  550,  551,  552,  553,
  554,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,  577,  578,  579,  580,  581,  582,  583,
  584,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
  614,  615,  616,  617,  618,  619,  620,  621,  622,  623,
  624,  625,  626,  627,  628,  629,  630,  631,  632,  633,
  634,  635,  636,  637,  638,  639,  640,  641,  642,  643,
  644,  645,  646,  647,  648,  649,  650,  651,  652,  653,
  654,  655,  656,  657,  658,  659,  660,  661,  662,  663,
  664,  665,  666,  667,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,  446,  447,  448,  449,  450,   -1,  452,
  453,  454,  455,  456,  457,  458,  459,  460,  461,  462,
  463,  464,  465,  466,   -1,   -1,  469,  470,  471,  472,
  473,  474,  475,  476,  477,  478,  479,  480,  481,  482,
  483,  484,  485,  486,  487,  488,  489,  490,  491,  492,
  493,  494,  495,  496,  497,  498,  499,  500,  501,  502,
  503,  504,  505,  506,  507,  508,  509,  510,  511,  512,
  513,  514,  515,  516,  517,  518,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,  544,  545,  546,  547,  548,  549,  550,  551,  552,
  553,  554,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,  577,  578,  579,  580,  581,  582,
  583,  584,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,   -1,  606,  607,  608,  609,  610,  611,  612,
  613,  614,  615,  616,  617,  618,  619,  620,  621,  622,
  623,  624,  625,  626,  627,  628,  629,  630,  631,  632,
  633,  634,  635,  636,  637,  638,  639,  640,  641,  642,
  643,  644,  645,  646,  647,  648,  649,  650,  651,  652,
  653,  654,  655,  656,  657,  658,  659,  660,  661,  662,
  663,  664,  665,  666,  667,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
  272,   -1,   -1,  275,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,  289,  290,  291,
   -1,  293,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,  331,
   -1,   -1,  334,   -1,  336,  337,  338,  339,  340,  341,
  342,  343,   -1,  345,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,  359,   -1,  361,
   -1,  363,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,  390,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,  406,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,   -1,   -1,  428,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,
  462,  463,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,  479,   -1,  481,
  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,
  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,  619,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,  638,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,  272,   -1,   -1,  275,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,  291,   -1,  293,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,  331,   -1,   -1,  334,   -1,  336,  337,  338,
  339,  340,  341,  342,  343,   -1,  345,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
  359,   -1,  361,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,  390,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,
  399,   -1,   -1,  402,  403,  404,  405,  406,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,  428,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  460,  461,  462,  463,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
  479,   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,   -1,
  599,  600,  601,  602,  603,  604,   -1,  606,  607,  608,
  609,  610,  611,  612,  613,   -1,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,  638,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,  272,   -1,   -1,  275,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,  291,   -1,  293,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,  331,   -1,   -1,  334,   -1,
  336,  337,  338,  339,  340,  341,  342,  343,   -1,  345,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,  359,   -1,  361,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,  390,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
  406,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,  428,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,  462,  463,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,  479,   -1,  481,  482,   -1,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,  638,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,  272,
   -1,   -1,  275,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,  291,   -1,
  293,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,  331,   -1,
   -1,  334,   -1,  336,  337,  338,  339,  340,  341,  342,
  343,   -1,  345,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,  359,   -1,  361,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,  390,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,  406,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,   -1,   -1,  428,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,  462,
  463,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,  479,   -1,  481,  482,
   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,
  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,   -1,  599,  600,  601,  602,
  603,  604,   -1,  606,  607,  608,  609,  610,  611,  612,
  613,   -1,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,  638,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,
   -1,   -1,  272,   -1,   -1,  275,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,  291,   -1,  293,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,  331,   -1,   -1,  334,   -1,  336,  337,  338,  339,
  340,  341,  342,  343,   -1,  345,   -1,   -1,  348,   -1,
   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,  359,
   -1,  361,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
  390,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,
   -1,   -1,  402,  403,  404,  405,  406,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,  428,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,  479,
   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,  638,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
  257,   -1,  259,  260,  261,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,  286,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,  296,
  297,   -1,  299,  300,  301,   -1,   -1,  304,   -1,  306,
  307,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,  330,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,  391,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,  400,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,  425,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,   -1,  599,  600,  601,  602,  603,  604,   -1,  606,
  607,  608,  609,  610,  611,  612,  613,   -1,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  644,  645,  646,
  647,  648,  649,  257,   -1,  259,   -1,  261,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,  286,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,  296,  297,   -1,  299,  300,  301,   -1,   -1,
  304,   -1,  306,  307,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,  330,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,  391,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,  400,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,  425,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,
   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  644,  645,  646,  647,  648,  649,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,
   -1,   -1,   -1,   -1,   -1,  316,   -1,   -1,  319,  320,
   -1,  322,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,
  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,   -1,   -1,   -1,   -1,  386,  387,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,
  421,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,
   -1,  432,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,
  501,  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,   -1,  599,  600,
  601,  602,  603,  604,   -1,  606,  607,  608,  609,  610,
  611,  612,  613,   -1,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,
  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,  329,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  370,   -1,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
   -1,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,   -1,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,  257,   -1,  259,   -1,   -1,   -1,  263,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,  322,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,   -1,  599,  600,  601,  602,  603,  604,
   -1,  606,  607,  608,  609,  610,  611,  612,  613,   -1,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
  292,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,
  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,  643,  644,  645,  646,  647,  648,  649,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,   -1,  441,   -1,  443,  444,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,   -1,
  599,  600,  601,  602,  603,  604,   -1,  606,  607,  608,
  609,  610,  611,  612,  613,   -1,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,  355,
   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,  322,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,
  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,   -1,  599,  600,  601,  602,
  603,  604,   -1,  606,  607,  608,  609,  610,  611,  612,
  613,   -1,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,
   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,  371,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,   -1,  599,  600,  601,  602,  603,  604,   -1,  606,
  607,  608,  609,  610,  611,  612,  613,   -1,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,  283,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,
   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,  283,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,
  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,
  501,  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,   -1,  599,  600,
  601,  602,  603,  604,   -1,  606,  607,  608,  609,  610,
  611,  612,  613,   -1,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,
  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
   -1,  309,  310,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,
  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
   -1,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,   -1,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,   -1,  599,  600,  601,  602,  603,  604,
   -1,  606,  607,  608,  609,  610,  611,  612,  613,   -1,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,  451,
  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,
  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,  451,  452,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,   -1,
  599,  600,  601,  602,  603,  604,   -1,  606,  607,  608,
  609,  610,  611,  612,  613,   -1,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,  301,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,
  443,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,
  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,   -1,  599,  600,  601,  602,
  603,  604,   -1,  606,  607,  608,  609,  610,  611,  612,
  613,   -1,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,
   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,   -1,  599,  600,  601,  602,  603,  604,   -1,  606,
  607,  608,  609,  610,  611,  612,  613,   -1,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,
   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,
  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,
  501,  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,   -1,  599,  600,
  601,  602,  603,  604,   -1,  606,  607,  608,  609,  610,
  611,  612,  613,   -1,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,
  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,
  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
   -1,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,   -1,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,   -1,  599,  600,  601,  602,  603,  604,
   -1,  606,  607,  608,  609,  610,  611,  612,  613,   -1,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,
  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,   -1,
  599,  600,  601,  602,  603,  604,   -1,  606,  607,  608,
  609,  610,  611,  612,  613,   -1,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,
  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,   -1,  599,  600,  601,  602,
  603,  604,   -1,  606,  607,  608,  609,  610,  611,  612,
  613,   -1,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,
   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,   -1,  594,  595,  596,
  597,   -1,  599,  600,  601,  602,  603,  604,   -1,  606,
  607,  608,  609,  610,  611,  612,  613,   -1,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,   -1,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,
  484,   -1,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,
   -1,   -1,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,   -1,   -1,   -1,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,
};
static int yyctable[] = {                                     -1,
 1162, 1196,   -1,  637, 1142,   -1,  638, 1142,   -1,   32,
   44,   -1,  950,  119,   -1,  119,  121,   -1,  638, 1144,
   -1, 1763, 1770,   -1, 1315, 1116,   -1, 1562, 1468,   -1,
 1563, 1467,   -1, 1229, 1162,   -1, 1240, 1162,   -1, 2017,
 1379,   -1,  591, 1189,   -1, 1162, 1189,   -1,  210,  639,
   -1,  215,  639,   -1,  224,  639,   -1,  318,  639,   -1,
  319,  639,   -1,  320,  639,   -1, 2358, 1381,   -1, 2360,
 1383,   -1,   82,   89,   -1,  591, 1162,   -1, 2453,  955,
   -1,  810, 1749,   -1, 2635, 1385,   -1,  228, 1173,   -1,
  591, 1191,   -1, 1162, 1191,   -1, 2694, 1072,   -1, 2352,
 1136,   -1, 2499,  953,   -1,  295, 1777,   -1,  295, 1952,
   -1, 3066, 1083,   -1, 3187,  568,   -1,
};
#define YYFINAL 20
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
#define YYMAXTOKEN 669
#if YYDEBUG
static const char *yyname[] = {
"end-of-file",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,"'('","')'","'*'","'+'","','","'-'","'.'","'/'",0,0,0,0,0,0,0,0,0,0,
"':'","';'","'<'","'='","'>'","'?'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,"'['",0,"']'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"ACTIVE","ADD","AFTER","ALL","ALTER","AND","ANY",
"AS","ASC","AT","AVG","AUTO","BEFORE","BEGIN","BETWEEN","BLOB","BY","CAST",
"CHARACTER","CHECK","COLLATE","COMMIT","COMMITTED","COMPUTED","CONCATENATE",
"CONDITIONAL","CONSTRAINT","CONTAINING","COUNT","CREATE","CSTRING","CURRENT",
"CURSOR","DATABASE","DATE","DB_KEY","DECIMAL","DECLARE","DEFAULT","KW_DELETE",
"DESC","DISTINCT","DO","KW_DOMAIN","DROP","ELSE","END","ENTRY_POINT","ESCAPE",
"EXCEPTION","EXECUTE","EXISTS","EXIT","EXTERNAL","FILTER","FOR","FOREIGN",
"FROM","FULL","FUNCTION","GDSCODE","GEQ","GENERATOR","GEN_ID","GRANT","GROUP",
"HAVING","IF","KW_IN","INACTIVE","INNER","INPUT_TYPE","INDEX","INSERT",
"INTEGER","INTO","IS","ISOLATION","JOIN","KEY","KW_CHAR","KW_DEC","KW_DOUBLE",
"KW_FILE","KW_FLOAT","KW_INT","KW_LONG","KW_NULL","KW_NUMERIC","KW_UPPER",
"KW_VALUE","LENGTH","LEFT","LEQ","LEVEL","LIKE","MANUAL","MAXIMUM","MERGE",
"MINIMUM","MODULE_NAME","NAMES","NATIONAL","NATURAL","NCHAR","NEQ","NO","NOT",
"NOT_GTR","NOT_LSS","OF","ON","ONLY","OPTION","OR","ORDER","OUTER",
"OUTPUT_TYPE","KW_OVERFLOW","PAGE","PAGES","KW_PAGE_SIZE","PARAMETER",
"PASSWORD","PLAN","POSITION","POST_EVENT","PRECISION","PRIMARY","PRIVILEGES",
"PROCEDURE","PROTECTED","READ","REAL","REFERENCES","RESERVING","RETAIN",
"RETURNING_VALUES","RETURNS","REVOKE","RIGHT","ROLLBACK","SEGMENT","SELECT",
"SET","SHADOW","KW_SHARED","SINGULAR","KW_SIZE","SMALLINT","SNAPSHOT","SOME",
"SORT","SQLCODE","STABILITY","STARTING","STATISTICS","SUB_TYPE","SUSPEND","SUM",
"TABLE","THEN","TO","TRANSACTION","TRIGGER","UNCOMMITTED","UNION","UNIQUE",
"UPDATE","USER","VALUES","VARCHAR","VARIABLE","VARYING","VERSION","VIEW","WAIT",
"WHEN","WHERE","WHILE","WITH","WORK","WRITE","FLOAT_NUMBER","SYMBOL","NUMBER",
"STRING","INTRODUCER","ACTION","ADMIN","CASCADE","FREE_IT","RESTRICT","ROLE",
"COLUMN","KW_TYPE","EXTRACT","YEAR","MONTH","DAY","HOUR","MINUTE","SECOND",
"WEEKDAY","YEARDAY","TIME","TIMESTAMP","CURRENT_DATE","CURRENT_TIME",
"CURRENT_TIMESTAMP","NUMBER64BIT","SCALEDINT","CURRENT_USER","CURRENT_ROLE",
"KW_BREAK","SUBSTRING","RECREATE","KW_DESCRIPTOR","FIRST","SKIP",
"CURRENT_CONNECTION","CURRENT_TRANSACTION","BIGINT","CASE","NULLIF","COALESCE",
"USING","NULLS","LAST","ROW_COUNT","LOCK","SAVEPOINT","RELEASE","STATEMENT",
"LEAVE","INSERTING","UPDATING","DELETING","BACKUP","KW_DIFFERENCE","OPEN",
"CLOSE","FETCH","ROWS","BLOCK","IIF","SCALAR_ARRAY","CROSS","NEXT","SEQUENCE",
"RESTART","BOTH","COLLATION","COMMENT","BIT_LENGTH","CHAR_LENGTH",
"CHARACTER_LENGTH","LEADING","KW_LOWER","OCTET_LENGTH","TRAILING","TRIM",
"RETURNING","KW_IGNORE","LIMBO","UNDO","REQUESTS","TIMEOUT","ABS","ACCENT",
"ACOS","ALWAYS","ASCII_CHAR","ASCII_VAL","ASIN","ATAN","ATAN2","BIN_AND",
"BIN_OR","BIN_SHL","BIN_SHR","BIN_XOR","CEIL","CONNECT","COS","COSH","COT",
"DATEADD","DATEDIFF","DECODE","DISCONNECT","EXP","FLOOR","GEN_UUID","GENERATED",
"GLOBAL","HASH","INSENSITIVE","LIST","LN","LOG","LOG10","LPAD","MATCHED",
"MATCHING","MAXVALUE","MILLISECOND","MINVALUE","MOD","OVERLAY","PAD","PI",
"PLACING","POWER","PRESERVE","RAND","RECURSIVE","REPLACE","REVERSE","ROUND",
"RPAD","SENSITIVE","SIGN","SIN","SINH","SPACE","SQRT","START","TAN","TANH",
"TEMPORARY","TRUNC","WEEK","AUTONOMOUS","CHAR_TO_UUID","FIRSTNAME","GRANTED",
"LASTNAME","MIDDLENAME","MAPPING","OS_NAME","SIMILAR","UUID_TO_CHAR","CALLER",
"COMMON","DATA","SOURCE","TWO_PHASE","BIND_PARAM","BIN_NOT","BODY","CONTINUE",
"DDL","DECRYPT","ENCRYPT","ENGINE","NAME","OVER","PACKAGE","PARTITION",
"RDB_GET_CONTEXT","RDB_SET_CONTEXT","SCROLL","PRIOR","KW_ABSOLUTE",
"KW_RELATIVE","ACOSH","ASINH","ATANH","RETURN","DETERMINISTIC","IDENTITY",
"DENSE_RANK","FIRST_VALUE","NTH_VALUE","LAST_VALUE","LAG","LEAD","RANK",
"ROW_NUMBER","SQLSTATE","KW_BOOLEAN","KW_FALSE","KW_TRUE","UNKNOWN","USAGE",
"RDB_RECORD_VERSION","LINGER","TAGS","PLUGIN","SERVERWIDE","INCREMENT",
"TRUSTED","ROW","OFFSET","STDDEV_SAMP","STDDEV_POP","VAR_SAMP","VAR_POP",
"COVAR_SAMP","COVAR_POP","CORR","REGR_AVGX","REGR_AVGY","REGR_COUNT",
"REGR_INTERCEPT","REGR_R2","REGR_SLOPE","REGR_SXX","REGR_SXY","REGR_SYY",
"UMINUS","UPLUS",
};
static const char *yyrule[] = {
"$accept : top",
"top : statement",
"top : statement ';'",
"statement : dml_statement",
"statement : ddl_statement",
"statement : tra_statement",
"dml_statement : delete",
"dml_statement : insert",
"dml_statement : merge",
"dml_statement : exec_procedure",
"dml_statement : exec_block",
"dml_statement : savepoint",
"dml_statement : select",
"dml_statement : update",
"dml_statement : update_or_insert",
"ddl_statement : alter",
"ddl_statement : comment",
"ddl_statement : create",
"ddl_statement : create_or_alter",
"ddl_statement : declare",
"ddl_statement : drop",
"ddl_statement : grant",
"ddl_statement : recreate",
"ddl_statement : revoke",
"ddl_statement : set_statistics",
"tra_statement : set_transaction",
"tra_statement : commit",
"tra_statement : rollback",
"tra_statement : set_role",
"$$1 :",
"$$2 :",
"grant : GRANT $$1 $$2 grant0",
"$$3 :",
"$$4 :",
"grant0 : $$3 privileges ON table_noise symbol_table_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 execute_privilege ON PROCEDURE symbol_procedure_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 execute_privilege ON FUNCTION symbol_UDF_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 execute_privilege ON PACKAGE symbol_package_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 usage_privilege ON EXCEPTION symbol_exception_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 usage_privilege ON GENERATOR symbol_generator_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 usage_privilege ON SEQUENCE symbol_generator_name TO $$4 non_role_grantee_list grant_option granted_by",
"$$5 :",
"grant0 : $$3 ddl_privileges object TO $$5 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 db_ddl_privileges DATABASE TO $$5 non_role_grantee_list grant_option granted_by",
"$$6 :",
"$$7 :",
"grant0 : $$6 role_name_list TO $$7 role_grantee_list role_admin_option granted_by",
"object : TABLE",
"object : VIEW",
"object : PROCEDURE",
"object : FUNCTION",
"object : PACKAGE",
"object : GENERATOR",
"object : SEQUENCE",
"object : KW_DOMAIN",
"object : EXCEPTION",
"object : ROLE",
"object : CHARACTER SET",
"object : COLLATION",
"object : FILTER",
"table_noise :",
"table_noise : TABLE",
"privileges : ALL",
"privileges : ALL PRIVILEGES",
"$$8 :",
"privileges : $$8 privilege_list",
"privilege_list : $$8 privilege",
"$$9 :",
"privilege_list : privilege_list ',' $$9 privilege",
"execute_privilege : EXECUTE",
"usage_privilege : USAGE",
"privilege : SELECT",
"privilege : INSERT",
"privilege : KW_DELETE",
"privilege : UPDATE column_parens_opt",
"privilege : REFERENCES column_parens_opt",
"ddl_privileges : ALL privileges_opt",
"ddl_privileges : $$8 ddl_privilege_list",
"privileges_opt :",
"privileges_opt : PRIVILEGES",
"ddl_privilege_list : $$8 ddl_privilege",
"ddl_privilege_list : ddl_privilege_list ',' $$9 ddl_privilege",
"ddl_privilege : CREATE",
"ddl_privilege : ALTER ANY",
"ddl_privilege : DROP ANY",
"db_ddl_privileges : ALL privileges_opt",
"db_ddl_privileges : $$8 db_ddl_privilege_list",
"db_ddl_privilege_list : $$8 db_ddl_privilege",
"db_ddl_privilege_list : db_ddl_privilege_list ',' $$9 db_ddl_privilege",
"db_ddl_privilege : CREATE",
"db_ddl_privilege : ALTER",
"db_ddl_privilege : DROP",
"grant_option :",
"grant_option : WITH GRANT OPTION",
"role_admin_option :",
"role_admin_option : WITH ADMIN OPTION",
"granted_by :",
"granted_by : granted_by_text grantor",
"granted_by_text : GRANTED BY",
"granted_by_text : AS",
"grantor : symbol_user_name",
"grantor : USER symbol_user_name",
"$$10 :",
"revoke : REVOKE $$10 $$2 revoke0",
"$$11 :",
"$$12 :",
"revoke0 : rev_grant_option $$11 privileges ON table_noise symbol_table_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 execute_privilege ON PROCEDURE symbol_procedure_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 execute_privilege ON FUNCTION symbol_UDF_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 execute_privilege ON PACKAGE symbol_package_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 usage_privilege ON EXCEPTION symbol_exception_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 usage_privilege ON GENERATOR symbol_generator_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 usage_privilege ON SEQUENCE symbol_generator_name FROM $$12 non_role_grantee_list granted_by",
"$$13 :",
"revoke0 : rev_grant_option $$11 ddl_privileges object FROM $$13 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 db_ddl_privileges DATABASE FROM $$13 non_role_grantee_list granted_by",
"$$14 :",
"revoke0 : rev_admin_option $$14 role_name_list FROM $$5 role_grantee_list granted_by",
"revoke0 : ALL ON ALL FROM $$5 non_role_grantee_list",
"rev_grant_option :",
"rev_grant_option : GRANT OPTION FOR",
"rev_admin_option :",
"rev_admin_option : ADMIN OPTION FOR",
"$$15 :",
"non_role_grantee_list : $$15 grantee",
"non_role_grantee_list : $$15 user_grantee",
"$$16 :",
"non_role_grantee_list : non_role_grantee_list ',' $$16 grantee",
"non_role_grantee_list : non_role_grantee_list ',' $$16 user_grantee",
"grantee : PROCEDURE symbol_procedure_name",
"grantee : FUNCTION symbol_UDF_name",
"grantee : PACKAGE symbol_package_name",
"grantee : TRIGGER symbol_trigger_name",
"grantee : VIEW symbol_view_name",
"grantee : ROLE symbol_role_name",
"user_grantee : symbol_user_name",
"user_grantee : USER symbol_user_name",
"user_grantee : GROUP symbol_user_name",
"role_name_list : $$15 role_name",
"role_name_list : role_name_list ',' $$16 role_name",
"role_name : symbol_role_name",
"role_grantee_list : $$15 role_grantee",
"role_grantee_list : role_grantee_list ',' $$16 role_grantee",
"role_grantee : grantor",
"declare : DECLARE declare_clause",
"declare_clause : FILTER filter_decl_clause",
"declare_clause : EXTERNAL FUNCTION udf_decl_clause",
"$$17 :",
"$$18 :",
"$$19 :",
"udf_decl_clause : symbol_UDF_name $$17 $$18 arg_desc_list1 RETURNS $$19 return_value1 ENTRY_POINT utf_string MODULE_NAME utf_string",
"udf_data_type : simple_type",
"udf_data_type : BLOB",
"udf_data_type : CSTRING '(' pos_short_integer ')' charset_clause",
"arg_desc_list1 :",
"$$20 :",
"arg_desc_list1 : $$20 arg_desc_list",
"$$21 :",
"arg_desc_list1 : '(' $$21 arg_desc_list ')'",
"arg_desc_list : $$20 arg_desc",
"$$22 :",
"arg_desc_list : arg_desc_list ',' $$22 arg_desc",
"arg_desc : udf_data_type param_mechanism",
"param_mechanism :",
"param_mechanism : BY KW_DESCRIPTOR",
"param_mechanism : BY SCALAR_ARRAY",
"param_mechanism : KW_NULL",
"$$23 :",
"return_value1 : $$23 return_value",
"$$24 :",
"return_value1 : '(' $$24 return_value ')'",
"return_value : udf_data_type return_mechanism",
"return_value : PARAMETER pos_short_integer",
"return_mechanism :",
"return_mechanism : BY KW_VALUE",
"return_mechanism : BY KW_DESCRIPTOR",
"return_mechanism : FREE_IT",
"return_mechanism : BY KW_DESCRIPTOR FREE_IT",
"filter_decl_clause : symbol_filter_name INPUT_TYPE blob_filter_subtype OUTPUT_TYPE blob_filter_subtype ENTRY_POINT utf_string MODULE_NAME utf_string",
"blob_filter_subtype : symbol_blob_subtype_name",
"blob_filter_subtype : signed_short_integer",
"create : CREATE create_clause",
"create_clause : EXCEPTION exception_clause",
"$$25 :",
"$$26 :",
"create_clause : unique_opt order_direction INDEX symbol_index_name ON simple_table_name $$25 $$26 index_definition",
"create_clause : FUNCTION function_clause",
"create_clause : PROCEDURE procedure_clause",
"create_clause : TABLE table_clause",
"create_clause : GLOBAL TEMPORARY TABLE gtt_table_clause",
"create_clause : TRIGGER trigger_clause",
"create_clause : VIEW view_clause",
"create_clause : GENERATOR generator_clause",
"create_clause : SEQUENCE generator_clause",
"create_clause : DATABASE db_clause",
"create_clause : KW_DOMAIN domain_clause",
"create_clause : SHADOW shadow_clause",
"create_clause : ROLE role_clause",
"create_clause : COLLATION collation_clause",
"create_clause : USER create_user_clause",
"create_clause : PACKAGE package_clause",
"create_clause : PACKAGE BODY package_body_clause",
"$$27 :",
"create_clause : MAPPING $$27 create_map_clause",
"$$28 :",
"create_clause : GLOBAL MAPPING $$28 create_map_clause",
"recreate : RECREATE recreate_clause",
"recreate_clause : PROCEDURE procedure_clause",
"recreate_clause : FUNCTION function_clause",
"recreate_clause : TABLE table_clause",
"recreate_clause : GLOBAL TEMPORARY TABLE gtt_table_clause",
"recreate_clause : VIEW view_clause",
"recreate_clause : TRIGGER trigger_clause",
"recreate_clause : PACKAGE package_clause",
"recreate_clause : PACKAGE BODY package_body_clause",
"recreate_clause : EXCEPTION exception_clause",
"recreate_clause : GENERATOR generator_clause",
"recreate_clause : SEQUENCE generator_clause",
"create_or_alter : CREATE OR ALTER replace_clause",
"replace_clause : PROCEDURE replace_procedure_clause",
"replace_clause : FUNCTION replace_function_clause",
"replace_clause : TRIGGER replace_trigger_clause",
"replace_clause : PACKAGE replace_package_clause",
"replace_clause : VIEW replace_view_clause",
"replace_clause : EXCEPTION replace_exception_clause",
"replace_clause : GENERATOR replace_sequence_clause",
"replace_clause : SEQUENCE replace_sequence_clause",
"replace_clause : USER replace_user_clause",
"replace_clause : MAPPING $$27 replace_map_clause",
"replace_clause : GLOBAL MAPPING $$28 replace_map_clause",
"exception_clause : symbol_exception_name sql_string",
"replace_exception_clause : symbol_exception_name sql_string",
"alter_exception_clause : symbol_exception_name sql_string",
"unique_opt :",
"unique_opt : UNIQUE",
"index_definition : column_list",
"index_definition : column_parens",
"index_definition : computed_by '(' value ')'",
"$$29 :",
"$$30 :",
"shadow_clause : pos_short_integer manual_auto conditional utf_string first_file_length $$29 $$30 sec_shadow_files",
"manual_auto :",
"manual_auto : MANUAL",
"manual_auto : AUTO",
"conditional :",
"conditional : CONDITIONAL",
"first_file_length :",
"first_file_length : LENGTH equals long_integer page_noise",
"sec_shadow_files :",
"$$31 :",
"sec_shadow_files : $$31 db_file_list",
"db_file_list : db_file",
"db_file_list : db_file_list db_file",
"$$32 :",
"$$33 :",
"domain_clause : symbol_column_name as_opt data_type domain_default_opt $$32 $$33 domain_constraints_opt collate_clause",
"domain_constraints_opt :",
"domain_constraints_opt : $$33 domain_constraints",
"domain_constraints : $$33 domain_constraint",
"$$34 :",
"domain_constraints : domain_constraints $$34 domain_constraint",
"domain_constraint : null_constraint",
"domain_constraint : check_constraint",
"as_opt :",
"as_opt : AS",
"domain_default : DEFAULT default_value",
"domain_default_opt :",
"domain_default_opt : domain_default",
"null_constraint : NOT KW_NULL",
"check_constraint : CHECK '(' search_condition ')'",
"generator_clause : symbol_generator_name start_with_opt step_option",
"start_with_opt :",
"start_with_opt : start_with",
"start_with : START WITH sequence_value",
"step_option :",
"step_option : INCREMENT by_noise signed_long_integer",
"by_noise :",
"by_noise : BY",
"replace_sequence_clause : symbol_generator_name replace_sequence_options step_option",
"replace_sequence_options : RESTART",
"replace_sequence_options : START WITH sequence_value",
"alter_sequence_clause : symbol_generator_name restart_value_opt2 step_option",
"restart_value_opt : RESTART",
"restart_value_opt : RESTART WITH sequence_value",
"restart_value_opt2 :",
"restart_value_opt2 : restart_value_opt",
"set_generator_clause : SET GENERATOR symbol_generator_name TO sequence_value",
"sequence_value : signed_long_integer",
"sequence_value : NUMBER64BIT",
"sequence_value : '-' NUMBER64BIT",
"role_clause : symbol_role_name",
"$$35 :",
"$$36 :",
"$$37 :",
"$$38 :",
"collation_clause : symbol_collation_name FOR symbol_character_set_name $$35 $$36 collation_sequence_definition $$37 collation_attribute_list_opt $$38 collation_specific_attribute_opt",
"collation_sequence_definition :",
"collation_sequence_definition : FROM symbol_collation_name",
"collation_sequence_definition : FROM EXTERNAL '(' utf_string ')'",
"collation_attribute_list_opt :",
"collation_attribute_list_opt : $$36 collation_attribute_list",
"collation_attribute_list : $$36 collation_attribute",
"$$39 :",
"collation_attribute_list : collation_attribute_list $$39 collation_attribute",
"collation_attribute : $$36 collation_pad_attribute",
"collation_attribute : $$36 collation_case_attribute",
"collation_attribute : $$36 collation_accent_attribute",
"collation_pad_attribute : NO PAD",
"collation_pad_attribute : PAD SPACE",
"collation_case_attribute : CASE SENSITIVE",
"collation_case_attribute : CASE INSENSITIVE",
"collation_accent_attribute : ACCENT SENSITIVE",
"collation_accent_attribute : ACCENT INSENSITIVE",
"collation_specific_attribute_opt :",
"collation_specific_attribute_opt : utf_string",
"alter_charset_clause : symbol_character_set_name SET DEFAULT COLLATION symbol_collation_name",
"$$40 :",
"$$41 :",
"$$42 :",
"db_clause : db_name $$40 $$41 db_initial_desc1 $$42 db_rem_desc1",
"equals :",
"equals : '='",
"db_name : utf_string",
"db_initial_desc1 :",
"db_initial_desc1 : $$41 db_initial_desc",
"db_initial_desc : $$41 db_initial_option",
"$$43 :",
"db_initial_desc : db_initial_desc $$43 db_initial_option",
"db_initial_option : KW_PAGE_SIZE equals pos_short_integer",
"db_initial_option : USER symbol_user_name",
"db_initial_option : USER utf_string",
"db_initial_option : ROLE valid_symbol_name",
"db_initial_option : ROLE utf_string",
"db_initial_option : PASSWORD utf_string",
"db_initial_option : SET NAMES utf_string",
"db_initial_option : LENGTH equals long_integer page_noise",
"db_rem_desc1 :",
"db_rem_desc1 : $$41 db_rem_desc",
"db_rem_desc : $$41 db_rem_option",
"db_rem_desc : db_rem_desc $$43 db_rem_option",
"db_rem_option : db_file",
"db_rem_option : DEFAULT CHARACTER SET symbol_character_set_name",
"db_rem_option : DEFAULT CHARACTER SET symbol_character_set_name COLLATION symbol_collation_name",
"db_rem_option : KW_DIFFERENCE KW_FILE utf_string",
"$$44 :",
"$$45 :",
"db_file : KW_FILE utf_string $$44 $$45 file_desc1",
"file_desc1 :",
"file_desc1 : $$45 file_desc",
"file_desc : $$45 file_clause",
"$$46 :",
"file_desc : file_desc $$46 file_clause",
"file_clause : STARTING file_clause_noise long_integer",
"file_clause : LENGTH equals long_integer page_noise",
"file_clause_noise :",
"file_clause_noise : AT",
"file_clause_noise : AT PAGE",
"page_noise :",
"page_noise : PAGE",
"page_noise : PAGES",
"$$47 :",
"$$48 :",
"table_clause : simple_table_name external_file $$47 '(' $$48 table_elements ')'",
"$$49 :",
"gtt_table_clause : simple_table_name $$49 '(' $$48 table_elements ')' gtt_scope",
"gtt_scope :",
"gtt_scope : ON COMMIT KW_DELETE ROWS",
"gtt_scope : ON COMMIT PRESERVE ROWS",
"external_file :",
"external_file : EXTERNAL KW_FILE utf_string",
"external_file : EXTERNAL utf_string",
"$$50 :",
"table_elements : $$50 table_element",
"$$51 :",
"table_elements : table_elements ',' $$51 table_element",
"$$52 :",
"table_element : $$52 column_def",
"table_element : $$52 table_constraint_definition",
"$$53 :",
"$$54 :",
"column_def : symbol_column_name data_type_or_domain domain_default_opt $$53 $$54 column_constraint_clause collate_clause",
"$$55 :",
"column_def : symbol_column_name data_type_or_domain identity_clause $$55 $$54 column_constraint_clause collate_clause",
"column_def : symbol_column_name non_array_type def_computed",
"column_def : symbol_column_name def_computed",
"identity_clause : GENERATED BY DEFAULT AS IDENTITY identity_clause_options",
"identity_clause_options :",
"identity_clause_options : '(' start_with ')'",
"def_computed : computed_clause '(' value ')'",
"computed_clause : computed_by",
"computed_clause : generated_always_clause",
"generated_always_clause : GENERATED ALWAYS AS",
"computed_by : COMPUTED BY",
"computed_by : COMPUTED",
"data_type_or_domain : data_type",
"data_type_or_domain : symbol_column_name",
"collate_clause :",
"collate_clause : COLLATE symbol_collation_name",
"data_type_descriptor : data_type",
"data_type_descriptor : KW_TYPE OF symbol_column_name",
"data_type_descriptor : KW_TYPE OF COLUMN symbol_column_name '.' symbol_column_name",
"data_type_descriptor : symbol_column_name",
"default_value : constant",
"default_value : current_user",
"default_value : current_role",
"default_value : internal_info",
"default_value : null_value",
"default_value : datetime_value_expression",
"column_constraint_clause :",
"$$56 :",
"column_constraint_clause : $$56 column_constraint_list",
"column_constraint_list : $$56 column_constraint_def",
"$$57 :",
"column_constraint_list : column_constraint_list $$57 column_constraint_def",
"column_constraint_def : constraint_name_opt $$57 column_constraint",
"column_constraint : null_constraint",
"column_constraint : check_constraint",
"column_constraint : REFERENCES symbol_table_name column_parens_opt referential_trigger_action constraint_index_opt",
"column_constraint : UNIQUE constraint_index_opt",
"column_constraint : PRIMARY KEY constraint_index_opt",
"$$58 :",
"table_constraint_definition : constraint_name_opt $$58 table_constraint",
"constraint_name_opt :",
"constraint_name_opt : CONSTRAINT symbol_constraint_name",
"table_constraint : UNIQUE column_parens constraint_index_opt",
"table_constraint : PRIMARY KEY column_parens constraint_index_opt",
"table_constraint : FOREIGN KEY column_parens REFERENCES symbol_table_name column_parens_opt referential_trigger_action constraint_index_opt",
"table_constraint : check_constraint",
"constraint_index_opt :",
"constraint_index_opt : USING order_direction INDEX symbol_index_name",
"referential_trigger_action :",
"referential_trigger_action : update_rule",
"referential_trigger_action : delete_rule",
"referential_trigger_action : delete_rule update_rule",
"referential_trigger_action : update_rule delete_rule",
"update_rule : ON UPDATE referential_action",
"delete_rule : ON KW_DELETE referential_action",
"referential_action : CASCADE",
"referential_action : SET DEFAULT",
"referential_action : SET KW_NULL",
"referential_action : NO ACTION",
"procedure_clause : psql_procedure_clause",
"procedure_clause : external_procedure_clause",
"psql_procedure_clause : procedure_clause_start AS local_declaration_list full_proc_block",
"external_procedure_clause : procedure_clause_start external_clause external_body_clause_opt",
"$$59 :",
"$$60 :",
"$$61 :",
"procedure_clause_start : symbol_procedure_name $$59 $$60 input_parameters $$61 output_parameters",
"alter_procedure_clause : procedure_clause",
"replace_procedure_clause : procedure_clause",
"input_parameters :",
"input_parameters : '(' ')'",
"input_parameters : '(' $$21 input_proc_parameters ')'",
"output_parameters :",
"output_parameters : RETURNS '(' $$22 output_proc_parameters ')'",
"input_proc_parameters : $$20 input_proc_parameter",
"input_proc_parameters : input_proc_parameters ',' $$22 input_proc_parameter",
"input_proc_parameter : column_domain_or_non_array_type collate_clause default_par_opt",
"output_proc_parameters : output_proc_parameter",
"output_proc_parameters : output_proc_parameters ',' $$22 output_proc_parameter",
"output_proc_parameter : column_domain_or_non_array_type collate_clause",
"column_domain_or_non_array_type : symbol_column_name domain_or_non_array_type",
"default_par_opt :",
"default_par_opt : DEFAULT default_value",
"default_par_opt : '=' default_value",
"function_clause : psql_function_clause",
"function_clause : external_function_clause",
"psql_function_clause : function_clause_start AS local_declaration_list full_proc_block",
"external_function_clause : function_clause_start external_clause external_body_clause_opt",
"$$62 :",
"function_clause_start : symbol_UDF_name $$62 $$18 input_parameters RETURNS domain_or_non_array_type collate_clause deterministic_opt",
"deterministic_opt :",
"deterministic_opt : NOT DETERMINISTIC",
"deterministic_opt : DETERMINISTIC",
"external_clause : EXTERNAL NAME utf_string ENGINE valid_symbol_name",
"external_clause : EXTERNAL ENGINE valid_symbol_name",
"external_body_clause_opt :",
"external_body_clause_opt : AS utf_string",
"alter_function_clause : function_clause",
"replace_function_clause : function_clause",
"package_clause : symbol_package_name AS BEGIN package_items_opt END",
"package_items_opt : package_items",
"package_items_opt :",
"package_items : package_item",
"package_items : package_items package_item",
"package_item : FUNCTION function_clause_start ';'",
"package_item : PROCEDURE procedure_clause_start ';'",
"alter_package_clause : package_clause",
"replace_package_clause : package_clause",
"package_body_clause : symbol_package_name AS BEGIN package_items package_body_items_opt END",
"package_body_clause : symbol_package_name AS BEGIN package_body_items_opt END",
"package_body_items_opt :",
"package_body_items_opt : package_body_items",
"package_body_items : package_body_item",
"package_body_items : package_body_items package_body_item",
"package_body_item : FUNCTION psql_function_clause",
"package_body_item : FUNCTION external_function_clause ';'",
"package_body_item : PROCEDURE psql_procedure_clause",
"package_body_item : PROCEDURE external_procedure_clause ';'",
"local_declaration_list :",
"local_declaration_list : local_declarations",
"local_declarations : local_declaration",
"local_declarations : local_declarations local_declaration",
"local_declaration : DECLARE var_decl_opt local_declaration_item ';'",
"$$63 :",
"$$64 :",
"$$65 :",
"local_declaration : DECLARE PROCEDURE symbol_procedure_name $$63 $$64 input_parameters $$65 output_parameters AS local_declaration_list full_proc_block",
"$$66 :",
"local_declaration : DECLARE FUNCTION symbol_UDF_name $$66 $$64 input_parameters RETURNS domain_or_non_array_type collate_clause deterministic_opt AS local_declaration_list full_proc_block",
"local_declaration_item : var_declaration_item",
"local_declaration_item : cursor_declaration_item",
"var_declaration_item : column_domain_or_non_array_type collate_clause default_par_opt",
"var_decl_opt :",
"var_decl_opt : VARIABLE",
"cursor_declaration_item : symbol_cursor_name scroll_opt CURSOR FOR '(' select ')'",
"scroll_opt :",
"scroll_opt : NO SCROLL",
"scroll_opt : SCROLL",
"proc_block : proc_statement",
"proc_block : full_proc_block",
"full_proc_block : BEGIN full_proc_block_body END",
"full_proc_block_body :",
"full_proc_block_body : proc_statements",
"full_proc_block_body : proc_statements excp_hndl_statements",
"proc_statements : proc_block",
"proc_statements : proc_statements proc_block",
"proc_statement : simple_proc_statement ';'",
"proc_statement : complex_proc_statement",
"simple_proc_statement : assignment_statement",
"simple_proc_statement : insert",
"simple_proc_statement : merge",
"simple_proc_statement : update",
"simple_proc_statement : update_or_insert",
"simple_proc_statement : delete",
"simple_proc_statement : singleton_select",
"simple_proc_statement : exec_procedure",
"simple_proc_statement : exec_sql",
"simple_proc_statement : exec_into",
"simple_proc_statement : exec_function",
"simple_proc_statement : excp_statement",
"simple_proc_statement : raise_statement",
"simple_proc_statement : post_event",
"simple_proc_statement : cursor_statement",
"simple_proc_statement : breakleave",
"simple_proc_statement : continue",
"simple_proc_statement : SUSPEND",
"simple_proc_statement : EXIT",
"simple_proc_statement : RETURN value",
"assignment_statement : assignment",
"assignment_statement : ':' assignment",
"complex_proc_statement : in_autonomous_transaction",
"complex_proc_statement : if_then_else",
"complex_proc_statement : while",
"complex_proc_statement : for_select",
"complex_proc_statement : for_exec_into",
"in_autonomous_transaction : KW_IN AUTONOMOUS TRANSACTION DO proc_block",
"excp_statement : EXCEPTION symbol_exception_name",
"excp_statement : EXCEPTION symbol_exception_name value",
"excp_statement : EXCEPTION symbol_exception_name USING '(' value_list ')'",
"raise_statement : EXCEPTION",
"$$67 :",
"$$68 :",
"for_select : label_def_opt FOR select $$67 $$68 for_select_into_cursor DO proc_block",
"for_select_into_cursor : into_variable_list cursor_def_opt",
"for_select_into_cursor : into_variable_list_opt cursor_def",
"into_variable_list_opt :",
"into_variable_list_opt : into_variable_list",
"into_variable_list : INTO variable_list",
"$$69 :",
"$$70 :",
"$$71 :",
"exec_sql : EXECUTE STATEMENT $$69 $$70 exec_stmt_inputs $$71 exec_stmt_options",
"exec_into : exec_sql INTO variable_list",
"for_exec_into : label_def_opt FOR exec_into DO proc_block",
"exec_stmt_inputs : value",
"$$72 :",
"exec_stmt_inputs : '(' value ')' '(' $$72 named_params_list ')'",
"exec_stmt_inputs : '(' value ')' '(' $$72 not_named_params_list ')'",
"named_params_list : $$70 named_param",
"named_params_list : named_params_list ',' $$71 named_param",
"named_param : symbol_variable_name BIND_PARAM value",
"not_named_params_list : $$70 not_named_param",
"not_named_params_list : not_named_params_list ',' $$71 not_named_param",
"not_named_param : value",
"exec_stmt_options :",
"exec_stmt_options : $$70 exec_stmt_options_list",
"$$73 :",
"exec_stmt_options_list : exec_stmt_options_list $$73 exec_stmt_option",
"exec_stmt_options_list : $$70 exec_stmt_option",
"exec_stmt_option : ON EXTERNAL DATA SOURCE value",
"exec_stmt_option : ON EXTERNAL value",
"exec_stmt_option : AS USER value",
"exec_stmt_option : PASSWORD value",
"exec_stmt_option : ROLE value",
"exec_stmt_option : WITH AUTONOMOUS TRANSACTION",
"exec_stmt_option : WITH COMMON TRANSACTION",
"exec_stmt_option : WITH CALLER PRIVILEGES",
"if_then_else : IF '(' search_condition ')' THEN proc_block ELSE proc_block",
"if_then_else : IF '(' search_condition ')' THEN proc_block",
"post_event : POST_EVENT value event_argument_opt",
"event_argument_opt :",
"singleton_select : select INTO variable_list",
"variable : ':' symbol_variable_name",
"variable_list : variable",
"variable_list : column_name",
"variable_list : variable_list ',' column_name",
"variable_list : variable_list ',' variable",
"while : label_def_opt WHILE '(' search_condition ')' DO proc_block",
"label_def_opt :",
"label_def_opt : symbol_label_name ':'",
"breakleave : KW_BREAK",
"breakleave : LEAVE label_use_opt",
"continue : CONTINUE label_use_opt",
"label_use_opt :",
"label_use_opt : symbol_label_name",
"cursor_def_opt :",
"cursor_def_opt : cursor_def",
"cursor_def : AS CURSOR symbol_cursor_name",
"excp_hndl_statements : excp_hndl_statement",
"excp_hndl_statements : excp_hndl_statements excp_hndl_statement",
"$$74 :",
"$$75 :",
"excp_hndl_statement : WHEN $$74 $$75 errors DO proc_block",
"$$76 :",
"errors : $$76 err",
"$$77 :",
"errors : errors ',' $$77 err",
"err : SQLCODE signed_short_integer",
"err : SQLSTATE STRING",
"err : GDSCODE symbol_gdscode_name",
"err : EXCEPTION symbol_exception_name",
"err : ANY",
"cursor_statement : open_cursor",
"cursor_statement : fetch_cursor",
"cursor_statement : close_cursor",
"open_cursor : OPEN symbol_cursor_name",
"close_cursor : CLOSE symbol_cursor_name",
"$$78 :",
"$$79 :",
"fetch_cursor : FETCH $$78 $$79 fetch_scroll FROM symbol_cursor_name into_variable_list_opt",
"fetch_cursor : FETCH symbol_cursor_name into_variable_list_opt",
"fetch_scroll : FIRST",
"fetch_scroll : LAST",
"fetch_scroll : PRIOR",
"fetch_scroll : NEXT",
"fetch_scroll : KW_ABSOLUTE value",
"fetch_scroll : KW_RELATIVE value",
"exec_procedure : EXECUTE PROCEDURE symbol_procedure_name proc_inputs proc_outputs_opt",
"exec_procedure : EXECUTE PROCEDURE symbol_package_name '.' symbol_procedure_name proc_inputs proc_outputs_opt",
"proc_inputs :",
"proc_inputs : value_list",
"proc_inputs : '(' value_list ')'",
"proc_outputs_opt :",
"proc_outputs_opt : RETURNING_VALUES variable_list",
"proc_outputs_opt : RETURNING_VALUES '(' variable_list ')'",
"$$80 :",
"exec_block : EXECUTE BLOCK $$80 $$64 block_input_params $$65 output_parameters AS local_declaration_list full_proc_block",
"block_input_params :",
"block_input_params : '(' $$21 block_parameters ')'",
"block_parameters : $$20 block_parameter",
"block_parameters : block_parameters ',' $$22 block_parameter",
"block_parameter : column_domain_or_non_array_type collate_clause '=' parameter",
"view_clause : simple_table_name column_parens_opt AS select_expr check_opt",
"replace_view_clause : view_clause",
"alter_view_clause : view_clause",
"check_opt :",
"check_opt : WITH CHECK OPTION",
"trigger_clause : symbol_trigger_name trigger_active trigger_type trigger_position AS local_declaration_list full_proc_block",
"trigger_clause : symbol_trigger_name trigger_active trigger_type trigger_position external_clause external_body_clause_opt",
"trigger_clause : symbol_trigger_name trigger_active trigger_type trigger_position ON symbol_table_name AS local_declaration_list full_proc_block",
"trigger_clause : symbol_trigger_name trigger_active trigger_type trigger_position ON symbol_table_name external_clause external_body_clause_opt",
"trigger_clause : symbol_trigger_name FOR symbol_table_name trigger_active trigger_type trigger_position AS local_declaration_list full_proc_block",
"trigger_clause : symbol_trigger_name FOR symbol_table_name trigger_active trigger_type trigger_position external_clause external_body_clause_opt",
"replace_trigger_clause : trigger_clause",
"trigger_active : ACTIVE",
"trigger_active : INACTIVE",
"trigger_active :",
"trigger_type : trigger_type_prefix trigger_type_suffix",
"trigger_type : ON trigger_db_type",
"trigger_type : trigger_type_prefix trigger_ddl_type",
"trigger_db_type : CONNECT",
"trigger_db_type : DISCONNECT",
"trigger_db_type : TRANSACTION START",
"trigger_db_type : TRANSACTION COMMIT",
"trigger_db_type : TRANSACTION ROLLBACK",
"trigger_ddl_type : trigger_ddl_type_items",
"trigger_ddl_type : ANY DDL STATEMENT",
"trigger_ddl_type_items : CREATE TABLE",
"trigger_ddl_type_items : ALTER TABLE",
"trigger_ddl_type_items : DROP TABLE",
"trigger_ddl_type_items : CREATE PROCEDURE",
"trigger_ddl_type_items : ALTER PROCEDURE",
"trigger_ddl_type_items : DROP PROCEDURE",
"trigger_ddl_type_items : CREATE FUNCTION",
"trigger_ddl_type_items : ALTER FUNCTION",
"trigger_ddl_type_items : DROP FUNCTION",
"trigger_ddl_type_items : CREATE TRIGGER",
"trigger_ddl_type_items : ALTER TRIGGER",
"trigger_ddl_type_items : DROP TRIGGER",
"trigger_ddl_type_items : CREATE EXCEPTION",
"trigger_ddl_type_items : ALTER EXCEPTION",
"trigger_ddl_type_items : DROP EXCEPTION",
"trigger_ddl_type_items : CREATE VIEW",
"trigger_ddl_type_items : ALTER VIEW",
"trigger_ddl_type_items : DROP VIEW",
"trigger_ddl_type_items : CREATE KW_DOMAIN",
"trigger_ddl_type_items : ALTER KW_DOMAIN",
"trigger_ddl_type_items : DROP KW_DOMAIN",
"trigger_ddl_type_items : CREATE ROLE",
"trigger_ddl_type_items : ALTER ROLE",
"trigger_ddl_type_items : DROP ROLE",
"trigger_ddl_type_items : CREATE SEQUENCE",
"trigger_ddl_type_items : ALTER SEQUENCE",
"trigger_ddl_type_items : DROP SEQUENCE",
"trigger_ddl_type_items : CREATE USER",
"trigger_ddl_type_items : ALTER USER",
"trigger_ddl_type_items : DROP USER",
"trigger_ddl_type_items : CREATE INDEX",
"trigger_ddl_type_items : ALTER INDEX",
"trigger_ddl_type_items : DROP INDEX",
"trigger_ddl_type_items : CREATE COLLATION",
"trigger_ddl_type_items : DROP COLLATION",
"trigger_ddl_type_items : ALTER CHARACTER SET",
"trigger_ddl_type_items : CREATE PACKAGE",
"trigger_ddl_type_items : ALTER PACKAGE",
"trigger_ddl_type_items : DROP PACKAGE",
"trigger_ddl_type_items : CREATE PACKAGE BODY",
"trigger_ddl_type_items : DROP PACKAGE BODY",
"trigger_ddl_type_items : CREATE MAPPING",
"trigger_ddl_type_items : ALTER MAPPING",
"trigger_ddl_type_items : DROP MAPPING",
"trigger_ddl_type_items : trigger_ddl_type OR trigger_ddl_type",
"trigger_type_prefix : BEFORE",
"trigger_type_prefix : AFTER",
"trigger_type_suffix : INSERT",
"trigger_type_suffix : UPDATE",
"trigger_type_suffix : KW_DELETE",
"trigger_type_suffix : INSERT OR UPDATE",
"trigger_type_suffix : INSERT OR KW_DELETE",
"trigger_type_suffix : UPDATE OR INSERT",
"trigger_type_suffix : UPDATE OR KW_DELETE",
"trigger_type_suffix : KW_DELETE OR INSERT",
"trigger_type_suffix : KW_DELETE OR UPDATE",
"trigger_type_suffix : INSERT OR UPDATE OR KW_DELETE",
"trigger_type_suffix : INSERT OR KW_DELETE OR UPDATE",
"trigger_type_suffix : UPDATE OR INSERT OR KW_DELETE",
"trigger_type_suffix : UPDATE OR KW_DELETE OR INSERT",
"trigger_type_suffix : KW_DELETE OR INSERT OR UPDATE",
"trigger_type_suffix : KW_DELETE OR UPDATE OR INSERT",
"trigger_position :",
"trigger_position : POSITION nonneg_short_integer",
"alter : ALTER alter_clause",
"alter : set_generator_clause",
"alter_clause : EXCEPTION alter_exception_clause",
"$$81 :",
"$$82 :",
"alter_clause : TABLE simple_table_name $$81 $$82 alter_ops",
"alter_clause : VIEW alter_view_clause",
"alter_clause : TRIGGER alter_trigger_clause",
"alter_clause : PROCEDURE alter_procedure_clause",
"alter_clause : PACKAGE alter_package_clause",
"$$83 :",
"alter_clause : DATABASE $$83 $$41 alter_db",
"alter_clause : KW_DOMAIN alter_domain",
"alter_clause : INDEX alter_index_clause",
"alter_clause : EXTERNAL FUNCTION alter_udf_clause",
"alter_clause : FUNCTION alter_function_clause",
"alter_clause : ROLE alter_role_clause",
"alter_clause : USER alter_user_clause",
"alter_clause : CURRENT USER alter_cur_user_clause",
"alter_clause : CHARACTER SET alter_charset_clause",
"alter_clause : GENERATOR alter_sequence_clause",
"alter_clause : SEQUENCE alter_sequence_clause",
"alter_clause : MAPPING $$27 alter_map_clause",
"alter_clause : GLOBAL MAPPING $$28 alter_map_clause",
"$$84 :",
"$$85 :",
"alter_domain : keyword_or_column $$84 $$85 alter_domain_ops",
"alter_domain_ops : $$85 alter_domain_op",
"$$86 :",
"alter_domain_ops : alter_domain_ops $$86 alter_domain_op",
"alter_domain_op : SET domain_default",
"alter_domain_op : ADD CONSTRAINT check_constraint",
"alter_domain_op : ADD check_constraint",
"alter_domain_op : DROP DEFAULT",
"alter_domain_op : DROP CONSTRAINT",
"alter_domain_op : DROP NOT KW_NULL",
"alter_domain_op : SET NOT KW_NULL",
"alter_domain_op : TO symbol_column_name",
"alter_domain_op : KW_TYPE non_array_type",
"alter_ops : $$82 alter_op",
"$$87 :",
"alter_ops : alter_ops ',' $$87 alter_op",
"alter_op : DROP symbol_column_name drop_behaviour",
"alter_op : DROP CONSTRAINT symbol_constraint_name",
"alter_op : ADD $$58 column_def",
"alter_op : ADD $$58 table_constraint_definition",
"alter_op : col_opt alter_column_name POSITION pos_short_integer",
"alter_op : col_opt alter_column_name TO symbol_column_name",
"alter_op : col_opt alter_column_name DROP NOT KW_NULL",
"alter_op : col_opt alter_column_name SET NOT KW_NULL",
"alter_op : col_opt symbol_column_name KW_TYPE alter_data_type_or_domain",
"alter_op : col_opt symbol_column_name KW_TYPE non_array_type def_computed",
"alter_op : col_opt symbol_column_name def_computed",
"alter_op : col_opt symbol_column_name SET domain_default",
"alter_op : col_opt symbol_column_name DROP DEFAULT",
"alter_op : col_opt symbol_column_name restart_value_opt",
"alter_column_name : keyword_or_column",
"keyword_or_column : valid_symbol_name",
"keyword_or_column : ADMIN",
"keyword_or_column : COLUMN",
"keyword_or_column : EXTRACT",
"keyword_or_column : YEAR",
"keyword_or_column : MONTH",
"keyword_or_column : DAY",
"keyword_or_column : HOUR",
"keyword_or_column : MINUTE",
"keyword_or_column : SECOND",
"keyword_or_column : TIME",
"keyword_or_column : TIMESTAMP",
"keyword_or_column : CURRENT_DATE",
"keyword_or_column : CURRENT_TIME",
"keyword_or_column : CURRENT_TIMESTAMP",
"keyword_or_column : CURRENT_USER",
"keyword_or_column : CURRENT_ROLE",
"keyword_or_column : RECREATE",
"keyword_or_column : CURRENT_CONNECTION",
"keyword_or_column : CURRENT_TRANSACTION",
"keyword_or_column : BIGINT",
"keyword_or_column : CASE",
"keyword_or_column : RELEASE",
"keyword_or_column : ROW_COUNT",
"keyword_or_column : SAVEPOINT",
"keyword_or_column : OPEN",
"keyword_or_column : CLOSE",
"keyword_or_column : FETCH",
"keyword_or_column : ROWS",
"keyword_or_column : USING",
"keyword_or_column : CROSS",
"keyword_or_column : BIT_LENGTH",
"keyword_or_column : BOTH",
"keyword_or_column : CHAR_LENGTH",
"keyword_or_column : CHARACTER_LENGTH",
"keyword_or_column : COMMENT",
"keyword_or_column : LEADING",
"keyword_or_column : KW_LOWER",
"keyword_or_column : OCTET_LENGTH",
"keyword_or_column : TRAILING",
"keyword_or_column : TRIM",
"keyword_or_column : CONNECT",
"keyword_or_column : DISCONNECT",
"keyword_or_column : GLOBAL",
"keyword_or_column : INSENSITIVE",
"keyword_or_column : RECURSIVE",
"keyword_or_column : SENSITIVE",
"keyword_or_column : START",
"keyword_or_column : SIMILAR",
"keyword_or_column : KW_BOOLEAN",
"keyword_or_column : CORR",
"keyword_or_column : COVAR_POP",
"keyword_or_column : COVAR_SAMP",
"keyword_or_column : DELETING",
"keyword_or_column : DETERMINISTIC",
"keyword_or_column : KW_FALSE",
"keyword_or_column : INSERTING",
"keyword_or_column : OFFSET",
"keyword_or_column : OVER",
"keyword_or_column : REGR_AVGX",
"keyword_or_column : REGR_AVGY",
"keyword_or_column : REGR_COUNT",
"keyword_or_column : REGR_INTERCEPT",
"keyword_or_column : REGR_R2",
"keyword_or_column : REGR_SLOPE",
"keyword_or_column : REGR_SXX",
"keyword_or_column : REGR_SXY",
"keyword_or_column : REGR_SYY",
"keyword_or_column : RETURN",
"keyword_or_column : RDB_RECORD_VERSION",
"keyword_or_column : ROW",
"keyword_or_column : SCROLL",
"keyword_or_column : SQLSTATE",
"keyword_or_column : STDDEV_SAMP",
"keyword_or_column : STDDEV_POP",
"keyword_or_column : KW_TRUE",
"keyword_or_column : UNKNOWN",
"keyword_or_column : UPDATING",
"keyword_or_column : VAR_SAMP",
"keyword_or_column : VAR_POP",
"col_opt : ALTER",
"col_opt : ALTER COLUMN",
"alter_data_type_or_domain : non_array_type",
"alter_data_type_or_domain : symbol_column_name",
"drop_behaviour :",
"drop_behaviour : RESTRICT",
"drop_behaviour : CASCADE",
"alter_index_clause : symbol_index_name ACTIVE",
"alter_index_clause : symbol_index_name INACTIVE",
"alter_udf_clause : symbol_UDF_name entry_op module_op",
"entry_op :",
"entry_op : ENTRY_POINT utf_string",
"module_op :",
"module_op : MODULE_NAME utf_string",
"alter_role_clause : symbol_role_name alter_role_enable AUTO ADMIN MAPPING",
"alter_role_enable : SET",
"alter_role_enable : DROP",
"alter_db : $$41 db_alter_clause",
"alter_db : alter_db $$43 db_alter_clause",
"$$88 :",
"db_alter_clause : ADD $$88 db_file_list",
"db_alter_clause : ADD KW_DIFFERENCE KW_FILE utf_string",
"db_alter_clause : DROP KW_DIFFERENCE KW_FILE",
"db_alter_clause : BEGIN BACKUP",
"db_alter_clause : END BACKUP",
"db_alter_clause : SET DEFAULT CHARACTER SET symbol_character_set_name",
"$$89 :",
"db_alter_clause : ENCRYPT WITH valid_symbol_name $$89 crypt_key_clause",
"db_alter_clause : DECRYPT",
"db_alter_clause : SET LINGER TO long_integer",
"db_alter_clause : DROP LINGER",
"crypt_key_clause :",
"crypt_key_clause : KEY valid_symbol_name",
"alter_trigger_clause : symbol_trigger_name trigger_active trigger_type_opt trigger_position AS local_declaration_list full_proc_block",
"alter_trigger_clause : symbol_trigger_name trigger_active trigger_type_opt trigger_position external_clause external_body_clause_opt",
"alter_trigger_clause : symbol_trigger_name trigger_active trigger_type_opt trigger_position",
"trigger_type_opt : trigger_type_prefix trigger_type_suffix",
"trigger_type_opt :",
"drop : DROP drop_clause",
"drop_clause : EXCEPTION symbol_exception_name",
"drop_clause : INDEX symbol_index_name",
"drop_clause : PROCEDURE symbol_procedure_name",
"drop_clause : TABLE symbol_table_name",
"drop_clause : TRIGGER symbol_trigger_name",
"drop_clause : VIEW symbol_view_name",
"drop_clause : FILTER symbol_filter_name",
"drop_clause : KW_DOMAIN symbol_domain_name",
"drop_clause : EXTERNAL FUNCTION symbol_UDF_name",
"drop_clause : FUNCTION symbol_UDF_name",
"drop_clause : SHADOW pos_short_integer opt_no_file_delete",
"drop_clause : ROLE symbol_role_name",
"drop_clause : GENERATOR symbol_generator_name",
"drop_clause : SEQUENCE symbol_generator_name",
"drop_clause : COLLATION symbol_collation_name",
"drop_clause : USER symbol_user_name USING PLUGIN valid_symbol_name",
"drop_clause : USER symbol_user_name",
"drop_clause : PACKAGE symbol_package_name",
"drop_clause : PACKAGE BODY symbol_package_name",
"drop_clause : MAPPING $$27 drop_map_clause",
"drop_clause : GLOBAL MAPPING $$28 drop_map_clause",
"opt_no_file_delete :",
"opt_no_file_delete : PRESERVE KW_FILE",
"opt_no_file_delete : KW_DELETE KW_FILE",
"data_type : non_array_type",
"data_type : array_type",
"domain_or_non_array_type : domain_or_non_array_type_name",
"domain_or_non_array_type : domain_or_non_array_type_name NOT KW_NULL",
"domain_or_non_array_type_name : non_array_type",
"domain_or_non_array_type_name : domain_type",
"domain_type : KW_TYPE OF symbol_column_name",
"domain_type : KW_TYPE OF COLUMN symbol_column_name '.' symbol_column_name",
"domain_type : symbol_column_name",
"non_array_type : simple_type",
"non_array_type : blob_type",
"array_type : non_charset_simple_type '[' array_spec ']'",
"array_type : character_type '[' array_spec ']' charset_clause",
"array_spec : array_range",
"array_spec : array_spec ',' array_range",
"array_range : signed_long_integer",
"array_range : signed_long_integer ':' signed_long_integer",
"simple_type : non_charset_simple_type",
"simple_type : character_type charset_clause",
"non_charset_simple_type : national_character_type",
"non_charset_simple_type : numeric_type",
"non_charset_simple_type : float_type",
"non_charset_simple_type : BIGINT",
"non_charset_simple_type : integer_keyword",
"non_charset_simple_type : SMALLINT",
"non_charset_simple_type : DATE",
"non_charset_simple_type : TIME",
"non_charset_simple_type : TIMESTAMP",
"non_charset_simple_type : KW_BOOLEAN",
"integer_keyword : INTEGER",
"integer_keyword : KW_INT",
"$$90 :",
"$$91 :",
"blob_type : BLOB $$90 $$91 blob_subtype blob_segsize charset_clause",
"blob_type : BLOB '(' unsigned_short_integer ')'",
"blob_type : BLOB '(' unsigned_short_integer ',' signed_short_integer ')'",
"blob_type : BLOB '(' ',' signed_short_integer ')'",
"blob_segsize :",
"blob_segsize : SEGMENT KW_SIZE unsigned_short_integer",
"blob_subtype :",
"blob_subtype : SUB_TYPE signed_short_integer",
"blob_subtype : SUB_TYPE symbol_blob_subtype_name",
"charset_clause :",
"charset_clause : CHARACTER SET symbol_character_set_name",
"national_character_type : national_character_keyword '(' pos_short_integer ')'",
"national_character_type : national_character_keyword",
"national_character_type : national_character_keyword VARYING '(' pos_short_integer ')'",
"character_type : character_keyword '(' pos_short_integer ')'",
"character_type : character_keyword",
"character_type : varying_keyword '(' pos_short_integer ')'",
"varying_keyword : VARCHAR",
"varying_keyword : CHARACTER VARYING",
"varying_keyword : KW_CHAR VARYING",
"character_keyword : CHARACTER",
"character_keyword : KW_CHAR",
"national_character_keyword : NCHAR",
"national_character_keyword : NATIONAL CHARACTER",
"national_character_keyword : NATIONAL KW_CHAR",
"numeric_type : KW_NUMERIC prec_scale",
"numeric_type : decimal_keyword prec_scale",
"prec_scale :",
"prec_scale : '(' signed_long_integer ')'",
"prec_scale : '(' signed_long_integer ',' signed_long_integer ')'",
"decimal_keyword : DECIMAL",
"decimal_keyword : KW_DEC",
"float_type : KW_FLOAT precision_opt",
"float_type : KW_LONG KW_FLOAT precision_opt",
"float_type : REAL",
"float_type : KW_DOUBLE PRECISION",
"precision_opt :",
"precision_opt : '(' nonneg_short_integer ')'",
"savepoint : set_savepoint",
"savepoint : release_savepoint",
"savepoint : undo_savepoint",
"set_savepoint : SAVEPOINT symbol_savepoint_name",
"release_savepoint : RELEASE SAVEPOINT symbol_savepoint_name release_only_opt",
"release_only_opt :",
"release_only_opt : ONLY",
"undo_savepoint : ROLLBACK optional_work TO optional_savepoint symbol_savepoint_name",
"optional_savepoint :",
"optional_savepoint : SAVEPOINT",
"commit : COMMIT optional_work optional_retain",
"rollback : ROLLBACK optional_work optional_retain",
"optional_work :",
"optional_work : WORK",
"optional_retain :",
"optional_retain : RETAIN opt_snapshot",
"opt_snapshot :",
"opt_snapshot : SNAPSHOT",
"$$92 :",
"$$93 :",
"set_transaction : SET TRANSACTION $$92 $$93 tran_option_list_opt",
"set_role : SET ROLE valid_symbol_name",
"set_role : SET TRUSTED ROLE",
"tran_option_list_opt :",
"tran_option_list_opt : $$93 tran_option_list",
"tran_option_list : $$93 tran_option",
"$$94 :",
"tran_option_list : tran_option_list $$94 tran_option",
"tran_option : READ ONLY",
"tran_option : READ WRITE",
"tran_option : WAIT",
"tran_option : NO WAIT",
"tran_option : isolation_mode",
"tran_option : NO AUTO UNDO",
"tran_option : KW_IGNORE LIMBO",
"tran_option : RESTART REQUESTS",
"tran_option : LOCK TIMEOUT nonneg_short_integer",
"$$95 :",
"$$96 :",
"tran_option : RESERVING $$95 $$96 restr_list",
"isolation_mode : ISOLATION LEVEL iso_mode",
"isolation_mode : iso_mode",
"iso_mode : snap_shot",
"iso_mode : READ UNCOMMITTED version_mode",
"iso_mode : READ COMMITTED version_mode",
"snap_shot : SNAPSHOT",
"snap_shot : SNAPSHOT TABLE",
"snap_shot : SNAPSHOT TABLE STABILITY",
"version_mode :",
"version_mode : VERSION",
"version_mode : NO VERSION",
"lock_type :",
"lock_type : KW_SHARED",
"lock_type : PROTECTED",
"lock_mode : READ",
"lock_mode : WRITE",
"restr_list : restr_option",
"restr_list : restr_list ',' restr_option",
"restr_option : table_list table_lock",
"table_lock :",
"table_lock : FOR lock_type lock_mode",
"table_list : symbol_table_name",
"table_list : table_list ',' symbol_table_name",
"set_statistics : SET STATISTICS INDEX symbol_index_name",
"comment : COMMENT ON ddl_type0 IS ddl_desc",
"comment : COMMENT ON ddl_type1 symbol_ddl_name IS ddl_desc",
"comment : COMMENT ON ddl_type2 symbol_ddl_name ddl_subname IS ddl_desc",
"comment : COMMENT ON ddl_type3 ddl_qualified_name ddl_subname IS ddl_desc",
"comment : COMMENT ON ddl_type4 ddl_qualified_name IS ddl_desc",
"comment : COMMENT ON USER symbol_user_name IS ddl_desc",
"ddl_type0 : DATABASE",
"ddl_type1 : KW_DOMAIN",
"ddl_type1 : TABLE",
"ddl_type1 : VIEW",
"ddl_type1 : TRIGGER",
"ddl_type1 : FILTER",
"ddl_type1 : EXCEPTION",
"ddl_type1 : GENERATOR",
"ddl_type1 : SEQUENCE",
"ddl_type1 : INDEX",
"ddl_type1 : ROLE",
"ddl_type1 : CHARACTER SET",
"ddl_type1 : COLLATION",
"ddl_type1 : PACKAGE",
"ddl_type2 : COLUMN",
"ddl_type3 : PARAMETER",
"ddl_type3 : PROCEDURE PARAMETER",
"ddl_type3 : FUNCTION PARAMETER",
"ddl_type4 : PROCEDURE",
"ddl_type4 : EXTERNAL FUNCTION",
"ddl_type4 : FUNCTION",
"ddl_subname : '.' symbol_ddl_name",
"ddl_qualified_name : symbol_ddl_name",
"ddl_qualified_name : symbol_ddl_name '.' symbol_ddl_name",
"ddl_desc : utf_string",
"ddl_desc : KW_NULL",
"select : select_expr for_update_clause lock_clause",
"for_update_clause :",
"for_update_clause : FOR UPDATE for_update_list",
"for_update_list :",
"for_update_list : OF column_list",
"lock_clause :",
"lock_clause : WITH LOCK",
"select_expr : with_clause select_expr_body order_clause rows_clause",
"select_expr : with_clause select_expr_body order_clause result_offset_clause fetch_first_clause",
"with_clause :",
"with_clause : WITH RECURSIVE with_list",
"with_clause : WITH with_list",
"with_list : with_item",
"with_list : with_list ',' with_item",
"with_item : symbol_table_alias_name derived_column_list AS '(' select_expr ')'",
"column_select : select_expr",
"column_singleton : column_select",
"select_expr_body : query_term",
"select_expr_body : select_expr_body UNION distinct_noise query_term",
"select_expr_body : select_expr_body UNION ALL query_term",
"query_term : query_spec",
"query_spec : SELECT limit_clause distinct_clause select_list from_clause where_clause group_clause having_clause plan_clause",
"limit_clause :",
"limit_clause : first_clause skip_clause",
"limit_clause : first_clause",
"limit_clause : skip_clause",
"first_clause : FIRST long_integer",
"first_clause : FIRST '(' value ')'",
"first_clause : FIRST parameter",
"skip_clause : SKIP long_integer",
"skip_clause : SKIP '(' value ')'",
"skip_clause : SKIP parameter",
"distinct_clause : DISTINCT",
"distinct_clause : all_noise",
"select_list : select_items",
"select_list : '*'",
"select_items : select_item",
"select_items : select_items ',' select_item",
"select_item : value_opt_alias",
"select_item : symbol_table_alias_name '.' '*'",
"value_opt_alias : value",
"value_opt_alias : value as_noise symbol_item_alias_name",
"as_noise :",
"as_noise : AS",
"from_clause : FROM from_list",
"from_list : table_reference",
"from_list : from_list ',' table_reference",
"table_reference : joined_table",
"table_reference : table_primary",
"table_primary : table_proc",
"table_primary : derived_table",
"table_primary : '(' joined_table ')'",
"derived_table : '(' select_expr ')' as_noise correlation_name derived_column_list",
"correlation_name :",
"correlation_name : symbol_table_alias_name",
"derived_column_list :",
"derived_column_list : '(' alias_list ')'",
"alias_list : symbol_item_alias_name",
"alias_list : alias_list ',' symbol_item_alias_name",
"joined_table : cross_join",
"joined_table : natural_join",
"joined_table : qualified_join",
"cross_join : table_reference CROSS JOIN table_primary",
"natural_join : table_reference NATURAL join_type JOIN table_primary",
"qualified_join : table_reference join_type JOIN table_reference join_condition",
"qualified_join : table_reference join_type JOIN table_reference named_columns_join",
"join_condition : ON search_condition",
"named_columns_join : USING '(' column_list ')'",
"table_proc : symbol_procedure_name table_proc_inputs as_noise symbol_table_alias_name",
"table_proc : symbol_procedure_name table_proc_inputs",
"table_proc : symbol_package_name '.' symbol_procedure_name table_proc_inputs as_noise symbol_table_alias_name",
"table_proc : symbol_package_name '.' symbol_procedure_name table_proc_inputs",
"table_proc_inputs :",
"table_proc_inputs : '(' value_list ')'",
"table_name : simple_table_name",
"table_name : symbol_table_name as_noise symbol_table_alias_name",
"simple_table_name : symbol_table_name",
"join_type :",
"join_type : INNER",
"join_type : LEFT outer_noise",
"join_type : RIGHT outer_noise",
"join_type : FULL outer_noise",
"outer_noise :",
"outer_noise : OUTER",
"group_clause :",
"group_clause : GROUP BY group_by_list",
"group_by_list : group_by_item",
"group_by_list : group_by_list ',' group_by_item",
"group_by_item : value",
"having_clause :",
"having_clause : HAVING search_condition",
"where_clause :",
"where_clause : WHERE search_condition",
"plan_clause :",
"plan_clause : PLAN plan_expression",
"$$97 :",
"$$98 :",
"plan_expression : plan_type $$97 '(' $$98 plan_item_list ')'",
"plan_type :",
"plan_type : JOIN",
"plan_type : SORT MERGE",
"plan_type : MERGE",
"plan_type : HASH",
"plan_type : SORT",
"plan_item_list : plan_item",
"plan_item_list : plan_item_list ',' plan_item",
"plan_item : table_or_alias_list access_type",
"plan_item : plan_expression",
"table_or_alias_list : symbol_table_name",
"table_or_alias_list : table_or_alias_list symbol_table_name",
"access_type : NATURAL",
"$$99 :",
"$$100 :",
"access_type : INDEX $$99 '(' $$100 index_list ')'",
"$$101 :",
"access_type : ORDER $$101 symbol_index_name $$100 extra_indices_opt",
"index_list : symbol_index_name",
"index_list : index_list ',' symbol_index_name",
"extra_indices_opt :",
"$$102 :",
"extra_indices_opt : INDEX '(' $$102 index_list ')'",
"order_clause :",
"order_clause : ORDER BY order_list",
"order_list : order_item",
"order_list : order_list ',' order_item",
"order_item : value order_direction nulls_clause",
"order_direction :",
"order_direction : ASC",
"order_direction : DESC",
"nulls_clause :",
"nulls_clause : NULLS nulls_placement",
"nulls_placement : FIRST",
"nulls_placement : LAST",
"rows_clause : ROWS value",
"rows_clause : ROWS value TO value",
"rows_clause_optional :",
"rows_clause_optional : rows_clause",
"row_noise : ROW",
"row_noise : ROWS",
"result_offset_clause :",
"result_offset_clause : OFFSET simple_value_spec row_noise",
"first_next_noise : FIRST",
"first_next_noise : NEXT",
"fetch_first_clause :",
"fetch_first_clause : FETCH first_next_noise simple_value_spec row_noise ONLY",
"fetch_first_clause : FETCH first_next_noise row_noise ONLY",
"$$103 :",
"insert : insert_start $$103 ins_column_parens_opt VALUES '(' value_list ')' returning_clause",
"insert : insert_start $$103 ins_column_parens_opt select_expr returning_clause",
"insert : insert_start DEFAULT VALUES returning_clause",
"insert_start : INSERT INTO simple_table_name",
"$$104 :",
"$$105 :",
"merge : MERGE INTO table_name USING table_reference ON search_condition $$104 $$105 merge_when_clause returning_clause",
"merge_when_clause : $$105 merge_when_matched_clause",
"merge_when_clause : $$105 merge_when_not_matched_clause",
"$$106 :",
"merge_when_clause : merge_when_clause $$106 merge_when_matched_clause",
"merge_when_clause : merge_when_clause $$106 merge_when_not_matched_clause",
"$$107 :",
"$$108 :",
"merge_when_matched_clause : WHEN MATCHED $$107 $$108 merge_update_specification",
"$$109 :",
"$$110 :",
"merge_when_not_matched_clause : WHEN NOT MATCHED $$109 $$110 merge_insert_specification",
"merge_update_specification : THEN UPDATE SET assignments",
"merge_update_specification : AND search_condition THEN UPDATE SET assignments",
"merge_update_specification : THEN KW_DELETE",
"merge_update_specification : AND search_condition THEN KW_DELETE",
"$$111 :",
"merge_insert_specification : THEN INSERT $$111 ins_column_parens_opt VALUES '(' value_list ')'",
"$$112 :",
"merge_insert_specification : AND search_condition THEN INSERT $$112 ins_column_parens_opt VALUES '(' value_list ')'",
"delete : delete_searched",
"delete : delete_positioned",
"delete_searched : KW_DELETE FROM table_name where_clause plan_clause order_clause rows_clause_optional returning_clause",
"delete_positioned : KW_DELETE FROM table_name cursor_clause returning_clause",
"update : update_searched",
"update : update_positioned",
"update_searched : UPDATE table_name SET assignments where_clause plan_clause order_clause rows_clause_optional returning_clause",
"update_positioned : UPDATE table_name SET assignments cursor_clause returning_clause",
"$$113 :",
"$$114 :",
"$$115 :",
"update_or_insert : UPDATE OR INSERT INTO simple_table_name $$113 $$114 ins_column_parens_opt VALUES '(' value_list ')' $$115 update_or_insert_matching_opt returning_clause",
"update_or_insert_matching_opt :",
"$$116 :",
"update_or_insert_matching_opt : MATCHING $$116 ins_column_parens",
"returning_clause :",
"returning_clause : RETURNING value_opt_alias_list",
"returning_clause : RETURNING value_opt_alias_list INTO variable_list",
"value_opt_alias_list : value_opt_alias",
"value_opt_alias_list : value_opt_alias_list ',' value_opt_alias",
"cursor_clause : WHERE CURRENT OF symbol_cursor_name",
"assignments : assignment",
"assignments : assignments ',' assignment",
"assignment : update_column_name '=' value",
"exec_function : udf",
"exec_function : non_aggregate_function",
"column_parens_opt :",
"column_parens_opt : column_parens",
"column_parens : '(' column_list ')'",
"column_list : simple_column_name",
"column_list : column_list ',' simple_column_name",
"ins_column_parens_opt :",
"$$117 :",
"ins_column_parens_opt : $$117 ins_column_parens",
"ins_column_parens : '(' $$116 ins_column_list ')'",
"ins_column_list : update_column_name",
"ins_column_list : ins_column_list ',' update_column_name",
"column_name : simple_column_name",
"column_name : symbol_table_alias_name '.' symbol_column_name",
"column_name : ':' symbol_table_alias_name '.' symbol_column_name",
"simple_column_name : symbol_column_name",
"update_column_name : simple_column_name",
"update_column_name : symbol_table_alias_name '.' symbol_column_name",
"search_condition : value",
"boolean_value_expression : predicate",
"boolean_value_expression : value OR value",
"boolean_value_expression : value AND value",
"boolean_value_expression : NOT value",
"boolean_value_expression : '(' boolean_value_expression ')'",
"boolean_value_expression : value IS boolean_literal",
"boolean_value_expression : value IS NOT boolean_literal",
"predicate : comparison_predicate",
"predicate : distinct_predicate",
"predicate : between_predicate",
"predicate : binary_pattern_predicate",
"predicate : ternary_pattern_predicate",
"predicate : in_predicate",
"predicate : null_predicate",
"predicate : quantified_predicate",
"predicate : exists_predicate",
"predicate : singular_predicate",
"predicate : trigger_action_predicate",
"comparison_predicate : value comparison_operator value",
"comparison_operator : '='",
"comparison_operator : '<'",
"comparison_operator : '>'",
"comparison_operator : GEQ",
"comparison_operator : LEQ",
"comparison_operator : NOT_GTR",
"comparison_operator : NOT_LSS",
"comparison_operator : NEQ",
"quantified_predicate : value comparison_operator quantified_flag '(' column_select ')'",
"quantified_flag : ALL",
"quantified_flag : SOME",
"quantified_flag : ANY",
"distinct_predicate : value IS DISTINCT FROM value",
"distinct_predicate : value IS NOT DISTINCT FROM value",
"between_predicate : value BETWEEN value_between AND value_between",
"between_predicate : value NOT BETWEEN value_between AND value_between",
"value_between : value_primary",
"value_between : '(' boolean_value_expression ')'",
"binary_pattern_predicate : value binary_pattern_operator value",
"binary_pattern_predicate : value NOT binary_pattern_operator value",
"binary_pattern_operator : CONTAINING",
"binary_pattern_operator : STARTING",
"binary_pattern_operator : STARTING WITH",
"ternary_pattern_predicate : value LIKE value",
"ternary_pattern_predicate : value LIKE value ESCAPE value",
"ternary_pattern_predicate : value NOT LIKE value",
"ternary_pattern_predicate : value NOT LIKE value ESCAPE value",
"ternary_pattern_predicate : value SIMILAR TO value",
"ternary_pattern_predicate : value SIMILAR TO value ESCAPE value",
"ternary_pattern_predicate : value NOT SIMILAR TO value",
"ternary_pattern_predicate : value NOT SIMILAR TO value ESCAPE value",
"in_predicate : value KW_IN in_predicate_value",
"in_predicate : value NOT KW_IN in_predicate_value",
"exists_predicate : EXISTS '(' select_expr ')'",
"singular_predicate : SINGULAR '(' select_expr ')'",
"trigger_action_predicate : INSERTING",
"trigger_action_predicate : UPDATING",
"trigger_action_predicate : DELETING",
"null_predicate : value IS KW_NULL",
"null_predicate : value IS UNKNOWN",
"null_predicate : value IS NOT KW_NULL",
"null_predicate : value IS NOT UNKNOWN",
"in_predicate_value : table_subquery",
"in_predicate_value : '(' value_list ')'",
"table_subquery : '(' column_select ')'",
"$$118 :",
"$$119 :",
"$$120 :",
"create_user_clause : symbol_user_name $$118 $$119 user_fixed_list_opt $$120 user_var_opts",
"$$121 :",
"alter_user_clause : symbol_user_name set_noise $$121 $$119 user_fixed_list_opt $$120 user_var_opts",
"$$122 :",
"alter_cur_user_clause : set_noise $$122 $$119 user_fixed_list_opt $$120 user_var_opts",
"$$123 :",
"replace_user_clause : symbol_user_name set_noise $$123 $$119 user_fixed_list_opt $$120 user_var_opts",
"set_noise :",
"set_noise : SET",
"user_fixed_list_opt :",
"user_fixed_list_opt : $$119 user_fixed_list",
"user_fixed_list : $$119 user_fixed_option",
"$$124 :",
"user_fixed_list : user_fixed_list $$124 user_fixed_option",
"user_fixed_option : FIRSTNAME utf_string",
"user_fixed_option : MIDDLENAME utf_string",
"user_fixed_option : LASTNAME utf_string",
"user_fixed_option : PASSWORD utf_string",
"user_fixed_option : GRANT ADMIN ROLE",
"user_fixed_option : REVOKE ADMIN ROLE",
"user_fixed_option : ACTIVE",
"user_fixed_option : INACTIVE",
"user_fixed_option : USING PLUGIN valid_symbol_name",
"user_var_opts :",
"user_var_opts : TAGS '(' $$120 user_var_list ')'",
"user_var_list : $$119 user_var_option",
"user_var_list : user_var_list ',' $$120 user_var_option",
"user_var_option : valid_symbol_name '=' utf_string",
"user_var_option : DROP valid_symbol_name",
"$$125 :",
"$$126 :",
"$$127 :",
"create_map_clause : $$125 map_clause $$126 $$127 map_to",
"$$128 :",
"$$129 :",
"alter_map_clause : $$128 map_clause $$129 $$127 map_to",
"$$130 :",
"$$131 :",
"replace_map_clause : $$130 map_clause $$131 $$127 map_to",
"drop_map_clause : map_name",
"$$132 :",
"$$133 :",
"$$134 :",
"map_clause : map_name $$132 USING $$133 map_using FROM $$134 map_from",
"map_name : valid_symbol_name",
"map_from : map_from_symbol_name map_logoninfo",
"map_from : ANY map_from_symbol_name",
"map_from_symbol_name : valid_symbol_name",
"map_from_symbol_name : USER",
"map_from_symbol_name : GROUP",
"map_logoninfo : STRING",
"map_logoninfo : valid_symbol_name",
"map_using : PLUGIN valid_symbol_name map_in",
"map_using : ANY PLUGIN map_in",
"map_using : ANY PLUGIN SERVERWIDE",
"map_using : MAPPING map_in",
"map_using : '*' map_in",
"map_in :",
"map_in : KW_IN valid_symbol_name",
"map_to : TO map_role valid_symbol_name",
"map_to : TO map_role",
"map_role : ROLE",
"map_role : USER",
"value : value_primary",
"value : boolean_value_expression",
"value_primary : nonparenthesized_value",
"value_primary : '(' value_primary ')'",
"simple_value_spec : constant",
"simple_value_spec : variable",
"simple_value_spec : parameter",
"nonparenthesized_value : column_name",
"nonparenthesized_value : array_element",
"nonparenthesized_value : function",
"nonparenthesized_value : u_constant",
"nonparenthesized_value : boolean_literal",
"nonparenthesized_value : parameter",
"nonparenthesized_value : variable",
"nonparenthesized_value : cast_specification",
"nonparenthesized_value : case_expression",
"nonparenthesized_value : next_value_expression",
"nonparenthesized_value : udf",
"nonparenthesized_value : '-' value_primary",
"nonparenthesized_value : '+' value_primary",
"nonparenthesized_value : value_primary '+' value_primary",
"nonparenthesized_value : value_primary CONCATENATE value_primary",
"nonparenthesized_value : value_primary COLLATE symbol_collation_name",
"nonparenthesized_value : value_primary '-' value_primary",
"nonparenthesized_value : value_primary '*' value_primary",
"nonparenthesized_value : value_primary '/' value_primary",
"nonparenthesized_value : '(' column_singleton ')'",
"nonparenthesized_value : current_user",
"nonparenthesized_value : current_role",
"nonparenthesized_value : internal_info",
"nonparenthesized_value : recordKeyType",
"nonparenthesized_value : symbol_table_alias_name '.' recordKeyType",
"nonparenthesized_value : KW_VALUE",
"nonparenthesized_value : datetime_value_expression",
"nonparenthesized_value : null_value",
"recordKeyType : DB_KEY",
"recordKeyType : RDB_RECORD_VERSION",
"datetime_value_expression : CURRENT_DATE",
"datetime_value_expression : CURRENT_TIME time_precision_opt",
"datetime_value_expression : CURRENT_TIMESTAMP timestamp_precision_opt",
"time_precision_opt :",
"time_precision_opt : '(' nonneg_short_integer ')'",
"timestamp_precision_opt :",
"timestamp_precision_opt : '(' nonneg_short_integer ')'",
"array_element : column_name '[' value_list ']'",
"value_list_opt :",
"value_list_opt : value_list",
"value_list : value",
"value_list : value_list ',' value",
"constant : u_constant",
"constant : '-' u_numeric_constant",
"constant : boolean_literal",
"u_numeric_constant : NUMBER",
"u_numeric_constant : FLOAT_NUMBER",
"u_numeric_constant : NUMBER64BIT",
"u_numeric_constant : SCALEDINT",
"u_constant : u_numeric_constant",
"u_constant : sql_string",
"u_constant : DATE STRING",
"u_constant : TIME STRING",
"u_constant : TIMESTAMP STRING",
"boolean_literal : KW_FALSE",
"boolean_literal : KW_TRUE",
"parameter : '?'",
"current_user : USER",
"current_user : CURRENT_USER",
"current_role : CURRENT_ROLE",
"internal_info : CURRENT_CONNECTION",
"internal_info : CURRENT_TRANSACTION",
"internal_info : GDSCODE",
"internal_info : SQLCODE",
"internal_info : SQLSTATE",
"internal_info : ROW_COUNT",
"sql_string : STRING",
"sql_string : INTRODUCER STRING",
"utf_string : sql_string",
"signed_short_integer : nonneg_short_integer",
"signed_short_integer : '-' neg_short_integer",
"nonneg_short_integer : NUMBER",
"neg_short_integer : NUMBER",
"pos_short_integer : nonneg_short_integer",
"unsigned_short_integer : NUMBER",
"signed_long_integer : long_integer",
"signed_long_integer : '-' long_integer",
"long_integer : NUMBER",
"function : aggregate_function",
"function : non_aggregate_function",
"function : over_clause",
"non_aggregate_function : numeric_value_function",
"non_aggregate_function : string_value_function",
"non_aggregate_function : system_function_expression",
"aggregate_function : COUNT '(' '*' ')'",
"aggregate_function : COUNT '(' all_noise value ')'",
"aggregate_function : COUNT '(' DISTINCT value ')'",
"aggregate_function : SUM '(' all_noise value ')'",
"aggregate_function : SUM '(' DISTINCT value ')'",
"aggregate_function : AVG '(' all_noise value ')'",
"aggregate_function : AVG '(' DISTINCT value ')'",
"aggregate_function : MINIMUM '(' all_noise value ')'",
"aggregate_function : MINIMUM '(' DISTINCT value ')'",
"aggregate_function : MAXIMUM '(' all_noise value ')'",
"aggregate_function : MAXIMUM '(' DISTINCT value ')'",
"aggregate_function : LIST '(' all_noise value delimiter_opt ')'",
"aggregate_function : LIST '(' DISTINCT value delimiter_opt ')'",
"aggregate_function : STDDEV_SAMP '(' value ')'",
"aggregate_function : STDDEV_POP '(' value ')'",
"aggregate_function : VAR_SAMP '(' value ')'",
"aggregate_function : VAR_POP '(' value ')'",
"aggregate_function : COVAR_SAMP '(' value ',' value ')'",
"aggregate_function : COVAR_POP '(' value ',' value ')'",
"aggregate_function : CORR '(' value ',' value ')'",
"aggregate_function : REGR_AVGX '(' value ',' value ')'",
"aggregate_function : REGR_AVGY '(' value ',' value ')'",
"aggregate_function : REGR_COUNT '(' value ',' value ')'",
"aggregate_function : REGR_INTERCEPT '(' value ',' value ')'",
"aggregate_function : REGR_R2 '(' value ',' value ')'",
"aggregate_function : REGR_SLOPE '(' value ',' value ')'",
"aggregate_function : REGR_SXX '(' value ',' value ')'",
"aggregate_function : REGR_SXY '(' value ',' value ')'",
"aggregate_function : REGR_SYY '(' value ',' value ')'",
"window_function : DENSE_RANK '(' ')'",
"window_function : RANK '(' ')'",
"window_function : ROW_NUMBER '(' ')'",
"window_function : FIRST_VALUE '(' value ')'",
"window_function : LAST_VALUE '(' value ')'",
"window_function : NTH_VALUE '(' value ',' value ')' nth_from",
"window_function : LAG '(' value ',' value ',' value ')'",
"window_function : LAG '(' value ',' value ')'",
"window_function : LAG '(' value ')'",
"window_function : LEAD '(' value ',' value ',' value ')'",
"window_function : LEAD '(' value ',' value ')'",
"window_function : LEAD '(' value ')'",
"nth_from :",
"nth_from : FROM FIRST",
"nth_from : FROM LAST",
"aggregate_window_function : aggregate_function",
"aggregate_window_function : window_function",
"over_clause : aggregate_window_function OVER '(' window_partition_opt order_clause ')'",
"window_partition_opt :",
"window_partition_opt : PARTITION BY value_list",
"delimiter_opt :",
"delimiter_opt : ',' value",
"numeric_value_function : extract_expression",
"numeric_value_function : length_expression",
"extract_expression : EXTRACT '(' timestamp_part FROM value ')'",
"length_expression : bit_length_expression",
"length_expression : char_length_expression",
"length_expression : octet_length_expression",
"bit_length_expression : BIT_LENGTH '(' value ')'",
"char_length_expression : CHAR_LENGTH '(' value ')'",
"char_length_expression : CHARACTER_LENGTH '(' value ')'",
"octet_length_expression : OCTET_LENGTH '(' value ')'",
"system_function_expression : system_function_std_syntax '(' value_list_opt ')'",
"system_function_expression : system_function_special_syntax",
"system_function_std_syntax : ABS",
"system_function_std_syntax : ACOS",
"system_function_std_syntax : ACOSH",
"system_function_std_syntax : ASCII_CHAR",
"system_function_std_syntax : ASCII_VAL",
"system_function_std_syntax : ASIN",
"system_function_std_syntax : ASINH",
"system_function_std_syntax : ATAN",
"system_function_std_syntax : ATAN2",
"system_function_std_syntax : ATANH",
"system_function_std_syntax : BIN_AND",
"system_function_std_syntax : BIN_NOT",
"system_function_std_syntax : BIN_OR",
"system_function_std_syntax : BIN_SHL",
"system_function_std_syntax : BIN_SHR",
"system_function_std_syntax : BIN_XOR",
"system_function_std_syntax : CEIL",
"system_function_std_syntax : CHAR_TO_UUID",
"system_function_std_syntax : COS",
"system_function_std_syntax : COSH",
"system_function_std_syntax : COT",
"system_function_std_syntax : EXP",
"system_function_std_syntax : FLOOR",
"system_function_std_syntax : GEN_UUID",
"system_function_std_syntax : HASH",
"system_function_std_syntax : LEFT",
"system_function_std_syntax : LN",
"system_function_std_syntax : LOG",
"system_function_std_syntax : LOG10",
"system_function_std_syntax : LPAD",
"system_function_std_syntax : MAXVALUE",
"system_function_std_syntax : MINVALUE",
"system_function_std_syntax : MOD",
"system_function_std_syntax : PI",
"system_function_std_syntax : POWER",
"system_function_std_syntax : RAND",
"system_function_std_syntax : RDB_GET_CONTEXT",
"system_function_std_syntax : RDB_SET_CONTEXT",
"system_function_std_syntax : REPLACE",
"system_function_std_syntax : REVERSE",
"system_function_std_syntax : RIGHT",
"system_function_std_syntax : ROUND",
"system_function_std_syntax : RPAD",
"system_function_std_syntax : SIGN",
"system_function_std_syntax : SIN",
"system_function_std_syntax : SINH",
"system_function_std_syntax : SQRT",
"system_function_std_syntax : TAN",
"system_function_std_syntax : TANH",
"system_function_std_syntax : TRUNC",
"system_function_std_syntax : UUID_TO_CHAR",
"system_function_special_syntax : DATEADD '(' value timestamp_part TO value ')'",
"system_function_special_syntax : DATEADD '(' timestamp_part ',' value ',' value ')'",
"system_function_special_syntax : DATEDIFF '(' timestamp_part FROM value TO value ')'",
"system_function_special_syntax : DATEDIFF '(' timestamp_part ',' value ',' value ')'",
"system_function_special_syntax : OVERLAY '(' value PLACING value FROM value FOR value ')'",
"system_function_special_syntax : OVERLAY '(' value PLACING value FROM value ')'",
"system_function_special_syntax : POSITION '(' value KW_IN value ')'",
"system_function_special_syntax : POSITION '(' value_list_opt ')'",
"string_value_function : substring_function",
"string_value_function : trim_function",
"string_value_function : KW_UPPER '(' value ')'",
"string_value_function : KW_LOWER '(' value ')'",
"substring_function : SUBSTRING '(' value FROM value string_length_opt ')'",
"substring_function : SUBSTRING '(' value SIMILAR value ESCAPE value ')'",
"string_length_opt :",
"string_length_opt : FOR value",
"trim_function : TRIM '(' trim_specification value FROM value ')'",
"trim_function : TRIM '(' value FROM value ')'",
"trim_function : TRIM '(' trim_specification FROM value ')'",
"trim_function : TRIM '(' value ')'",
"trim_specification : BOTH",
"trim_specification : TRAILING",
"trim_specification : LEADING",
"udf : symbol_UDF_call_name '(' value_list ')'",
"udf : symbol_UDF_call_name '(' ')'",
"udf : symbol_package_name '.' symbol_UDF_name '(' value_list ')'",
"udf : symbol_package_name '.' symbol_UDF_name '(' ')'",
"cast_specification : CAST '(' value AS data_type_descriptor ')'",
"case_expression : case_abbreviation",
"case_expression : case_specification",
"case_abbreviation : NULLIF '(' value ',' value ')'",
"case_abbreviation : IIF '(' search_condition ',' value ',' value ')'",
"case_abbreviation : COALESCE '(' value ',' value_list ')'",
"case_abbreviation : DECODE '(' value ',' decode_pairs ')'",
"case_abbreviation : DECODE '(' value ',' decode_pairs ',' value ')'",
"case_specification : simple_case",
"case_specification : searched_case",
"$$135 :",
"$$136 :",
"$$137 :",
"simple_case : CASE case_operand $$135 $$136 $$137 simple_when_clause else_case_result_opt END",
"simple_when_clause : WHEN when_operand THEN case_result",
"simple_when_clause : simple_when_clause WHEN when_operand THEN case_result",
"else_case_result_opt :",
"else_case_result_opt : ELSE case_result",
"searched_case : CASE searched_when_clause END",
"searched_case : CASE searched_when_clause ELSE case_result END",
"searched_when_clause : WHEN search_condition THEN case_result",
"searched_when_clause : searched_when_clause WHEN search_condition THEN case_result",
"when_operand : value",
"case_operand : value",
"case_result : value",
"decode_pairs : value ',' value",
"decode_pairs : decode_pairs ',' value ',' value",
"next_value_expression : NEXT KW_VALUE FOR symbol_generator_name",
"next_value_expression : GEN_ID '(' symbol_generator_name ',' value ')'",
"timestamp_part : YEAR",
"timestamp_part : MONTH",
"timestamp_part : DAY",
"timestamp_part : HOUR",
"timestamp_part : MINUTE",
"timestamp_part : SECOND",
"timestamp_part : MILLISECOND",
"timestamp_part : WEEK",
"timestamp_part : WEEKDAY",
"timestamp_part : YEARDAY",
"all_noise :",
"all_noise : ALL",
"distinct_noise :",
"distinct_noise : DISTINCT",
"null_value : KW_NULL",
"null_value : UNKNOWN",
"symbol_UDF_call_name : SYMBOL",
"symbol_UDF_name : valid_symbol_name",
"symbol_blob_subtype_name : valid_symbol_name",
"symbol_character_set_name : valid_symbol_name",
"symbol_collation_name : valid_symbol_name",
"symbol_column_name : valid_symbol_name",
"symbol_constraint_name : valid_symbol_name",
"symbol_cursor_name : valid_symbol_name",
"symbol_domain_name : valid_symbol_name",
"symbol_exception_name : valid_symbol_name",
"symbol_filter_name : valid_symbol_name",
"symbol_gdscode_name : valid_symbol_name",
"symbol_generator_name : valid_symbol_name",
"symbol_index_name : valid_symbol_name",
"symbol_item_alias_name : valid_symbol_name",
"symbol_label_name : valid_symbol_name",
"symbol_ddl_name : valid_symbol_name",
"symbol_procedure_name : valid_symbol_name",
"symbol_role_name : valid_symbol_name",
"symbol_table_alias_name : valid_symbol_name",
"symbol_table_name : valid_symbol_name",
"symbol_trigger_name : valid_symbol_name",
"symbol_user_name : valid_symbol_name",
"symbol_variable_name : valid_symbol_name",
"symbol_view_name : valid_symbol_name",
"symbol_savepoint_name : valid_symbol_name",
"symbol_package_name : valid_symbol_name",
"valid_symbol_name : SYMBOL",
"valid_symbol_name : non_reserved_word",
"non_reserved_word : ACTION",
"non_reserved_word : CASCADE",
"non_reserved_word : FREE_IT",
"non_reserved_word : RESTRICT",
"non_reserved_word : ROLE",
"non_reserved_word : KW_TYPE",
"non_reserved_word : KW_BREAK",
"non_reserved_word : KW_DESCRIPTOR",
"non_reserved_word : SUBSTRING",
"non_reserved_word : COALESCE",
"non_reserved_word : LAST",
"non_reserved_word : LEAVE",
"non_reserved_word : LOCK",
"non_reserved_word : NULLIF",
"non_reserved_word : NULLS",
"non_reserved_word : STATEMENT",
"non_reserved_word : FIRST",
"non_reserved_word : SKIP",
"non_reserved_word : BLOCK",
"non_reserved_word : BACKUP",
"non_reserved_word : KW_DIFFERENCE",
"non_reserved_word : IIF",
"non_reserved_word : SCALAR_ARRAY",
"non_reserved_word : WEEKDAY",
"non_reserved_word : YEARDAY",
"non_reserved_word : SEQUENCE",
"non_reserved_word : NEXT",
"non_reserved_word : RESTART",
"non_reserved_word : COLLATION",
"non_reserved_word : RETURNING",
"non_reserved_word : KW_IGNORE",
"non_reserved_word : LIMBO",
"non_reserved_word : UNDO",
"non_reserved_word : REQUESTS",
"non_reserved_word : TIMEOUT",
"non_reserved_word : ABS",
"non_reserved_word : ACCENT",
"non_reserved_word : ACOS",
"non_reserved_word : ALWAYS",
"non_reserved_word : ASCII_CHAR",
"non_reserved_word : ASCII_VAL",
"non_reserved_word : ASIN",
"non_reserved_word : ATAN",
"non_reserved_word : ATAN2",
"non_reserved_word : BIN_AND",
"non_reserved_word : BIN_OR",
"non_reserved_word : BIN_SHL",
"non_reserved_word : BIN_SHR",
"non_reserved_word : BIN_XOR",
"non_reserved_word : CEIL",
"non_reserved_word : COS",
"non_reserved_word : COSH",
"non_reserved_word : COT",
"non_reserved_word : DATEADD",
"non_reserved_word : DATEDIFF",
"non_reserved_word : DECODE",
"non_reserved_word : EXP",
"non_reserved_word : FLOOR",
"non_reserved_word : GEN_UUID",
"non_reserved_word : GENERATED",
"non_reserved_word : HASH",
"non_reserved_word : LIST",
"non_reserved_word : LN",
"non_reserved_word : LOG",
"non_reserved_word : LOG10",
"non_reserved_word : LPAD",
"non_reserved_word : MATCHED",
"non_reserved_word : MATCHING",
"non_reserved_word : MAXVALUE",
"non_reserved_word : MILLISECOND",
"non_reserved_word : MINVALUE",
"non_reserved_word : MOD",
"non_reserved_word : OVERLAY",
"non_reserved_word : PAD",
"non_reserved_word : PI",
"non_reserved_word : PLACING",
"non_reserved_word : POWER",
"non_reserved_word : PRESERVE",
"non_reserved_word : RAND",
"non_reserved_word : REPLACE",
"non_reserved_word : REVERSE",
"non_reserved_word : ROUND",
"non_reserved_word : RPAD",
"non_reserved_word : SIGN",
"non_reserved_word : SIN",
"non_reserved_word : SINH",
"non_reserved_word : SPACE",
"non_reserved_word : SQRT",
"non_reserved_word : TAN",
"non_reserved_word : TANH",
"non_reserved_word : TEMPORARY",
"non_reserved_word : TRUNC",
"non_reserved_word : WEEK",
"non_reserved_word : AUTONOMOUS",
"non_reserved_word : CHAR_TO_UUID",
"non_reserved_word : FIRSTNAME",
"non_reserved_word : MIDDLENAME",
"non_reserved_word : LASTNAME",
"non_reserved_word : MAPPING",
"non_reserved_word : OS_NAME",
"non_reserved_word : UUID_TO_CHAR",
"non_reserved_word : GRANTED",
"non_reserved_word : CALLER",
"non_reserved_word : COMMON",
"non_reserved_word : DATA",
"non_reserved_word : SOURCE",
"non_reserved_word : TWO_PHASE",
"non_reserved_word : BIN_NOT",
"non_reserved_word : ACTIVE",
"non_reserved_word : AFTER",
"non_reserved_word : ASC",
"non_reserved_word : AUTO",
"non_reserved_word : BEFORE",
"non_reserved_word : COMMITTED",
"non_reserved_word : COMPUTED",
"non_reserved_word : CONDITIONAL",
"non_reserved_word : CONTAINING",
"non_reserved_word : CSTRING",
"non_reserved_word : DATABASE",
"non_reserved_word : DESC",
"non_reserved_word : DO",
"non_reserved_word : KW_DOMAIN",
"non_reserved_word : ENTRY_POINT",
"non_reserved_word : EXCEPTION",
"non_reserved_word : EXIT",
"non_reserved_word : KW_FILE",
"non_reserved_word : GENERATOR",
"non_reserved_word : GEN_ID",
"non_reserved_word : IF",
"non_reserved_word : INACTIVE",
"non_reserved_word : INPUT_TYPE",
"non_reserved_word : ISOLATION",
"non_reserved_word : KEY",
"non_reserved_word : LENGTH",
"non_reserved_word : LEVEL",
"non_reserved_word : MANUAL",
"non_reserved_word : MODULE_NAME",
"non_reserved_word : NAMES",
"non_reserved_word : OPTION",
"non_reserved_word : OUTPUT_TYPE",
"non_reserved_word : KW_OVERFLOW",
"non_reserved_word : PAGE",
"non_reserved_word : PAGES",
"non_reserved_word : KW_PAGE_SIZE",
"non_reserved_word : PASSWORD",
"non_reserved_word : PRIVILEGES",
"non_reserved_word : PROTECTED",
"non_reserved_word : READ",
"non_reserved_word : RESERVING",
"non_reserved_word : RETAIN",
"non_reserved_word : SEGMENT",
"non_reserved_word : SHADOW",
"non_reserved_word : KW_SHARED",
"non_reserved_word : SINGULAR",
"non_reserved_word : KW_SIZE",
"non_reserved_word : SNAPSHOT",
"non_reserved_word : SORT",
"non_reserved_word : STABILITY",
"non_reserved_word : STARTING",
"non_reserved_word : STATISTICS",
"non_reserved_word : SUB_TYPE",
"non_reserved_word : SUSPEND",
"non_reserved_word : TRANSACTION",
"non_reserved_word : UNCOMMITTED",
"non_reserved_word : WAIT",
"non_reserved_word : WORK",
"non_reserved_word : WRITE",
"non_reserved_word : KW_ABSOLUTE",
"non_reserved_word : ACOSH",
"non_reserved_word : ASINH",
"non_reserved_word : ATANH",
"non_reserved_word : BODY",
"non_reserved_word : CONTINUE",
"non_reserved_word : DDL",
"non_reserved_word : DECRYPT",
"non_reserved_word : ENCRYPT",
"non_reserved_word : ENGINE",
"non_reserved_word : IDENTITY",
"non_reserved_word : NAME",
"non_reserved_word : PACKAGE",
"non_reserved_word : PARTITION",
"non_reserved_word : PRIOR",
"non_reserved_word : RDB_GET_CONTEXT",
"non_reserved_word : RDB_SET_CONTEXT",
"non_reserved_word : KW_RELATIVE",
"non_reserved_word : DENSE_RANK",
"non_reserved_word : FIRST_VALUE",
"non_reserved_word : NTH_VALUE",
"non_reserved_word : LAST_VALUE",
"non_reserved_word : LAG",
"non_reserved_word : LEAD",
"non_reserved_word : RANK",
"non_reserved_word : ROW_NUMBER",
"non_reserved_word : USAGE",
"non_reserved_word : LINGER",
"non_reserved_word : TAGS",
"non_reserved_word : PLUGIN",
"non_reserved_word : SERVERWIDE",
"non_reserved_word : INCREMENT",
"non_reserved_word : TRUSTED",
};
#endif

#ifdef YYREDUCEPOSNFUNC
#define YYCALLREDUCEPOSN(e)   \
	if (reduce_posn) {     \
	  YYREDUCEPOSNFUNC(yyps->pos, &(yyps->psp)[1 - yym], &(yyps->vsp)[1 - yym], \
			   yym, yyps->psp - yyps->ps, yychar, yyposn, e);       \
	  reduce_posn = 0;    \
	}

#ifndef YYCALLREDUCEPOSNARG
#define YYCALLREDUCEPOSNARG yyps->val
#endif


#define YYPOSNARG(n) ((yyps->psp)[1 - yym + (n) - 1])
#define YYPOSNOUT    (yyps->pos)
#endif

// If delete function is not defined by the user, do not deletions.
#ifndef YYDELETEVAL
#define YYDELETEVAL(v, n) 
#endif

// If delete function is not defined by the user, do not deletions.
#ifndef YYDELETEPOSN
#define YYDELETEPOSN(v, n) 
#endif

#define yyclearin (yychar = (-1))

#define yyerrok (yyps->errflag = 0)

#ifndef YYSTACKGROWTH
#define YYSTACKGROWTH 16
#endif

#ifndef YYDEFSTACKSIZE
#define YYDEFSTACKSIZE 12
#endif

#ifdef YYDEBUG
int yydebug;
#endif


#define YYABORT  goto yyabort
#define YYACCEPT goto yyaccept
#define YYERROR  goto yyerrlab
#define YYVALID         do { if (yyps->save)          goto yyvalid; } while(0)
#define YYVALID_NESTED  do { if (yyps->save && \
                                 yyps->save->save == 0) goto yyvalid; } while(0)
//
// For use in generated program
//
#define yytrial (yyps->save)
#define yyvsp   (yyps->vsp)
#define yyval   (yyps->val)
#define yydepth (yyps->ssp - yyps->ss)





void Parser::yySCopy(YYSTYPE* to, YYSTYPE* from, int size)
{
  int i;                             
  for (i = size - 1; i >= 0; i--) {
    to[i] = from[i];
  }
}


void Parser::yyPCopy(YYPOSN* to, YYPOSN* from, int size)
{
  int i;                             
  for (i = size - 1; i >= 0; i--) {
    to[i] = from[i];
  }
}


void Parser::yyMoreStack(yyparsestate* yyps)
{
  int p = yyps->ssp - yyps->ss;                               
  Yshort  *tss = yyps->ss;
  YYSTYPE *tvs = yyps->vs;
  YYPOSN  *tps = yyps->ps;
  yyps->ss = FB_NEW_POOL(getPool()) Yshort [yyps->stacksize + YYSTACKGROWTH];   
  yyps->vs = FB_NEW_POOL(getPool()) YYSTYPE[yyps->stacksize + YYSTACKGROWTH];  
  yyps->ps = FB_NEW_POOL(getPool()) YYPOSN [yyps->stacksize + YYSTACKGROWTH];  
  memcpy(yyps->ss, tss, yyps->stacksize * sizeof(Yshort));  
  yySCopy(yyps->vs, tvs, yyps->stacksize);
  yyPCopy(yyps->ps, tps, yyps->stacksize);
  yyps->stacksize += YYSTACKGROWTH;
  delete[] tss;
  delete[] tvs;
  delete[] tps;
  yyps->ssp = yyps->ss + p;                                   
  yyps->vsp = yyps->vs + p;                                   
  yyps->psp = yyps->ps + p;                                   
}


Parser::yyparsestate* Parser::yyNewState(int size)
{
  yyparsestate *p = FB_NEW_POOL(getPool()) yyparsestate;
  p->stacksize = size + 4;
  p->ss = FB_NEW_POOL(getPool()) Yshort [size + 4];
  p->vs = FB_NEW_POOL(getPool()) YYSTYPE[size + 4];
  p->ps = FB_NEW_POOL(getPool()) YYPOSN [size + 4];
  memset(&p->vs[0], 0, (size + 4) * sizeof(YYSTYPE));
  memset(&p->ps[0], 0, (size + 4) * sizeof(YYPOSN));
  return p;
}


void Parser::yyFreeState(Parser::yyparsestate* p)
{
  delete[] p->ss;
  delete[] p->vs;
  delete[] p->ps;
  delete p;
}


int Parser::parseAux()
{
  int yym, yyn, yystate, yychar, yynewerrflag;
  yyparsestate *yyerrctx = NULL;
  int reduce_posn;

#if YYDEBUG
  const char *yys;
  
  if ((yys = getenv("YYDEBUG"))) {
    yyn = *yys;
    if (yyn >= '0' && yyn <= '9')
      yydebug = yyn - '0'; 
  }
#endif
  
  yyps = yyNewState(YYDEFSTACKSIZE);
  yyps->save = 0;
  yynerrs = 0;
  yyps->errflag = 0;
  yychar = (-1);
  
  yyps->ssp = yyps->ss;
  yyps->vsp = yyps->vs;
  yyps->psp = yyps->ps;
  *(yyps->ssp) = yystate = 0;
  

  //
  // Main parsing loop
  //
 yyloop:
  if ((yyn = yydefred[yystate])) {
    goto yyreduce;
  }

  //
  // Read one token
  //
  if (yychar < 0) {
    if ((yychar = yylex1()) < 0) yychar = 0;
#if YYDEBUG
    if (yydebug) {
      yys = 0;
      if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
      if (!yys) yys = "illegal-symbol";
      printf("yydebug[%d,%p]: state %d, reading %d (%s)", 
	     int(yydepth), yytrial, yystate, yychar, yys);
#ifdef YYDBPR
      printf("<");
      YYDBPR(yylval);
      printf(">");
#endif
      printf("\n"); 
    }
#endif
  }

  //
  // Do we have a conflict?
  //
  if ((yyn = yycindex[yystate]) &&
      (yyn += yychar) >= 0 &&
      yyn <= YYTABLESIZE &&
      yycheck[yyn] == yychar) {
    int ctry;

    if (yypath) {
#if YYDEBUG
      if (yydebug) {
        printf("yydebug[%d,%p]: CONFLICT in state %d: following successful trial parse\n", 
	       int(yydepth), yytrial, yystate);
      }
#endif
      // Switch to the next conflict context
      yyparsestate *save = yypath;
      yypath = save->save;
      ctry = save->ctry;
      if (save->state != yystate) 
        goto yyabort;
      yyFreeState(save); 

    } else {

#if YYDEBUG
      if (yydebug) {
        printf("yydebug[%d,%p]: CONFLICT in state %d. ", 
	       int(yydepth), yytrial, yystate);
        if (yyps->save) {
          printf("ALREADY in conflict. Continue trial parse.");
        } else {
          printf("Start trial parse.");
        }
        printf("\n");
      }
#endif
      yyparsestate *save = yyNewState(yyps->ssp - yyps->ss);
      save->save    = yyps->save;
      save->state   = yystate;
      save->errflag = yyps->errflag;
      save->ssp     = save->ss + (yyps->ssp - yyps->ss);
      save->vsp     = save->vs + (yyps->vsp - yyps->vs);
      save->psp     = save->ps + (yyps->psp - yyps->ps);
      memcpy (save->ss, yyps->ss, (yyps->ssp - yyps->ss + 1) * sizeof(Yshort));
      yySCopy(save->vs, yyps->vs, (yyps->ssp - yyps->ss + 1));
      yyPCopy(save->ps, yyps->ps, (yyps->ssp - yyps->ss + 1));
      ctry = yytable[yyn];
      if (yyctable[ctry] == -1) {
#if YYDEBUG
        if (yydebug && yychar >= 0)
          printf("yydebug[%p]: backtracking 1 token\n", yytrial);
#endif
        ctry++; 
      }
      save->ctry = ctry;
      if (!yyps->save) {
        // If this is a first conflict in the stack, start saving lexemes
        if (!yylexemes) {
          yylexemes = FB_NEW_POOL(getPool()) Yshort[YYSTACKGROWTH];
          yylvals = FB_NEW_POOL(getPool()) YYSTYPE[YYSTACKGROWTH];
          yylvlim = yylvals + YYSTACKGROWTH; 
          yylpsns = FB_NEW_POOL(getPool()) YYPOSN[YYSTACKGROWTH];
          yylplim = yylpsns + YYSTACKGROWTH; 
        }
        if (yylvp == yylve) {
          yylvp = yylve = yylvals;
	  yylpp = yylpe = yylpsns;
          yylexp = yylexemes;
          if (yychar >= 0) {
            *yylve++ = yylval;
            *yylpe++ = yyposn;
            *yylexp = yychar;
            yychar = -1; 
          } 
        } 
      }
      if (yychar >= 0) {
        yylvp--, yylpp--, yylexp--;
        yychar = -1; 
      }
      save->lexeme = yylvp - yylvals;
      yyps->save = save; 
    }
    if (yytable[yyn] == ctry) {
#if YYDEBUG
      if (yydebug)
        printf("yydebug[%d,%p]: state %d, shifting to state %d\n",
               int(yydepth), yytrial, yystate, yyctable[ctry]);
#endif
      if (yychar < 0)
        yylvp++, yylpp++, yylexp++;
      yychar = -1;
      if (yyps->errflag > 0) --yyps->errflag;
      yystate = yyctable[ctry];
      goto yyshift; 
    } else {
      yyn = yyctable[ctry];
      goto yyreduce; 
    } 
  }

  //
  // Is action a shift?
  //
  if ((yyn = yysindex[yystate]) &&
      (yyn += yychar) >= 0 &&
      yyn <= YYTABLESIZE &&
      yycheck[yyn] == yychar) {
#if YYDEBUG
    if (yydebug)
      printf("yydebug[%d,%p]: state %d, shifting to state %d\n",
             int(yydepth), yytrial, yystate, yytable[yyn]);
#endif
    yychar = (-1);
    if (yyps->errflag > 0)  --yyps->errflag;
    yystate = yytable[yyn];
  yyshift:
    if (yyps->ssp >= yyps->ss + yyps->stacksize - 1) {
      yyMoreStack(yyps);
    }
    *++(yyps->ssp) = yystate;
    *++(yyps->vsp) = yylval;
    *++(yyps->psp) = yyposn;
    goto yyloop;
  }
  if ((yyn = yyrindex[yystate]) &&
      (yyn += yychar) >= 0 &&
      yyn <= YYTABLESIZE &&
      yycheck[yyn] == yychar) {
    yyn = yytable[yyn];
    goto yyreduce;
  }

  //
  // Action: error
  //
  if (yyps->errflag) goto yyinrecovery;
  yynewerrflag = 1;
  goto yyerrhandler;
yyerrlab:
  yynewerrflag = 0;
yyerrhandler:
  while (yyps->save) { 
    int ctry; 
    yyparsestate *save = yyps->save;
#if YYDEBUG
    if (yydebug)
      printf("yydebug[%d,%p]: ERROR in state %d, CONFLICT BACKTRACKING to state %d, %d tokens\n",
             int(yydepth), yytrial, yystate, yyps->save->state, int(yylvp - yylvals - yyps->save->lexeme));
#endif
    // Memorize most forward-looking error state in case
    // it's really an error.
    if (yyerrctx == NULL || yyerrctx->lexeme < yylvp-yylvals) {
      // Free old saved error context state
      if (yyerrctx) yyFreeState(yyerrctx);
      // Create and fill out new saved error context state
      yyerrctx = yyNewState(yyps->ssp - yyps->ss);
      yyerrctx->save = yyps->save;
      yyerrctx->state = yystate;
      yyerrctx->errflag = yyps->errflag;
      yyerrctx->ssp = yyerrctx->ss + (yyps->ssp - yyps->ss);
      yyerrctx->vsp = yyerrctx->vs + (yyps->vsp - yyps->vs);
      yyerrctx->psp = yyerrctx->ps + (yyps->psp - yyps->ps);
      memcpy (yyerrctx->ss, yyps->ss, (yyps->ssp - yyps->ss + 1) * sizeof(Yshort));
      yySCopy(yyerrctx->vs, yyps->vs, (yyps->ssp - yyps->ss + 1));
      yyPCopy(yyerrctx->ps, yyps->ps, (yyps->ssp - yyps->ss + 1));
      yyerrctx->lexeme = yylvp - yylvals;
    }
    yylvp  = yylvals   + save->lexeme;
    yylpp  = yylpsns   + save->lexeme;
    yylexp = yylexemes + save->lexeme;
    yychar = -1;
    yyps->ssp = yyps->ss + (save->ssp - save->ss);
    yyps->vsp = yyps->vs + (save->vsp - save->vs);
    yyps->psp = yyps->ps + (save->psp - save->ps);
    memcpy (yyps->ss, save->ss, (yyps->ssp - yyps->ss + 1) * sizeof(Yshort));
    yySCopy(yyps->vs, save->vs,  yyps->vsp - yyps->vs + 1);
    yyPCopy(yyps->ps, save->ps,  yyps->psp - yyps->ps + 1);
    ctry = ++save->ctry;
    yystate = save->state;
    // We tried shift, try reduce now
    if ((yyn = yyctable[ctry]) >= 0) {
      goto yyreduce;
    }
    yyps->save = save->save;
    yyFreeState(save);
    //
    // Nothing left on the stack -- error
    //
    if (!yyps->save) {
#if YYDEBUG
      if (yydebug) {
        printf("yydebug[%p]: trial parse FAILED, entering ERROR mode\n", 
	       yytrial);
      }
#endif
      // Restore state as it was in the most forward-advanced error
      yylvp  = yylvals   + yyerrctx->lexeme;
      yylpp  = yylpsns   + yyerrctx->lexeme;
      yylexp = yylexemes + yyerrctx->lexeme;
      yychar = yylexp[-1];
      yylval = yylvp[-1];
      yyposn = yylpp[-1];
      yyps->ssp = yyps->ss + (yyerrctx->ssp - yyerrctx->ss);
      yyps->vsp = yyps->vs + (yyerrctx->vsp - yyerrctx->vs);
      yyps->psp = yyps->ps + (yyerrctx->psp - yyerrctx->ps);
      memcpy (yyps->ss, yyerrctx->ss, (yyps->ssp - yyps->ss + 1) * sizeof(Yshort));
      yySCopy(yyps->vs, yyerrctx->vs,  yyps->vsp - yyps->vs + 1);
      yyPCopy(yyps->ps, yyerrctx->ps,  yyps->psp - yyps->ps + 1);
      yystate = yyerrctx->state;
      yyFreeState(yyerrctx);
      yyerrctx = NULL;
    }
    yynewerrflag = 1; 
  }
  if (yynewerrflag) {
#ifdef YYERROR_DETAILED
    yyerror_detailed("syntax error", yychar, yylval, yyposn);
#else
    yyerror("syntax error");
#endif
  }
  ++yynerrs;
 yyinrecovery:
  if (yyps->errflag < 3) {
    yyps->errflag = 3;
    for (;;) {
      if ((yyn = yysindex[*(yyps->ssp)]) && 
	  (yyn += YYERRCODE) >= 0 &&
          yyn <= YYTABLESIZE && 
	  yycheck[yyn] == YYERRCODE) {
#if YYDEBUG
        if (yydebug)
          printf("yydebug[%d,%p]: state %d, ERROR recovery shifts to state %d\n",
                 int(yydepth), yytrial, *(yyps->ssp), yytable[yyn]);
#endif
        /* Use label yyerrlab, so that compiler does not warn */
        if (yyps->errflag != yyps->errflag) goto yyerrlab;
        yystate = yytable[yyn];
        goto yyshift; 
      } else {
#if YYDEBUG
        if (yydebug)
          printf("yydebug[%d,%p]: ERROR recovery discards state %d\n",
                 int(yydepth), yytrial, *(yyps->ssp));
#endif
        if (yyps->ssp <= yyps->ss) {
	  goto yyabort;
	}
	if (!yytrial) {
	  YYDELETEVAL(yyps->vsp[0], 1);
	  YYDELETEPOSN(yyps->psp[0], 1);
	}
        --(yyps->ssp);
        --(yyps->vsp);
        --(yyps->psp);
      }
    }
  } else {
    if (yychar == 0) goto yyabort;
#if YYDEBUG
    if (yydebug) {
      yys = 0;
      if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
      if (!yys) yys = "illegal-symbol";
      printf("yydebug[%d,%p]: state %d, ERROR recovery discards token %d (%s)\n",
             int(yydepth), yytrial, yystate, yychar, yys); 
    }
#endif
    if (!yytrial) {
      YYDELETEVAL(yylval, 0);
      YYDELETEPOSN(yyposn, 0);
    }
    yychar = (-1);
    goto yyloop;
  }

  //
  // Reduce the rule
  //
yyreduce:
  yym = yylen[yyn];
#if YYDEBUG
  if (yydebug) {
    printf("yydebug[%d,%p]: state %d, reducing by rule %d (%s)",
           int(yydepth), yytrial, yystate, yyn, yyrule[yyn]);
#ifdef YYDBPR
    if (yym) {
      int i;
      printf("<");
      for (i = yym; i > 0; i--) {
        if (i != yym) printf(", ");
        YYDBPR((yyps->vsp)[1 - i]);
      }
      printf(">");
    }
#endif
    printf("\n");
  }
#endif
  if (yyps->ssp + 1 - yym >= yyps->ss + yyps->stacksize) {
    yyMoreStack(yyps);
  }

  /* default action - assign last argument as in standard yacc */
  yyps->val = yyvsp[1 - yym];

  /* default reduced position is NULL -- no position at all.
     no position will be assigned at trial time and if no position handling is present */
  memset(&yyps->pos, 0, sizeof(yyps->pos));

  reduce_posn = TRUE;

  yyposn.firstLine = YYPOSNARG(1).firstLine; 
  yyposn.firstColumn = YYPOSNARG(1).firstColumn; 

  switch (yyn) {

case 1:
  if (!yytrial)
{ DSQL_parse = yyvsp[0].dsqlReq; }
break;
case 2:
  if (!yytrial)
{ DSQL_parse = yyvsp[-1].dsqlReq; }
break;
case 3:
  if (!yytrial)
{ yyval.dsqlReq = newNode<DsqlDmlRequest>(yyvsp[0].stmtNode); }
break;
case 4:
  if (!yytrial)
{ yyval.dsqlReq = newNode<DsqlDdlRequest>(yyvsp[0].ddlNode); }
break;
case 5:
  if (!yytrial)
{ yyval.dsqlReq = newNode<DsqlTransactionRequest>(yyvsp[0].traNode); }
break;
case 6:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 7:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].storeNode; }
break;
case 8:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].mergeNode; }
break;
case 9:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 10:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].execBlockNode; }
break;
case 11:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 12:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].selectNode; }
break;
case 13:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 14:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].updInsNode; }
break;
case 15:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 16:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 17:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 18:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 19:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 20:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 21:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].grantRevokeNode; }
break;
case 22:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 23:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].grantRevokeNode; }
break;
case 24:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 25:
  if (!yytrial)
{ yyval.traNode = yyvsp[0].setTransactionNode; }
break;
case 26:
  if (!yytrial)
{ yyval.traNode = yyvsp[0].traNode; }
break;
case 27:
  if (!yytrial)
{ yyval.traNode = yyvsp[0].traNode; }
break;
case 28:
  if (!yytrial)
{ yyval.traNode = yyvsp[0].setRoleNode; }
break;
case 29:
  if (!yytrial)
{ yyval.grantRevokeNode = newNode<GrantRevokeNode>(true); }
break;
case 30:
yyval.grantRevokeNode = yyvsp[0].grantRevokeNode;
break;
case 31:
  if (!yytrial)
{ yyval.grantRevokeNode = yyvsp[-2].grantRevokeNode; }
break;
case 32:
yyval.privilegeArray = NOTRIAL(&yyvsp[0].grantRevokeNode->privileges);
break;
case 33:
yyval.granteeArray = NOTRIAL(&yyvsp[-6].grantRevokeNode->users);
break;
case 34:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_relation, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 35:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_procedure, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 36:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_udf, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 37:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_package_header, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 38:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_exception, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 39:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_generator, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 40:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_generator, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 41:
yyval.granteeArray = NOTRIAL(&yyvsp[-4].grantRevokeNode->users);
break;
case 42:
  if (!yytrial)
{ 
			yyvsp[-8].grantRevokeNode->object = yyvsp[-5].granteeClause;
			yyvsp[-8].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-8].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
			yyvsp[-8].grantRevokeNode->isDdl = true;
		}
break;
case 43:
  if (!yytrial)
{
			yyvsp[-8].grantRevokeNode->object = newNode<GranteeClause>(obj_database, get_object_name(obj_database));
			yyvsp[-8].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-8].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
			yyvsp[-8].grantRevokeNode->isDdl = true;
		}
break;
case 44:
yyval.granteeArray = NOTRIAL(&yyvsp[0].grantRevokeNode->roles);
break;
case 45:
yyval.granteeArray = NOTRIAL(&yyvsp[-3].grantRevokeNode->users);
break;
case 46:
  if (!yytrial)
{
			yyvsp[-7].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-7].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 47:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_relations, get_object_name(obj_relations)); }
break;
case 48:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_views, get_object_name(obj_views)); }
break;
case 49:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_procedures, get_object_name(obj_procedures)); }
break;
case 50:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_functions, get_object_name(obj_functions)); }
break;
case 51:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_packages, get_object_name(obj_packages)); }
break;
case 52:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_generators, get_object_name(obj_generators)); }
break;
case 53:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_generators, get_object_name(obj_generators)); }
break;
case 54:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_domains, get_object_name(obj_domains)); }
break;
case 55:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_exceptions, get_object_name(obj_exceptions)); }
break;
case 56:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_roles, get_object_name(obj_roles)); }
break;
case 57:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_charsets, get_object_name(obj_charsets)); }
break;
case 58:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_collations, get_object_name(obj_collations)); }
break;
case 59:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_filters, get_object_name(obj_filters)); }
break;
case 62:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('A', NULL)); }
break;
case 63:
  if (!yytrial)
{ yyvsp[-2].privilegeArray->add(PrivilegeClause('A', NULL)); }
break;
case 64:
yyval.privilegeArray = yyvsp[0].privilegeArray;
break;
case 67:
yyval.privilegeArray = yyvsp[-2].privilegeArray;
break;
case 69:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('X', NULL)); }
break;
case 70:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('G', NULL)); }
break;
case 71:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('S', NULL)); }
break;
case 72:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('I', NULL)); }
break;
case 73:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('D', NULL)); }
break;
case 74:
  if (!yytrial)
{ yyvsp[-2].privilegeArray->add(PrivilegeClause('U', yyvsp[0].valueListNode)); }
break;
case 75:
  if (!yytrial)
{ yyvsp[-2].privilegeArray->add(PrivilegeClause('R', yyvsp[0].valueListNode)); }
break;
case 76:
  if (!yytrial)
{
			yyvsp[-2].privilegeArray->add(PrivilegeClause('C', NULL));
			yyvsp[-2].privilegeArray->add(PrivilegeClause('L', NULL));
			yyvsp[-2].privilegeArray->add(PrivilegeClause('O', NULL));
		}
break;
case 82:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('C', NULL)); }
break;
case 83:
  if (!yytrial)
{ yyvsp[-2].privilegeArray->add(PrivilegeClause('L', NULL)); }
break;
case 84:
  if (!yytrial)
{ yyvsp[-2].privilegeArray->add(PrivilegeClause('O', NULL)); }
break;
case 85:
  if (!yytrial)
{
			yyvsp[-2].privilegeArray->add(PrivilegeClause('L', NULL));
			yyvsp[-2].privilegeArray->add(PrivilegeClause('O', NULL));
		}
break;
case 89:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('C', NULL)); }
break;
case 90:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('L', NULL)); }
break;
case 91:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('O', NULL)); }
break;
case 92:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 93:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 94:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 95:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 96:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 97:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 101:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 102:
  if (!yytrial)
{ yyval.grantRevokeNode = newNode<GrantRevokeNode>(false); }
break;
case 103:
  if (!yytrial)
{ yyval.grantRevokeNode = yyvsp[-2].grantRevokeNode; }
break;
case 104:
yyval.privilegeArray = NOTRIAL(&yyvsp[-1].grantRevokeNode->privileges);
break;
case 105:
yyval.granteeArray = NOTRIAL(&yyvsp[-7].grantRevokeNode->users);
break;
case 106:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_relation, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 107:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_procedure, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 108:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_udf, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 109:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_package_header, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 110:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_exception, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 111:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_generator, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 112:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_generator, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 113:
yyval.granteeArray = NOTRIAL(&yyvsp[-5].grantRevokeNode->users);
break;
case 114:
  if (!yytrial)
{
			yyvsp[-8].grantRevokeNode->object = yyvsp[-4].granteeClause;
			yyvsp[-8].grantRevokeNode->grantAdminOption = yyvsp[-7].boolVal;
			yyvsp[-8].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
			yyvsp[-8].grantRevokeNode->isDdl = true;
		}
break;
case 115:
  if (!yytrial)
{
			yyvsp[-8].grantRevokeNode->object = newNode<GranteeClause>(obj_database, get_object_name(obj_database));
			yyvsp[-8].grantRevokeNode->grantAdminOption = yyvsp[-7].boolVal;
			yyvsp[-8].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
			yyvsp[-8].grantRevokeNode->isDdl = true;
		}
break;
case 116:
yyval.granteeArray = NOTRIAL(&yyvsp[-1].grantRevokeNode->roles);
break;
case 117:
  if (!yytrial)
{
			yyvsp[-7].grantRevokeNode->grantAdminOption = yyvsp[-6].boolVal;
			yyvsp[-7].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 119:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 120:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 121:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 122:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 123:
yyval.granteeArray = yyvsp[0].granteeArray;
break;
case 126:
yyval.granteeArray = yyvsp[-2].granteeArray;
break;
case 129:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_procedure, *yyvsp[0].metaNamePtr)); }
break;
case 130:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_udf, *yyvsp[0].metaNamePtr)); }
break;
case 131:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_package_header, *yyvsp[0].metaNamePtr)); }
break;
case 132:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_trigger, *yyvsp[0].metaNamePtr)); }
break;
case 133:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_view, *yyvsp[0].metaNamePtr)); }
break;
case 134:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_sql_role, *yyvsp[0].metaNamePtr)); }
break;
case 135:
  if (!yytrial)
{ yyvsp[-1].granteeArray->add(GranteeClause(obj_user_or_role, *yyvsp[0].metaNamePtr)); }
break;
case 136:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_user, *yyvsp[0].metaNamePtr)); }
break;
case 137:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_user_group, *yyvsp[0].metaNamePtr)); }
break;
case 140:
  if (!yytrial)
{ yyvsp[-1].granteeArray->add(GranteeClause(obj_sql_role, *yyvsp[0].metaNamePtr)); }
break;
case 143:
  if (!yytrial)
{ yyvsp[-1].granteeArray->add(GranteeClause(obj_user, *yyvsp[0].metaNamePtr)); }
break;
case 144:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode;}
break;
case 145:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 146:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterFunctionNode; }
break;
case 147:
  if (!yytrial)
{ yyval.createAlterFunctionNode = newNode<CreateAlterFunctionNode>(*yyvsp[0].metaNamePtr); }
break;
case 148:
yyval.parametersClause = NOTRIAL(&yyvsp[0].createAlterFunctionNode->parameters);
break;
case 149:
yyval.createAlterFunctionNode = yyvsp[-3].createAlterFunctionNode;
break;
case 150:
  if (!yytrial)
{
				yyval.createAlterFunctionNode = yyvsp[-9].createAlterFunctionNode;
				yyval.createAlterFunctionNode->external = newNode<ExternalClause>();
				yyval.createAlterFunctionNode->external->name = *yyvsp[-2].stringPtr;
				yyval.createAlterFunctionNode->external->udfModule = *yyvsp[0].stringPtr;
			}
break;
case 152:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_blob;
			yyval.legacyField->length = sizeof(bid);
		}
break;
case 153:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_cstring;
			yyval.legacyField->charLength = (USHORT) yyvsp[-2].int32Val;
			if (yyvsp[0].metaNamePtr)
				yyval.legacyField->charSet = *yyvsp[0].metaNamePtr;
		}
break;
case 155:
yyval.parametersClause = yyvsp[0].parametersClause;
break;
case 157:
yyval.parametersClause = yyvsp[-1].parametersClause;
break;
case 160:
yyval.parametersClause = yyvsp[-2].parametersClause;
break;
case 162:
  if (!yytrial)
{
			yyvsp[-2].parametersClause->add(newNode<ParameterClause>(yyvsp[-1].legacyField, MetaName()));
			yyvsp[-2].parametersClause->back()->udfMechanism = yyvsp[0].nullableIntVal;
		}
break;
case 163:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::empty(); }
break;
case 164:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::val(FUN_descriptor); }
break;
case 165:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::val(FUN_scalar_array); }
break;
case 166:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::val(FUN_ref_with_null); }
break;
case 167:
yyval.createAlterFunctionNode = yyvsp[0].createAlterFunctionNode;
break;
case 169:
yyval.createAlterFunctionNode = yyvsp[-1].createAlterFunctionNode;
break;
case 171:
  if (!yytrial)
{
			yyvsp[-2].createAlterFunctionNode->returnType = newNode<ParameterClause>(yyvsp[-1].legacyField, MetaName());
			yyvsp[-2].createAlterFunctionNode->returnType->udfMechanism = yyvsp[0].int32Val;
		}
break;
case 172:
  if (!yytrial)
{ yyvsp[-2].createAlterFunctionNode->udfReturnPos = yyvsp[0].int32Val; }
break;
case 173:
  if (!yytrial)
{ yyval.int32Val = FUN_reference; }
break;
case 174:
  if (!yytrial)
{ yyval.int32Val = FUN_value; }
break;
case 175:
  if (!yytrial)
{ yyval.int32Val = FUN_descriptor; }
break;
case 176:
  if (!yytrial)
{ yyval.int32Val = -1 * FUN_reference; }
break;
case 177:
  if (!yytrial)
{ yyval.int32Val = -1 * FUN_descriptor; }
break;
case 178:
  if (!yytrial)
{
				CreateFilterNode* node = newNode<CreateFilterNode>(*yyvsp[-8].metaNamePtr);
				node->inputFilter = yyvsp[-6].filterNameNumber;
				node->outputFilter = yyvsp[-4].filterNameNumber;
				node->entryPoint = *yyvsp[-2].stringPtr;
				node->moduleName = *yyvsp[0].stringPtr;
				yyval.ddlNode = node;
			}
break;
case 179:
  if (!yytrial)
{ yyval.filterNameNumber = newNode<CreateFilterNode::NameNumber>(*yyvsp[0].metaNamePtr); }
break;
case 180:
  if (!yytrial)
{ yyval.filterNameNumber = newNode<CreateFilterNode::NameNumber>(yyvsp[0].int32Val); }
break;
case 181:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 182:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterExceptionNode; }
break;
case 183:
  if (!yytrial)
{
				CreateIndexNode* node = newNode<CreateIndexNode>(*yyvsp[-2].metaNamePtr);
				node->unique = yyvsp[-5].boolVal;
				node->descending = yyvsp[-4].boolVal;
				node->relation = yyvsp[0].relSourceNode;
				yyval.ddlNode = node;
			}
break;
case 184:
yyval.createIndexNode = static_cast<CreateIndexNode*>(yyvsp[0].ddlNode);
break;
case 185:
  if (!yytrial)
{
				yyval.ddlNode = yyvsp[-2].ddlNode;
			}
break;
case 186:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterFunctionNode; }
break;
case 187:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterProcedureNode; }
break;
case 188:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createRelationNode; }
break;
case 189:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createRelationNode; }
break;
case 190:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterTriggerNode; }
break;
case 191:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterViewNode; }
break;
case 192:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 193:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 194:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].alterDatabaseNode; }
break;
case 195:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createDomainNode; }
break;
case 196:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createShadowNode; }
break;
case 197:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 198:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createCollationNode; }
break;
case 199:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterUserNode; }
break;
case 200:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterPackageNode; }
break;
case 201:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createPackageBodyNode; }
break;
case 202:
yyval.boolVal = false;
break;
case 203:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 204:
yyval.boolVal = true;
break;
case 205:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 206:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 207:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateProcedureNode>(yyvsp[0].createAlterProcedureNode); }
break;
case 208:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateFunctionNode>(yyvsp[0].createAlterFunctionNode); }
break;
case 209:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateTableNode>(yyvsp[0].createRelationNode); }
break;
case 210:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateTableNode>(yyvsp[0].createRelationNode); }
break;
case 211:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateViewNode>(yyvsp[0].createAlterViewNode); }
break;
case 212:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateTriggerNode>(yyvsp[0].createAlterTriggerNode); }
break;
case 213:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreatePackageNode>(yyvsp[0].createAlterPackageNode); }
break;
case 214:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreatePackageBodyNode>(yyvsp[0].createPackageBodyNode); }
break;
case 215:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateExceptionNode>(yyvsp[0].createAlterExceptionNode); }
break;
case 216:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateSequenceNode>(yyvsp[0].createAlterSequenceNode); }
break;
case 217:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateSequenceNode>(yyvsp[0].createAlterSequenceNode); }
break;
case 218:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 219:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterProcedureNode; }
break;
case 220:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterFunctionNode; }
break;
case 221:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterTriggerNode; }
break;
case 222:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterPackageNode; }
break;
case 223:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 224:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterExceptionNode; }
break;
case 225:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 226:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 227:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterUserNode; }
break;
case 228:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 229:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 230:
  if (!yytrial)
{ yyval.createAlterExceptionNode = newNode<CreateAlterExceptionNode>(*yyvsp[-1].metaNamePtr, yyvsp[0].intlStringPtr->getString()); }
break;
case 231:
  if (!yytrial)
{
			CreateAlterExceptionNode* node = newNode<CreateAlterExceptionNode>(*yyvsp[-1].metaNamePtr, yyvsp[0].intlStringPtr->getString());
			node->alter = true;
			yyval.createAlterExceptionNode = node;
		}
break;
case 232:
  if (!yytrial)
{
			CreateAlterExceptionNode* node = newNode<CreateAlterExceptionNode>(*yyvsp[-1].metaNamePtr, yyvsp[0].intlStringPtr->getString());
			node->create = false;
			node->alter = true;
			yyval.createAlterExceptionNode = node;
		}
break;
case 233:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 234:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 235:
  if (!yytrial)
{ yyvsp[-1].createIndexNode->columns = yyvsp[0].valueListNode; }
break;
case 236:
  if (!yytrial)
{ yyvsp[-1].createIndexNode->columns = yyvsp[0].valueListNode; }
break;
case 237:
  if (!yytrial)
{
 			yyvsp[-4].createIndexNode->computed = newNode<ValueSourceClause>();
			yyvsp[-4].createIndexNode->computed->value = yyvsp[-1].valueExprNode;
			yyvsp[-4].createIndexNode->computed->source = makeParseStr(YYPOSNARG(2), YYPOSNARG(4));
		}
break;
case 238:
  if (!yytrial)
{
	 			yyval.createShadowNode = newNode<CreateShadowNode>(yyvsp[-4].int32Val);
		 		yyval.createShadowNode->manual = yyvsp[-3].boolVal;
		 		yyval.createShadowNode->conditional = yyvsp[-2].boolVal;
		 		yyval.createShadowNode->files.add(newNode<DbFileClause>(*yyvsp[-1].stringPtr));
		 		yyval.createShadowNode->files.front()->length = yyvsp[0].int32Val;
	 		}
break;
case 239:
yyval.dbFilesClause = NOTRIAL(&yyvsp[0].createShadowNode->files);
break;
case 240:
  if (!yytrial)
{ yyval.createShadowNode = yyvsp[-2].createShadowNode; }
break;
case 241:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 242:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 243:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 244:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 245:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 246:
  if (!yytrial)
{ yyval.int32Val = 0; }
break;
case 247:
  if (!yytrial)
{ yyval.int32Val = yyvsp[-1].int32Val; }
break;
case 249:
yyval.dbFilesClause = yyvsp[0].dbFilesClause;
break;
case 251:
  if (!yytrial)
{ yyvsp[-1].dbFilesClause->add(yyvsp[0].dbFileClause); }
break;
case 252:
  if (!yytrial)
{ yyvsp[-2].dbFilesClause->add(yyvsp[0].dbFileClause); }
break;
case 253:
  if (!yytrial)
{
				yyvsp[-1].legacyField->fld_name = *yyvsp[-3].metaNamePtr;
				yyval.createDomainNode = newNode<CreateDomainNode>(
					newNode<ParameterClause>(yyvsp[-1].legacyField, MetaName(), yyvsp[0].valueSourceClause));
			}
break;
case 254:
yyval.createDomainNode = yyvsp[0].createDomainNode;
break;
case 255:
  if (!yytrial)
{
				yyval.createDomainNode = yyvsp[-3].createDomainNode;
				if (yyvsp[0].metaNamePtr)
					yyval.createDomainNode->nameType->type->collate = *yyvsp[0].metaNamePtr;
			}
break;
case 259:
yyval.createDomainNode = yyvsp[-1].createDomainNode;
break;
case 261:
  if (!yytrial)
{ setClause(yyvsp[-1].createDomainNode->notNull, "NOT NULL"); }
break;
case 262:
  if (!yytrial)
{ setClause(yyvsp[-1].createDomainNode->check, "DOMAIN CHECK CONSTRAINT", yyvsp[0].boolSourceClause); }
break;
case 265:
  if (!yytrial)
{
			ValueSourceClause* clause = newNode<ValueSourceClause>();
			clause->value = yyvsp[0].valueExprNode;
			clause->source = makeParseStr(YYPOSNARG(1), YYPOSNARG(2));
			yyval.valueSourceClause = clause;
		}
break;
case 266:
  if (!yytrial)
{ yyval.valueSourceClause = NULL; }
break;
case 269:
  if (!yytrial)
{
			BoolSourceClause* clause = newNode<BoolSourceClause>();
			clause->value = yyvsp[-1].boolExprNode;
			clause->source = makeParseStr(YYPOSNARG(1), YYPOSNARG(4));
			yyval.boolSourceClause = clause;
		}
break;
case 270:
  if (!yytrial)
{ yyval.createAlterSequenceNode = newNode<CreateAlterSequenceNode>(*yyvsp[-2].metaNamePtr, yyvsp[-1].nullableInt64Val, yyvsp[0].nullableInt32Val); }
break;
case 271:
  if (!yytrial)
{ yyval.nullableInt64Val = Nullable<SINT64>::empty(); }
break;
case 272:
  if (!yytrial)
{ yyval.nullableInt64Val = Nullable<SINT64>::val(yyvsp[0].int64Val); }
break;
case 273:
  if (!yytrial)
{ yyval.int64Val = yyvsp[0].int64Val; }
break;
case 274:
  if (!yytrial)
{ yyval.nullableInt32Val = Nullable<SLONG>::empty(); }
break;
case 275:
  if (!yytrial)
{ yyval.nullableInt32Val = Nullable<SLONG>::val(yyvsp[0].int32Val); }
break;
case 278:
  if (!yytrial)
{
			CreateAlterSequenceNode* node = newNode<CreateAlterSequenceNode>(*yyvsp[-2].metaNamePtr, yyvsp[-1].nullableInt64Val, yyvsp[0].nullableInt32Val);
			node->alter = true;
			node->restartSpecified = true;
			yyval.createAlterSequenceNode = node;
		}
break;
case 279:
  if (!yytrial)
{ yyval.nullableInt64Val = Nullable<SINT64>::empty(); }
break;
case 280:
  if (!yytrial)
{ yyval.nullableInt64Val = Nullable<SINT64>::val(yyvsp[0].int64Val); }
break;
case 281:
  if (!yytrial)
{
			if (!yyvsp[-1].nullableNullableInt64Val.specified && !yyvsp[0].nullableInt32Val.specified)
				yyerrorIncompleteCmd();
			CreateAlterSequenceNode* node = newNode<CreateAlterSequenceNode>(*yyvsp[-2].metaNamePtr, yyvsp[-1].nullableNullableInt64Val.value, yyvsp[0].nullableInt32Val);
			node->create = false;
			node->alter = true;
			node->restartSpecified = yyvsp[-1].nullableNullableInt64Val.specified;
			yyval.createAlterSequenceNode = node;
		}
break;
case 282:
  if (!yytrial)
{ yyval.nullableInt64Val = Nullable<SINT64>::empty(); }
break;
case 283:
  if (!yytrial)
{ yyval.nullableInt64Val = Nullable<SINT64>::val(yyvsp[0].int64Val); }
break;
case 284:
  if (!yytrial)
{ yyval.nullableNullableInt64Val = Nullable<BaseNullable<SINT64> >::empty(); }
break;
case 285:
  if (!yytrial)
{ yyval.nullableNullableInt64Val = Nullable<BaseNullable<SINT64> > ::val(yyvsp[0].nullableInt64Val); }
break;
case 286:
  if (!yytrial)
{
			CreateAlterSequenceNode* node = newNode<CreateAlterSequenceNode>(*yyvsp[-2].metaNamePtr,
				Nullable<SINT64>::val(yyvsp[0].int64Val), Nullable<SLONG>::empty());
			node->create = false;
			node->alter = true;
			node->legacy = true;
			node->restartSpecified = true;
			yyval.createAlterSequenceNode = node;
		}
break;
case 287:
  if (!yytrial)
{ yyval.int64Val = yyvsp[0].int32Val; }
break;
case 288:
  if (!yytrial)
{
			SINT64 signedNumber = (SINT64) yyvsp[0].scaledNumber.number;

			if (!yyvsp[0].scaledNumber.hex && yyvsp[0].scaledNumber.number > MAX_SINT64)
			{
				ERRD_post(
					Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
					Arg::Gds(isc_arith_except) <<
					Arg::Gds(isc_numeric_out_of_range));
			}

			yyval.int64Val = signedNumber;
		}
break;
case 289:
  if (!yytrial)
{
			SINT64 signedNumber = (SINT64) yyvsp[0].scaledNumber.number;

			if (yyvsp[0].scaledNumber.hex && signedNumber == MIN_SINT64)
				ERRD_post(Arg::Gds(isc_exception_integer_overflow));

			yyval.int64Val = -signedNumber;
		}
break;
case 290:
  if (!yytrial)
{ yyval.ddlNode = newNode<CreateRoleNode>(*yyvsp[0].metaNamePtr); }
break;
case 291:
  if (!yytrial)
{ yyval.createCollationNode = newNode<CreateCollationNode>(*yyvsp[-2].metaNamePtr, *yyvsp[0].metaNamePtr); }
break;
case 292:
yyval.createCollationNode = yyvsp[0].createCollationNode;
break;
case 293:
yyval.createCollationNode = yyvsp[-2].createCollationNode;
break;
case 294:
yyval.createCollationNode = yyvsp[-4].createCollationNode;
break;
case 295:
  if (!yytrial)
{ yyval.createCollationNode = yyvsp[-6].createCollationNode; }
break;
case 297:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->fromName = *yyvsp[0].metaNamePtr; }
break;
case 298:
  if (!yytrial)
{ yyvsp[-5].createCollationNode->fromExternal = *yyvsp[-1].stringPtr; }
break;
case 302:
yyval.createCollationNode = yyvsp[-1].createCollationNode;
break;
case 307:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->unsetAttribute(TEXTTYPE_ATTR_PAD_SPACE); }
break;
case 308:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->setAttribute(TEXTTYPE_ATTR_PAD_SPACE); }
break;
case 309:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->unsetAttribute(TEXTTYPE_ATTR_CASE_INSENSITIVE); }
break;
case 310:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->setAttribute(TEXTTYPE_ATTR_CASE_INSENSITIVE); }
break;
case 311:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->unsetAttribute(TEXTTYPE_ATTR_ACCENT_INSENSITIVE); }
break;
case 312:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->setAttribute(TEXTTYPE_ATTR_ACCENT_INSENSITIVE); }
break;
case 314:
  if (!yytrial)
{
			const string& s = *yyvsp[0].stringPtr;
			yyvsp[-1].createCollationNode->specificAttributes.clear();
			yyvsp[-1].createCollationNode->specificAttributes.add((const UCHAR*) s.begin(), s.length());
		}
break;
case 315:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterCharSetNode>(*yyvsp[-4].metaNamePtr, *yyvsp[0].metaNamePtr); }
break;
case 316:
  if (!yytrial)
{
				yyval.alterDatabaseNode = newNode<AlterDatabaseNode>();
				yyval.alterDatabaseNode->create = true;
			}
break;
case 317:
yyval.alterDatabaseNode = yyvsp[0].alterDatabaseNode;
break;
case 318:
yyval.alterDatabaseNode = yyvsp[-2].alterDatabaseNode;
break;
case 319:
  if (!yytrial)
{ yyval.alterDatabaseNode = yyvsp[-4].alterDatabaseNode; }
break;
case 326:
yyval.alterDatabaseNode = yyvsp[-1].alterDatabaseNode;
break;
case 335:
  if (!yytrial)
{ yyvsp[-4].alterDatabaseNode->createLength = yyvsp[-1].int32Val; }
break;
case 340:
  if (!yytrial)
{ yyvsp[-1].alterDatabaseNode->files.add(yyvsp[0].dbFileClause); }
break;
case 341:
  if (!yytrial)
{ yyvsp[-4].alterDatabaseNode->setDefaultCharSet = *yyvsp[0].metaNamePtr; }
break;
case 342:
  if (!yytrial)
{
			yyvsp[-6].alterDatabaseNode->setDefaultCharSet = *yyvsp[-2].metaNamePtr;
			yyvsp[-6].alterDatabaseNode->setDefaultCollation = *yyvsp[0].metaNamePtr;
		}
break;
case 343:
  if (!yytrial)
{ yyvsp[-3].alterDatabaseNode->differenceFile = *yyvsp[0].stringPtr; }
break;
case 344:
  if (!yytrial)
{
				DbFileClause* clause = newNode<DbFileClause>(*yyvsp[0].stringPtr);
				yyval.dbFileClause = clause;
			}
break;
case 345:
yyval.dbFileClause = yyvsp[0].dbFileClause;
break;
case 346:
  if (!yytrial)
{ yyval.dbFileClause = yyvsp[-2].dbFileClause; }
break;
case 350:
yyval.dbFileClause = yyvsp[-1].dbFileClause;
break;
case 352:
  if (!yytrial)
{ yyvsp[-3].dbFileClause->start = yyvsp[0].int32Val; }
break;
case 353:
  if (!yytrial)
{ yyvsp[-4].dbFileClause->length = yyvsp[-1].int32Val; }
break;
case 360:
  if (!yytrial)
{ yyval.createRelationNode = newNode<CreateRelationNode>(yyvsp[-1].relSourceNode, yyvsp[0].stringPtr); }
break;
case 361:
yyval.createRelationNode = yyvsp[-1].createRelationNode;
break;
case 362:
  if (!yytrial)
{ yyval.createRelationNode = yyvsp[-4].createRelationNode; }
break;
case 363:
  if (!yytrial)
{ yyval.createRelationNode = newNode<CreateRelationNode>(yyvsp[0].relSourceNode); }
break;
case 364:
  if (!yytrial)
{
				yyval.createRelationNode = yyvsp[-5].createRelationNode;
				yyval.createRelationNode->relationType = static_cast<rel_t>(yyvsp[0].intVal);
			}
break;
case 365:
  if (!yytrial)
{ yyval.intVal = rel_global_temp_delete; }
break;
case 366:
  if (!yytrial)
{ yyval.intVal = rel_global_temp_delete; }
break;
case 367:
  if (!yytrial)
{ yyval.intVal = rel_global_temp_preserve; }
break;
case 368:
  if (!yytrial)
{ yyval.stringPtr = NULL; }
break;
case 369:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 370:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 371:
yyval.createRelationNode = yyvsp[0].createRelationNode;
break;
case 373:
yyval.createRelationNode = yyvsp[-2].createRelationNode;
break;
case 375:
yyval.relationNode = yyvsp[0].createRelationNode;
break;
case 378:
  if (!yytrial)
{
				RelationNode::AddColumnClause* clause = yyval.addColumnClause =
					newNode<RelationNode::AddColumnClause>();
				clause->field = yyvsp[-1].legacyField;
				clause->field->fld_name = *yyvsp[-2].metaNamePtr;
				clause->defaultValue = yyvsp[0].valueSourceClause;
				yyvsp[-3].relationNode->clauses.add(clause);
			}
break;
case 379:
yyval.addColumnClause = NOTRIAL(yyvsp[0].addColumnClause);
break;
case 380:
  if (!yytrial)
{
				if (yyvsp[0].metaNamePtr)
					yyvsp[-3].addColumnClause->collate = *yyvsp[0].metaNamePtr;
			}
break;
case 381:
  if (!yytrial)
{
				RelationNode::AddColumnClause* clause = yyval.addColumnClause =
					newNode<RelationNode::AddColumnClause>();
				clause->field = yyvsp[-1].legacyField;
				clause->field->fld_name = *yyvsp[-2].metaNamePtr;
				clause->identity = true;
				clause->identityStart = yyvsp[0].int64Val;
				yyvsp[-3].relationNode->clauses.add(clause);
			}
break;
case 382:
  if (!yytrial)
{
				if (yyvsp[0].metaNamePtr)
					yyvsp[-3].addColumnClause->collate = *yyvsp[0].metaNamePtr;
			}
break;
case 383:
  if (!yytrial)
{
			RelationNode::AddColumnClause* clause = newNode<RelationNode::AddColumnClause>();
			clause->field = yyvsp[-1].legacyField;
			clause->field->fld_name = *yyvsp[-2].metaNamePtr;
			clause->computed = yyvsp[0].valueSourceClause;
			yyvsp[-3].relationNode->clauses.add(clause);
			clause->field->flags |= FLD_computed;
		}
break;
case 384:
  if (!yytrial)
{
			RelationNode::AddColumnClause* clause = newNode<RelationNode::AddColumnClause>();
			clause->field = newNode<dsql_fld>();
			clause->field->fld_name = *yyvsp[-1].metaNamePtr;
			clause->computed = yyvsp[0].valueSourceClause;
			yyvsp[-2].relationNode->clauses.add(clause);
			clause->field->flags |= FLD_computed;
		}
break;
case 385:
  if (!yytrial)
{ yyval.int64Val = yyvsp[0].int64Val; }
break;
case 386:
  if (!yytrial)
{ yyval.int64Val = 0; }
break;
case 387:
  if (!yytrial)
{ yyval.int64Val = yyvsp[-1].int64Val; }
break;
case 388:
  if (!yytrial)
{
			ValueSourceClause* clause = newNode<ValueSourceClause>();
			clause->value = yyvsp[-1].valueExprNode;
			clause->source = makeParseStr(YYPOSNARG(2), YYPOSNARG(4));
			yyval.valueSourceClause = clause;
		}
break;
case 395:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
		}
break;
case 396:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 397:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 399:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
		}
break;
case 400:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfTable = *yyvsp[-2].metaNamePtr;
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
		}
break;
case 401:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
			yyval.legacyField->fullDomain = true;
		}
break;
case 402:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 403:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 404:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 405:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 406:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 407:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 409:
yyval.addColumnClause = yyvsp[0].addColumnClause;
break;
case 412:
yyval.addColumnClause = yyvsp[-1].addColumnClause;
break;
case 414:
  if (!yytrial)
{
			if (yyvsp[-2].metaNamePtr)
				yyvsp[-3].addColumnClause->constraints.back()->name = *yyvsp[-2].metaNamePtr;
		}
break;
case 415:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = yyvsp[-1].addColumnClause->constraints.add();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_NOT_NULL;
		}
break;
case 416:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = yyvsp[-1].addColumnClause->constraints.add();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_CHECK;
			constraint.check = yyvsp[0].boolSourceClause;
		}
break;
case 417:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = yyvsp[-5].addColumnClause->constraints.add();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_FK;

			constraint.columns.add(yyvsp[-5].addColumnClause->field->fld_name);
			constraint.refRelation = *yyvsp[-3].metaNamePtr;
			constraint.refAction = yyvsp[-1].refActionClause;

			const ValueListNode* refColumns = yyvsp[-2].valueListNode;
			if (refColumns)
			{
				const NestConst<ValueExprNode>* ptr = refColumns->items.begin();

				for (const NestConst<ValueExprNode>* const end = refColumns->items.end(); ptr != end; ++ptr)
					constraint.refColumns.add((*ptr)->as<FieldNode>()->dsqlName);
			}

			constraint.index = yyvsp[0].indexConstraintClause;
		}
break;
case 418:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = yyvsp[-2].addColumnClause->constraints.add();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_UNIQUE;
			constraint.index = yyvsp[0].indexConstraintClause;
		}
break;
case 419:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = yyvsp[-3].addColumnClause->constraints.add();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_PK;
			constraint.index = yyvsp[0].indexConstraintClause;
		}
break;
case 420:
yyval.relationNode = yyvsp[-1].relationNode;
break;
case 421:
  if (!yytrial)
{
			if (yyvsp[-2].metaNamePtr)
			{
				static_cast<RelationNode::AddConstraintClause*>(
					yyvsp[-3].relationNode->clauses.back().getObject())->name = *yyvsp[-2].metaNamePtr;
			}
		}
break;
case 422:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 423:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 424:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = *newNode<RelationNode::AddConstraintClause>();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_UNIQUE;

			const ValueListNode* columns = yyvsp[-1].valueListNode;
			const NestConst<ValueExprNode>* ptr = columns->items.begin();

			for (const NestConst<ValueExprNode>* const end = columns->items.end(); ptr != end; ++ptr)
				constraint.columns.add((*ptr)->as<FieldNode>()->dsqlName);

			constraint.index = yyvsp[0].indexConstraintClause;

			yyvsp[-3].relationNode->clauses.add(&constraint);
		}
break;
case 425:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = *newNode<RelationNode::AddConstraintClause>();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_PK;

			const ValueListNode* columns = yyvsp[-1].valueListNode;
			const NestConst<ValueExprNode>* ptr = columns->items.begin();

			for (const NestConst<ValueExprNode>* const end = columns->items.end(); ptr != end; ++ptr)
				constraint.columns.add((*ptr)->as<FieldNode>()->dsqlName);

			constraint.index = yyvsp[0].indexConstraintClause;

			yyvsp[-4].relationNode->clauses.add(&constraint);
		}
break;
case 426:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = *newNode<RelationNode::AddConstraintClause>();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_FK;

			const ValueListNode* columns = yyvsp[-5].valueListNode;
			const NestConst<ValueExprNode>* ptr = columns->items.begin();

			for (const NestConst<ValueExprNode>* const end = columns->items.end(); ptr != end; ++ptr)
				constraint.columns.add((*ptr)->as<FieldNode>()->dsqlName);

			constraint.refRelation = *yyvsp[-3].metaNamePtr;
			constraint.refAction = yyvsp[-1].refActionClause;

			const ValueListNode* refColumns = yyvsp[-2].valueListNode;
			if (refColumns)
			{
				const NestConst<ValueExprNode>* ptr = refColumns->items.begin();

				for (const NestConst<ValueExprNode>* const end = refColumns->items.end(); ptr != end; ++ptr)
					constraint.refColumns.add((*ptr)->as<FieldNode>()->dsqlName);
			}

			constraint.index = yyvsp[0].indexConstraintClause;

			yyvsp[-8].relationNode->clauses.add(&constraint);
		}
break;
case 427:
  if (!yytrial)
{
			RelationNode::AddConstraintClause* constraint = newNode<RelationNode::AddConstraintClause>();
			constraint->constraintType = RelationNode::AddConstraintClause::CTYPE_CHECK;
			constraint->check = yyvsp[0].boolSourceClause;
			yyvsp[-1].relationNode->clauses.add(constraint);
		}
break;
case 428:
  if (!yytrial)
{ yyval.indexConstraintClause = newNode<RelationNode::IndexConstraintClause>(); }
break;
case 429:
  if (!yytrial)
{
			RelationNode::IndexConstraintClause* clause = yyval.indexConstraintClause =
				newNode<RelationNode::IndexConstraintClause>();
			clause->descending = yyvsp[-2].boolVal;
			clause->name = *yyvsp[0].metaNamePtr;
		}
break;
case 430:
  if (!yytrial)
{ yyval.refActionClause = NULL; }
break;
case 431:
  if (!yytrial)
{ yyval.refActionClause = newNode<RelationNode::RefActionClause>(yyvsp[0].uintVal, 0); }
break;
case 432:
  if (!yytrial)
{ yyval.refActionClause = newNode<RelationNode::RefActionClause>(0, yyvsp[0].uintVal); }
break;
case 433:
  if (!yytrial)
{ yyval.refActionClause = newNode<RelationNode::RefActionClause>(yyvsp[0].uintVal, yyvsp[-1].uintVal); }
break;
case 434:
  if (!yytrial)
{ yyval.refActionClause = newNode<RelationNode::RefActionClause>(yyvsp[-1].uintVal, yyvsp[0].uintVal); }
break;
case 435:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal;}
break;
case 436:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal;}
break;
case 437:
  if (!yytrial)
{ yyval.uintVal = RelationNode::RefActionClause::ACTION_CASCADE; }
break;
case 438:
  if (!yytrial)
{ yyval.uintVal = RelationNode::RefActionClause::ACTION_SET_DEFAULT; }
break;
case 439:
  if (!yytrial)
{ yyval.uintVal = RelationNode::RefActionClause::ACTION_SET_NULL; }
break;
case 440:
  if (!yytrial)
{ yyval.uintVal = RelationNode::RefActionClause::ACTION_NONE; }
break;
case 443:
  if (!yytrial)
{
			yyval.createAlterProcedureNode = yyvsp[-3].createAlterProcedureNode;
			yyval.createAlterProcedureNode->source = makeParseStr(YYPOSNARG(3), YYPOSNARG(4));
			yyval.createAlterProcedureNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterProcedureNode->body = yyvsp[0].stmtNode;
		}
break;
case 444:
  if (!yytrial)
{
			yyval.createAlterProcedureNode = yyvsp[-2].createAlterProcedureNode;
			yyval.createAlterProcedureNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterProcedureNode->source = *yyvsp[0].stringPtr;
		}
break;
case 445:
  if (!yytrial)
{ yyval.createAlterProcedureNode = newNode<CreateAlterProcedureNode>(*yyvsp[0].metaNamePtr); }
break;
case 446:
yyval.parametersClause = NOTRIAL(&yyvsp[0].createAlterProcedureNode->parameters);
break;
case 447:
yyval.parametersClause = NOTRIAL(&yyvsp[-2].createAlterProcedureNode->returns);
break;
case 448:
  if (!yytrial)
{ yyval.createAlterProcedureNode = yyvsp[-4].createAlterProcedureNode; }
break;
case 449:
  if (!yytrial)
{
			yyval.createAlterProcedureNode = yyvsp[0].createAlterProcedureNode;
			yyval.createAlterProcedureNode->alter = true;
			yyval.createAlterProcedureNode->create = false;
		}
break;
case 450:
  if (!yytrial)
{
			yyval.createAlterProcedureNode = yyvsp[0].createAlterProcedureNode;
			yyval.createAlterProcedureNode->alter = true;
		}
break;
case 458:
  if (!yytrial)
{ yyvsp[-3].parametersClause->add(newNode<ParameterClause>(yyvsp[-2].legacyField, optName(yyvsp[-1].metaNamePtr), yyvsp[0].valueSourceClause)); }
break;
case 461:
  if (!yytrial)
{ yyvsp[-2].parametersClause->add(newNode<ParameterClause>(yyvsp[-1].legacyField, optName(yyvsp[0].metaNamePtr))); }
break;
case 462:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[0].legacyField;
			yyval.legacyField->fld_name = *yyvsp[-1].metaNamePtr;
		}
break;
case 463:
  if (!yytrial)
{ yyval.valueSourceClause = NULL; }
break;
case 464:
  if (!yytrial)
{
			ValueSourceClause* clause = newNode<ValueSourceClause>();
			clause->value = yyvsp[0].valueExprNode;
			clause->source = makeParseStr(YYPOSNARG(1), YYPOSNARG(2));
			yyval.valueSourceClause = clause;
		}
break;
case 465:
  if (!yytrial)
{
			ValueSourceClause* clause = newNode<ValueSourceClause>();
			clause->value = yyvsp[0].valueExprNode;
			clause->source = makeParseStr(YYPOSNARG(1), YYPOSNARG(2));
			yyval.valueSourceClause = clause;
		}
break;
case 468:
  if (!yytrial)
{
			yyval.createAlterFunctionNode = yyvsp[-3].createAlterFunctionNode;
			yyval.createAlterFunctionNode->source = makeParseStr(YYPOSNARG(3), YYPOSNARG(4));
			yyval.createAlterFunctionNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterFunctionNode->body = yyvsp[0].stmtNode;
		}
break;
case 469:
  if (!yytrial)
{
			yyval.createAlterFunctionNode = yyvsp[-2].createAlterFunctionNode;
			yyval.createAlterFunctionNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterFunctionNode->source = *yyvsp[0].stringPtr;
		}
break;
case 470:
  if (!yytrial)
{ yyval.createAlterFunctionNode = newNode<CreateAlterFunctionNode>(*yyvsp[0].metaNamePtr); }
break;
case 471:
  if (!yytrial)
{
				yyval.createAlterFunctionNode = yyvsp[-6].createAlterFunctionNode;
				yyval.createAlterFunctionNode->returnType = newNode<ParameterClause>(yyvsp[-2].legacyField, optName(yyvsp[-1].metaNamePtr));
				yyval.createAlterFunctionNode->deterministic = yyvsp[0].boolVal;
			}
break;
case 472:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 473:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 474:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 475:
  if (!yytrial)
{
			yyval.externalClause = newNode<ExternalClause>();
			yyval.externalClause->name = *yyvsp[-2].stringPtr;
			yyval.externalClause->engine = *yyvsp[0].metaNamePtr;
		}
break;
case 476:
  if (!yytrial)
{
			yyval.externalClause = newNode<ExternalClause>();
			yyval.externalClause->engine = *yyvsp[0].metaNamePtr;
		}
break;
case 477:
  if (!yytrial)
{ yyval.stringPtr = NULL; }
break;
case 478:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 479:
  if (!yytrial)
{
			yyval.createAlterFunctionNode = yyvsp[0].createAlterFunctionNode;
			yyval.createAlterFunctionNode->alter = true;
			yyval.createAlterFunctionNode->create = false;
		}
break;
case 480:
  if (!yytrial)
{
			yyval.createAlterFunctionNode = yyvsp[0].createAlterFunctionNode;
			yyval.createAlterFunctionNode->alter = true;
		}
break;
case 481:
  if (!yytrial)
{
			CreateAlterPackageNode* node = newNode<CreateAlterPackageNode>(*yyvsp[-4].metaNamePtr);
			node->source = makeParseStr(YYPOSNARG(3), YYPOSNARG(5));
			node->items = yyvsp[-1].packageItems;
			yyval.createAlterPackageNode = node;
		}
break;
case 483:
  if (!yytrial)
{ yyval.packageItems = newNode<Array<CreateAlterPackageNode::Item> >(); }
break;
case 484:
  if (!yytrial)
{
			yyval.packageItems = newNode<Array<CreateAlterPackageNode::Item> >();
			yyval.packageItems->add(yyvsp[0].packageItem);
		}
break;
case 485:
  if (!yytrial)
{
			yyval.packageItems = yyvsp[-1].packageItems;
			yyval.packageItems->add(yyvsp[0].packageItem);
		}
break;
case 486:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[-1].createAlterFunctionNode); }
break;
case 487:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[-1].createAlterProcedureNode); }
break;
case 488:
  if (!yytrial)
{
			yyval.createAlterPackageNode = yyvsp[0].createAlterPackageNode;
			yyval.createAlterPackageNode->alter = true;
			yyval.createAlterPackageNode->create = false;
		}
break;
case 489:
  if (!yytrial)
{
			yyval.createAlterPackageNode = yyvsp[0].createAlterPackageNode;
			yyval.createAlterPackageNode->alter = true;
		}
break;
case 490:
  if (!yytrial)
{
			CreatePackageBodyNode* node = newNode<CreatePackageBodyNode>(*yyvsp[-5].metaNamePtr);
			node->source = makeParseStr(YYPOSNARG(3), YYPOSNARG(6));
			node->declaredItems = yyvsp[-2].packageItems;
			node->items = yyvsp[-1].packageItems;
			yyval.createPackageBodyNode = node;
		}
break;
case 491:
  if (!yytrial)
{
			CreatePackageBodyNode* node = newNode<CreatePackageBodyNode>(*yyvsp[-4].metaNamePtr);
			node->source = makeParseStr(YYPOSNARG(3), YYPOSNARG(5));
			node->items = yyvsp[-1].packageItems;
			yyval.createPackageBodyNode = node;
		}
break;
case 492:
  if (!yytrial)
{ yyval.packageItems = newNode<Array<CreateAlterPackageNode::Item> >(); }
break;
case 494:
  if (!yytrial)
{
			yyval.packageItems = newNode<Array<CreateAlterPackageNode::Item> >();
			yyval.packageItems->add(yyvsp[0].packageItem);
		}
break;
case 495:
  if (!yytrial)
{
			yyval.packageItems = yyvsp[-1].packageItems;
			yyval.packageItems->add(yyvsp[0].packageItem);
		}
break;
case 496:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[0].createAlterFunctionNode); }
break;
case 497:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[-1].createAlterFunctionNode); }
break;
case 498:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[0].createAlterProcedureNode); }
break;
case 499:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[-1].createAlterProcedureNode); }
break;
case 500:
  if (!yytrial)
{ yyval.compoundStmtNode = NULL; }
break;
case 502:
  if (!yytrial)
{
			yyval.compoundStmtNode = newNode<CompoundStmtNode>();
			yyval.compoundStmtNode->statements.add(yyvsp[0].stmtNode);
		}
break;
case 503:
  if (!yytrial)
{
			yyvsp[-1].compoundStmtNode->statements.add(yyvsp[0].stmtNode);
			yyval.compoundStmtNode = yyvsp[-1].compoundStmtNode;
		}
break;
case 504:
  if (!yytrial)
{
			yyval.stmtNode = yyvsp[-1].stmtNode;
			yyval.stmtNode->line = YYPOSNARG(1).firstLine;
			yyval.stmtNode->column = YYPOSNARG(1).firstColumn;
		}
break;
case 505:
  if (!yytrial)
{ yyval.execBlockNode = newNode<ExecBlockNode>(); }
break;
case 506:
yyval.parametersClause = NOTRIAL(&yyvsp[0].execBlockNode->parameters);
break;
case 507:
yyval.parametersClause = NOTRIAL(&yyvsp[-2].execBlockNode->returns);
break;
case 508:
  if (!yytrial)
{
			DeclareSubProcNode* node = newNode<DeclareSubProcNode>(*yyvsp[-8].metaNamePtr);
			node->dsqlBlock = yyvsp[-7].execBlockNode;
			node->dsqlBlock->localDeclList = yyvsp[-1].compoundStmtNode;
			node->dsqlBlock->body = yyvsp[0].stmtNode;

			for (FB_SIZE_T i = 0; i < node->dsqlBlock->parameters.getCount(); ++i)
				node->dsqlBlock->parameters[i]->parameterExpr = make_parameter();

			yyval.stmtNode = node;
		}
break;
case 509:
  if (!yytrial)
{ yyval.execBlockNode = newNode<ExecBlockNode>(); }
break;
case 510:
  if (!yytrial)
{
			DeclareSubFuncNode* node = newNode<DeclareSubFuncNode>(*yyvsp[-10].metaNamePtr);
			node->dsqlDeterministic = yyvsp[-3].boolVal;
			node->dsqlBlock = yyvsp[-9].execBlockNode;
			node->dsqlBlock->localDeclList = yyvsp[-1].compoundStmtNode;
			node->dsqlBlock->body = yyvsp[0].stmtNode;

			for (FB_SIZE_T i = 0; i < node->dsqlBlock->parameters.getCount(); ++i)
				node->dsqlBlock->parameters[i]->parameterExpr = make_parameter();

			node->dsqlBlock->returns.add(newNode<ParameterClause>(yyvsp[-5].legacyField, optName(yyvsp[-4].metaNamePtr)));

			yyval.stmtNode = node;
		}
break;
case 513:
  if (!yytrial)
{
			DeclareVariableNode* node = newNode<DeclareVariableNode>();
			node->dsqlDef = newNode<ParameterClause>(yyvsp[-2].legacyField, optName(yyvsp[-1].metaNamePtr), yyvsp[0].valueSourceClause);
			yyval.stmtNode = node;
		}
break;
case 516:
  if (!yytrial)
{
			DeclareCursorNode* node = newNode<DeclareCursorNode>(*yyvsp[-6].metaNamePtr,
				DeclareCursorNode::CUR_TYPE_EXPLICIT);
			node->dsqlScroll = yyvsp[-5].boolVal;
			node->dsqlSelect = yyvsp[-1].selectNode;
			yyval.stmtNode = node;
		}
break;
case 517:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 518:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 519:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 522:
  if (!yytrial)
{ yyval.stmtNode = newNode<LineColumnNode>(YYPOSNARG(1).firstLine, YYPOSNARG(1).firstColumn, yyvsp[-1].stmtNode); }
break;
case 523:
  if (!yytrial)
{ yyval.stmtNode = newNode<CompoundStmtNode>(); }
break;
case 524:
  if (!yytrial)
{
			BlockNode* node = newNode<BlockNode>();
			node->action = yyvsp[0].compoundStmtNode;
			yyval.stmtNode = node;
		}
break;
case 525:
  if (!yytrial)
{
			BlockNode* node = newNode<BlockNode>();
			node->action = yyvsp[-1].compoundStmtNode;
			node->handlers = yyvsp[0].compoundStmtNode;
			yyval.stmtNode = node;
		}
break;
case 526:
  if (!yytrial)
{
			yyval.compoundStmtNode = newNode<CompoundStmtNode>();
			yyval.compoundStmtNode->statements.add(yyvsp[0].stmtNode);
		}
break;
case 527:
  if (!yytrial)
{
			yyvsp[-1].compoundStmtNode->statements.add(yyvsp[0].stmtNode);
			yyval.compoundStmtNode = yyvsp[-1].compoundStmtNode;
		}
break;
case 528:
  if (!yytrial)
{ yyval.stmtNode = newNode<LineColumnNode>(YYPOSNARG(1).firstLine, YYPOSNARG(1).firstColumn, yyvsp[-1].stmtNode); }
break;
case 529:
  if (!yytrial)
{ yyval.stmtNode = newNode<LineColumnNode>(YYPOSNARG(1).firstLine, YYPOSNARG(1).firstColumn, yyvsp[0].stmtNode); }
break;
case 531:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].storeNode; }
break;
case 532:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].mergeNode; }
break;
case 534:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].updInsNode; }
break;
case 538:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].execStatementNode; }
break;
case 539:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].execStatementNode; }
break;
case 541:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 547:
  if (!yytrial)
{ yyval.stmtNode = newNode<SuspendNode>(); }
break;
case 548:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExitNode>(); }
break;
case 549:
  if (!yytrial)
{ yyval.stmtNode = newNode<ReturnNode>(yyvsp[0].valueExprNode); }
break;
case 551:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 555:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].forNode; }
break;
case 556:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].execStatementNode; }
break;
case 557:
  if (!yytrial)
{
			InAutonomousTransactionNode* node = newNode<InAutonomousTransactionNode>();
			node->action = yyvsp[0].stmtNode;
			yyval.stmtNode = node;
		}
break;
case 558:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExceptionNode>(*yyvsp[0].metaNamePtr); }
break;
case 559:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExceptionNode>(*yyvsp[-1].metaNamePtr, yyvsp[0].valueExprNode); }
break;
case 560:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExceptionNode>(*yyvsp[-4].metaNamePtr, (ValueExprNode*) NULL, yyvsp[-1].valueListNode); }
break;
case 561:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExceptionNode>(); }
break;
case 562:
  if (!yytrial)
{
				ForNode* node = newNode<ForNode>();
				node->dsqlLabelName = yyvsp[-2].metaNamePtr;
				node->dsqlSelect = yyvsp[0].selectNode;
				yyval.forNode = node;
			}
break;
case 563:
yyval.forNode = yyvsp[0].forNode;
break;
case 564:
  if (!yytrial)
{
				ForNode* node = yyvsp[-4].forNode;
				node->statement = yyvsp[0].stmtNode;
				yyval.forNode = node;
			}
break;
case 565:
  if (!yytrial)
{
			yyvsp[-2].forNode->dsqlInto = yyvsp[-1].valueListNode;
			yyvsp[-2].forNode->dsqlCursor = yyvsp[0].declCursorNode;
		}
break;
case 566:
  if (!yytrial)
{
			yyvsp[-2].forNode->dsqlInto = yyvsp[-1].valueListNode;
			yyvsp[-2].forNode->dsqlCursor = yyvsp[0].declCursorNode;
		}
break;
case 567:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 569:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 570:
  if (!yytrial)
{ yyval.execStatementNode = newNode<ExecStatementNode>(); }
break;
case 571:
yyval.execStatementNode = yyvsp[0].execStatementNode;
break;
case 572:
yyval.execStatementNode = yyvsp[-2].execStatementNode;
break;
case 573:
  if (!yytrial)
{
			yyval.execStatementNode = yyvsp[-4].execStatementNode;
		}
break;
case 574:
  if (!yytrial)
{
			yyval.execStatementNode = yyvsp[-2].execStatementNode;
			yyval.execStatementNode->outputs = yyvsp[0].valueListNode;
		}
break;
case 575:
  if (!yytrial)
{
			yyval.execStatementNode = yyvsp[-2].execStatementNode;
			yyval.execStatementNode->dsqlLabelName = yyvsp[-4].metaNamePtr;
			yyval.execStatementNode->innerStmt = yyvsp[0].stmtNode;
		}
break;
case 576:
  if (!yytrial)
{ yyvsp[-1].execStatementNode->sql = yyvsp[0].valueExprNode; }
break;
case 577:
yyval.execStatementNode = yyvsp[-4].execStatementNode;
break;
case 578:
  if (!yytrial)
{ yyvsp[-7].execStatementNode->sql = yyvsp[-5].valueExprNode; }
break;
case 579:
  if (!yytrial)
{ yyvsp[-7].execStatementNode->sql = yyvsp[-5].valueExprNode; }
break;
case 582:
  if (!yytrial)
{
			if (!yyvsp[-3].execStatementNode->inputNames)
				yyvsp[-3].execStatementNode->inputNames = FB_NEW_POOL(getPool()) EDS::ParamNames(getPool());

			yyvsp[-3].execStatementNode->inputNames->add(yyvsp[-2].metaNamePtr);

			if (!yyvsp[-3].execStatementNode->inputs)
				yyvsp[-3].execStatementNode->inputs = newNode<ValueListNode>(yyvsp[0].valueExprNode);
			else
				yyvsp[-3].execStatementNode->inputs->add(yyvsp[0].valueExprNode);
		}
break;
case 585:
  if (!yytrial)
{
			if (!yyvsp[-1].execStatementNode->inputs)
				yyvsp[-1].execStatementNode->inputs = newNode<ValueListNode>(yyvsp[0].valueExprNode);
			else
				yyvsp[-1].execStatementNode->inputs->add(yyvsp[0].valueExprNode);
		}
break;
case 588:
yyval.execStatementNode = yyvsp[-1].execStatementNode;
break;
case 591:
  if (!yytrial)
{ setClause(yyvsp[-5].execStatementNode->dataSource, "EXTERNAL DATA SOURCE", yyvsp[0].valueExprNode); }
break;
case 592:
  if (!yytrial)
{ setClause(yyvsp[-3].execStatementNode->dataSource, "EXTERNAL DATA SOURCE", yyvsp[0].valueExprNode); }
break;
case 593:
  if (!yytrial)
{ setClause(yyvsp[-3].execStatementNode->userName, "USER", yyvsp[0].valueExprNode); }
break;
case 594:
  if (!yytrial)
{ setClause(yyvsp[-2].execStatementNode->password, "PASSWORD", yyvsp[0].valueExprNode); }
break;
case 595:
  if (!yytrial)
{ setClause(yyvsp[-2].execStatementNode->role, "ROLE", yyvsp[0].valueExprNode); }
break;
case 596:
  if (!yytrial)
{ setClause(yyvsp[-3].execStatementNode->traScope, "TRANSACTION", EDS::traAutonomous); }
break;
case 597:
  if (!yytrial)
{ setClause(yyvsp[-3].execStatementNode->traScope, "TRANSACTION", EDS::traCommon); }
break;
case 598:
  if (!yytrial)
{ setClause(yyvsp[-3].execStatementNode->useCallerPrivs, "CALLER PRIVILEGES"); }
break;
case 599:
  if (!yytrial)
{
			IfNode* node = newNode<IfNode>();
			node->condition = yyvsp[-5].boolExprNode;
			node->trueAction = yyvsp[-2].stmtNode;
			node->falseAction = yyvsp[0].stmtNode;
			yyval.stmtNode = node;
		}
break;
case 600:
  if (!yytrial)
{
			IfNode* node = newNode<IfNode>();
			node->condition = yyvsp[-3].boolExprNode;
			node->trueAction = yyvsp[0].stmtNode;
			yyval.stmtNode = node;
		}
break;
case 601:
  if (!yytrial)
{
			PostEventNode* node = newNode<PostEventNode>();
			node->event = yyvsp[-1].valueExprNode;
			node->argument = yyvsp[0].valueExprNode;
			yyval.stmtNode = node;
		}
break;
case 602:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 603:
  if (!yytrial)
{
			ForNode* node = newNode<ForNode>();
			node->dsqlSelect = yyvsp[-2].selectNode;
			node->dsqlInto = yyvsp[0].valueListNode;
			yyval.stmtNode = node;
		}
break;
case 604:
  if (!yytrial)
{
			VariableNode* node = newNode<VariableNode>();
			node->dsqlName = *yyvsp[0].metaNamePtr;
			yyval.valueExprNode = node;
		}
break;
case 605:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 606:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].fieldNode); }
break;
case 607:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].fieldNode); }
break;
case 608:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 609:
  if (!yytrial)
{
			LoopNode* node = newNode<LoopNode>();
			node->dsqlLabelName = yyvsp[-6].metaNamePtr;
			node->dsqlExpr = yyvsp[-3].boolExprNode;
			node->statement = yyvsp[0].stmtNode;
			yyval.stmtNode = node;
		}
break;
case 610:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 611:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[-1].metaNamePtr; }
break;
case 612:
  if (!yytrial)
{ yyval.stmtNode = newNode<ContinueLeaveNode>(blr_leave); }
break;
case 613:
  if (!yytrial)
{
			ContinueLeaveNode* node = newNode<ContinueLeaveNode>(blr_leave);
			node->dsqlLabelName = yyvsp[0].metaNamePtr;
			yyval.stmtNode = node;
		}
break;
case 614:
  if (!yytrial)
{
			ContinueLeaveNode* node = newNode<ContinueLeaveNode>(blr_continue_loop);
			node->dsqlLabelName = yyvsp[0].metaNamePtr;
			yyval.stmtNode = node;
		}
break;
case 615:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 617:
  if (!yytrial)
{ yyval.declCursorNode = NULL; }
break;
case 619:
  if (!yytrial)
{ yyval.declCursorNode = newNode<DeclareCursorNode>(*yyvsp[0].metaNamePtr, DeclareCursorNode::CUR_TYPE_FOR); }
break;
case 620:
  if (!yytrial)
{
			yyval.compoundStmtNode = newNode<CompoundStmtNode>();
			yyval.compoundStmtNode->statements.add(yyvsp[0].stmtNode);
		}
break;
case 621:
  if (!yytrial)
{
			yyvsp[-1].compoundStmtNode->statements.add(yyvsp[0].stmtNode);
			yyval.compoundStmtNode = yyvsp[-1].compoundStmtNode;
		}
break;
case 622:
  if (!yytrial)
{ yyval.errorHandlerNode = newNode<ErrorHandlerNode>(); }
break;
case 623:
yyval.exceptionArray = NOTRIAL(&yyvsp[0].errorHandlerNode->conditions);
break;
case 624:
  if (!yytrial)
{
				ErrorHandlerNode* node = yyvsp[-4].errorHandlerNode;
				node->action = yyvsp[0].stmtNode;
				yyval.stmtNode = node;
			}
break;
case 625:
yyval.exceptionArray = yyvsp[0].exceptionArray;
break;
case 627:
yyval.exceptionArray = yyvsp[-2].exceptionArray;
break;
case 629:
  if (!yytrial)
{
			ExceptionItem& item = yyvsp[-2].exceptionArray->add();
			item.type = ExceptionItem::SQL_CODE;
			item.code = yyvsp[0].int32Val;
		}
break;
case 630:
  if (!yytrial)
{
			ExceptionItem& item = yyvsp[-2].exceptionArray->add();
			item.type = ExceptionItem::SQL_STATE;
			item.name = yyvsp[0].intlStringPtr->getString();
		}
break;
case 631:
  if (!yytrial)
{
			ExceptionItem& item = yyvsp[-2].exceptionArray->add();
			item.type = ExceptionItem::GDS_CODE;
			item.name = yyvsp[0].metaNamePtr->c_str();
		}
break;
case 632:
  if (!yytrial)
{
			ExceptionItem& item = yyvsp[-2].exceptionArray->add();
			item.type = ExceptionItem::XCP_CODE;
			item.name = yyvsp[0].metaNamePtr->c_str();
		}
break;
case 633:
  if (!yytrial)
{
			ExceptionItem& item = yyvsp[-1].exceptionArray->add();
			item.type = ExceptionItem::XCP_DEFAULT;
		}
break;
case 637:
  if (!yytrial)
{ yyval.stmtNode = newNode<CursorStmtNode>(blr_cursor_open, *yyvsp[0].metaNamePtr); }
break;
case 638:
  if (!yytrial)
{ yyval.stmtNode = newNode<CursorStmtNode>(blr_cursor_close, *yyvsp[0].metaNamePtr); }
break;
case 639:
  if (!yytrial)
{ yyval.cursorStmtNode = newNode<CursorStmtNode>(blr_cursor_fetch_scroll); }
break;
case 640:
yyval.cursorStmtNode = yyvsp[0].cursorStmtNode;
break;
case 641:
  if (!yytrial)
{
			CursorStmtNode* cursorStmt = yyvsp[-5].cursorStmtNode;
			cursorStmt->dsqlName = *yyvsp[-1].metaNamePtr;
			cursorStmt->dsqlIntoStmt = yyvsp[0].valueListNode;
			yyval.stmtNode = cursorStmt;
		}
break;
case 642:
  if (!yytrial)
{ yyval.stmtNode = newNode<CursorStmtNode>(blr_cursor_fetch, *yyvsp[-1].metaNamePtr, yyvsp[0].valueListNode); }
break;
case 643:
  if (!yytrial)
{ yyvsp[-1].cursorStmtNode->scrollOp = blr_scroll_bof; }
break;
case 644:
  if (!yytrial)
{ yyvsp[-1].cursorStmtNode->scrollOp = blr_scroll_eof; }
break;
case 645:
  if (!yytrial)
{ yyvsp[-1].cursorStmtNode->scrollOp = blr_scroll_backward; }
break;
case 646:
  if (!yytrial)
{ yyvsp[-1].cursorStmtNode->scrollOp = blr_scroll_forward; }
break;
case 647:
  if (!yytrial)
{
			yyvsp[-2].cursorStmtNode->scrollOp = blr_scroll_absolute;
			yyvsp[-2].cursorStmtNode->scrollExpr = yyvsp[0].valueExprNode;
		}
break;
case 648:
  if (!yytrial)
{
			yyvsp[-2].cursorStmtNode->scrollOp = blr_scroll_relative;
			yyvsp[-2].cursorStmtNode->scrollExpr = yyvsp[0].valueExprNode;
		}
break;
case 649:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExecProcedureNode>(QualifiedName(*yyvsp[-2].metaNamePtr), yyvsp[-1].valueListNode, yyvsp[0].valueListNode); }
break;
case 650:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExecProcedureNode>(QualifiedName(*yyvsp[-2].metaNamePtr, *yyvsp[-4].metaNamePtr), yyvsp[-1].valueListNode, yyvsp[0].valueListNode); }
break;
case 651:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 652:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 653:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-1].valueListNode; }
break;
case 654:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 655:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 656:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-1].valueListNode; }
break;
case 657:
  if (!yytrial)
{ yyval.execBlockNode = newNode<ExecBlockNode>(); }
break;
case 658:
  if (!yytrial)
{
			ExecBlockNode* node = yyvsp[-7].execBlockNode;
			node->localDeclList = yyvsp[-1].compoundStmtNode;
			node->body = yyvsp[0].stmtNode;
			yyval.execBlockNode = node;
		}
break;
case 663:
  if (!yytrial)
{ yyvsp[-4].parametersClause->add(newNode<ParameterClause>(yyvsp[-3].legacyField, optName(yyvsp[-2].metaNamePtr), (ValueSourceClause*) NULL, yyvsp[0].valueExprNode)); }
break;
case 664:
  if (!yytrial)
{
			CreateAlterViewNode* node = newNode<CreateAlterViewNode>(yyvsp[-4].relSourceNode, yyvsp[-3].valueListNode, yyvsp[-1].selectExprNode);
			node->source = makeParseStr(YYPOSNARG(4), YYPOSNARG(5));
			node->withCheckOption = yyvsp[0].boolVal;
			yyval.createAlterViewNode = node;
		}
break;
case 665:
  if (!yytrial)
{
			yyvsp[0].createAlterViewNode->alter = true;
			yyval.ddlNode = yyvsp[0].createAlterViewNode;
		}
break;
case 666:
  if (!yytrial)
{
			yyvsp[0].createAlterViewNode->alter = true;
			yyvsp[0].createAlterViewNode->create = false;
			yyval.ddlNode = yyvsp[0].createAlterViewNode;
		}
break;
case 667:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 668:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 669:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-6].metaNamePtr);
			yyval.createAlterTriggerNode->active = yyvsp[-5].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-4].uint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-3].nullableIntVal;
			yyval.createAlterTriggerNode->source = makeParseStr(YYPOSNARG(5), YYPOSNARG(7));
			yyval.createAlterTriggerNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterTriggerNode->body = yyvsp[0].stmtNode;
		}
break;
case 670:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-5].metaNamePtr);
			yyval.createAlterTriggerNode->active = yyvsp[-4].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-3].uint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-2].nullableIntVal;
			yyval.createAlterTriggerNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterTriggerNode->source = *yyvsp[0].stringPtr;
		}
break;
case 671:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-8].metaNamePtr);
			yyval.createAlterTriggerNode->active = yyvsp[-7].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-6].uint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-5].nullableIntVal;
			yyval.createAlterTriggerNode->relationName = *yyvsp[-3].metaNamePtr;
			yyval.createAlterTriggerNode->source = makeParseStr(YYPOSNARG(7), YYPOSNARG(9));
			yyval.createAlterTriggerNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterTriggerNode->body = yyvsp[0].stmtNode;
		}
break;
case 672:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-7].metaNamePtr);
			yyval.createAlterTriggerNode->active = yyvsp[-6].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-5].uint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-4].nullableIntVal;
			yyval.createAlterTriggerNode->relationName = *yyvsp[-2].metaNamePtr;
			yyval.createAlterTriggerNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterTriggerNode->source = *yyvsp[0].stringPtr;
		}
break;
case 673:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-8].metaNamePtr);
			yyval.createAlterTriggerNode->active = yyvsp[-5].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-4].uint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-3].nullableIntVal;
			yyval.createAlterTriggerNode->relationName = *yyvsp[-6].metaNamePtr;
			yyval.createAlterTriggerNode->source = makeParseStr(YYPOSNARG(7), YYPOSNARG(9));
			yyval.createAlterTriggerNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterTriggerNode->body = yyvsp[0].stmtNode;
		}
break;
case 674:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-7].metaNamePtr);
			yyval.createAlterTriggerNode->active = yyvsp[-4].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-3].uint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-2].nullableIntVal;
			yyval.createAlterTriggerNode->relationName = *yyvsp[-5].metaNamePtr;
			yyval.createAlterTriggerNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterTriggerNode->source = *yyvsp[0].stringPtr;
		}
break;
case 675:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = yyvsp[0].createAlterTriggerNode;
			yyval.createAlterTriggerNode->alter = true;
		}
break;
case 676:
  if (!yytrial)
{ yyval.nullableBoolVal = Nullable<bool>::val(true); }
break;
case 677:
  if (!yytrial)
{ yyval.nullableBoolVal = Nullable<bool>::val(false); }
break;
case 678:
  if (!yytrial)
{ yyval.nullableBoolVal = Nullable<bool>::empty(); }
break;
case 679:
  if (!yytrial)
{ yyval.uint64Val = yyvsp[-1].uint64Val + yyvsp[0].uint64Val - 1; }
break;
case 680:
  if (!yytrial)
{ yyval.uint64Val = yyvsp[0].uint64Val; }
break;
case 681:
  if (!yytrial)
{ yyval.uint64Val = yyvsp[-1].uint64Val + yyvsp[0].uint64Val; }
break;
case 682:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DB | DB_TRIGGER_CONNECT; }
break;
case 683:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DB | DB_TRIGGER_DISCONNECT; }
break;
case 684:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DB | DB_TRIGGER_TRANS_START; }
break;
case 685:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DB | DB_TRIGGER_TRANS_COMMIT; }
break;
case 686:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DB | DB_TRIGGER_TRANS_ROLLBACK; }
break;
case 688:
  if (!yytrial)
{
			yyval.uint64Val = TRIGGER_TYPE_DDL | DDL_TRIGGER_ANY;
		}
break;
case 689:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_TABLE); }
break;
case 690:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_TABLE); }
break;
case 691:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_TABLE); }
break;
case 692:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_PROCEDURE); }
break;
case 693:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_PROCEDURE); }
break;
case 694:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_PROCEDURE); }
break;
case 695:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_FUNCTION); }
break;
case 696:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_FUNCTION); }
break;
case 697:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_FUNCTION); }
break;
case 698:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_TRIGGER); }
break;
case 699:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_TRIGGER); }
break;
case 700:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_TRIGGER); }
break;
case 701:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_EXCEPTION); }
break;
case 702:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_EXCEPTION); }
break;
case 703:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_EXCEPTION); }
break;
case 704:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_VIEW); }
break;
case 705:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_VIEW); }
break;
case 706:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_VIEW); }
break;
case 707:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_DOMAIN); }
break;
case 708:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_DOMAIN); }
break;
case 709:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_DOMAIN); }
break;
case 710:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_ROLE); }
break;
case 711:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_ROLE); }
break;
case 712:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_ROLE); }
break;
case 713:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_SEQUENCE); }
break;
case 714:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_SEQUENCE); }
break;
case 715:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_SEQUENCE); }
break;
case 716:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_USER); }
break;
case 717:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_USER); }
break;
case 718:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_USER); }
break;
case 719:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_INDEX); }
break;
case 720:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_INDEX); }
break;
case 721:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_INDEX); }
break;
case 722:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_COLLATION); }
break;
case 723:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_COLLATION); }
break;
case 724:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_CHARACTER_SET); }
break;
case 725:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_PACKAGE); }
break;
case 726:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_PACKAGE); }
break;
case 727:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_PACKAGE); }
break;
case 728:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_PACKAGE_BODY); }
break;
case 729:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_PACKAGE_BODY); }
break;
case 730:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_MAPPING); }
break;
case 731:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_MAPPING); }
break;
case 732:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_MAPPING); }
break;
case 733:
  if (!yytrial)
{ yyval.uint64Val = yyvsp[-2].uint64Val | yyvsp[0].uint64Val; }
break;
case 734:
  if (!yytrial)
{ yyval.uint64Val = 0; }
break;
case 735:
  if (!yytrial)
{ yyval.uint64Val = 1; }
break;
case 736:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(1, 0, 0); }
break;
case 737:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(2, 0, 0); }
break;
case 738:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(3, 0, 0); }
break;
case 739:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(1, 2, 0); }
break;
case 740:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(1, 3, 0); }
break;
case 741:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(2, 1, 0); }
break;
case 742:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(2, 3, 0); }
break;
case 743:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(3, 1, 0); }
break;
case 744:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(3, 2, 0); }
break;
case 745:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(1, 2, 3); }
break;
case 746:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(1, 3, 2); }
break;
case 747:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(2, 1, 3); }
break;
case 748:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(2, 3, 1); }
break;
case 749:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(3, 1, 2); }
break;
case 750:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(3, 2, 1); }
break;
case 751:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::empty(); }
break;
case 752:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::val(yyvsp[0].int32Val); }
break;
case 753:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 754:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 755:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterExceptionNode; }
break;
case 756:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterRelationNode>(yyvsp[0].relSourceNode); }
break;
case 757:
yyval.relationNode = yyvsp[0].relationNode;
break;
case 758:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[-2].relationNode; }
break;
case 759:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 760:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterTriggerNode; }
break;
case 761:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterProcedureNode; }
break;
case 762:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterPackageNode; }
break;
case 763:
  if (!yytrial)
{ yyval.alterDatabaseNode = newNode<AlterDatabaseNode>(); }
break;
case 764:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[-2].alterDatabaseNode; }
break;
case 765:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].alterDomainNode; }
break;
case 766:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 767:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 768:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterFunctionNode; }
break;
case 769:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 770:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterUserNode; }
break;
case 771:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterUserNode; }
break;
case 772:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 773:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 774:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 775:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 776:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 777:
  if (!yytrial)
{ yyval.alterDomainNode = newNode<AlterDomainNode>(*yyvsp[0].metaNamePtr); }
break;
case 778:
yyval.alterDomainNode = yyvsp[0].alterDomainNode;
break;
case 779:
  if (!yytrial)
{ yyval.alterDomainNode = yyvsp[-2].alterDomainNode; }
break;
case 781:
yyval.alterDomainNode = yyvsp[-1].alterDomainNode;
break;
case 783:
  if (!yytrial)
{ setClause(yyvsp[-2].alterDomainNode->setDefault, "DOMAIN DEFAULT", yyvsp[0].valueSourceClause); }
break;
case 784:
  if (!yytrial)
{ setClause(yyvsp[-3].alterDomainNode->setConstraint, "DOMAIN CONSTRAINT", yyvsp[0].boolSourceClause); }
break;
case 785:
  if (!yytrial)
{ setClause(yyvsp[-2].alterDomainNode->setConstraint, "DOMAIN CONSTRAINT", yyvsp[0].boolSourceClause); }
break;
case 786:
  if (!yytrial)
{ setClause(yyvsp[-2].alterDomainNode->dropDefault, "DOMAIN DROP DEFAULT"); }
break;
case 787:
  if (!yytrial)
{ setClause(yyvsp[-2].alterDomainNode->dropConstraint, "DOMAIN DROP CONSTRAINT"); }
break;
case 788:
  if (!yytrial)
{ setClause(yyvsp[-3].alterDomainNode->notNullFlag, "{SET | DROP} NOT NULL", false); }
break;
case 789:
  if (!yytrial)
{ setClause(yyvsp[-3].alterDomainNode->notNullFlag, "{SET | DROP} NOT NULL", true); }
break;
case 790:
  if (!yytrial)
{ setClause(yyvsp[-2].alterDomainNode->renameTo, "DOMAIN NAME", *yyvsp[0].metaNamePtr); }
break;
case 791:
  if (!yytrial)
{
			/*// FIXME: ALTER DOMAIN doesn't support collations, and altered domain's*/
			/*// collation is always lost.*/
			dsql_fld* type = yyvsp[0].legacyField;
			type->collate = "";
			setClause(yyvsp[-2].alterDomainNode->type, "DOMAIN TYPE", type);
		}
break;
case 793:
yyval.relationNode = yyvsp[-2].relationNode;
break;
case 795:
  if (!yytrial)
{
			RelationNode::DropColumnClause* clause = newNode<RelationNode::DropColumnClause>();
			clause->name = *yyvsp[-1].metaNamePtr;
			clause->cascade = yyvsp[0].boolVal;
			yyvsp[-3].relationNode->clauses.add(clause);
		}
break;
case 796:
  if (!yytrial)
{
			RelationNode::DropConstraintClause* clause = newNode<RelationNode::DropConstraintClause>();
			clause->name = *yyvsp[0].metaNamePtr;
			yyvsp[-3].relationNode->clauses.add(clause);
		}
break;
case 799:
  if (!yytrial)
{
			RelationNode::AlterColPosClause* clause = newNode<RelationNode::AlterColPosClause>();
			clause->name = *yyvsp[-2].metaNamePtr;
			clause->newPos = yyvsp[0].int32Val;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 800:
  if (!yytrial)
{
			RelationNode::AlterColNameClause* clause = newNode<RelationNode::AlterColNameClause>();
			clause->fromName = *yyvsp[-2].metaNamePtr;
			clause->toName = *yyvsp[0].metaNamePtr;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 801:
  if (!yytrial)
{
			RelationNode::AlterColNullClause* clause = newNode<RelationNode::AlterColNullClause>();
			clause->name = *yyvsp[-3].metaNamePtr;
			clause->notNullFlag = false;
			yyvsp[-5].relationNode->clauses.add(clause);
		}
break;
case 802:
  if (!yytrial)
{
			RelationNode::AlterColNullClause* clause = newNode<RelationNode::AlterColNullClause>();
			clause->name = *yyvsp[-3].metaNamePtr;
			clause->notNullFlag = true;
			yyvsp[-5].relationNode->clauses.add(clause);
		}
break;
case 803:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = yyvsp[0].legacyField;
			clause->field->fld_name = *yyvsp[-2].metaNamePtr;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 804:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = yyvsp[-1].legacyField;
			clause->field->fld_name = *yyvsp[-3].metaNamePtr;
			clause->computed = yyvsp[0].valueSourceClause;
			yyvsp[-5].relationNode->clauses.add(clause);
			clause->field->flags |= FLD_computed;
		}
break;
case 805:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = newNode<dsql_fld>();
			clause->field->fld_name = *yyvsp[-1].metaNamePtr;
			clause->computed = yyvsp[0].valueSourceClause;
			yyvsp[-3].relationNode->clauses.add(clause);
			clause->field->flags |= FLD_computed;
		}
break;
case 806:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = newNode<dsql_fld>();
			clause->field->fld_name = *yyvsp[-2].metaNamePtr;
			clause->defaultValue = yyvsp[0].valueSourceClause;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 807:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = newNode<dsql_fld>();
			clause->field->fld_name = *yyvsp[-2].metaNamePtr;
			clause->dropDefault = true;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 808:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = newNode<dsql_fld>();
			clause->field->fld_name = *yyvsp[-1].metaNamePtr;
			clause->identityRestart = true;
			clause->identityRestartValue = yyvsp[0].nullableInt64Val;
			yyvsp[-3].relationNode->clauses.add(clause);
		}
break;
case 893:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
		}
break;
case 894:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 895:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 896:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 897:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterIndexNode>(*yyvsp[-1].metaNamePtr, true); }
break;
case 898:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterIndexNode>(*yyvsp[-1].metaNamePtr, false); }
break;
case 899:
  if (!yytrial)
{
			AlterExternalFunctionNode* node = newNode<AlterExternalFunctionNode>(*yyvsp[-2].metaNamePtr);
			if (yyvsp[-1].stringPtr)
				node->clauses.name = *yyvsp[-1].stringPtr;
			if (yyvsp[0].stringPtr)
				node->clauses.udfModule = *yyvsp[0].stringPtr;
			yyval.ddlNode = node;
		}
break;
case 900:
  if (!yytrial)
{ yyval.stringPtr = NULL; }
break;
case 901:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 902:
  if (!yytrial)
{ yyval.stringPtr = NULL; }
break;
case 903:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 904:
  if (!yytrial)
{
			yyval.mappingNode = newNode<MappingNode>(MappingNode::MAP_RPL, "AutoAdminImplementationMapping");
			yyval.mappingNode->op = yyvsp[-3].boolVal ? MappingNode::MAP_RPL : MappingNode::MAP_DROP;
			yyval.mappingNode->from = newNode<IntlString>(FB_DOMAIN_ANY_RID_ADMINS);
			yyval.mappingNode->fromType = newNode<MetaName>(FB_PREDEFINED_GROUP);
			yyval.mappingNode->mode = 'P';
			yyval.mappingNode->plugin = newNode<MetaName>("Win_Sspi");
			yyval.mappingNode->role = true;
			yyval.mappingNode->to = yyvsp[-4].metaNamePtr;
			yyval.mappingNode->validateAdmin();
		}
break;
case 905:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 906:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 909:
yyval.dbFilesClause = NOTRIAL(&yyvsp[-1].alterDatabaseNode->files);
break;
case 911:
  if (!yytrial)
{ yyvsp[-4].alterDatabaseNode->differenceFile = *yyvsp[0].stringPtr; }
break;
case 912:
  if (!yytrial)
{ yyvsp[-3].alterDatabaseNode->clauses |= AlterDatabaseNode::CLAUSE_DROP_DIFFERENCE; }
break;
case 913:
  if (!yytrial)
{ yyvsp[-2].alterDatabaseNode->clauses |= AlterDatabaseNode::CLAUSE_BEGIN_BACKUP; }
break;
case 914:
  if (!yytrial)
{ yyvsp[-2].alterDatabaseNode->clauses |= AlterDatabaseNode::CLAUSE_END_BACKUP; }
break;
case 915:
  if (!yytrial)
{ yyvsp[-5].alterDatabaseNode->setDefaultCharSet = *yyvsp[0].metaNamePtr; }
break;
case 916:
yyval.alterDatabaseNode = yyvsp[-3].alterDatabaseNode;
break;
case 917:
  if (!yytrial)
{
			setClauseFlag(yyvsp[-5].alterDatabaseNode->clauses, AlterDatabaseNode::CLAUSE_CRYPT, "CRYPT");
			yyvsp[-5].alterDatabaseNode->cryptPlugin = *yyvsp[-2].metaNamePtr;
		}
break;
case 918:
  if (!yytrial)
{ setClauseFlag(yyvsp[-1].alterDatabaseNode->clauses, AlterDatabaseNode::CLAUSE_CRYPT, "CRYPT"); }
break;
case 919:
  if (!yytrial)
{ yyvsp[-4].alterDatabaseNode->linger = yyvsp[0].int32Val; }
break;
case 920:
  if (!yytrial)
{ yyvsp[-2].alterDatabaseNode->linger = 0; }
break;
case 922:
  if (!yytrial)
{ yyvsp[-2].alterDatabaseNode->keyName = *yyvsp[0].metaNamePtr; }
break;
case 923:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-6].metaNamePtr);
			yyval.createAlterTriggerNode->alter = true;
			yyval.createAlterTriggerNode->create = false;
			yyval.createAlterTriggerNode->active = yyvsp[-5].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-4].nullableUint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-3].nullableIntVal;
			yyval.createAlterTriggerNode->source = makeParseStr(YYPOSNARG(5), YYPOSNARG(7));
			yyval.createAlterTriggerNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterTriggerNode->body = yyvsp[0].stmtNode;
		}
break;
case 924:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-5].metaNamePtr);
			yyval.createAlterTriggerNode->alter = true;
			yyval.createAlterTriggerNode->create = false;
			yyval.createAlterTriggerNode->active = yyvsp[-4].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-3].nullableUint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-2].nullableIntVal;
			yyval.createAlterTriggerNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterTriggerNode->source = *yyvsp[0].stringPtr;
		}
break;
case 925:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-3].metaNamePtr);
			yyval.createAlterTriggerNode->alter = true;
			yyval.createAlterTriggerNode->create = false;
			yyval.createAlterTriggerNode->active = yyvsp[-2].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-1].nullableUint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[0].nullableIntVal;
		}
break;
case 926:
  if (!yytrial)
{ yyval.nullableUint64Val = Nullable<FB_UINT64>::val(yyvsp[-1].uint64Val + yyvsp[0].uint64Val - 1); }
break;
case 927:
  if (!yytrial)
{ yyval.nullableUint64Val = Nullable<FB_UINT64>::empty(); }
break;
case 928:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 929:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropExceptionNode>(*yyvsp[0].metaNamePtr); }
break;
case 930:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropIndexNode>(*yyvsp[0].metaNamePtr); }
break;
case 931:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropProcedureNode>(*yyvsp[0].metaNamePtr); }
break;
case 932:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropRelationNode>(*yyvsp[0].metaNamePtr, false); }
break;
case 933:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropTriggerNode>(*yyvsp[0].metaNamePtr); }
break;
case 934:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropRelationNode>(*yyvsp[0].metaNamePtr, true); }
break;
case 935:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropFilterNode>(*yyvsp[0].metaNamePtr); }
break;
case 936:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropDomainNode>(*yyvsp[0].metaNamePtr); }
break;
case 937:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropFunctionNode>(*yyvsp[0].metaNamePtr); }
break;
case 938:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropFunctionNode>(*yyvsp[0].metaNamePtr); }
break;
case 939:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropShadowNode>(yyvsp[-1].int32Val, yyvsp[0].boolVal); }
break;
case 940:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropRoleNode>(*yyvsp[0].metaNamePtr); }
break;
case 941:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropSequenceNode>(*yyvsp[0].metaNamePtr); }
break;
case 942:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropSequenceNode>(*yyvsp[0].metaNamePtr); }
break;
case 943:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropCollationNode>(*yyvsp[0].metaNamePtr); }
break;
case 944:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropUserNode>(*yyvsp[-3].metaNamePtr, yyvsp[0].metaNamePtr); }
break;
case 945:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropUserNode>(*yyvsp[0].metaNamePtr); }
break;
case 946:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropPackageNode>(*yyvsp[0].metaNamePtr); }
break;
case 947:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropPackageBodyNode>(*yyvsp[0].metaNamePtr); }
break;
case 948:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 949:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 950:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 951:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 952:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 956:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[-2].legacyField;
			yyval.legacyField->notNull = true;
		}
break;
case 959:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
		}
break;
case 960:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
			yyval.legacyField->typeOfTable = *yyvsp[-2].metaNamePtr;
		}
break;
case 961:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
			yyval.legacyField->fullDomain = true;
		}
break;
case 964:
  if (!yytrial)
{
			yyvsp[-3].legacyField->ranges = yyvsp[-1].valueListNode;
			yyvsp[-3].legacyField->dimensions = yyvsp[-3].legacyField->ranges->items.getCount() / 2;
			yyvsp[-3].legacyField->elementDtype = yyvsp[-3].legacyField->dtype;
			yyval.legacyField = yyvsp[-3].legacyField;
		}
break;
case 965:
  if (!yytrial)
{
			yyvsp[-4].legacyField->ranges = yyvsp[-2].valueListNode;
			yyvsp[-4].legacyField->dimensions = yyvsp[-4].legacyField->ranges->items.getCount() / 2;
			yyvsp[-4].legacyField->elementDtype = yyvsp[-4].legacyField->dtype;
			if (yyvsp[0].metaNamePtr)
				yyvsp[-4].legacyField->charSet = *yyvsp[0].metaNamePtr;
			yyval.legacyField = yyvsp[-4].legacyField;
		}
break;
case 967:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueListNode->items[0])->add(yyvsp[0].valueListNode->items[1]); }
break;
case 968:
  if (!yytrial)
{
			if (yyvsp[0].int32Val < 1)
		 		yyval.valueListNode = newNode<ValueListNode>(MAKE_const_slong(yyvsp[0].int32Val))->add(MAKE_const_slong(1));
			else
		 		yyval.valueListNode = newNode<ValueListNode>(MAKE_const_slong(1))->add(MAKE_const_slong(yyvsp[0].int32Val));
		}
break;
case 969:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(MAKE_const_slong(yyvsp[-2].int32Val))->add(MAKE_const_slong(yyvsp[0].int32Val)); }
break;
case 971:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[-1].legacyField;
			if (yyvsp[0].metaNamePtr)
				yyval.legacyField->charSet = *yyvsp[0].metaNamePtr;
		}
break;
case 975:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();

			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post (Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
					Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
																	Arg::Str("BIGINT"));
			}

			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post (Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
					Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
																Arg::Str("BIGINT"));
			}

			yyval.legacyField->dtype = dtype_int64;
			yyval.legacyField->length = sizeof(SINT64);
		}
break;
case 976:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_long;
			yyval.legacyField->length = sizeof(SLONG);
		}
break;
case 977:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_short;
			yyval.legacyField->length = sizeof(SSHORT);
		}
break;
case 978:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			stmt_ambiguous = true;

			if (client_dialect <= SQL_DIALECT_V5)
			{
				/* Post warning saying that DATE is equivalent to TIMESTAMP*/
				ERRD_post_warning(Arg::Warning(isc_sqlwarn) << Arg::Num(301) <<
								  Arg::Warning(isc_dtype_renamed));
				yyval.legacyField->dtype = dtype_timestamp;
				yyval.legacyField->length = sizeof(GDS_TIMESTAMP);
			}
			else if (client_dialect == SQL_DIALECT_V6_TRANSITION)
				yyabandon(-104, isc_transitional_date);
			else
			{
				yyval.legacyField->dtype = dtype_sql_date;
				yyval.legacyField->length = sizeof(ULONG);
			}
		}
break;
case 979:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();

			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
																		  Arg::Str("TIME"));
			}
			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
																		  Arg::Str("TIME"));
			}
			yyval.legacyField->dtype = dtype_sql_time;
			yyval.legacyField->length = sizeof(SLONG);
		}
break;
case 980:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_timestamp;
			yyval.legacyField->length = sizeof(GDS_TIMESTAMP);
		}
break;
case 981:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_boolean;
			yyval.legacyField->length = sizeof(UCHAR);
		}
break;
case 984:
  if (!yytrial)
{ yyval.legacyField = newNode<dsql_fld>(); }
break;
case 985:
yyval.legacyField = NOTRIAL(yyvsp[0].legacyField);
break;
case 986:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[-4].legacyField;
			yyval.legacyField->dtype = dtype_blob;
			yyval.legacyField->length = sizeof(ISC_QUAD);
			yyval.legacyField->segLength = yyvsp[-1].uintVal;
			if (yyvsp[0].metaNamePtr)
				yyval.legacyField->charSet = *yyvsp[0].metaNamePtr;
		}
break;
case 987:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_blob;
			yyval.legacyField->length = sizeof(ISC_QUAD);
			yyval.legacyField->segLength = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->subType = 0;
		}
break;
case 988:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_blob;
			yyval.legacyField->length = sizeof(ISC_QUAD);
			yyval.legacyField->segLength = (USHORT) yyvsp[-3].int32Val;
			yyval.legacyField->subType = (USHORT) yyvsp[-1].int32Val;
		}
break;
case 989:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_blob;
			yyval.legacyField->length = sizeof(ISC_QUAD);
			yyval.legacyField->segLength = 80;
			yyval.legacyField->subType = (USHORT) yyvsp[-1].int32Val;
		}
break;
case 990:
  if (!yytrial)
{ yyval.uintVal = (USHORT) 80; }
break;
case 991:
  if (!yytrial)
{ yyval.uintVal = (USHORT) yyvsp[0].int32Val; }
break;
case 992:
  if (!yytrial)
{ yyvsp[0].legacyField->subType = (USHORT) 0; }
break;
case 993:
  if (!yytrial)
{ yyvsp[-2].legacyField->subType = (USHORT) yyvsp[0].int32Val; }
break;
case 994:
  if (!yytrial)
{ yyvsp[-2].legacyField->subTypeName = *yyvsp[0].metaNamePtr; }
break;
case 995:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 996:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 997:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_text;
			yyval.legacyField->charLength = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->flags |= FLD_national;
		}
break;
case 998:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_text;
			yyval.legacyField->charLength = 1;
			yyval.legacyField->flags |= FLD_national;
		}
break;
case 999:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_varying;
			yyval.legacyField->charLength = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->flags |= FLD_national;
		}
break;
case 1000:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_text;
			yyval.legacyField->charLength = (USHORT) yyvsp[-1].int32Val;
		}
break;
case 1001:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_text;
			yyval.legacyField->charLength = 1;
		}
break;
case 1002:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_varying;
			yyval.legacyField->charLength = (USHORT) yyvsp[-1].int32Val;
		}
break;
case 1011:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[0].legacyField;
			yyval.legacyField->subType = dsc_num_type_numeric;
		}
break;
case 1012:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[0].legacyField;
			yyval.legacyField->subType = dsc_num_type_decimal;

			if (yyval.legacyField->dtype == dtype_short)
			{
				yyval.legacyField->dtype = dtype_long;
				yyval.legacyField->length = sizeof(SLONG);
			}
		}
break;
case 1013:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_long;
			yyval.legacyField->length = sizeof(SLONG);
			yyval.legacyField->precision = 9;
		}
break;
case 1014:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();

			if (yyvsp[-1].int32Val < 1 || yyvsp[-1].int32Val > 18)
				yyabandon(-842, isc_precision_err);	/* Precision must be between 1 and 18.*/

			if (yyvsp[-1].int32Val > 9)
			{
				if ( ( (client_dialect <= SQL_DIALECT_V5) && (db_dialect > SQL_DIALECT_V5) ) ||
					( (client_dialect > SQL_DIALECT_V5) && (db_dialect <= SQL_DIALECT_V5) ) )
				{
					ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-817) <<
							  Arg::Gds(isc_ddl_not_allowed_by_db_sql_dial) << Arg::Num(db_dialect));
				}

				if (client_dialect <= SQL_DIALECT_V5)
				{
					yyval.legacyField->dtype = dtype_double;
					yyval.legacyField->length = sizeof(double);
				}
				else
				{
					if (client_dialect == SQL_DIALECT_V6_TRANSITION)
					{
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous));
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous1));
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous2));
					}

					yyval.legacyField->dtype = dtype_int64;
					yyval.legacyField->length = sizeof(SINT64);
				}
			}
			else
			{
				if (yyvsp[-1].int32Val < 5)
				{
					yyval.legacyField->dtype = dtype_short;
					yyval.legacyField->length = sizeof(SSHORT);
				}
				else
				{
					yyval.legacyField->dtype = dtype_long;
					yyval.legacyField->length = sizeof(SLONG);
				}
			}

			yyval.legacyField->precision = (USHORT) yyvsp[-1].int32Val;
		}
break;
case 1015:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();

			if (yyvsp[-3].int32Val < 1 || yyvsp[-3].int32Val > 18)
				yyabandon (-842, isc_precision_err);	/* Precision should be between 1 and 18*/

			if (yyvsp[-1].int32Val > yyvsp[-3].int32Val || yyvsp[-1].int32Val < 0)
				yyabandon (-842, isc_scale_nogt);	/* Scale must be between 0 and precision*/

			if (yyvsp[-3].int32Val > 9)
			{
				if ( ( (client_dialect <= SQL_DIALECT_V5) && (db_dialect > SQL_DIALECT_V5) ) ||
					( (client_dialect > SQL_DIALECT_V5) && (db_dialect <= SQL_DIALECT_V5) ) )
				{
					ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-817) <<
							  Arg::Gds(isc_ddl_not_allowed_by_db_sql_dial) << Arg::Num(db_dialect));
				}

				if (client_dialect <= SQL_DIALECT_V5)
				{
					yyval.legacyField->dtype = dtype_double;
					yyval.legacyField->length = sizeof(double);
				}
				else
				{
					if (client_dialect == SQL_DIALECT_V6_TRANSITION)
					{
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous));
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous1));
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous2));
					}
					/* client_dialect >= SQL_DIALECT_V6*/
					yyval.legacyField->dtype = dtype_int64;
					yyval.legacyField->length = sizeof(SINT64);
				}
			}
			else
			{
				if (yyvsp[-3].int32Val < 5)
				{
					yyval.legacyField->dtype = dtype_short;
					yyval.legacyField->length = sizeof(SSHORT);
				}
				else
				{
					yyval.legacyField->dtype = dtype_long;
					yyval.legacyField->length = sizeof(SLONG);
				}
			}

			yyval.legacyField->precision = (USHORT) yyvsp[-3].int32Val;
			yyval.legacyField->scale = - (SSHORT) yyvsp[-1].int32Val;
		}
break;
case 1018:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();

			if (yyvsp[0].int32Val > 7)
			{
				yyval.legacyField->dtype = dtype_double;
				yyval.legacyField->length = sizeof(double);
			}
			else
			{
				yyval.legacyField->dtype = dtype_real;
				yyval.legacyField->length = sizeof(float);
			}
		}
break;
case 1019:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_double;
			yyval.legacyField->length = sizeof(double);
		}
break;
case 1020:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_real;
			yyval.legacyField->length = sizeof(float);
		}
break;
case 1021:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_double;
			yyval.legacyField->length = sizeof(double);
		}
break;
case 1022:
  if (!yytrial)
{ yyval.int32Val = 0; }
break;
case 1023:
  if (!yytrial)
{ yyval.int32Val = yyvsp[-1].int32Val; }
break;
case 1027:
  if (!yytrial)
{
			UserSavepointNode* node = newNode<UserSavepointNode>();
			node->command = UserSavepointNode::CMD_SET;
			node->name = *yyvsp[0].metaNamePtr;
			yyval.stmtNode = node;
		}
break;
case 1028:
  if (!yytrial)
{
			UserSavepointNode* node = newNode<UserSavepointNode>();
			node->command = (yyvsp[0].boolVal ? UserSavepointNode::CMD_RELEASE_ONLY : UserSavepointNode::CMD_RELEASE);
			node->name = *yyvsp[-1].metaNamePtr;
			yyval.stmtNode = node;
		}
break;
case 1029:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1030:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1031:
  if (!yytrial)
{
			UserSavepointNode* node = newNode<UserSavepointNode>();
			node->command = UserSavepointNode::CMD_ROLLBACK;
			node->name = *yyvsp[0].metaNamePtr;
			yyval.stmtNode = node;
		}
break;
case 1034:
  if (!yytrial)
{ yyval.traNode = newNode<CommitRollbackNode>(CommitRollbackNode::CMD_COMMIT, yyvsp[0].boolVal); }
break;
case 1035:
  if (!yytrial)
{ yyval.traNode = newNode<CommitRollbackNode>(CommitRollbackNode::CMD_ROLLBACK, yyvsp[0].boolVal); }
break;
case 1038:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1039:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1042:
  if (!yytrial)
{ yyval.setTransactionNode = newNode<SetTransactionNode>(); }
break;
case 1043:
yyval.setTransactionNode = yyvsp[0].setTransactionNode;
break;
case 1044:
  if (!yytrial)
{ yyval.setTransactionNode = yyvsp[-2].setTransactionNode; }
break;
case 1045:
  if (!yytrial)
{ yyval.setRoleNode = newNode<SetRoleNode>(yyvsp[0].metaNamePtr); }
break;
case 1046:
  if (!yytrial)
{ yyval.setRoleNode = newNode<SetRoleNode>(); }
break;
case 1050:
yyval.setTransactionNode = yyvsp[-1].setTransactionNode;
break;
case 1052:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->readOnly, "READ {ONLY | WRITE}", true); }
break;
case 1053:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->readOnly, "READ {ONLY | WRITE}", false); }
break;
case 1054:
  if (!yytrial)
{ setClause(yyvsp[-1].setTransactionNode->wait, "[NO] WAIT", true); }
break;
case 1055:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->wait, "[NO] WAIT", false); }
break;
case 1056:
  if (!yytrial)
{ setClause(yyvsp[-1].setTransactionNode->isoLevel, "ISOLATION LEVEL", yyvsp[0].uintVal); }
break;
case 1057:
  if (!yytrial)
{ setClause(yyvsp[-3].setTransactionNode->noAutoUndo, "NO AUTO UNDO", true); }
break;
case 1058:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->ignoreLimbo, "IGNORE LIMBO", true); }
break;
case 1059:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->restartRequests, "RESTART REQUESTS", true); }
break;
case 1060:
  if (!yytrial)
{ setClause(yyvsp[-3].setTransactionNode->lockTimeout, "LOCK TIMEOUT", (USHORT) yyvsp[0].int32Val); }
break;
case 1061:
  if (!yytrial)
{ checkDuplicateClause(yyvsp[-1].setTransactionNode->reserveList, "RESERVING"); }
break;
case 1062:
yyval.setTransactionNode = yyvsp[-2].setTransactionNode;
break;
case 1064:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal;}
break;
case 1067:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal; }
break;
case 1068:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal; }
break;
case 1069:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_CONCURRENCY; }
break;
case 1070:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_CONSISTENCY; }
break;
case 1071:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_CONSISTENCY; }
break;
case 1072:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_READ_COMMITTED_NO_REC_VERSION; }
break;
case 1073:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_READ_COMMITTED_REC_VERSION; }
break;
case 1074:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_READ_COMMITTED_NO_REC_VERSION; }
break;
case 1075:
  if (!yytrial)
{ yyval.uintVal = 0; }
break;
case 1076:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::LOCK_MODE_SHARED; }
break;
case 1077:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::LOCK_MODE_PROTECTED; }
break;
case 1078:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::LOCK_MODE_READ; }
break;
case 1079:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::LOCK_MODE_WRITE; }
break;
case 1080:
  if (!yytrial)
{ yyvsp[-1].setTransactionNode->reserveList.add(yyvsp[0].setTransactionRestrictionClause); }
break;
case 1081:
  if (!yytrial)
{ yyvsp[-3].setTransactionNode->reserveList.add(yyvsp[0].setTransactionRestrictionClause); }
break;
case 1082:
  if (!yytrial)
{ yyval.setTransactionRestrictionClause = newNode<SetTransactionNode::RestrictionOption>(yyvsp[-1].metaNameArray, yyvsp[0].uintVal); }
break;
case 1083:
  if (!yytrial)
{ yyval.uintVal = 0; }
break;
case 1084:
  if (!yytrial)
{ yyval.uintVal = yyvsp[-1].uintVal | yyvsp[0].uintVal; }
break;
case 1085:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = newNode<ObjectsArray<MetaName> >();
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1086:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = yyvsp[-2].metaNameArray;
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1087:
  if (!yytrial)
{ yyval.ddlNode = newNode<SetStatisticsNode>(*yyvsp[0].metaNamePtr); }
break;
case 1088:
  if (!yytrial)
{ yyval.ddlNode = newNode<CommentOnNode>(yyvsp[-2].intVal, QualifiedName(""), "", *yyvsp[0].stringPtr); }
break;
case 1089:
  if (!yytrial)
{ yyval.ddlNode = newNode<CommentOnNode>(yyvsp[-3].intVal, QualifiedName(*yyvsp[-2].metaNamePtr), "", *yyvsp[0].stringPtr); }
break;
case 1090:
  if (!yytrial)
{ yyval.ddlNode = newNode<CommentOnNode>(yyvsp[-4].intVal, QualifiedName(*yyvsp[-3].metaNamePtr), *yyvsp[-2].metaNamePtr, *yyvsp[0].stringPtr); }
break;
case 1091:
  if (!yytrial)
{ yyval.ddlNode = newNode<CommentOnNode>(yyvsp[-4].intVal, *yyvsp[-3].qualifiedNamePtr, *yyvsp[-2].metaNamePtr, *yyvsp[0].stringPtr); }
break;
case 1092:
  if (!yytrial)
{ yyval.ddlNode = newNode<CommentOnNode>(yyvsp[-3].intVal, *yyvsp[-2].qualifiedNamePtr, "", *yyvsp[0].stringPtr); }
break;
case 1093:
  if (!yytrial)
{
			CreateAlterUserNode* node =
				newNode<CreateAlterUserNode>(CreateAlterUserNode::USER_MOD, *yyvsp[-2].metaNamePtr);
			node->comment = yyvsp[0].stringPtr;
			yyval.ddlNode = node;
		}
break;
case 1094:
  if (!yytrial)
{ yyval.intVal = obj_database; }
break;
case 1095:
  if (!yytrial)
{ yyval.intVal = obj_field; }
break;
case 1096:
  if (!yytrial)
{ yyval.intVal = obj_relation; }
break;
case 1097:
  if (!yytrial)
{ yyval.intVal = obj_view; }
break;
case 1098:
  if (!yytrial)
{ yyval.intVal = obj_trigger; }
break;
case 1099:
  if (!yytrial)
{ yyval.intVal = obj_blob_filter; }
break;
case 1100:
  if (!yytrial)
{ yyval.intVal = obj_exception; }
break;
case 1101:
  if (!yytrial)
{ yyval.intVal = obj_generator; }
break;
case 1102:
  if (!yytrial)
{ yyval.intVal = obj_generator; }
break;
case 1103:
  if (!yytrial)
{ yyval.intVal = obj_index; }
break;
case 1104:
  if (!yytrial)
{ yyval.intVal = obj_sql_role; }
break;
case 1105:
  if (!yytrial)
{ yyval.intVal = obj_charset; }
break;
case 1106:
  if (!yytrial)
{ yyval.intVal = obj_collation; }
break;
case 1107:
  if (!yytrial)
{ yyval.intVal = obj_package_header; }
break;
case 1108:
  if (!yytrial)
{ yyval.intVal = obj_relation; }
break;
case 1109:
  if (!yytrial)
{ yyval.intVal = obj_parameter; }
break;
case 1110:
  if (!yytrial)
{ yyval.intVal = obj_procedure; }
break;
case 1111:
  if (!yytrial)
{ yyval.intVal = obj_udf; }
break;
case 1112:
  if (!yytrial)
{ yyval.intVal = obj_procedure; }
break;
case 1113:
  if (!yytrial)
{ yyval.intVal = obj_udf; }
break;
case 1114:
  if (!yytrial)
{ yyval.intVal = obj_udf; }
break;
case 1115:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 1116:
  if (!yytrial)
{ yyval.qualifiedNamePtr = newNode<QualifiedName>(*yyvsp[0].metaNamePtr); }
break;
case 1117:
  if (!yytrial)
{ yyval.qualifiedNamePtr = newNode<QualifiedName>(*yyvsp[0].metaNamePtr, *yyvsp[-2].metaNamePtr); }
break;
case 1118:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 1119:
  if (!yytrial)
{ yyval.stringPtr = newString(""); }
break;
case 1120:
  if (!yytrial)
{
			SelectNode* node = newNode<SelectNode>();
			node->dsqlExpr = yyvsp[-2].selectExprNode;
			node->dsqlForUpdate = yyvsp[-1].boolVal;
			node->dsqlWithLock = yyvsp[0].boolVal;
			yyval.selectNode = node;
		}
break;
case 1121:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1122:
  if (!yytrial)
{ yyval.boolVal = true; /* for_update_list is ignored */ }
break;
case 1123:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1124:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1125:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1126:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1127:
  if (!yytrial)
{
			SelectExprNode* node = yyval.selectExprNode = newNode<SelectExprNode>();
			node->querySpec = yyvsp[-2].recSourceNode;
			node->orderClause = yyvsp[-1].valueListNode;
			node->rowsClause = yyvsp[0].rowsClause;
			node->withClause = yyvsp[-3].withClause;
		}
break;
case 1128:
  if (!yytrial)
{
			SelectExprNode* node = yyval.selectExprNode = newNode<SelectExprNode>();
			node->querySpec = yyvsp[-3].recSourceNode;
			node->orderClause = yyvsp[-2].valueListNode;

			if (yyvsp[-1].valueExprNode || yyvsp[0].valueExprNode)
			{
				RowsClause* rowsNode = newNode<RowsClause>();
				rowsNode->skip = yyvsp[-1].valueExprNode;
				rowsNode->length = yyvsp[0].valueExprNode;
				node->rowsClause = rowsNode;
			}

			node->withClause = yyvsp[-4].withClause;
		}
break;
case 1129:
  if (!yytrial)
{ yyval.withClause = NULL; }
break;
case 1130:
  if (!yytrial)
{
			yyval.withClause = yyvsp[0].withClause;
			yyval.withClause->recursive = true;
		}
break;
case 1131:
  if (!yytrial)
{ yyval.withClause = yyvsp[0].withClause; }
break;
case 1132:
  if (!yytrial)
{
			yyval.withClause = newNode<WithClause>();
			yyval.withClause->add(yyvsp[0].selectExprNode);
		}
break;
case 1133:
  if (!yytrial)
{
			yyval.withClause = yyvsp[-2].withClause;
			yyval.withClause->add(yyvsp[0].selectExprNode);
		}
break;
case 1134:
  if (!yytrial)
{
			yyval.selectExprNode = yyvsp[-1].selectExprNode;
			yyval.selectExprNode->dsqlFlags |= RecordSourceNode::DFLAG_DERIVED;
			yyval.selectExprNode->alias = yyvsp[-5].metaNamePtr->c_str();
			yyval.selectExprNode->columns = yyvsp[-4].metaNameArray;
		}
break;
case 1135:
  if (!yytrial)
{
			yyval.selectExprNode = yyvsp[0].selectExprNode;
			yyval.selectExprNode->dsqlFlags |= RecordSourceNode::DFLAG_VALUE;
		}
break;
case 1136:
  if (!yytrial)
{
			yyvsp[0].selectExprNode->dsqlFlags |= RecordSourceNode::DFLAG_SINGLETON;
			yyval.valueExprNode = newNode<SubQueryNode>(blr_via, yyvsp[0].selectExprNode);
		}
break;
case 1137:
  if (!yytrial)
{ yyval.recSourceNode = yyvsp[0].rseNode; }
break;
case 1138:
  if (!yytrial)
{
			UnionSourceNode* node = yyvsp[-3].recSourceNode->as<UnionSourceNode>();
			if (node && !node->dsqlAll)
				node->dsqlClauses->add(yyvsp[0].rseNode);
			else
			{
				node = newNode<UnionSourceNode>();
				node->dsqlClauses = newNode<RecSourceListNode>(yyvsp[-3].recSourceNode)->add(yyvsp[0].rseNode);
			}
			yyval.recSourceNode = node;
		}
break;
case 1139:
  if (!yytrial)
{
			UnionSourceNode* node = yyvsp[-3].recSourceNode->as<UnionSourceNode>();
			if (node && node->dsqlAll)
				node->dsqlClauses->add(yyvsp[0].rseNode);
			else
			{
				node = newNode<UnionSourceNode>();
				node->dsqlAll = true;
				node->dsqlClauses = newNode<RecSourceListNode>(yyvsp[-3].recSourceNode)->add(yyvsp[0].rseNode);
			}
			yyval.recSourceNode = node;
		}
break;
case 1141:
  if (!yytrial)
{
			RseNode* rse = newNode<RseNode>();
			rse->dsqlFirst = yyvsp[-7].valueListNode ? yyvsp[-7].valueListNode->items[1] : NULL;
			rse->dsqlSkip = yyvsp[-7].valueListNode ? yyvsp[-7].valueListNode->items[0] : NULL;
			rse->dsqlDistinct = yyvsp[-6].valueListNode;
			rse->dsqlSelectList = yyvsp[-5].valueListNode;
			rse->dsqlFrom = yyvsp[-4].recSourceListNode;
			rse->dsqlWhere = yyvsp[-3].boolExprNode;
			rse->dsqlGroup = yyvsp[-2].valueListNode;
			rse->dsqlHaving = yyvsp[-1].boolExprNode;
			rse->rse_plan = yyvsp[0].planNode;
			yyval.rseNode = rse;
		}
break;
case 1142:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1143:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode)->add(yyvsp[-1].valueExprNode); }
break;
case 1144:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(1u)->add(yyvsp[0].valueExprNode); }
break;
case 1145:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode)->add(NULL); }
break;
case 1146:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(yyvsp[0].int32Val); }
break;
case 1147:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueExprNode; }
break;
case 1148:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1149:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(yyvsp[0].int32Val); }
break;
case 1150:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueExprNode; }
break;
case 1151:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1152:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(0); }
break;
case 1153:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1154:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1155:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1156:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 1157:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 1159:
  if (!yytrial)
{
			FieldNode* fieldNode = newNode<FieldNode>();
			fieldNode->dsqlQualifier = *yyvsp[-2].metaNamePtr;
			yyval.valueExprNode = fieldNode;
		}
break;
case 1161:
  if (!yytrial)
{ yyval.valueExprNode = newNode<DsqlAliasNode>(*yyvsp[0].metaNamePtr, yyvsp[-2].valueExprNode); }
break;
case 1164:
  if (!yytrial)
{ yyval.recSourceListNode = yyvsp[0].recSourceListNode; }
break;
case 1165:
  if (!yytrial)
{ yyval.recSourceListNode = newNode<RecSourceListNode>(yyvsp[0].recSourceNode); }
break;
case 1166:
  if (!yytrial)
{ yyval.recSourceListNode = yyvsp[-2].recSourceListNode->add(yyvsp[0].recSourceNode); }
break;
case 1170:
  if (!yytrial)
{ yyval.recSourceNode = yyvsp[0].selectExprNode; }
break;
case 1171:
  if (!yytrial)
{ yyval.recSourceNode = yyvsp[-1].recSourceNode; }
break;
case 1172:
  if (!yytrial)
{
			yyval.selectExprNode = yyvsp[-4].selectExprNode;
			yyval.selectExprNode->dsqlFlags |= RecordSourceNode::DFLAG_DERIVED;
			if (yyvsp[-1].metaNamePtr)
				yyval.selectExprNode->alias = yyvsp[-1].metaNamePtr->c_str();
			yyval.selectExprNode->columns = yyvsp[0].metaNameArray;
		}
break;
case 1173:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 1175:
  if (!yytrial)
{ yyval.metaNameArray = NULL; }
break;
case 1176:
  if (!yytrial)
{ yyval.metaNameArray = yyvsp[-1].metaNameArray; }
break;
case 1177:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = newNode<ObjectsArray<MetaName> >();
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1178:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = yyvsp[-2].metaNameArray;
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1182:
  if (!yytrial)
{
			RseNode* rse = newNode<RseNode>();
			rse->dsqlExplicitJoin = true;
			rse->rse_jointype = blr_inner;
			rse->dsqlFrom = newNode<RecSourceListNode>(yyvsp[-3].recSourceNode)->add(yyvsp[0].recSourceNode);
			yyval.recSourceNode = rse;
		}
break;
case 1183:
  if (!yytrial)
{
			RseNode* rse = newNode<RseNode>();
			rse->dsqlExplicitJoin = true;
			rse->rse_jointype = yyvsp[-2].blrOp;
			rse->dsqlFrom = newNode<RecSourceListNode>(yyvsp[-4].recSourceNode)->add(yyvsp[0].recSourceNode);
			rse->dsqlJoinUsing = newNode<ValueListNode>(0u);	/* using list with size 0 -> natural*/
			yyval.recSourceNode = rse;
		}
break;
case 1184:
  if (!yytrial)
{
			RseNode* rse = newNode<RseNode>();
			rse->dsqlExplicitJoin = true;
			rse->rse_jointype = yyvsp[-3].blrOp;
			rse->dsqlFrom = newNode<RecSourceListNode>(yyvsp[-4].recSourceNode);
			rse->dsqlFrom->add(yyvsp[-1].recSourceNode);
			rse->dsqlWhere = yyvsp[0].boolExprNode;
			yyval.recSourceNode = rse;
		}
break;
case 1185:
  if (!yytrial)
{
			RseNode* rse = newNode<RseNode>();
			rse->dsqlExplicitJoin = true;
			rse->rse_jointype = yyvsp[-3].blrOp;
			rse->dsqlFrom = newNode<RecSourceListNode>(yyvsp[-4].recSourceNode);
			rse->dsqlFrom->add(yyvsp[-1].recSourceNode);
			rse->dsqlJoinUsing = yyvsp[0].valueListNode;
			yyval.recSourceNode = rse;
		}
break;
case 1186:
  if (!yytrial)
{ yyval.boolExprNode = yyvsp[0].boolExprNode; }
break;
case 1187:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-1].valueListNode; }
break;
case 1188:
  if (!yytrial)
{
			ProcedureSourceNode* node = newNode<ProcedureSourceNode>(QualifiedName(*yyvsp[-3].metaNamePtr));
			node->sourceList = yyvsp[-2].valueListNode;
			node->alias = yyvsp[0].metaNamePtr->c_str();
			yyval.recSourceNode = node;
		}
break;
case 1189:
  if (!yytrial)
{
			ProcedureSourceNode* node = newNode<ProcedureSourceNode>(QualifiedName(*yyvsp[-1].metaNamePtr));
			node->sourceList = yyvsp[0].valueListNode;
			yyval.recSourceNode = node;
		}
break;
case 1190:
  if (!yytrial)
{
			ProcedureSourceNode* node = newNode<ProcedureSourceNode>(
				QualifiedName(*yyvsp[-3].metaNamePtr, *yyvsp[-5].metaNamePtr));
			node->sourceList = yyvsp[-2].valueListNode;
			node->alias = yyvsp[0].metaNamePtr->c_str();
			yyval.recSourceNode = node;
		}
break;
case 1191:
  if (!yytrial)
{
			ProcedureSourceNode* node = newNode<ProcedureSourceNode>(
				QualifiedName(*yyvsp[-1].metaNamePtr, *yyvsp[-3].metaNamePtr));
			node->sourceList = yyvsp[0].valueListNode;
			yyval.recSourceNode = node;
		}
break;
case 1192:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1193:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-1].valueListNode; }
break;
case 1195:
  if (!yytrial)
{
			RelationSourceNode* node = newNode<RelationSourceNode>(*yyvsp[-2].metaNamePtr);
			node->alias = yyvsp[0].metaNamePtr->c_str();
			yyval.relSourceNode = node;
		}
break;
case 1196:
  if (!yytrial)
{ yyval.relSourceNode = newNode<RelationSourceNode>(*yyvsp[0].metaNamePtr); }
break;
case 1197:
  if (!yytrial)
{ yyval.blrOp = blr_inner; }
break;
case 1198:
  if (!yytrial)
{ yyval.blrOp = blr_inner; }
break;
case 1199:
  if (!yytrial)
{ yyval.blrOp = blr_left; }
break;
case 1200:
  if (!yytrial)
{ yyval.blrOp = blr_right; }
break;
case 1201:
  if (!yytrial)
{ yyval.blrOp = blr_full; }
break;
case 1204:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1205:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1206:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 1207:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 1209:
  if (!yytrial)
{ yyval.boolExprNode = NULL; }
break;
case 1210:
  if (!yytrial)
{ yyval.boolExprNode = yyvsp[0].boolExprNode; }
break;
case 1211:
  if (!yytrial)
{ yyval.boolExprNode = NULL; }
break;
case 1212:
  if (!yytrial)
{ yyval.boolExprNode = yyvsp[0].boolExprNode; }
break;
case 1213:
  if (!yytrial)
{ yyval.planNode = NULL; }
break;
case 1214:
  if (!yytrial)
{ yyval.planNode = yyvsp[0].planNode; }
break;
case 1215:
  if (!yytrial)
{ yyval.planNode = newNode<PlanNode>(PlanNode::TYPE_RETRIEVE); }
break;
case 1216:
yyval.planNode = yyvsp[-1].planNode;
break;
case 1217:
  if (!yytrial)
{ yyval.planNode = yyvsp[-4].planNode; }
break;
case 1224:
  if (!yytrial)
{ yyvsp[-1].planNode->subNodes.add(yyvsp[0].planNode); }
break;
case 1225:
  if (!yytrial)
{ yyvsp[-3].planNode->subNodes.add(yyvsp[0].planNode); }
break;
case 1226:
  if (!yytrial)
{
			yyval.planNode = newNode<PlanNode>(PlanNode::TYPE_RETRIEVE);
			yyval.planNode->dsqlNames = yyvsp[-1].metaNameArray;
			yyval.planNode->accessType = yyvsp[0].accessType;
		}
break;
case 1228:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = newNode<ObjectsArray<MetaName> >();
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1229:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = yyvsp[-1].metaNameArray;
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1230:
  if (!yytrial)
{ yyval.accessType = newNode<PlanNode::AccessType>(PlanNode::AccessType::TYPE_SEQUENTIAL); }
break;
case 1231:
  if (!yytrial)
{ yyval.accessType = newNode<PlanNode::AccessType>(PlanNode::AccessType::TYPE_INDICES); }
break;
case 1232:
yyval.accessType = yyvsp[-1].accessType;
break;
case 1233:
  if (!yytrial)
{ yyval.accessType = yyvsp[-4].accessType; }
break;
case 1234:
  if (!yytrial)
{ yyval.accessType = newNode<PlanNode::AccessType>(PlanNode::AccessType::TYPE_NAVIGATIONAL); }
break;
case 1235:
  if (!yytrial)
{
			yyval.accessType = yyvsp[-3].accessType;
			yyval.accessType->items.insert(0).indexName = *yyvsp[-2].metaNamePtr;
		}
break;
case 1236:
  if (!yytrial)
{
			PlanNode::AccessItem& item = yyvsp[-1].accessType->items.add();
			item.indexName = *yyvsp[0].metaNamePtr;
		}
break;
case 1237:
  if (!yytrial)
{
			PlanNode::AccessItem& item = yyvsp[-3].accessType->items.add();
			item.indexName = *yyvsp[0].metaNamePtr;
		}
break;
case 1239:
yyval.accessType = yyvsp[-2].accessType;
break;
case 1241:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1242:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1243:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 1244:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 1245:
  if (!yytrial)
{
			OrderNode* node = newNode<OrderNode>(yyvsp[-2].valueExprNode);
			node->descending = yyvsp[-1].boolVal;
			node->nullsPlacement = yyvsp[0].nullsPlacement;
			yyval.valueExprNode = node;
		}
break;
case 1246:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1247:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1248:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1249:
  if (!yytrial)
{ yyval.nullsPlacement = OrderNode::NULLS_DEFAULT; }
break;
case 1250:
  if (!yytrial)
{ yyval.nullsPlacement = yyvsp[0].nullsPlacement; }
break;
case 1251:
  if (!yytrial)
{ yyval.nullsPlacement = OrderNode::NULLS_FIRST; }
break;
case 1252:
  if (!yytrial)
{ yyval.nullsPlacement = OrderNode::NULLS_LAST; }
break;
case 1253:
  if (!yytrial)
{
			yyval.rowsClause = newNode<RowsClause>();
			yyval.rowsClause->length = yyvsp[0].valueExprNode;
		}
break;
case 1254:
  if (!yytrial)
{
			yyval.rowsClause = newNode<RowsClause>();
			yyval.rowsClause->skip = newNode<ArithmeticNode>(blr_subtract, true, yyvsp[-2].valueExprNode, MAKE_const_slong(1));
			yyval.rowsClause->length = newNode<ArithmeticNode>(blr_add, true,
				newNode<ArithmeticNode>(blr_subtract, true, yyvsp[0].valueExprNode, yyvsp[-2].valueExprNode), MAKE_const_slong(1));
		}
break;
case 1255:
  if (!yytrial)
{ yyval.rowsClause = NULL; }
break;
case 1259:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 1260:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueExprNode; }
break;
case 1263:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 1264:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-2].valueExprNode; }
break;
case 1265:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(1); }
break;
case 1266:
yyval.nestFieldArray = NOTRIAL(&yyvsp[0].storeNode->dsqlFields);
break;
case 1267:
  if (!yytrial)
{
			StoreNode* node = yyval.storeNode = yyvsp[-7].storeNode;
			node->dsqlValues = yyvsp[-2].valueListNode;
			node->dsqlReturning = yyvsp[0].returningClause;
		}
break;
case 1268:
  if (!yytrial)
{
			StoreNode* node = yyval.storeNode = yyvsp[-4].storeNode;
			node->dsqlRse = yyvsp[-1].selectExprNode;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.storeNode = node;
		}
break;
case 1269:
  if (!yytrial)
{
			StoreNode* node = yyval.storeNode = yyvsp[-3].storeNode;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.storeNode = node;
		}
break;
case 1270:
  if (!yytrial)
{
			StoreNode* node = newNode<StoreNode>();
			node->dsqlRelation = yyvsp[0].relSourceNode;
			yyval.storeNode = node;
		}
break;
case 1271:
  if (!yytrial)
{
				MergeNode* node = yyval.mergeNode = newNode<MergeNode>();
				node->relation = yyvsp[-4].relSourceNode;
				node->usingClause = yyvsp[-2].recSourceNode;
				node->condition = yyvsp[0].boolExprNode;
			}
break;
case 1272:
yyval.mergeNode = yyvsp[0].mergeNode;
break;
case 1273:
  if (!yytrial)
{
				MergeNode* node = yyval.mergeNode = yyvsp[-3].mergeNode;
				node->returning = yyvsp[0].returningClause;
			}
break;
case 1276:
yyval.mergeNode = yyvsp[-1].mergeNode;
break;
case 1279:
  if (!yytrial)
{ yyval.mergeMatchedClause = &yyvsp[-2].mergeNode->whenMatched.add(); }
break;
case 1280:
yyval.mergeMatchedClause = NOTRIAL(yyvsp[0].mergeMatchedClause);
break;
case 1282:
  if (!yytrial)
{ yyval.mergeNotMatchedClause = &yyvsp[-3].mergeNode->whenNotMatched.add(); }
break;
case 1283:
yyval.mergeNotMatchedClause = NOTRIAL(yyvsp[0].mergeNotMatchedClause);
break;
case 1285:
  if (!yytrial)
{ yyvsp[-4].mergeMatchedClause->assignments = yyvsp[0].compoundStmtNode; }
break;
case 1286:
  if (!yytrial)
{
			yyvsp[-6].mergeMatchedClause->condition = yyvsp[-4].boolExprNode;
			yyvsp[-6].mergeMatchedClause->assignments = yyvsp[0].compoundStmtNode;
		}
break;
case 1288:
  if (!yytrial)
{ yyvsp[-4].mergeMatchedClause->condition = yyvsp[-2].boolExprNode; }
break;
case 1289:
yyval.nestFieldArray = NOTRIAL(&yyvsp[-2].mergeNotMatchedClause->fields);
break;
case 1290:
  if (!yytrial)
{ yyvsp[-8].mergeNotMatchedClause->values = yyvsp[-1].valueListNode; }
break;
case 1291:
yyval.nestFieldArray = NOTRIAL(&yyvsp[-4].mergeNotMatchedClause->fields);
break;
case 1292:
  if (!yytrial)
{
			yyvsp[-10].mergeNotMatchedClause->values = yyvsp[-1].valueListNode;
			yyvsp[-10].mergeNotMatchedClause->condition = yyvsp[-8].boolExprNode;
		}
break;
case 1295:
  if (!yytrial)
{
			EraseNode* node = newNode<EraseNode>();
			node->dsqlRelation = yyvsp[-5].relSourceNode;
			node->dsqlBoolean = yyvsp[-4].boolExprNode;
			node->dsqlPlan = yyvsp[-3].planNode;
			node->dsqlOrder = yyvsp[-2].valueListNode;
			node->dsqlRows = yyvsp[-1].rowsClause;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.stmtNode = node;
		}
break;
case 1296:
  if (!yytrial)
{
			EraseNode* node = newNode<EraseNode>();
			node->dsqlRelation = yyvsp[-2].relSourceNode;
			node->dsqlCursorName = *yyvsp[-1].metaNamePtr;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.stmtNode = node;
		}
break;
case 1299:
  if (!yytrial)
{
			ModifyNode* node = newNode<ModifyNode>();
			node->dsqlRelation = yyvsp[-7].relSourceNode;
			node->statement = yyvsp[-5].compoundStmtNode;
			node->dsqlBoolean = yyvsp[-4].boolExprNode;
			node->dsqlPlan = yyvsp[-3].planNode;
			node->dsqlOrder = yyvsp[-2].valueListNode;
			node->dsqlRows = yyvsp[-1].rowsClause;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.stmtNode = node;
		}
break;
case 1300:
  if (!yytrial)
{
			ModifyNode* node = newNode<ModifyNode>();
			node->dsqlRelation = yyvsp[-4].relSourceNode;
			node->statement = yyvsp[-2].compoundStmtNode;
			node->dsqlCursorName = *yyvsp[-1].metaNamePtr;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.stmtNode = node;
		}
break;
case 1301:
  if (!yytrial)
{
				UpdateOrInsertNode* node = yyval.updInsNode = newNode<UpdateOrInsertNode>();
				node->relation = yyvsp[0].relSourceNode;
			}
break;
case 1302:
yyval.nestFieldArray = NOTRIAL(&yyvsp[0].updInsNode->fields);
break;
case 1303:
yyval.nestFieldArray = NOTRIAL(&yyvsp[-6].updInsNode->matching);
break;
case 1304:
  if (!yytrial)
{
				UpdateOrInsertNode* node = yyval.updInsNode = yyvsp[-9].updInsNode;
				node->values = yyvsp[-4].valueListNode;
				node->returning = yyvsp[0].returningClause;
			}
break;
case 1306:
yyval.nestFieldArray = yyvsp[-1].nestFieldArray;
break;
case 1308:
  if (!yytrial)
{ yyval.returningClause = NULL; }
break;
case 1309:
  if (!yytrial)
{
			yyval.returningClause = FB_NEW_POOL(getPool()) ReturningClause(getPool());
			yyval.returningClause->first = yyvsp[0].valueListNode;
		}
break;
case 1310:
  if (!yytrial)
{
			yyval.returningClause = FB_NEW_POOL(getPool()) ReturningClause(getPool());
			yyval.returningClause->first = yyvsp[-2].valueListNode;
			yyval.returningClause->second = yyvsp[0].valueListNode;
		}
break;
case 1311:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 1312:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 1313:
  if (!yytrial)
{ yyval.metaNamePtr = newNode<MetaName>(*yyvsp[0].metaNamePtr); }
break;
case 1314:
  if (!yytrial)
{
			yyval.compoundStmtNode = newNode<CompoundStmtNode>();
			yyval.compoundStmtNode->statements.add(yyvsp[0].stmtNode);
		}
break;
case 1315:
  if (!yytrial)
{
			yyvsp[-2].compoundStmtNode->statements.add(yyvsp[0].stmtNode);
			yyval.compoundStmtNode = yyvsp[-2].compoundStmtNode;
		}
break;
case 1316:
  if (!yytrial)
{
			AssignmentNode* node = newNode<AssignmentNode>();
			node->asgnTo = yyvsp[-2].fieldNode;
			node->asgnFrom = yyvsp[0].valueExprNode;
			yyval.stmtNode = node;
		}
break;
case 1317:
  if (!yytrial)
{
			AssignmentNode* node = newNode<AssignmentNode>();
			node->asgnTo = newNode<NullNode>();
			node->asgnFrom = yyvsp[0].valueExprNode;
			yyval.stmtNode = node;
		}
break;
case 1318:
  if (!yytrial)
{
			AssignmentNode* node = newNode<AssignmentNode>();
			node->asgnTo = newNode<NullNode>();
			node->asgnFrom = yyvsp[0].valueExprNode;
			yyval.stmtNode = node;
		}
break;
case 1319:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1321:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-1].valueListNode; }
break;
case 1322:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].fieldNode); }
break;
case 1323:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].fieldNode); }
break;
case 1325:
yyval.nestFieldArray = yyvsp[0].nestFieldArray;
break;
case 1328:
  if (!yytrial)
{ yyvsp[-1].nestFieldArray->add(yyvsp[0].fieldNode); }
break;
case 1329:
  if (!yytrial)
{ yyvsp[-3].nestFieldArray->add(yyvsp[0].fieldNode); }
break;
case 1331:
  if (!yytrial)
{
			FieldNode* fieldNode = newNode<FieldNode>();
			fieldNode->dsqlQualifier = *yyvsp[-2].metaNamePtr;
			fieldNode->dsqlName = *yyvsp[0].metaNamePtr;
			yyval.fieldNode = fieldNode;
		}
break;
case 1332:
  if (!yytrial)
{
			FieldNode* fieldNode = newNode<FieldNode>();
			fieldNode->dsqlQualifier = *yyvsp[-2].metaNamePtr;
			fieldNode->dsqlName = *yyvsp[0].metaNamePtr;
			fieldNode->dsqlCursorField = true;
			yyval.fieldNode = fieldNode;
		}
break;
case 1333:
  if (!yytrial)
{
			FieldNode* fieldNode = newNode<FieldNode>();
			fieldNode->dsqlName = *yyvsp[0].metaNamePtr;
			yyval.fieldNode = fieldNode;
		}
break;
case 1335:
  if (!yytrial)
{
			FieldNode* fieldNode = newNode<FieldNode>();
			fieldNode->dsqlQualifier = *yyvsp[-2].metaNamePtr;
			fieldNode->dsqlName = *yyvsp[0].metaNamePtr;
			yyval.fieldNode = fieldNode;
		}
break;
case 1336:
  if (!yytrial)
{ yyval.boolExprNode = valueToBool(yyvsp[0].valueExprNode); }
break;
case 1338:
  if (!yytrial)
{ yyval.boolExprNode = newNode<BinaryBoolNode>(blr_or, valueToBool(yyvsp[-2].valueExprNode), valueToBool(yyvsp[0].valueExprNode)); }
break;
case 1339:
  if (!yytrial)
{ yyval.boolExprNode = newNode<BinaryBoolNode>(blr_and, valueToBool(yyvsp[-2].valueExprNode), valueToBool(yyvsp[0].valueExprNode)); }
break;
case 1340:
  if (!yytrial)
{ yyval.boolExprNode = newNode<NotBoolNode>(valueToBool(yyvsp[0].valueExprNode)); }
break;
case 1341:
  if (!yytrial)
{ yyval.boolExprNode = yyvsp[-1].boolExprNode; }
break;
case 1342:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_eql, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode);
			node->dsqlCheckBoolean = true;
			yyval.boolExprNode = node;
		}
break;
case 1343:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_eql, yyvsp[-3].valueExprNode, yyvsp[0].valueExprNode);
			node->dsqlCheckBoolean = true;
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1355:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(yyvsp[-1].blrOp, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1356:
  if (!yytrial)
{ yyval.blrOp = blr_eql; }
break;
case 1357:
  if (!yytrial)
{ yyval.blrOp = blr_lss; }
break;
case 1358:
  if (!yytrial)
{ yyval.blrOp = blr_gtr; }
break;
case 1359:
  if (!yytrial)
{ yyval.blrOp = blr_geq; }
break;
case 1360:
  if (!yytrial)
{ yyval.blrOp = blr_leq; }
break;
case 1361:
  if (!yytrial)
{ yyval.blrOp = blr_leq; }
break;
case 1362:
  if (!yytrial)
{ yyval.blrOp = blr_geq; }
break;
case 1363:
  if (!yytrial)
{ yyval.blrOp = blr_neq; }
break;
case 1364:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(yyvsp[-4].blrOp, yyvsp[-5].valueExprNode);
			node->dsqlFlag = yyvsp[-3].cmpBoolFlag;
			node->dsqlSpecialArg = yyvsp[-1].selectExprNode;
			yyval.boolExprNode = node;
		}
break;
case 1365:
  if (!yytrial)
{ yyval.cmpBoolFlag = ComparativeBoolNode::DFLAG_ANSI_ALL; }
break;
case 1366:
  if (!yytrial)
{ yyval.cmpBoolFlag = ComparativeBoolNode::DFLAG_ANSI_ANY; }
break;
case 1367:
  if (!yytrial)
{ yyval.cmpBoolFlag = ComparativeBoolNode::DFLAG_ANSI_ANY; }
break;
case 1368:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_equiv, yyvsp[-4].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1369:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_equiv, yyvsp[-5].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1370:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_between, yyvsp[-4].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1371:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_between, yyvsp[-5].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1373:
  if (!yytrial)
{ yyval.valueExprNode = newNode<BoolAsValueNode>(yyvsp[-1].boolExprNode); }
break;
case 1374:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(yyvsp[-1].blrOp, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1375:
  if (!yytrial)
{
			ComparativeBoolNode* cmpNode = newNode<ComparativeBoolNode>(yyvsp[-1].blrOp, yyvsp[-3].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(cmpNode);
		}
break;
case 1376:
  if (!yytrial)
{ yyval.blrOp = blr_containing; }
break;
case 1377:
  if (!yytrial)
{ yyval.blrOp = blr_starting; }
break;
case 1378:
  if (!yytrial)
{ yyval.blrOp = blr_starting; }
break;
case 1379:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_like, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1380:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_like, yyvsp[-4].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1381:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_like, yyvsp[-3].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1382:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_like, yyvsp[-5].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1383:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_similar, yyvsp[-3].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1384:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_similar, yyvsp[-5].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1385:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_similar, yyvsp[-4].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1386:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_similar, yyvsp[-6].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1387:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_eql, yyvsp[-2].valueExprNode);
			node->dsqlFlag = ComparativeBoolNode::DFLAG_ANSI_ANY;
			node->dsqlSpecialArg = yyvsp[0].exprNode;
			yyval.boolExprNode = node;
		}
break;
case 1388:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_eql, yyvsp[-3].valueExprNode);
			node->dsqlFlag = ComparativeBoolNode::DFLAG_ANSI_ANY;
			node->dsqlSpecialArg = yyvsp[0].exprNode;
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1389:
  if (!yytrial)
{ yyval.boolExprNode = newNode<RseBoolNode>(blr_any, yyvsp[-1].selectExprNode); }
break;
case 1390:
  if (!yytrial)
{ yyval.boolExprNode = newNode<RseBoolNode>(blr_unique, yyvsp[-1].selectExprNode); }
break;
case 1391:
  if (!yytrial)
{
			yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_eql,
					newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_TRIGGER_ACTION)),
					MAKE_const_slong(1));
		}
break;
case 1392:
  if (!yytrial)
{
			yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_eql,
					newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_TRIGGER_ACTION)),
					MAKE_const_slong(2));
		}
break;
case 1393:
  if (!yytrial)
{
			yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_eql,
					newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_TRIGGER_ACTION)),
					MAKE_const_slong(3));
		}
break;
case 1394:
  if (!yytrial)
{ yyval.boolExprNode = newNode<MissingBoolNode>(yyvsp[-2].valueExprNode); }
break;
case 1395:
  if (!yytrial)
{ yyval.boolExprNode = newNode<MissingBoolNode>(yyvsp[-2].valueExprNode, true); }
break;
case 1396:
  if (!yytrial)
{ yyval.boolExprNode = newNode<NotBoolNode>(newNode<MissingBoolNode>(yyvsp[-3].valueExprNode)); }
break;
case 1397:
  if (!yytrial)
{ yyval.boolExprNode = newNode<NotBoolNode>(newNode<MissingBoolNode>(yyvsp[-3].valueExprNode, true)); }
break;
case 1398:
  if (!yytrial)
{ yyval.exprNode = yyvsp[0].selectExprNode; }
break;
case 1399:
  if (!yytrial)
{ yyval.exprNode = yyvsp[-1].valueListNode; }
break;
case 1400:
  if (!yytrial)
{ yyval.selectExprNode = yyvsp[-1].selectExprNode; }
break;
case 1401:
  if (!yytrial)
{
			yyval.createAlterUserNode = newNode<CreateAlterUserNode>(CreateAlterUserNode::USER_ADD, *yyvsp[0].metaNamePtr);
		}
break;
case 1402:
yyval.createAlterUserNode = yyvsp[0].createAlterUserNode;
break;
case 1403:
yyval.createAlterUserNode = yyvsp[-2].createAlterUserNode;
break;
case 1404:
  if (!yytrial)
{
			yyval.createAlterUserNode = yyvsp[-4].createAlterUserNode;
		}
break;
case 1405:
  if (!yytrial)
{
			yyval.createAlterUserNode = newNode<CreateAlterUserNode>(CreateAlterUserNode::USER_MOD, *yyvsp[-1].metaNamePtr);
		}
break;
case 1406:
  if (!yytrial)
{
			yyval.createAlterUserNode = yyvsp[-4].createAlterUserNode;
		}
break;
case 1407:
  if (!yytrial)
{
			yyval.createAlterUserNode = newNode<CreateAlterUserNode>(CreateAlterUserNode::USER_MOD, "");
		}
break;
case 1408:
  if (!yytrial)
{
			yyval.createAlterUserNode = yyvsp[-4].createAlterUserNode;
		}
break;
case 1409:
  if (!yytrial)
{
			yyval.createAlterUserNode = newNode<CreateAlterUserNode>(CreateAlterUserNode::USER_RPL, *yyvsp[-1].metaNamePtr);
		}
break;
case 1410:
  if (!yytrial)
{
			yyval.createAlterUserNode = yyvsp[-4].createAlterUserNode;
		}
break;
case 1416:
yyval.createAlterUserNode = yyvsp[-1].createAlterUserNode;
break;
case 1418:
  if (!yytrial)
{ setClause(yyvsp[-2].createAlterUserNode->firstName, "FIRSTNAME", yyvsp[0].stringPtr); }
break;
case 1419:
  if (!yytrial)
{ setClause(yyvsp[-2].createAlterUserNode->middleName, "MIDDLENAME", yyvsp[0].stringPtr); }
break;
case 1420:
  if (!yytrial)
{ setClause(yyvsp[-2].createAlterUserNode->lastName, "LASTNAME", yyvsp[0].stringPtr); }
break;
case 1421:
  if (!yytrial)
{ setClause(yyvsp[-2].createAlterUserNode->password, "PASSWORD", yyvsp[0].stringPtr); }
break;
case 1422:
  if (!yytrial)
{ setClause(yyvsp[-3].createAlterUserNode->adminRole, "ADMIN ROLE", Nullable<bool>(true)); }
break;
case 1423:
  if (!yytrial)
{ setClause(yyvsp[-3].createAlterUserNode->adminRole, "ADMIN ROLE", Nullable<bool>(false)); }
break;
case 1424:
  if (!yytrial)
{ setClause(yyvsp[-1].createAlterUserNode->active, "ACTIVE/INACTIVE", Nullable<bool>(true)); }
break;
case 1425:
  if (!yytrial)
{ setClause(yyvsp[-1].createAlterUserNode->active, "ACTIVE/INACTIVE", Nullable<bool>(false)); }
break;
case 1426:
  if (!yytrial)
{ setClause(yyvsp[-3].createAlterUserNode->plugin, "USING PLUGIN", yyvsp[0].metaNamePtr); }
break;
case 1431:
  if (!yytrial)
{
			yyvsp[-3].createAlterUserNode->addProperty(yyvsp[-2].metaNamePtr, yyvsp[0].stringPtr);
		}
break;
case 1432:
  if (!yytrial)
{
			yyvsp[-2].createAlterUserNode->addProperty(yyvsp[0].metaNamePtr);
		}
break;
case 1433:
yyval.mappingOp = MappingNode::MAP_ADD;
break;
case 1434:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[0].mappingNode;
				yyval.mappingNode->global = yyvsp[-2].boolVal;
			}
break;
case 1435:
yyval.mappingNode = yyvsp[0].mappingNode;
break;
case 1436:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[-2].mappingNode;
			}
break;
case 1437:
yyval.mappingOp = MappingNode::MAP_MOD;
break;
case 1438:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[0].mappingNode;
				yyval.mappingNode->global = yyvsp[-2].boolVal;
			}
break;
case 1439:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[-2].mappingNode;
			}
break;
case 1440:
yyval.mappingOp = MappingNode::MAP_RPL;
break;
case 1441:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[0].mappingNode;
				yyval.mappingNode->global = yyvsp[-2].boolVal;
			}
break;
case 1442:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[-2].mappingNode;
			}
break;
case 1443:
  if (!yytrial)
{
 			MappingNode* node = newNode<MappingNode>(MappingNode::MAP_DROP, *yyvsp[0].metaNamePtr);
			node->global = yyvsp[-1].boolVal;
			yyval.mappingNode = node;
		}
break;
case 1444:
  if (!yytrial)
{
				yyval.mappingNode = newNode<MappingNode>(yyvsp[-1].mappingOp, *yyvsp[0].metaNamePtr);
			}
break;
case 1445:
yyval.mappingNode = yyvsp[-1].mappingNode;
break;
case 1446:
yyval.mappingNode = yyvsp[-4].mappingNode;
break;
case 1447:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[-6].mappingNode;
			}
break;
case 1448:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 1449:
  if (!yytrial)
{
			yyvsp[-2].mappingNode->fromType = yyvsp[-1].metaNamePtr;
			yyvsp[-2].mappingNode->from = yyvsp[0].intlStringPtr;
		}
break;
case 1450:
  if (!yytrial)
{
			yyvsp[-2].mappingNode->fromType = yyvsp[0].metaNamePtr;
			yyvsp[-2].mappingNode->from = newNode<IntlString>("*");
		}
break;
case 1452:
  if (!yytrial)
{ yyval.metaNamePtr = newNode<MetaName>("USER"); }
break;
case 1453:
  if (!yytrial)
{ yyval.metaNamePtr = newNode<MetaName>("GROUP"); }
break;
case 1455:
  if (!yytrial)
{ yyval.intlStringPtr = newNode<IntlString>(yyvsp[0].metaNamePtr->c_str()); }
break;
case 1456:
  if (!yytrial)
{
			yyvsp[-3].mappingNode->mode = 'P';
			yyvsp[-3].mappingNode->plugin = yyvsp[-1].metaNamePtr;
			yyvsp[-3].mappingNode->db = yyvsp[0].metaNamePtr;
		}
break;
case 1457:
  if (!yytrial)
{
			yyvsp[-3].mappingNode->mode = 'P';
			yyvsp[-3].mappingNode->db = yyvsp[0].metaNamePtr;
		}
break;
case 1458:
  if (!yytrial)
{
			yyvsp[-3].mappingNode->mode = 'S';
		}
break;
case 1459:
  if (!yytrial)
{
			yyvsp[-2].mappingNode->mode = 'M';
			yyvsp[-2].mappingNode->db = yyvsp[0].metaNamePtr;
		}
break;
case 1460:
  if (!yytrial)
{
			yyvsp[-2].mappingNode->mode = '*';
			yyvsp[-2].mappingNode->db = yyvsp[0].metaNamePtr;
		}
break;
case 1461:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 1462:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 1463:
  if (!yytrial)
{
			yyvsp[-3].mappingNode->role = yyvsp[-1].boolVal;
			yyvsp[-3].mappingNode->to = yyvsp[0].metaNamePtr;
		}
break;
case 1464:
  if (!yytrial)
{
			yyvsp[-2].mappingNode->role = yyvsp[0].boolVal;
		}
break;
case 1465:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1466:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1468:
  if (!yytrial)
{ yyval.valueExprNode = newNode<BoolAsValueNode>(yyvsp[0].boolExprNode); }
break;
case 1470:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueExprNode; }
break;
case 1474:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].fieldNode; }
break;
case 1476:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1483:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1484:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1485:
  if (!yytrial)
{ yyval.valueExprNode = newNode<NegateNode>(yyvsp[0].valueExprNode); }
break;
case 1486:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1487:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ArithmeticNode>(blr_add, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1488:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ConcatenateNode>(yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1489:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CollateNode>(yyvsp[-2].valueExprNode, *yyvsp[0].metaNamePtr); }
break;
case 1490:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ArithmeticNode>(blr_subtract, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1491:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ArithmeticNode>(blr_multiply, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1492:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ArithmeticNode>(blr_divide, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1493:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueExprNode; }
break;
case 1494:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1495:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1496:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1497:
  if (!yytrial)
{ yyval.valueExprNode = newNode<RecordKeyNode>(yyvsp[0].blrOp); }
break;
case 1498:
  if (!yytrial)
{ yyval.valueExprNode = newNode<RecordKeyNode>(yyvsp[0].blrOp, *yyvsp[-2].metaNamePtr); }
break;
case 1499:
  if (!yytrial)
{ yyval.valueExprNode = newNode<DomainValidationNode>(); }
break;
case 1500:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1501:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1502:
  if (!yytrial)
{ yyval.blrOp = blr_dbkey; }
break;
case 1503:
  if (!yytrial)
{ yyval.blrOp = blr_record_version2; }
break;
case 1504:
  if (!yytrial)
{
			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
						  												  Arg::Str("DATE"));
			}

			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
						  												  Arg::Str("DATE"));
			}

			yyval.valueExprNode = newNode<CurrentDateNode>();
		}
break;
case 1505:
  if (!yytrial)
{
			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
						  												  Arg::Str("TIME"));
			}

			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
						  												  Arg::Str("TIME"));
			}

			yyval.valueExprNode = newNode<CurrentTimeNode>(yyvsp[0].uintVal);
		}
break;
case 1506:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CurrentTimeStampNode>(yyvsp[0].uintVal); }
break;
case 1507:
  if (!yytrial)
{ yyval.uintVal = DEFAULT_TIME_PRECISION; }
break;
case 1508:
  if (!yytrial)
{ yyval.uintVal = yyvsp[-1].int32Val; }
break;
case 1509:
  if (!yytrial)
{ yyval.uintVal = DEFAULT_TIMESTAMP_PRECISION; }
break;
case 1510:
  if (!yytrial)
{ yyval.uintVal = yyvsp[-1].int32Val; }
break;
case 1511:
  if (!yytrial)
{
			ArrayNode* node = newNode<ArrayNode>(yyvsp[-3].fieldNode);
			node->field->dsqlIndices = yyvsp[-1].valueListNode;
			yyval.valueExprNode = node;
		}
break;
case 1512:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(0); }
break;
case 1513:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1514:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 1515:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 1517:
  if (!yytrial)
{ yyval.valueExprNode = newNode<NegateNode>(yyvsp[0].valueExprNode); }
break;
case 1519:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(yyvsp[0].int32Val); }
break;
case 1520:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant(yyvsp[0].stringPtr->c_str(), CONSTANT_DOUBLE); }
break;
case 1521:
  if (!yytrial)
{
			SINT64 signedNumber = (SINT64) yyvsp[0].scaledNumber.number;

			if (yyvsp[0].scaledNumber.hex && signedNumber < 0)
				yyval.valueExprNode = newNode<NegateNode>(MAKE_const_sint64(-signedNumber, yyvsp[0].scaledNumber.scale));
			else
				yyval.valueExprNode = MAKE_const_sint64(signedNumber, yyvsp[0].scaledNumber.scale);
		}
break;
case 1522:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_sint64((SINT64) yyvsp[0].scaledNumber.number, yyvsp[0].scaledNumber.scale); }
break;
case 1524:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_str_constant(yyvsp[0].intlStringPtr, lex.att_charset); }
break;
case 1525:
  if (!yytrial)
{
			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
						  												  Arg::Str("DATE"));
			}
			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
						  												  Arg::Str("DATE"));
			}
			yyval.valueExprNode = MAKE_constant(yyvsp[0].intlStringPtr->getString().c_str(), CONSTANT_DATE);
		}
break;
case 1526:
  if (!yytrial)
{
			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
						  												  Arg::Str("TIME"));
			}
			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
						  												  Arg::Str("TIME"));
			}
			yyval.valueExprNode = MAKE_constant(yyvsp[0].intlStringPtr->getString().c_str(), CONSTANT_TIME);
		}
break;
case 1527:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant(yyvsp[0].intlStringPtr->getString().c_str(), CONSTANT_TIMESTAMP); }
break;
case 1528:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant("", CONSTANT_BOOLEAN); }
break;
case 1529:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant("1", CONSTANT_BOOLEAN); }
break;
case 1530:
  if (!yytrial)
{ yyval.valueExprNode = make_parameter(); }
break;
case 1531:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CurrentUserNode>(); }
break;
case 1532:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CurrentUserNode>(); }
break;
case 1533:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CurrentRoleNode>(); }
break;
case 1534:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_CONNECTION_ID)); }
break;
case 1535:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_TRANSACTION_ID)); }
break;
case 1536:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_GDSCODE)); }
break;
case 1537:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_SQLCODE)); }
break;
case 1538:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_SQLSTATE)); }
break;
case 1539:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_ROWS_AFFECTED)); }
break;
case 1541:
  if (!yytrial)
{
			yyval.intlStringPtr = yyvsp[0].intlStringPtr;
			yyval.intlStringPtr->setCharSet(*yyvsp[-1].metaNamePtr);

			StrMark* mark = strMarks.get(yyvsp[0].intlStringPtr);

			if (mark)	/* hex string is not in strMarks*/
				mark->introduced = true;
		}
break;
case 1542:
  if (!yytrial)
{ yyval.stringPtr = newString(yyvsp[0].intlStringPtr->toUtf8(scratch)); }
break;
case 1544:
  if (!yytrial)
{ yyval.int32Val = -yyvsp[0].int32Val; }
break;
case 1545:
  if (!yytrial)
{
			if (yyvsp[0].int32Val > SHRT_POS_MAX)
				yyabandon(-842, isc_expec_short);	/* Short integer expected*/

			yyval.int32Val = yyvsp[0].int32Val;
		}
break;
case 1546:
  if (!yytrial)
{
			if (yyvsp[0].int32Val > SHRT_NEG_MAX)
				yyabandon(-842, isc_expec_short);	/* Short integer expected*/

			yyval.int32Val = yyvsp[0].int32Val;
		}
break;
case 1547:
  if (!yytrial)
{
			if (yyvsp[0].int32Val == 0)
				yyabandon(-842, isc_expec_positive);	/* Positive number expected*/

			yyval.int32Val = yyvsp[0].int32Val;
		}
break;
case 1548:
  if (!yytrial)
{
			if (yyvsp[0].int32Val > SHRT_UNSIGNED_MAX)
				yyabandon(-842, isc_expec_ushort);	/* Unsigned short integer expected*/

			yyval.int32Val = yyvsp[0].int32Val;
		}
break;
case 1550:
  if (!yytrial)
{ yyval.int32Val = -yyvsp[0].int32Val; }
break;
case 1551:
  if (!yytrial)
{ yyval.int32Val = yyvsp[0].int32Val;}
break;
case 1552:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].aggNode; }
break;
case 1558:
  if (!yytrial)
{ yyval.aggNode = newNode<CountAggNode>(false, (client_dialect < SQL_DIALECT_V6_TRANSITION)); }
break;
case 1559:
  if (!yytrial)
{ yyval.aggNode = newNode<CountAggNode>(false, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode); }
break;
case 1560:
  if (!yytrial)
{ yyval.aggNode = newNode<CountAggNode>(true, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode); }
break;
case 1561:
  if (!yytrial)
{
			yyval.aggNode = newNode<SumAggNode>(false,
				(client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode);
		}
break;
case 1562:
  if (!yytrial)
{
			yyval.aggNode = newNode<SumAggNode>(true,
				(client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode);
		}
break;
case 1563:
  if (!yytrial)
{
			yyval.aggNode = newNode<AvgAggNode>(false,
				(client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode);
		}
break;
case 1564:
  if (!yytrial)
{
			yyval.aggNode = newNode<AvgAggNode>(true,
				(client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode);
		}
break;
case 1565:
  if (!yytrial)
{ yyval.aggNode = newNode<MaxMinAggNode>(MaxMinAggNode::TYPE_MIN, yyvsp[-1].valueExprNode); }
break;
case 1566:
  if (!yytrial)
{ yyval.aggNode = newNode<MaxMinAggNode>(MaxMinAggNode::TYPE_MIN, yyvsp[-1].valueExprNode); }
break;
case 1567:
  if (!yytrial)
{ yyval.aggNode = newNode<MaxMinAggNode>(MaxMinAggNode::TYPE_MAX, yyvsp[-1].valueExprNode); }
break;
case 1568:
  if (!yytrial)
{ yyval.aggNode = newNode<MaxMinAggNode>(MaxMinAggNode::TYPE_MAX, yyvsp[-1].valueExprNode); }
break;
case 1569:
  if (!yytrial)
{ yyval.aggNode = newNode<ListAggNode>(false, yyvsp[-2].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1570:
  if (!yytrial)
{ yyval.aggNode = newNode<ListAggNode>(true, yyvsp[-2].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1571:
  if (!yytrial)
{ yyval.aggNode = newNode<StdDevAggNode>(StdDevAggNode::TYPE_STDDEV_SAMP, yyvsp[-1].valueExprNode); }
break;
case 1572:
  if (!yytrial)
{ yyval.aggNode = newNode<StdDevAggNode>(StdDevAggNode::TYPE_STDDEV_POP, yyvsp[-1].valueExprNode); }
break;
case 1573:
  if (!yytrial)
{ yyval.aggNode = newNode<StdDevAggNode>(StdDevAggNode::TYPE_VAR_SAMP, yyvsp[-1].valueExprNode); }
break;
case 1574:
  if (!yytrial)
{ yyval.aggNode = newNode<StdDevAggNode>(StdDevAggNode::TYPE_VAR_POP, yyvsp[-1].valueExprNode); }
break;
case 1575:
  if (!yytrial)
{ yyval.aggNode = newNode<CorrAggNode>(CorrAggNode::TYPE_COVAR_SAMP, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1576:
  if (!yytrial)
{ yyval.aggNode = newNode<CorrAggNode>(CorrAggNode::TYPE_COVAR_POP, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1577:
  if (!yytrial)
{ yyval.aggNode = newNode<CorrAggNode>(CorrAggNode::TYPE_CORR, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1578:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_AVGX, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1579:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_AVGY, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1580:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrCountAggNode>(yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1581:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_INTERCEPT, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1582:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_R2, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1583:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_SLOPE, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1584:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_SXX, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1585:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_SXY, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1586:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_SYY, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1587:
  if (!yytrial)
{ yyval.aggNode = newNode<DenseRankWinNode>(); }
break;
case 1588:
  if (!yytrial)
{ yyval.aggNode = newNode<RankWinNode>(); }
break;
case 1589:
  if (!yytrial)
{ yyval.aggNode = newNode<RowNumberWinNode>(); }
break;
case 1590:
  if (!yytrial)
{ yyval.aggNode = newNode<FirstValueWinNode>(yyvsp[-1].valueExprNode); }
break;
case 1591:
  if (!yytrial)
{ yyval.aggNode = newNode<LastValueWinNode>(yyvsp[-1].valueExprNode); }
break;
case 1592:
  if (!yytrial)
{ yyval.aggNode = newNode<NthValueWinNode>(yyvsp[-4].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1593:
  if (!yytrial)
{ yyval.aggNode = newNode<LagWinNode>(yyvsp[-5].valueExprNode, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1594:
  if (!yytrial)
{ yyval.aggNode = newNode<LagWinNode>(yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode, newNode<NullNode>()); }
break;
case 1595:
  if (!yytrial)
{ yyval.aggNode = newNode<LagWinNode>(yyvsp[-1].valueExprNode, MAKE_const_slong(1), newNode<NullNode>()); }
break;
case 1596:
  if (!yytrial)
{ yyval.aggNode = newNode<LeadWinNode>(yyvsp[-5].valueExprNode, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1597:
  if (!yytrial)
{ yyval.aggNode = newNode<LeadWinNode>(yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode, newNode<NullNode>()); }
break;
case 1598:
  if (!yytrial)
{ yyval.aggNode = newNode<LeadWinNode>(yyvsp[-1].valueExprNode, MAKE_const_slong(1), newNode<NullNode>()); }
break;
case 1599:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(NthValueWinNode::FROM_FIRST); }
break;
case 1600:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(NthValueWinNode::FROM_FIRST); }
break;
case 1601:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(NthValueWinNode::FROM_LAST); }
break;
case 1604:
  if (!yytrial)
{ yyval.valueExprNode = newNode<OverNode>(yyvsp[-5].aggNode, yyvsp[-2].valueListNode, yyvsp[-1].valueListNode); }
break;
case 1605:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1606:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1607:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_str_constant(newIntlString(","), lex.att_charset); }
break;
case 1608:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1611:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ExtractNode>(yyvsp[-3].blrOp, yyvsp[-1].valueExprNode); }
break;
case 1615:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrLenNode>(blr_strlen_bit, yyvsp[-1].valueExprNode); }
break;
case 1616:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrLenNode>(blr_strlen_char, yyvsp[-1].valueExprNode); }
break;
case 1617:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrLenNode>(blr_strlen_char, yyvsp[-1].valueExprNode); }
break;
case 1618:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrLenNode>(blr_strlen_octet, yyvsp[-1].valueExprNode); }
break;
case 1619:
  if (!yytrial)
{ yyval.valueExprNode = newNode<SysFuncCallNode>(*yyvsp[-3].metaNamePtr, yyvsp[-1].valueListNode); }
break;
case 1620:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].sysFuncCallNode; }
break;
case 1672:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-6].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-4].valueExprNode)->add(MAKE_const_slong(yyvsp[-3].blrOp))->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1673:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-7].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-3].valueExprNode)->add(MAKE_const_slong(yyvsp[-5].blrOp))->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1674:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-7].metaNamePtr,
				newNode<ValueListNode>(MAKE_const_slong(yyvsp[-5].blrOp))->add(yyvsp[-3].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1675:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-7].metaNamePtr,
				newNode<ValueListNode>(MAKE_const_slong(yyvsp[-5].blrOp))->add(yyvsp[-3].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1676:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-9].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-7].valueExprNode)->add(yyvsp[-5].valueExprNode)->add(yyvsp[-3].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1677:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-7].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-5].valueExprNode)->add(yyvsp[-3].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1678:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-5].metaNamePtr, newNode<ValueListNode>(yyvsp[-3].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1679:
  if (!yytrial)
{ yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-3].metaNamePtr, yyvsp[-1].valueListNode); }
break;
case 1682:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrCaseNode>(blr_upcase, yyvsp[-1].valueExprNode); }
break;
case 1683:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrCaseNode>(blr_lowcase, yyvsp[-1].valueExprNode); }
break;
case 1684:
  if (!yytrial)
{
			/* SQL spec requires numbering to start with 1,*/
			/* hence we decrement the first parameter to make it*/
			/* compatible with the engine's implementation*/
			ArithmeticNode* subtractNode = newNode<ArithmeticNode>(
				blr_subtract, true, yyvsp[-2].valueExprNode, MAKE_const_slong(1));

			yyval.valueExprNode = newNode<SubstringNode>(yyvsp[-4].valueExprNode, subtractNode, yyvsp[-1].valueExprNode);
		}
break;
case 1685:
  if (!yytrial)
{ yyval.valueExprNode = newNode<SubstringSimilarNode>(yyvsp[-5].valueExprNode, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1686:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 1687:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1688:
  if (!yytrial)
{ yyval.valueExprNode = newNode<TrimNode>(yyvsp[-4].blrOp, yyvsp[-1].valueExprNode, yyvsp[-3].valueExprNode); }
break;
case 1689:
  if (!yytrial)
{ yyval.valueExprNode = newNode<TrimNode>(blr_trim_both, yyvsp[-1].valueExprNode, yyvsp[-3].valueExprNode); }
break;
case 1690:
  if (!yytrial)
{ yyval.valueExprNode = newNode<TrimNode>(yyvsp[-3].blrOp, yyvsp[-1].valueExprNode); }
break;
case 1691:
  if (!yytrial)
{ yyval.valueExprNode = newNode<TrimNode>(blr_trim_both, yyvsp[-1].valueExprNode); }
break;
case 1692:
  if (!yytrial)
{ yyval.blrOp = blr_trim_both; }
break;
case 1693:
  if (!yytrial)
{ yyval.blrOp = blr_trim_trailing; }
break;
case 1694:
  if (!yytrial)
{ yyval.blrOp = blr_trim_leading; }
break;
case 1695:
  if (!yytrial)
{ yyval.valueExprNode = newNode<UdfCallNode>(QualifiedName(*yyvsp[-3].metaNamePtr, ""), yyvsp[-1].valueListNode); }
break;
case 1696:
  if (!yytrial)
{ yyval.valueExprNode = newNode<UdfCallNode>(QualifiedName(*yyvsp[-2].metaNamePtr, ""), newNode<ValueListNode>(0)); }
break;
case 1697:
  if (!yytrial)
{ yyval.valueExprNode = newNode<UdfCallNode>(QualifiedName(*yyvsp[-3].metaNamePtr, *yyvsp[-5].metaNamePtr), yyvsp[-1].valueListNode); }
break;
case 1698:
  if (!yytrial)
{ yyval.valueExprNode = newNode<UdfCallNode>(QualifiedName(*yyvsp[-2].metaNamePtr, *yyvsp[-4].metaNamePtr), newNode<ValueListNode>(0)); }
break;
case 1699:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CastNode>(yyvsp[-3].valueExprNode, yyvsp[-1].legacyField); }
break;
case 1702:
  if (!yytrial)
{
			ComparativeBoolNode* condition = newNode<ComparativeBoolNode>(blr_eql, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode);
			yyval.valueExprNode = newNode<ValueIfNode>(condition, newNode<NullNode>(), yyvsp[-3].valueExprNode);
		}
break;
case 1703:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ValueIfNode>(yyvsp[-5].boolExprNode, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1704:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CoalesceNode>(yyvsp[-1].valueListNode->addFront(yyvsp[-3].valueExprNode)); }
break;
case 1705:
  if (!yytrial)
{
			ValueListNode* list = yyvsp[-1].valueListNode;
			ValueListNode* conditions = newNode<ValueListNode>(list->items.getCount() / 2);
			ValueListNode* values = newNode<ValueListNode>(list->items.getCount() / 2);

			for (FB_SIZE_T i = 0; i < list->items.getCount(); i += 2)
			{
				conditions->items[i / 2] = list->items[i];
				values->items[i / 2] = list->items[i + 1];
			}

			yyval.valueExprNode = newNode<DecodeNode>(yyvsp[-3].valueExprNode, conditions, values);
		}
break;
case 1706:
  if (!yytrial)
{
			ValueListNode* list = yyvsp[-3].valueListNode;
			ValueListNode* conditions = newNode<ValueListNode>(list->items.getCount() / 2);
			ValueListNode* values = newNode<ValueListNode>(list->items.getCount() / 2 + 1);

			for (FB_SIZE_T i = 0; i < list->items.getCount(); i += 2)
			{
				conditions->items[i / 2] = list->items[i];
				values->items[i / 2] = list->items[i + 1];
			}

			values->items[list->items.getCount() / 2] = yyvsp[-1].valueExprNode;

			yyval.valueExprNode = newNode<DecodeNode>(yyvsp[-5].valueExprNode, conditions, values);
		}
break;
case 1707:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].decodeNode; }
break;
case 1708:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1709:
  if (!yytrial)
{ yyval.decodeNode = newNode<DecodeNode>(yyvsp[0].valueExprNode, newNode<ValueListNode>(0u), newNode<ValueListNode>(0u)); }
break;
case 1710:
yyval.valueListNode = NOTRIAL(yyvsp[0].decodeNode->conditions);
break;
case 1711:
yyval.valueListNode =  NOTRIAL(yyvsp[-1].decodeNode->values);
break;
case 1712:
  if (!yytrial)
{
				DecodeNode* node = yyval.decodeNode = yyvsp[-5].decodeNode;
				node->label = "CASE";
				if (yyvsp[-1].valueExprNode)
					node->values->add(yyvsp[-1].valueExprNode);
			}
break;
case 1713:
  if (!yytrial)
{
			yyvsp[-5].valueListNode->add(yyvsp[-2].valueExprNode);
			yyvsp[-4].valueListNode->add(yyvsp[0].valueExprNode);
		}
break;
case 1714:
  if (!yytrial)
{
			yyvsp[-6].valueListNode->add(yyvsp[-2].valueExprNode);
			yyvsp[-5].valueListNode->add(yyvsp[0].valueExprNode);
		}
break;
case 1715:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 1716:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1717:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueIfNode; }
break;
case 1718:
  if (!yytrial)
{
			ValueIfNode* last = yyvsp[-3].valueIfNode;
			ValueIfNode* next;

			while ((next = last->falseValue->as<ValueIfNode>()))
				last = next;

			fb_assert(last->falseValue->is<NullNode>());

			last->falseValue = yyvsp[-1].valueExprNode;
			yyval.valueExprNode = yyvsp[-3].valueIfNode;
		}
break;
case 1719:
  if (!yytrial)
{ yyval.valueIfNode = newNode<ValueIfNode>(yyvsp[-2].boolExprNode, yyvsp[0].valueExprNode, newNode<NullNode>()); }
break;
case 1720:
  if (!yytrial)
{
			ValueIfNode* cond = newNode<ValueIfNode>(yyvsp[-2].boolExprNode, yyvsp[0].valueExprNode, newNode<NullNode>());
			ValueIfNode* last = yyvsp[-4].valueIfNode;
			ValueIfNode* next;

			while ((next = last->falseValue->as<ValueIfNode>()))
				last = next;

			fb_assert(last->falseValue->is<NullNode>());

			last->falseValue = cond;
			yyval.valueIfNode = yyvsp[-4].valueIfNode;
		}
break;
case 1724:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(0u)->add(yyvsp[-2].valueExprNode)->add(yyvsp[0].valueExprNode); }
break;
case 1725:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-4].valueListNode->add(yyvsp[-2].valueExprNode)->add(yyvsp[0].valueExprNode); }
break;
case 1726:
  if (!yytrial)
{
			yyval.valueExprNode = newNode<GenIdNode>((client_dialect < SQL_DIALECT_V6_TRANSITION),
				*yyvsp[0].metaNamePtr, ((Jrd::ValueExprNode*) NULL), true, false);
		}
break;
case 1727:
  if (!yytrial)
{
			yyval.valueExprNode = newNode<GenIdNode>((client_dialect < SQL_DIALECT_V6_TRANSITION),
				*yyvsp[-3].metaNamePtr, yyvsp[-1].valueExprNode, false, false);
		}
break;
case 1728:
  if (!yytrial)
{ yyval.blrOp = blr_extract_year; }
break;
case 1729:
  if (!yytrial)
{ yyval.blrOp = blr_extract_month; }
break;
case 1730:
  if (!yytrial)
{ yyval.blrOp = blr_extract_day; }
break;
case 1731:
  if (!yytrial)
{ yyval.blrOp = blr_extract_hour; }
break;
case 1732:
  if (!yytrial)
{ yyval.blrOp = blr_extract_minute; }
break;
case 1733:
  if (!yytrial)
{ yyval.blrOp = blr_extract_second; }
break;
case 1734:
  if (!yytrial)
{ yyval.blrOp = blr_extract_millisecond; }
break;
case 1735:
  if (!yytrial)
{ yyval.blrOp = blr_extract_week; }
break;
case 1736:
  if (!yytrial)
{ yyval.blrOp = blr_extract_weekday; }
break;
case 1737:
  if (!yytrial)
{ yyval.blrOp = blr_extract_yearday; }
break;
case 1742:
  if (!yytrial)
{ yyval.valueExprNode = newNode<NullNode>(); }
break;
case 1743:
  if (!yytrial)
{
			dsql_fld* field = newNode<dsql_fld>();
			field->dtype = dtype_boolean;
			field->length = sizeof(UCHAR);

			CastNode* castNode = newNode<CastNode>(newNode<NullNode>(), field);
			castNode->dsqlAlias = "CONSTANT";
			yyval.valueExprNode = castNode;
		}
break;

  default:
    break;
  }

#if YYDEBUG && defined(YYDBPR)
  if (yydebug) {
    printf("yydebug[%d]: after reduction, result is ", yytrial);
    YYDBPR(yyps->val);
    printf("\n");
  }
#endif

  // Perform user-defined position reduction
#ifdef YYREDUCEPOSNFUNC
  if (!yytrial) {
    YYCALLREDUCEPOSN(YYREDUCEPOSNFUNCARG);
  }
#endif

  yyps->ssp -= yym;
  yystate = *(yyps->ssp);
  yyps->vsp -= yym;
  yyps->psp -= yym;

  yym = yylhs[yyn];
  if (yystate == 0 && yym == 0) {
#if YYDEBUG
    if (yydebug) {
      printf("yydebug[%d,%p]: after reduction, shifting from state 0 to state %d\n", 
	     int(yydepth), yytrial, YYFINAL);
    }
#endif
    yystate = YYFINAL;
    *++(yyps->ssp) = YYFINAL;
    *++(yyps->vsp) = yyps->val;
    yyretlval = yyps->val;	// return value of root non-terminal to yylval
    *++(yyps->psp) = yyps->pos;
    yyretposn = yyps->pos;	// return value of root position to yyposn
    if (yychar < 0) {
      if ((yychar = yylex1()) < 0) {
        yychar = 0;
      }
#if YYDEBUG
      if (yydebug) {
        yys = 0;
        if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
        if (!yys) yys = "illegal-symbol";
        printf("yydebug[%d,%p]: state %d, reading %d (%s)\n", 
	       int(yydepth), yytrial, YYFINAL, yychar, yys); 
      }
#endif
    }
    if (yychar == 0) goto yyaccept;
    goto yyloop;
  }

  if ((yyn = yygindex[yym]) && (yyn += yystate) >= 0 &&
      yyn <= YYTABLESIZE && yycheck[yyn] == yystate) {
    yystate = yytable[yyn];
  } else {
    yystate = yydgoto[yym];
  }
#if YYDEBUG
  if (yydebug)
    printf("yydebug[%d,%p]: after reduction, shifting from state %d to state %d\n",
           int(yydepth), yytrial, *(yyps->ssp), yystate);
#endif
  if (yyps->ssp >= yyps->ss + yyps->stacksize - 1) {
    yyMoreStack(yyps);
  }
  *++(yyps->ssp) = yystate;
  *++(yyps->vsp) = yyps->val;
  *++(yyps->psp) = yyps->pos;
  goto yyloop;


  //
  // Reduction declares that this path is valid.
  // Set yypath and do a full parse
  //
yyvalid:
  if (yypath) {
    goto yyabort;
  }
  while (yyps->save) {
    yyparsestate *save = yyps->save;
    yyps->save = save->save;
    save->save = yypath;
    yypath = save;
  }
#if YYDEBUG
  if (yydebug)
    printf("yydebug[%d,%p]: CONFLICT trial successful, backtracking to state %d, %d tokens\n",
           int(yydepth), yytrial, yypath->state, int(yylvp - yylvals - yypath->lexeme));
#endif
  if (yyerrctx) {
    yyFreeState(yyerrctx);
    yyerrctx = NULL;
  }
  yychar = -1;
  yyps->ssp = yyps->ss + (yypath->ssp - yypath->ss);
  yyps->vsp = yyps->vs + (yypath->vsp - yypath->vs);
  yyps->psp = yyps->ps + (yypath->psp - yypath->ps);
  memcpy (yyps->ss, yypath->ss, (yyps->ssp - yyps->ss + 1) * sizeof(Yshort));
  yySCopy(yyps->vs, yypath->vs,  yyps->vsp - yyps->vs + 1);
  yyPCopy(yyps->ps, yypath->ps,  yyps->psp - yyps->ps + 1);
  yylvp = yylvals + yypath->lexeme;
  yylpp = yylpsns + yypath->lexeme;
  yylexp = yylexemes + yypath->lexeme;
  yystate = yypath->state;
  goto yyloop;


yyabort:
  if (yyerrctx) {
    yyFreeState(yyerrctx);
    yyerrctx = NULL;
  }

  YYSTYPE *pv;
  for(pv = yyps->vs; pv < yyps->vsp; pv++) {
    YYDELETEVAL(*pv, 2);
  }

  YYPOSN *pp;
  for(pp = yyps->ps; pp < yyps->psp; pp++) {
    YYDELETEPOSN(*pp, 2);
  }

  while (yyps) {
    yyparsestate *save = yyps;
    yyps = save->save;
    yyFreeState(save);
  }
  while (yypath) {
    yyparsestate *save = yypath;
    yypath = save->save;
    yyFreeState(save); 
  }
  return (1);


yyaccept:
  if (yyps->save) goto yyvalid;
  if (yyerrctx) {
    yyFreeState(yyerrctx);
    yyerrctx = NULL;
  }
  while (yyps) {
    yyparsestate *save = yyps;
    yyps = save->save;
    yyFreeState(save);
  }
  while (yypath) {
    yyparsestate *save = yypath;
    yypath = save->save;
    yyFreeState(save); 
  }
  return (0);
}


int Parser::yylex1()
{
  if (yylvp < yylve) {
    yylval = *yylvp++;
    yyposn = *yylpp++;
    return *yylexp++;
  } else {
    if (yyps->save) {
      if (yylvp == yylvlim) {
	yyexpand();
      }
      *yylexp = yylex();
      *yylvp++ = yylval;
      yylve++;
      *yylpp++ = yyposn;
      yylpe++;
      return *yylexp++;
    } else {
      return yylex();
    }
  }
}


int Parser::yyexpand()
{
  int p = yylvp - yylvals;
  int s = yylvlim - yylvals;
  s += YYSTACKGROWTH;
  { Yshort  *tl = yylexemes; 
    YYSTYPE *tv = yylvals;
    YYPOSN  *tp = yylpsns;
    yylvals = FB_NEW_POOL(getPool()) YYSTYPE[s];
    yylpsns = FB_NEW_POOL(getPool()) YYPOSN[s];
    yylexemes = FB_NEW_POOL(getPool()) Yshort[s];
    memcpy(yylexemes, tl, (s - YYSTACKGROWTH) * sizeof(Yshort));
    yySCopy(yylvals, tv, s - YYSTACKGROWTH);
    yyPCopy(yylpsns, tp, s - YYSTACKGROWTH);
    delete[] tl;
    delete[] tv;
    delete[] tp;
  }
  yylvp = yylve = yylvals + p;
  yylvlim = yylvals + s;
  yylpp = yylpe = yylpsns + p;
  yylplim = yylpsns + s;
  yylexp = yylexemes + p;
  return 0;
}

